(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     61607,       1712]*)
(*NotebookOutlinePosition[     85945,       2596]*)
(*  CellTagsIndexPosition[     85837,       2589]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["COMPLEX ANALYSIS: ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Mathematica 4.1",
    FontSize->18,
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" Notebooks\n(c) John H. Mathews, and\nRussell W. Howell, 2002",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Complimentary software to accompany our textbook:",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]]
}], "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["COMPLEX ANALYSIS: for Mathematics and Engineering, \n4th Edition, \
 2001,  ISBN: ",
    FontSize->18,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["0-7637-1425-9",
    FontFamily->"Times New Roman",
    FontSize->18,
    FontColor->RGBColor[0, 0, 0.996109]],
  StyleBox["\n",
    FontSize->18,
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[ButtonBox["Jones & Bartlett Publishers, Inc.",
    ButtonData:>{
      URL[ "http://www.jbpub.com/"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" \n",
    FontSize->18,
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["40 Tall Pine Drive, Sudbury, MA 01776  \nTele.  (800) 832-0034, \
FAX:  (508)  443-8000  \nE-mail:  mkt@jbpub.com  \nInternet:  ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["http://www.jbpub.com/",
    ButtonData:>{
      URL[ "http://www.jbpub.com/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox["  ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n",
    FontSize->14],
  StyleBox["This free software is compliments of the authors.\n",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  ButtonBox["John H. Mathews",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[",   ",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["mathews@fullerton.edu \n",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  ButtonBox["Russell W. Howell",
    ButtonData:>{
      URL[ "http://www.westmont.edu/~howell"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[", ",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["howell@westmont.edu ",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CHAPTER 4",
    FontSize->18,
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["  ",
    FontSize->18],
  StyleBox["SEQUENCES, JULIA and MANDELBROT SETS, and POWER SERIES",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 4"],

Cell[BoxData[{
    \(\(c = \(q = \(S = \(t = \(x = \(y = \(z = 
                    0\)\)\)\)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[a, absZn, c, cx, cy, dot, i, juliaC, k, lim, limX, limY, limZ, 
        list, mandelbrotC, n, newton, Pn, q, Qn, R, s, S, Sn, set, sum, sumN, 
        sumX, sumY, sumZ, t, table, x, Xn, y, Yn, z, Z, 
        Zn];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Section 4.1",
    FontSize->18,
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["  ",
    FontSize->18],
  StyleBox["Sequences and Series",
    FontSize->18,
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001f80@0006@000000000000001D0000E0000
00000000001?0`00C`<00215CDH00040R1d001@00002000000000000002l000080<005P200100@00
l000000000000000000004H0003H3000bP`004M4BD<1002000<00393]ST00000/P`000402@000eT6
00010284000000T0000V1Pl0201OATeBBE@Y80<0000N00D0000;0P0000050000308O01l01@800?L0
00<00@00001gMgL0EEEE0<`0b`3^k^h0IP1U0?g;0028R8P006Gm0?ooo`14A4@08R8R000000000000
00000000003k:O00M`400000e03b4P00b8/G002ni@110;`0lQ800:Cc4P00/?l04P140;OcM`0hc_<0
Mooo0?oob02;5`00^o530038G@0H01P0o18006H00000b8/05`2600:D0@3P_AX000400000b01M6000
C00000260P2D0@0004000<QM6000000000000000000100000>Bn01X0100100000000000000000>00
_AX0063c4P00K000200A000P000000000<R;01L0H01c@000e098001?L01UKP0000<000800000g?<0
4P100>i20004000001810000n00JG`00@cYL06Q_K@1UL640IfEL06MYIP1c04d0HGAX06E]H@1dJF<0
HD9Y06L^I`1YIP00g?<B0007PP3WM`000000000000008000003L0?<B000lm18004mR0?Mgc03c4P00
<0000000000300800000043^@P00kB40igND004200000P000000000060000@00dLjR00lH00000480
000000800000Ha40igN600:D0@0B0@0009G`00004P007`000000002N0P00004000000:QSG`00n1X0
G`3@00PF000C000002H0000000000000G?DB0002<`3]M`00000000PTG`00QP80U04B0040002El000
00000000P03d4P00OUSW07L8901O0000000000040000000000000000003RF>L0M`PT05l000000000
00@00030>P3XMd<0>UaX06m]I@1`HFL0IEaW06UVL`1LCF40M6QU06eQM01YHf40@VUW02iWJ@1V08H0
0Y@100000000RDX0mWM800DD001V000000P00000QP02U040>aM500260P2D0I@00@8001810000@aL0
A@2600:D0@30ma800080000000000000n1YO0007002:0A00mA8009XAk@1ge`@00GD7002:0@0N0`00
00000000J0035P000001003Hm@0B06@0BZ]g09810P00G?D04P0>05_WM`30RaL00000000000005000
8040000800000040000008Se4P00/bP0l7L0000D000800@001P10000IP000000IP0000260P2D0ML0
105e00000000208000000000001f0P00053e018000000000/?lB0014]`3cMlP0cO=g0?ooo`3o1HH0
@`2600:D0@040000=08000<0000e00D000070@<0000R1000@`lP0<`0000P02000000020080000000
:0000200000P00000@08000000001000a0h00<@>00000@0000000000001gMgL0EEEE0</0c03^k^h0
I@1V003;o@28R8P0oFD00?ooo`14A4@08R8R00000000000000000000003`:O/0005g0=@000004_80
5h_80>Fn002l044001;b01;cY03o/000A00B07Oc]`3ccSP0oomg0<Soo`005h/0@o6k05g8000H01P0
01;l0000IP2;b000QP0G006D0P0J_N0000400<P0000065d0001<00:600000I@0040001QMb0000000
0000000000000040_^@000@06P00004000000000003P000001Zm01;cH000K0004@08000P00000000
RlP006005`00@7<0B0;D071?0000KVD000<000000P3cg000@00B0012kP0000@00A800?P00000GaX0
G3Y306e_J01QL6D0G6EW06IYI`1=07<0J7AQ065]I@1SJG@0JD9Q06L^I`00IVT04_?L08870000MnL0
0000000000008000g000000Bl`0Bm3`0HTl00<agm`004_<0000`0000000200<0000004;^@00Qk@00
U7OW00020@000P00000001P000000@00X/kA000H3`120000000000000P0AH`00QWOW006D0P000A80
l9D0018000007`00000000:N00010000000005mSZ00Jn000d01O000F200001<002H0000000000000
4_EL03<20000Mnd0000005lT2002QP004P6D00000@00l9D00000080000004_@0ieQn02@8M`0005l0
000000040000000000000000003WF>8090Qg0000G`00000000@003[00013MnP0J5`j06E]K`1WHG00
IeaU07=VJ@1QCE`0IFQd07AQK@1QHfT0IfU206UW;P2606H00I@20000001:R@00B7Of000D1@0006H0
00P008H00001U080AALk00:6002D0I@0008100014P0G@`00QP15006D0P0Bml000080000000000000
Ga[h0007000@0HX001;e0>dAVP04egL01gD1006:00000ah0000006P000005P<00@000?GH001T0180
Mj]:0081TP3eG0003P0B07OWF`0GRl000000000000005000004P000800010000000001;eR00X/`00
07O`000D000400P00AP006H000000000001V00:6003G0I@0M@440000000220000000000000000WH0
mE0000004P0000004_n`0;M40038Mo<0Mo?=0?ooo`261Ol0QP13006D0P092@T00000000000000000
0000000000000000000000T000071`L71`L71`L71`L71`L71`L71`L71`L71`L000T0000000000000
0000000000000000000000001`002@0410@410@410@410@410@410@410@410@4100700T0000410@4
10@410@410@410@410@410@410@400L000T010@410@400000P4410@41040004410@410@01`002@04
10@410@02000000:100000D0000010@4100700T0000410@4100820011P0000D500030`0410@400L0
00T010@410@400P820001P051@070P0300@410@01`002@0410@4104020P8208000D01`L72`0210@4
100700T0000410@40@0820P8208000L71`L200@410@400L000T010@4104000P820P820071`L71`80
0@@410@01`002@0410@400D5000000000000000000000@@4100700T000040@0000002`X21`080P05
1@0000L000@400L000T010@000L71`L71`L000P820801@0000L000@01`002@0400<300L71`L70006
00P820P000030004100700T000000`<300L71`0000H600P820P00`<010@400L000T010800`<300L0
00D01PH600P800<30`<010@01`002@0410X0000000051@061PH600030`<30`<0100700T0000410@2
0000000000H61PH:00<30`0000@400L000T010@410@:00<30P000000000000000@@410@01`002@04
10@4100500830`<30`<300H6004410@4100700T0000410@1000700<30`<30`001PH010@410@400L0
00T010@410001`L00P<30`<020P01P0410@410@01`002@0410@400L:00000`<30P0020P000@410@4
100700T0000410@0000110400`80108000P010@410@400L000T010@410@410@4100300@410@10004
10@410@01`002@0410@410@410@4100410@410@40P@410@4100700T0000410@410@410@410@410@4
10@410@410@400L000T010@410@410@410@410@410@410@410@410@01`002@0410@410@410@410@4
10@410@410@410@410002@T000000000000000000000000000000000000000T9100002L1ool30000
00000140000<0000200000/0000@00005@0001D000090000400001D0000E00008@0000P0000:0000
40000000000000002@000100000O00007`000340000@10000@00000300400000MgMg05EEE@3<0</0
k^k^06H0I@3mb`00R8R8001Uo@3oool0A4A4028R8P0000000000000000000000nbW`07L100000=@0
lQ800<R;5`00_^D0@@2l0?8B002Tla800;3o0180A02glgL0><kc07Ooo`3oolP0RaL00;_a@`00b5d0
600H0?`B001V00000<R;01L0QP02U040h;dJ000100000<P0GAP004`00000QP80U04000100038GAP0
00000000000000000@00003T_P0J00@00@00000000000000003P0;dJ001Pla8006`000P04@008000
00000038R`0G0600Ld000=@2B000Cg00IFh00003000200000=cc0180@03^@P001000000B0@000?P0
6Ul004<jG01XKfd0IG1Q06MUG01WJFH0L`1=065dJ01UKF40M6US0652J@1W;VL0JFH00=cc4P001h80
igL000000000000002000000g03c4P00??@B001?HP3gMl`0la800300000000000`0200000010kT80
0>dQ0>MgU0010P0000800000000001P000400=7>XP0?6000001200000002000006<A0>MgQP02U040
4P40002El000018001l000000000WP8000010000002XHel00?PJ05l0d0085P004`00000V00000000
000005ce4P000S<0kGL00000000895l008H209@14P010000UO00000000000800m18007iHi`1g22@0
G`000000000010000000000000000000hUSW07L8901O0000000000040000`3X0j7M303YLJ01_KFD0
L65W06ELI`1YIW<0G4eQ07AXI@1]HG@0JF=Q049YI`0^IfT0IP2600:D0@00000008U:0?IgB0055000
IP000008000008H00Y@103/GA@00QP80U06D0042000B0@0004<G04D0QP02U040`?LB000200000000
00000?PJG`001`00RP4@0?DB002J4Nd0MmL4005e1`00RP407P<00000000006P00aH000000@00f?D0
4P1T04Z[M`2B0@8005ce01803P1KigL0`8/G00000000000001@0020100002000000100000028mA80
0;<X0?1g000050002004000H0@0006H0000006H00000QP80U07G00@1M@00000000P2000000000000
MP80001@m@0B000000000;3o4P00A;L0lgO80<gcM`3oool0o`F604<0QP02U040<00000`000010000
=00000P0000E0000300000<0001A0000N0P00000000000005@0001D0000000000000000000000000
80000200001@0000:0@007P40000100000000200c00P0000800002P0000P00008000004020000000
00@00<@>00343P000040000000000000MgMg05EEE@3;0<`0k^k^06D0IP00bod0R8R80?eU003oool0
A4A4028R8P0000000000000000000000l2Wk0001M`3D000001;b01N;b03U_P00_011000BlP0Blj@0
ok0004@04P1glkL0llhh0?ooM`38ool001N;04?a^`1Mb000600H000Bo00006H0RlP008H05`01U080
6[gP00010038000001QM0000C002QP00006D0010000HGLP0000000000000000000010;kT000401X0
0001000000000000h000000J_@0Blf0006`0014020008000000008_8001P01L0041c04P2e01`C`00
06iU000300000080lm`004004P00@^h00004004B003h000005lJ05`j@`1]KfP0HG1U05aUI`1VJFL0
C@1c06QdH@1QKFD0HfUd06U2H@1W;VL006IY01;cg0221`0007OW00000000000002000=`000004_<0
4_@l069?003<MoL001;c0000<00000000P0300000012kT008Nd009Agi`000P4000800000000H0000
00400:;>d@0060l0@P000000000000804F<008Igi`01U080004B0?2E000B000001l000000002WP00
0@000000001OHjP06_P00=00G`005PP0000C000V00000000000001;eG00c0P0007O]0000001O90P0
0XH00181U00000400?2E00000020000001;d0>MHOP0T27L0001O0000000010000000000000000000
ieSR02@8M`0005l000000004000j`000@gOX06QL>P1UKFl0If5`06MLI@1cIVT0HDeL06EXM01dHFd0
HF=Y06MY@P1YIbh0QP1V006D0P000000BXT004QgmP0050D0001V0008002600000I@204DG>`02QP00
U06D00020@000A805d<008H0A@01U0804_O0000200000000000005lJn0001`00406:000Bm@3]4IX0
1=Mg00Me0@01RP0000<N0000001X000001H30040003ef000I00B07N[BP020I80mE`000h04P1gie/0
5h_000000000000001@00001800020000@000000000BmHP0:;<0001gl00050001008004H001V0000
00000000IP02QP00e`6D07D1100000000PP0000000000000009f0?E@00000180000001;o/02gA000
b7Oc07Occ@3oool0QPGo08H0@`01U0802@T900000000000000000000000000000000000000090000
1`L71`L71`L71`L71`L71`L71`L71`L71`L7000900000000000000000000000000000000000000L0
00T010@410@410@410@410@410@410@410@410@01`09000010@410@410@410@410@410@410@410@4
1007000900@410@41000008110@410@1000110@410@400L000T010@410@400P000002P@000050000
00@410@01`09000010@410@020P00@H000051@000`<010@41007000900@410@4100820P000H01@D0
1`800`0410@400L000T010@410@100P820P2000500L71`/00P@410@01`09000010@4104020P820P2
00071`L70P0410@41007000900@410@1000820P820P01`L71`L2004410@400L000T010@410051@00
0000000000000000004410@01`0900001040000000/:0PL020801@D0000700041007000900@40007
1`L71`L7000820P200D00007000400L000T010030`071`L71`001P0820P800000`0010@01`090000
00<30`071`L000061P0820P800<300@41007000900@200<30`07000500H61P0820030`<300@400L0
00T010@:000000001@D01PH61P000`<30`<300@01`09000010@40P00000000061PH62P030`<00004
1007000900@410@42P030`80000000000000004410@400L000T010@410@01@020`<30`<30`061P01
10@410@01`09000010@40@001`030`<30`<000H600@410@41007000900@410@000L700830`<300P8
00H010@410@400L000T010@410072P0000<30`8000P8000410@410@01`09000010@400000@@100<2
00@2000800@410@41007000900@410@410@410@00`0410@40@0010@410@400L000T010@410@410@4
10@010@410@4108410@410@01`09000010@410@410@410@410@410@410@410@41007000900@410@4
10@410@410@410@410@410@410@400L000T010@410@410@410@410@410@410@410@410@000T90000
0000000000000000000000000000000000092B80000<0000ooooobD0000<00001`00P2D0000<0000
0000P300000<00003`00P4/0000@0000000000D0000X000030000040000>000010<00;`0000@0000
000007MgM`1EEED0c03;0>k^kP1V06D0oL/008R8R000IOd0oooo04A4A00R8R80nbW`07L100000=@0
lQ800<R;5`00_^D0@@2l0:Cc4P00/?l04P140;OcM`0hc_<0Mooo0?oob02;5`00^o530038G@0H01P0
o18006H00000b8/05`2600:D0@3P_AX000400000b01M6000C00000260P2D0@0004000<QM60010000
0>Bn01X010000>00_AX0063c4P00K000200A000P000G0600Ld000=@2B000Cg00IFh0000300020000
0=cc0180@03^@P001000000B0@000?P06Ul004<jG01XKfd0IG1Q06MUG01WJFH0L`1=065dJ01UKF40
M6US0652J@1W;VL0JFH00=cc4P001h80igL00000g03c4P00??@B001?HP3gMl`0<00000<00P10kT80
0>dQ0>MgU0010P0000800000603AcZ803aP00000@P00Ha40igN601810000UO00000B000O0000WP80
00010:QSG`00n1X0G`3@00PF000C000002H005ce4P000S<0kGL000PTG`2D0A80UO000000P03d4P00
OUSW07L8901O000000@00>9Hi`00`3X0j7M303YLJ01_KFD0L65W06ELI`1YIW<0G4eQ07AXI@1]HG@0
JF=Q049YI`0^IfT0IP260029BP3fMdP01A@00008000008H0>aM509@1U000@aL0A@260<3g4P3h6Ul0
00L008X1403e4P00VQ7]07OG1001M@L008X101h3000006P00aH0003Hm@0B06@0BZ]g09810P00G?D0
4P0>05_WM`30RaL001@002010028mA800;<X0?1g000800@001P10000IP2D0ML0105e00080P1f0P00
053e0180002`oa8004Bg0?=gb03=lgL0o`F604<0QP040`00
\>"], "Graphics",
    ImageSize->{21, 21}],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"Section 4.1"],

Cell[TextData[{
  "\tIn this chapter we learn the basics for ",
  StyleBox["complex sequences",
    FontColor->RGBColor[0, 0, 1]],
  " and series.  We also explore an application of these ideas in what has \
popularly \[Infinity]come to be known as ",
  StyleBox["chaotic processes",
    FontColor->RGBColor[0, 0, 1]],
  ".\n\n\tIn formal terms, a complex sequence is a function whose domain is \
the positive integers and whose range is a subset of the complex numbers.  \
The following are examples of sequences: \n\n\t",
  Cell[BoxData[
      \(f \((n)\) = \((2 - 
              1\/n)\) + \(\(\[ImaginaryI]\) \((5 + 
                1\/n)\)\(\ \ \ \ \ \ \)\((n = 1, 2, 3,  ... )\)\(\ \)\)\)]],
  "\n\n\t",
  Cell[BoxData[
      \(g \((n)\) = \((2 - 
              1\/n)\) + \(\(\[ImaginaryI]\) \((5 + 
                1\/n)\)\(\ \ \ \ \ \ \)\((n = 1, 2, 3,  ... )\)\(\ \)\)\)]],
  "\n\n\t",
  Cell[BoxData[
      \(h \((n)\) = 
        5 + 3  \[ImaginaryI] + \(\(\((1\/\(1 + \[ImaginaryI]\))\)\^n\)\(\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\((n = 1, 2, 3,  ... )\)\(\ \)\)\)]],
  "\n\n\t",
  Cell[BoxData[
      \(r \((n)\) = 
        5 + 3  \[ImaginaryI] + \(\(\((1\/4 + \[ImaginaryI]\/2)\)\^n\)\(\
\ \ \ \ \ \ \ \ \ \)\((n = 1, 2, 3,  ... )\)\(\ \)\)\)]],
  "\n\t\n\tFor convenience, we at times use the term ",
  StyleBox["sequence",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " rather than ",
  StyleBox["complex sequence",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ".  If we wish a function  s  to represent an arbitrary sequence, we could \
specify it by writing  ",
  Cell[BoxData[
      \(s \((1)\) = z\_1, s \((2)\) = z\_2, s \((3)\) = z\_3\)]],
  ",  and so on.  The values   ",
  Cell[BoxData[
      \(z\_1, z\_2, z\_3,  ... \)]],
  ",  are called the ",
  StyleBox["terms",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " of a sequence, and mathematicians, being generally lazy when it comes to \
things like this, often refer to ",
  Cell[BoxData[
      \(z\_1, z\_2, z\_3, \(\(etc\)\(.\)\)\)]],
  " as the sequence itself, even though they are really speaking of the range \
of the sequence when they do this.  You will usually see a sequence written \
as  ",
  Cell[BoxData[
      \({z\_n}\_\(n = 1\)\%\[Infinity]\)]],
  ", ",
  Cell[BoxData[
      \({z\_n}\_1\%\[Infinity]\)]],
  ", or when the indices are understood, as ",
  Cell[BoxData[
      \({z\_n}\)]],
  ".  Mathematicians are also not so fussy about starting a sequence at  ",
  Cell[BoxData[
      \(z\_1\)]],
  ", so that  ",
  Cell[BoxData[
      \({z\_n}\_\(n = \(-1\)\)\%\[Infinity]\)]],
  ", ",
  Cell[BoxData[
      \({z\_n}\_\(n = 0\)\%\[Infinity]\)]],
  ", etc., would also be acceptable notation, ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\[Placeholder]\)]],
  "provided all terms were defined. \n\n\tInformally, the sequence  ",
  Cell[BoxData[
      \({z\_n}\_1\%\[Infinity]\)]],
  "  has  ",
  Cell[BoxData[
      \(\[Zeta]\)]],
  "  as its limit as  n  approaches infinity, provided the terms  ",
  Cell[BoxData[
      \(z\_n\)]],
  "  can be made as close as we please to  ",
  Cell[BoxData[
      \(\[Zeta]\)]],
  "  by making  n  large enough.  When this happens, we write \n\n\t",
  Cell[BoxData[
      RowBox[{\(lim\+\(n \[Rule] \[Infinity]\)\ z\_n\), "=", 
        RowBox[{
          RowBox[{"\[Zeta]", "    ", 
            StyleBox["or",
              FontFamily->"Times New Roman"], "    ", \(z\_n\)}], 
          "\[Rule]", \(\[Zeta]\ \ \ as\ \ n\  \[Rule] \[Infinity]\)}]}]]],
  "\n\nIf  ",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ z\_n = \[Zeta]\)]],
  ",  we say that the sequence  ",
  Cell[BoxData[
      \({z\_n}\_1\%\[Infinity]\)]],
  "  ",
  StyleBox["converges",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " to  ",
  Cell[BoxData[
      \(\[Zeta]\)]],
  ".  \n\n\tHowever, we need a rigorous definition, if we are to do honest \
mathematics.  Thus, we have the following."
}], "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Definition 4.1 (Limit of a Sequence), Page 126.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ z\_n = \[Zeta]\)]],
  "  means that for any real number  ",
  Cell[BoxData[
      \(\[Epsilon] > 0\)]],
  "  there corresponds a positive integer  ",
  Cell[BoxData[
      \(N\_\[Epsilon]\)]],
  "  (which depends on  ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  ")  such that  ",
  Cell[BoxData[
      \(z\_n \[Element] \(D\_\[Epsilon]\) \((\[Zeta])\)\)]],
  "  whenever  ",
  Cell[BoxData[
      \(n > N\_\[Epsilon]\)]],
  ",  in other words  ",
  Cell[BoxData[
      \(\(\(|\)\(\[Zeta] - z\_n\)\(|\)\(\(<\)\(\[Element]\)\)\)\)]],
  "  whenever  ",
  Cell[BoxData[
      \(n > N\_\[Epsilon]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 4.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The reason we use the notation ",
  Cell[BoxData[
      \(N\_\[Epsilon]\)]],
  " is to emphasize the fact that this number depends on our choice of ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  ". Sometimes it will be convenient to drop the subscript."
}], "Text"],

Cell["\<\

\tIn form, Definition 4.1 is exactly the same as the corresponding definition \
for limits of real sequences. In fact, there is a simple criterion that casts \
the convergence of complex sequences in terms of the convergence of real \
sequences.\
\>", "Text"],

Cell[TextData[{
  StyleBox["\nTheorem 4.1,  Page 126.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(z\_n = x\_n + \[ImaginaryI]\ y\_n\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Zeta] = u + \[ImaginaryI]\ v\)]],
  ".  Then \n\n\t\t",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ z\_n = \[Zeta]\)]],
  "  \n\n\tif and only if  \n\n\t\t",
  Cell[BoxData[
      RowBox[{\(lim\+\(n \[Rule] \[Infinity]\)\ x\_n\), "=", 
        RowBox[{
          RowBox[{"u", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], 
            "  ", \(lim\+\(n \[Rule] \[Infinity]\)\ y\_n\)}], "=", "v"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Proof of Theorem 4.1,  see text Page 126.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.1,  Page 128.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the limit of the sequence  ",
  Cell[BoxData[
      \({z\_n} = {\(\@n\  + \ \[ImaginaryI] \((\ n + 1)\)\)\/n}\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the formula for the terms of the sequence.", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[limX, limY, limZ, n];\)\ \), "\n", 
    \(\(x\_n_\  = \ \@n\/n;\)\ \), "\n", 
    \(\(y\_n_\  = \ \(n + 1\)\/n;\)\ \), "\n", 
    \(\(z\_n_\  = \ 
        x\_n\  + \ \[ImaginaryI]\ y\_n;\)\ \), "\[IndentingNewLine]", 
    \(\(table = Table[z\_n, {n, 1, 9}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\n", 
    \(\(limX\  = \ Limit[x\_n, \ n \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(limY\  = \ Limit[y\_n, \ n \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(limZ\  = \ 
        Limit[z\_n, \ n \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_n\) = \>\"", 
        z\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_n\) = \>\"", 
        x\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_n\) = \>\"", 
        y\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(x\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", x\_n, "\< = \>", 
        limX];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(y\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", y\_n, "\< = \>", 
        limY];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(z\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(z\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(z\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) (\>\"", 
        z\_n, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(z\_n\) = \>\"", 
        limX, "\< + \[ImaginaryI] (\>", limY, "\<) = \>", 
        limZ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the terms in the sequence."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(set\  = \ \ Table[{N[x\_n], N[y\_n]}, {n, 1, 
            50}];\)\ \), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{PointSize[0.025], Magenta, 
            Point[{0, 1}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr = 
        ListPlot[set, Prolog \[Rule] {PointSize[0.02], Green}, 
          PlotRange \[Rule] {{0.0, 1.0}, {0.0, 2.0}}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \[IndentingNewLine]Ticks \
\[Rule] {Range[0, 1, 1\/2], 
              Range[0, 2, 1\/2]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr, dot];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(z\_n\) = \
\!\(lim\+\(n \[Rule] \[Infinity]\)\) (\>\"", z\_n, "\<) = \>", 
        limX, "\< + \[ImaginaryI] (\>", limY, "\<) = \>", 
        limZ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the limit of the sequence  ",
  Cell[BoxData[
      \({z\_n} = {\(\@n\  + \ \[ImaginaryI] \((\ n + 1)\)\)\/n}\ \ \ is\
\ \ \ \[ImaginaryI]\)]],
  ".  However, the real part is converging slowly to 0  and the imaginary \
part is converging a little faster to  ",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.2,  Page 128.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the sequence ",
  Cell[BoxData[
      \({\((1 + \[ImaginaryI])\)\^n}\)]],
  " diverges.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the formula for the terms of the sequence, and determine if \
the sequence converges or diverges.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[limX, limY, limZ, n];\)\ \), "\n", 
    \(\(z\_n_ = \ \((1\  + \ \[ImaginaryI])\)\^n;\)\ \), \
"\[IndentingNewLine]", 
    \(\(table = Table[z\_n, {n, 1, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\n", 
    \(\(lim\  = \ 
        Limit[z\_n, \ n \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(z\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", 
        z\_n, "\< = \>", lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\

Investigate the limit in more detail.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(x\_n_ = 
        ComplexExpand[Re[z\_n]];\)\ \), "\[IndentingNewLine]", 
    \(\(y\_n_ = ComplexExpand[Im[z\_n]];\)\ \), "\n", 
    \(\(limX\  = \ Limit[x\_n, \ n \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(limY\  = \ Limit[y\_n, \ n \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(limZ\  = \ limX\  + \ \[ImaginaryI]\ limY;\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(x\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", x\_n, "\< = \>", 
        limX];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(y\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", y\_n, "\< = \>", 
        limY];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(z\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", 
        z\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", limX, "\< + \[ImaginaryI] (\>", 
        limY, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(z\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", 
        z\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", limZ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nTherefore, the limit of the sequence does ",
  StyleBox["NOT",
    FontColor->RGBColor[1, 0, 1]],
  " exist, and exhibits \"divergent oscillations.\"\n\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the terms in the sequence."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(set\  = \ \ Table[{N[x\_n], N[y\_n]}, {n, 1, 
            7}];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[set, Prolog \[Rule] {PointSize[0.02], Blue}, 
        PlotRange \[Rule] {{\(-4.3\), 8.0}, {\(-9.0\), 2.5}}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \[IndentingNewLine]AspectRatio \
\[Rule] 1, 
        Ticks \[Rule] {Range[\(-4\), 8, 2], 
            Range[\(-8\), 2, 2]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(z\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", 
        z\_n, "\< = \>", limX, "\< + \[ImaginaryI] \>", 
        limY];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the sequence  ",
  Cell[BoxData[
      \({z\_n} = {\((1 + \[ImaginaryI])\)\^n}\)]],
  "  is divergent.  "
}], "Text"]
}, Closed]],

Cell["\<\

\tAs with real numbers, we also have the following definition.  \
\>", "Text"],

Cell[TextData[{
  StyleBox["\nDefinition 4.2, Page 128.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The sequence  ",
  Cell[BoxData[
      \({z\_n}\)]],
  "  is said to be a ",
  ButtonBox["Cauchy Sequence",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CauchySequence.html"], None},
    ButtonStyle->"Hyperlink"],
  " if for every  ",
  Cell[BoxData[
      \(\[Epsilon] > 0\)]],
  "  there exists a positive integer  ",
  Cell[BoxData[
      \(N\_\[Epsilon]\)]],
  ",  such that if  ",
  Cell[BoxData[
      \(m, n > N\_\[Epsilon]\)]],
  ",  then  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_m - z\_n\)\(|\)\(\(<\)\(\[Element]\)\)\)\)]],
  ",  or, equivalently,  ",
  Cell[BoxData[
      \(z\_m - z\_n\)]],
  "  belongs to the disk  ",
  Cell[BoxData[
      \(\(D\_\[Epsilon]\) \((0)\)\)]],
  "."
}], "Text"],

Cell["\tThe following should now come as no surprise.", "Text"],

Cell[TextData[{
  StyleBox["\nTheorem 4.2,  (Cauchy Sequences Converge)Page 128.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \({z\_n}\)]],
  "  is a Cauchy sequence, then ",
  Cell[BoxData[
      \({z\_n}\)]],
  "  converges."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Proof of Theorem 4.2,  see text Page 128.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\n\tIf we have a complex sequence ",
  Cell[BoxData[
      \({z\_n}\)]],
  ", we can form a new sequence ",
  Cell[BoxData[
      \({S\_n}\)]],
  ", called the ",
  StyleBox["sequence of partial sums",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ", in the following way:  \n\n\t\t\t\t",
  Cell[BoxData[
      \(S\_1 = z\_1\)]],
  ",  \n\t\t\t\t",
  Cell[BoxData[
      \(S\_2 = z\_1 + z\_2\)]],
  ",  \n\t\t\t\t",
  Cell[BoxData[
      \(S\_3 = z\_1 + z\_2 + z\_3\)]],
  ", \n\t\t\t\t     ",
  Cell[BoxData[
      \(\[VerticalEllipsis]\)]],
  "  \n\t\t\t\t",
  Cell[BoxData[
      \(S\_n = \(\(z\_1 + z\_2 +  ... \) + 
            z\_n = \[Sum]\+\(k = 1\)\%\[Infinity] z\_k\)\)]],
  ",\n\t\t\t\t     ",
  Cell[BoxData[
      \(\[VerticalEllipsis]\)]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["\nDefinition 4.3 (Infinite Series), Page 129.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The formal expression ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 1\)\%\[Infinity] z\_k = \(z\_1 + z\_2 +  ... \) + 
            z\_n +  ... \)]],
  "  is called an ",
  StyleBox["infinite series",
    FontSlant->"Italic"],
  ", and ",
  Cell[BoxData[
      \(z\_1, z\_2,  ... \)]],
  ", are called the ",
  StyleBox["terms",
    FontSlant->"Italic"],
  " of the series."
}], "Text"],

Cell[TextData[{
  "\n\tIf there is a complex number S for which \n\n\t\t\t",
  Cell[BoxData[
      \(S = \(lim\+\(n \[Rule] \[Infinity]\)\ S\_n = 
          lim\+\(n \[Rule] \[Infinity]\)\(\[Sum]\+\(k = 1\)\%n z\_k\)\)\)]],
  ", \n\t\t\t\nwe will say that the infinite series ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 1\)\%\[Infinity] z\_k\)]],
  " ",
  StyleBox["converges",
    FontSlant->"Italic"],
  " to S, and that S is the ",
  StyleBox["sum",
    FontSlant->"Italic"],
  " of the infinite series. When this happens, we write \n\n\t\t\t",
  Cell[BoxData[
      \(S = \[Sum]\+\(k = 1\)\%\[Infinity] z\_k\)]],
  ".  \n\n\tThe series ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 1\)\%\[Infinity] z\_k\)]],
  " is said to be ",
  StyleBox["absolutely convergent",
    FontSlant->"Italic"],
  " provided that the (real) series of magnitudes ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 1\)\%\[Infinity]\(\(|\)\(z\_k\)\(|\)\)\)]],
  " converges.  \n\n\tIf a series does not converge, we say that it ",
  StyleBox["diverges",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Remark 4.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " It is important to note that the first finitely many terms of a series do \
not affect its convergence or divergence and that in this respect the \
beginning index of a series is irrelevant. Thus, we will without comment \
conclude that if a series ",
  Cell[BoxData[
      \(\[Sum]\+\(k = N + 1\)\%\[Infinity] z\_k\)]],
  " converges, then so does ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 0\)\%\[Infinity] z\_k\)]],
  ", where ",
  Cell[BoxData[
      \(z\_0, z\_1, z\_2,  ... , z\_N\)]],
  " is ",
  StyleBox["any",
    FontSlant->"Italic"],
  " finite collection of terms. A similar remark holds for determining \
divergence of a series."
}], "Text"],

Cell["\<\

\tAs one might expect, many of the results concerning real series carry over \
to the complex case. We now give several of the more standard theorems along \
with examples of how they are used.\
\>", "Text"],

Cell[TextData[{
  StyleBox["\nTheorem 4.3,  Page 130.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(z\_n = x\_n + \[ImaginaryI]\ y\_n\)]],
  "  and  ",
  Cell[BoxData[
      \(S = U + \[ImaginaryI]\ V\)]],
  ".  Then  \n\n\t\t\t",
  Cell[BoxData[
      \(S = \(\[Sum]\+\(n = 1\)\%\[Infinity] z\_n = \[Sum]\+\(n = 1\)\%\
\[Infinity]\((x\_n + \[ImaginaryI]\ y\_n)\)\)\)]],
  "  converges \n\nif and only if both  \n\t\t\t",
  Cell[BoxData[
      \(U = \(\[Sum]\+\(n = 1\)\%\[Infinity] x\_n\ \ and\ \ V = \[Sum]\+\(n = \
1\)\%\[Infinity] y\_n\)\)]],
  "  converge.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Proof of Theorem 4.3,  see text Page 130.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\nTheorem 4.4,  Page 130.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] z\_n\)]],
  "  is a convergent complex series, then  ",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ z\_n = 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Proof of Theorem 4.4, Page 130.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  " The proof is left as an exercise."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.3,  Page 130.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\( 1 + \[ImaginaryI]\ n \((\(-1\))\)\^n\
\)\/n\^2\)]],
  "  ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FormBox["",
            "TraditionalForm"],
          FontSize->14], TraditionalForm]]],
  "is convergent."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the formula for the series, and determine if the series \
converges or diverges.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", \(Clear[k, n, sumX, sumY, sumZ];\), 
      " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"sumX", " ", "=", 
          StyleBox[\(\[Sum]\+\(n = 1\)\%\[Infinity] 1\/n\^2\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"sumY", " ", "=", " ", 
          
          StyleBox[\(\[Sum]\+\(n = 1\)\%\[Infinity]\( n \
\((\(-1\))\)\^n\)\/n\^2\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{\(sumZ\  = \ sumX\  + \ \[ImaginaryI]\ sumY;\), " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<         \!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(1\/n\^2\) = \
\>\"", 
            StyleBox[",",
              FontSize->14], "sumX"}], "]"}], ";"}], " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<    \!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\(n \
\((\(-1\))\)\^n\)\/n\^2\) = \>\"", 
            StyleBox[",",
              FontSize->14], "sumY"}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\(1 + \
\[ImaginaryI]n \((\(-1\))\)\^n\)\/n\^2\) = \>\"", sumZ];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\(1 + \
\[ImaginaryI]n \((\(-1\))\)\^n\)\/n\^2\) = \>\"", N[sumZ]];\), 
      " "}]}], "Input"],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", 
      "\[IndentingNewLine]", \(X\_n_\  = \[Sum]\+\(k = 1\)\%n 1\/k\^2;\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(Y\_n_\  = \[Sum]\+\(k = 1\)\%n\((\(-1\))\)\^k\/k\^2\), 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(S\_n_\), " ", "=", " ", 
          RowBox[{
            StyleBox[\(\[Sum]\+\(k = 1\)\%n 1\/k\^2\),
              FontSize->14], 
            StyleBox[" ",
              FontSize->14], 
            StyleBox["+",
              FontSize->14], 
            StyleBox[" ",
              FontSize->14], 
            RowBox[{"\[ImaginaryI]", "  ", 
              StyleBox[\(\[Sum]\+\(k = 1\)\%n\((\(-1\))\)\^k\/k\^2\),
                FontSize->14]}]}]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\[IndentingNewLine]", 
    RowBox[{\(table = Table[FullSimplify[S\_n], {n, 1, 10}];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(table = Append[table, "\<...\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", table];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", N[table]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(S\_n\) = (\!\(\[Sum]\+\(k = \
1\)\%n\)\!\(1\/k\^2\))+\[ImaginaryI](\!\(\[Sum]\+\(k = 1\)\%n\)\!\(\((\(-1\))\
\)\^k\/k\^2\)) = \>\"", S\_n];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\< \!\(\[Sum]\+\(k = 1\)\%n\)\!\(1\/k\^2\)+\
\[ImaginaryI]\!\(\[Sum]\+\(k = 1\)\%n\)\!\(\((\(-1\))\)\^k\/k\^2\) = \>\"", 
          sumZ];\), " "}]}], "Input"],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(set\  = \ \ Table[{X\_n, Y\_n}, {n, 1, 
            40}];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[set, Prolog \[Rule] {PointSize[0.02], Magenta}, 
        PlotRange \[Rule] {{0.0, 1.7}, {\(-1.05\), 
              0.05}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", \
"\<y\>"}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2, 0.2], 
            Range[\(-1\), 0, 0.2]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(S\_n\) = \>\"", 
        sumZ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(S\_n\) = \>\"", 
        N[sumZ]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 1\)\%n\)\!\(\(1 + \[ImaginaryI] \
\((\(-1\))\)\^k\)\/k\^2\) = \>\"", sumZ];\)\ \), "\[IndentingNewLine]", 
    \(Null\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nTherefore, we see that the infinite series converges, indeed  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\( 1\  + \ \[ImaginaryI]\ n \
\((\(-1\))\)\^n\)\/n\^2 = \[Pi]\^2\/6 - \[ImaginaryI]\ Log[2]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.4,  Page 130.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\(\((\(-1\))\)\^n + \
\[ImaginaryI]\)\/n\)]],
  "  is divergent."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the formula for the series, and determine if the series \
converges or diverges.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[n, sumN, sumX, sumY, sumZ];\)\ \), "\n", 
    \(\(sumX\  = \ \[Sum]\+\(n = 1\)\%\[Infinity]\((\(-1\))\)\^n\/n;\)\ \), "\
\n", 
    \(\(sumY\  = \ \[Sum]\+\(n = 1\)\%\[Infinity] 1\/n;\)\ \), "\n", 
    \(\(sumZ\  = \ sumX\  + \ \[ImaginaryI]\ sumY;\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = \
1\)\%\[Infinity]\)\!\(\((\(-1\))\)\^n\/n\) = \>\"", sumX];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(1\/n\) = \>\"", 
        sumY];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = \
1\)\%\[Infinity]\)\!\(\(\((\(-1\))\)\^n + \[ImaginaryI]\)\/n\) = \>\"", 
        sumZ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  Since the answer returned for the imaginary part was  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] 1\/n\)]],
  ",  this means that a sum was not found.\nIt is known that the partial sums \
of the harmonic series grow slowly without bound.  \nFor example, adding 10,  \
100,  1000  and  10000 terms yields:"
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%m\)\!\(1\/n\) \
= \>\"", \[Sum]\+\(n = 1\)\%m 1\/n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] 4, \(i++\), \n\ \ Print["\<m = \>", 
          10\^i, \*"\"\<,     \!\(\[Sum]\+\(n = 1\)\%m\)\!\(1\/n\) = \>\"", 
          N[HarmonicNumber[10\^i]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nTherefore, the series slowly diverges to ",
  Cell[BoxData[
      \(\[Infinity]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.5,  Page 131.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the series ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\((1 + \[ImaginaryI])\)\^n\)]],
  " is divergent.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the formula ",
  Cell[BoxData[
      \(z\_n = \((1 + \[ImaginaryI])\)\^n\)]],
  " for the terms of the sequence, and look at the modulus."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[limX, limY, limZ, n];\)\ \), "\n", 
    \(\(z\_n_ = \ \((1\  + \ \[ImaginaryI])\)\^n;\)\ \), \
"\[IndentingNewLine]", 
    \(\(m\_n_ = Abs[z\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(M\_n_ = ComplexExpand[m\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(lim\  = \ 
        Limit[m\_n, \ n \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) |\>\"", 
        z\_n, \*"\"\<| = \!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", 
        m\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) |\>\"", 
        z\_n, \*"\"\<| = \!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", 
        M\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) |\>\"", 
        z\_n, "\<| = \>", lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nHence ",
  Cell[BoxData[
      \(lim\+\(n\  \[Rule] \ \[Infinity]\)\ z\_n \[NotEqual] 0\)]],
  ", and the series is divergent."
}], "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will indicate that there is a problem with convergence. "
}], "Text"],

Cell[BoxData[{
    \(\(sum = \[Sum]\+\(n = 1\)\%\[Infinity]\((1 + \[ImaginaryI])\)\^n;\)\ \ \
\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\((1 + \
\[ImaginaryI])\)\^n\) = \>\"", sum];\)\ \)}], "Input"],

Cell[TextData[{
  "Which is comforting to see that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows the answer too! "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["\nTheorem 4.5,  Page 131.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] z\_n\ \ and\ \ \(\[Sum]\+\(n = 1\)\%\
\[Infinity] w\_n\)\)]],
  "  be convergent series, and let  c  be a complex number.  Then  \n\n\t\t\t\
",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] c\ z\_n = 
        c \(\[Sum]\+\(n = 1\)\%\[Infinity] z\_n\)\)]],
  "  \n\t\tand  \n\t\t\t",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\((z\_n + 
              w\_n)\) = \[Sum]\+\(n = 1\)\%\[Infinity] z\_n + \[Sum]\+\(n = 1\
\)\%\[Infinity] w\_n\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Proof of Theorem 4.5,  see text Page 131.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  " The proof of this theorem is left as an exercise."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\nDefinition 4.4, Page 131.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] a\_n\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] b\_n\)]],
  "  be convergent series, where ",
  Cell[BoxData[
      \(a\_n\ \ and\ \ b\_n\)]],
  "  are complex numbers.  The ",
  ButtonBox["Cauchy Product",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CauchyProduct.html"], None},
    ButtonStyle->"Hyperlink"],
  " of the two series is defined to be the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] c\_n\)]],
  ",  where  ",
  Cell[BoxData[
      \(c\_n = \[Sum]\+\(k = 1\)\%n\( a\_k\) b\_\(n - k\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["\nTheorem 4.6,  Page 131.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If the Cauchy product converges, then  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] c\_n = \((\[Sum]\+\(n = 1\)\%\
\[Infinity] a\_n)\) \((\[Sum]\+\(n = 1\)\%\[Infinity] b\_n)\)\)]],
  ",  \n\t\twhere  \n\t\t\t",
  Cell[BoxData[
      \(c\_n = \[Sum]\+\(k = 1\)\%n\( a\_k\) b\_\(n - k\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Proof of Theorem 4.6,  see text Page 131.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  The proof can be found in a number of texts, for example, ",
  StyleBox["Infinite Sequences and Series",
    FontSlant->"Italic"],
  ", by ",
  ButtonBox["Konrad Knopp",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Knopp.html"]\
, None},
    ButtonStyle->"Hyperlink"],
  " (translated by Frederick Bagemihl",
  "; ",
  " New York: Dover, 1956)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\nTheorem 4.7,  Page 132.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ButtonBox["Comparison Test",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ComparisonTest.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] M\_n\)]],
  "  be a convergent series of real nonnegative terms.  If  ",
  Cell[BoxData[
      \({z\_n}\)]],
  "  is a sequence of complex numbers and  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_n\)\(|\)\(\(\[LessEqual]\)\(\ \)\(M\_n\)\)\)\)]],
  "  holds for all  n, then  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] z\_n\)]],
  "  converges."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Proof of Theorem 4.7,  see text Page 132.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\nCorollary 4.1, Page 132. ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " If  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\(\(|\)\(z\_n\)\(|\)\)\)]],
  ", then  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] z\_n\)]],
  "  converges.  In other words, absolute convergence implies convergence for \
complex series as well as for real series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Proof of Corollary 4.1, see text Page 132.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.6,  Page 132.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\((3\  + \ 4  \
\[ImaginaryI])\)\^n\/\(5\^n\ n\^2\)\)]],
  "  is convergent."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the formula for the series, and determine if the series \
converges or diverges.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[absZn, n, sum, sumX, sumY, sumZ];\)\ \), "\n", 
    \(\(z\_n_\  = \ \((3 + 4  \[ImaginaryI])\)\^n\/\(5\^n\ n\^2\);\)\ \), "\n\
", 
    \(\(x\_n_\  = \ ComplexExpand[Re[z\_n]];\)\ \), "\n", 
    \(\(y\_n_\  = \ ComplexExpand[Im[z\_n]];\)\ \), "\n", 
    \(\(sumX\  = \ \[Sum]\+\(n = 1\)\%\[Infinity] x\_n;\)\ \), "\n", 
    \(\(sumY\  = \ \[Sum]\+\(n = 1\)\%\[Infinity] y\_n;\)\ \), "\n", 
    \(\(sumZ\  = \ \[Sum]\+\(n = 1\)\%\[Infinity] z\_n;\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_n\) = \>\"", z\_n];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_n\) = \>\"", ComplexExpand[z\_n]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(x\_n\) = \>\"", x\_n];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_n\) = \>\"", 
        y\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(x\_n\) = \>\"", 
        sumX];\)\ \), "\n", 
    \(\(Print["\<     = \>", Chop[N[sumX]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(y\_n\) = \>\"", 
        sumY];\)\ \), "\n", 
    \(\(Print["\<     = \>", Chop[N[sumY]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\((3 + 4  \
\[ImaginaryI])\)\^n\/\(5\^n*n\^2\)\) = \>\"", 
        sumZ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\((3 + 4  \
\[ImaginaryI])\)\^n\/\(5\^n*n\^2\)\) = \>\"", 
        N[sumZ]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nHence we see that the series converges and that  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\((3\  + \ 4  \
\[ImaginaryI])\)\^n\/\(5\^n\ n\^2\) = 
        PolyLog[2, 3\/5 + \(4\ \[ImaginaryI]\)\/5]\)]],
  ".  \n\n",
  "Or we could use Corollary 4.1 and show that the series converges \
absolutely.  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(absZn\  = \ 
        ComplexExpand[Abs[z\_n]];\)\ \), "\n", 
    \(\(sum\ \  = \ \ \[Sum]\+\(n = 1\)\%\[Infinity] 1\/n\^2;\)\ \), "\n", 
    \(\(Print["\<|\>", z\_n, "\<| = \>", 
        absZn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)|\!\(\((3 + 4  \
\[ImaginaryI])\)\^n\/\(5\^n*n\^2\)\)| = \>\"", 
        sum];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nThe series of absolute values converges, therefore the series converges.\
\n\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(S\_n_\  = \ \[Sum]\+\(k = 1\)\%n\((3 + 4  \
\[ImaginaryI])\)\^k\/\(5\^k\ k\^2\);\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Table[FullSimplify[S\_n], {n, 1, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_n\) = \!\(\[Sum]\+\(k = 1\)\%n\)\!\(\((3 + 4  \
\[ImaginaryI])\)\^k\/\(5\^k*k\^2\)\) = \>\"", 
        S\_n];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(set\  = \ \ Table[{Re[S\_n], Im[S\_n]}, {n, 1, 
            10}];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[set, 
        Prolog \[Rule] {PointSize[0.03], 
            Green}, \[IndentingNewLine]PlotRange \[Rule] {{0, 0.7}, {0, 
              1.1}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        AspectRatio \[Rule] 
          1.1\/0.7, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1, 0.2], 
            Range[0, 1, 0.2]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\((3 + 4  \
\[ImaginaryI])\)\^n\/\(5\^n*n\^2\)\) = \>\"", sumZ, "\< = \>", 
        N[sumZ]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nTherefore, we see that the series converges, and we have  ",
  Cell[BoxData[
      \(\(\(\ \)\(\[Sum]\+\(n = 1\)\%\[Infinity]\((3\  + \ 4  \
\[ImaginaryI])\)\^n\/\(5\^n\ n\^2\) = 
        PolyLog[2, 3\/5 + \(4\ \[ImaginaryI]\)\/5]\)\(\ \)\)\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Library Research Experience for Undergraduates",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox["Project I. Write a report on series.",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0, 0.996109]],
  "\n\t\n",
  StyleBox["1.",
    FontWeight->"Bold"],
  " Agnew, R. P. and R. P. Boas, ''An Integral Test for Convergence (in Math. \
Notes),'' Am. Math. M., Vol. 56, No. 10. (Dec., 1949), pp. 677-678, ",
  StyleBox[ButtonBox["Jstor.",
    ButtonData:>{
      URL[ "http://www.jstor.org/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "   \n\n",
  StyleBox["2.",
    FontWeight->"Bold"],
  " Barry, P. D. and D. J. Hurley, (1991), ''On Series of Partial \
Fractions,'' Am. Math. M., V. 98, No. 3, pp. 240-242.\n\n",
  StyleBox["3.",
    FontWeight->"Bold"],
  " Gluchoff, Alan D., (1993), ''Complex Power Series -- a Vector Field \
Visualization,'' Math. Mag., V. 66, No. 3, pp. 189-191.\n\n",
  StyleBox["4.",
    FontWeight->"Bold"],
  " Lee, Sanboh, and J. C. M. Li, (1988), ''Summation of Infinite Series \
Related to Roots of Certain Functions,'' Int. J. of Math. Ed. in Sci. and \
Tech., V. 19, No. 1, pp. 89-93.\n\n",
  StyleBox["5.",
    FontWeight->"Bold"],
  " Marafino, John and Timothy J. McDevitt, (1995) ''Convergence of Complex \
Continued Fractions,'' Math. Mag., Vol.68, No 3, pp.202-208."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Section 4.1",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["  ",
    FontSize->16,
    FontWeight->"Bold"],
  StyleBox["Exercises for Sequences and Series\n",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0.500008, 0.996109]],
  StyleBox["See textbook page 132.",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Section 4",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".2",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Julia and Mandelbrot Sets",
    ButtonData:>{"ca0402.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["Section 4",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".3",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Geometric Series and Convergence Theorems",
    ButtonData:>{"ca0403.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["Section 4",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".4",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Power Series Functions",
    ButtonData:>{"ca0404.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["GO TO  THE",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox["  ",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox[ButtonBox["Table of Contents",
    ButtonData:>{"content.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "\n"
}], "Text"]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{755, 599},
WindowMargins->{{32, Automatic}, {Automatic, 6}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->16,
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 4"->{
    Cell[4362, 144, 355, 12, 35, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 4"]},
  "Section 4.1"->{
    Cell[5303, 172, 10683, 143, 38, "Text",
      Evaluatable->False,
      CellTags->"Section 4.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 4", 85592, 2577},
  {"Section 4.1", 85709, 2581}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 615, 20, 109, "Text",
  Evaluatable->False],
Cell[2345, 74, 1980, 65, 248, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4362, 144, 355, 12, 35, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 4"],
Cell[4720, 158, 546, 9, 110, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5303, 172, 10683, 143, 38, "Text",
  Evaluatable->False,
  CellTags->"Section 4.1"],
Cell[15989, 317, 3977, 111, 578, "Text"],
Cell[19969, 430, 825, 30, 71, "Text"],
Cell[20797, 462, 368, 11, 52, "Text"],
Cell[21168, 475, 270, 6, 71, "Text"],
Cell[21441, 483, 745, 24, 166, "Text",
  Evaluatable->False],
Cell[22189, 509, 179, 4, 33, "Text",
  Evaluatable->False],
Cell[22371, 515, 313, 11, 61, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[22709, 530, 152, 4, 33, "Text",
  Evaluatable->False],
Cell[22864, 536, 64, 0, 33, "Text"],
Cell[22931, 538, 2084, 39, 578, "Input"],
Cell[25018, 579, 139, 5, 52, "Text"],
Cell[25160, 586, 903, 18, 213, "Input"],
Cell[26066, 606, 357, 10, 80, "Text"]
}, Closed]],
Cell[26438, 619, 286, 11, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[26749, 634, 152, 4, 33, "Text",
  Evaluatable->False],
Cell[26904, 640, 127, 3, 33, "Text"],
Cell[27034, 645, 740, 14, 239, "Input"],
Cell[27777, 661, 62, 3, 52, "Text"],
Cell[27842, 666, 1351, 23, 324, "Input"],
Cell[29196, 691, 292, 8, 90, "Text"],
Cell[29491, 701, 824, 16, 198, "Input"],
Cell[30318, 719, 150, 5, 52, "Text"]
}, Closed]],
Cell[30483, 727, 89, 3, 49, "Text"],
Cell[30575, 732, 839, 31, 75, "Text"],
Cell[31417, 765, 63, 0, 33, "Text"],
Cell[31483, 767, 337, 13, 52, "Text",
  Evaluatable->False],
Cell[31823, 782, 179, 4, 33, "Text",
  Evaluatable->False],
Cell[32005, 788, 806, 31, 185, "Text"],
Cell[32814, 821, 520, 18, 71, "Text"],
Cell[33337, 841, 1060, 30, 242, "Text"],
Cell[34400, 873, 766, 22, 90, "Text"],
Cell[35169, 897, 218, 5, 71, "Text"],
Cell[35390, 904, 676, 21, 147, "Text",
  Evaluatable->False],
Cell[36069, 927, 179, 4, 33, "Text",
  Evaluatable->False],
Cell[36251, 933, 375, 13, 52, "Text",
  Evaluatable->False],
Cell[36629, 948, 219, 7, 33, "Text",
  Evaluatable->False],
Cell[36851, 957, 446, 17, 55, "Text"],

Cell[CellGroupData[{
Cell[37322, 978, 152, 4, 33, "Text",
  Evaluatable->False],
Cell[37477, 984, 110, 3, 33, "Text"],
Cell[37590, 989, 1645, 46, 358, "Input"],
Cell[39238, 1037, 158, 5, 52, "Text"],
Cell[39399, 1044, 1915, 45, 424, "Input"],
Cell[41317, 1091, 153, 5, 52, "Text"],
Cell[41473, 1098, 937, 16, 250, "Input"],
Cell[42413, 1116, 256, 6, 56, "Text"]
}, Closed]],
Cell[42684, 1125, 282, 10, 52, "Text"],

Cell[CellGroupData[{
Cell[42991, 1139, 152, 4, 33, "Text",
  Evaluatable->False],
Cell[43146, 1145, 110, 3, 33, "Text"],
Cell[43259, 1150, 765, 14, 325, "Input"],
Cell[44027, 1166, 441, 11, 93, "Text"],
Cell[44471, 1179, 445, 8, 177, "Input"],
Cell[44919, 1189, 125, 5, 52, "Text"]
}, Closed]],
Cell[45059, 1197, 316, 11, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[45400, 1212, 152, 4, 33, "Text",
  Evaluatable->False],
Cell[45555, 1218, 175, 5, 33, "Text"],
Cell[45733, 1225, 1015, 18, 277, "Input"],
Cell[46751, 1245, 160, 5, 52, "Text"],
Cell[46914, 1252, 237, 9, 52, "Text"],
Cell[47154, 1263, 248, 4, 92, "Input"],
Cell[47405, 1269, 145, 5, 33, "Text"]
}, Closed]],
Cell[47565, 1277, 712, 21, 125, "Text",
  Evaluatable->False],
Cell[48280, 1300, 245, 7, 33, "Text",
  Evaluatable->False],
Cell[48528, 1309, 774, 25, 79, "Text"],
Cell[49305, 1336, 501, 14, 128, "Text",
  Evaluatable->False],
Cell[49809, 1352, 592, 19, 56, "Text",
  Evaluatable->False],
Cell[50404, 1373, 826, 26, 75, "Text",
  Evaluatable->False],
Cell[51233, 1401, 179, 4, 33, "Text",
  Evaluatable->False],
Cell[51415, 1407, 472, 14, 71, "Text",
  Evaluatable->False],
Cell[51890, 1423, 180, 4, 33, "Text",
  Evaluatable->False],
Cell[52073, 1429, 294, 10, 55, "Text"],

Cell[CellGroupData[{
Cell[52392, 1443, 152, 4, 33, "Text",
  Evaluatable->False],
Cell[52547, 1449, 110, 3, 33, "Text"],
Cell[52660, 1454, 1630, 29, 628, "Input"],
Cell[54293, 1485, 347, 9, 93, "Text"],
Cell[54643, 1496, 492, 10, 196, "Input"],
Cell[55138, 1508, 236, 6, 90, "Text"],
Cell[55377, 1516, 787, 15, 269, "Input"],
Cell[56167, 1533, 153, 5, 52, "Text"],
Cell[56323, 1540, 884, 17, 249, "Input"],
Cell[57210, 1559, 286, 7, 55, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[57533, 1571, 166, 3, 34, "Text"],
Cell[57702, 1576, 1297, 33, 269, "Text"]
}, Closed]],
Cell[59014, 1612, 473, 16, 57, "Text"]
}, Open  ]],
Cell[59502, 1631, 580, 20, 35, "Text"],
Cell[60085, 1653, 596, 20, 35, "Text"],
Cell[60684, 1675, 577, 20, 35, "Text"],
Cell[61264, 1697, 339, 13, 57, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

