(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     65522,       1808]*)
(*NotebookOutlinePosition[     89887,       2693]*)
(*  CellTagsIndexPosition[     89779,       2686]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["COMPLEX ANALYSIS: ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Mathematica 4.1",
    FontSize->18,
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" Notebooks\n(c) John H. Mathews, and\nRussell W. Howell, 2002",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Complimentary software to accompany our textbook:",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]]
}], "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["COMPLEX ANALYSIS: for Mathematics and Engineering, \n4th Edition, \
 2001,  ISBN: ",
    FontSize->18,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["0-7637-1425-9",
    FontFamily->"Times New Roman",
    FontSize->18,
    FontColor->RGBColor[0, 0, 0.996109]],
  StyleBox["\n",
    FontSize->18,
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[ButtonBox["Jones & Bartlett Publishers, Inc.",
    ButtonData:>{
      URL[ "http://www.jbpub.com/"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" \n",
    FontSize->18,
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["40 Tall Pine Drive, Sudbury, MA 01776  \nTele.  (800) 832-0034, \
FAX:  (508)  443-8000  \nE-mail:  mkt@jbpub.com  \nInternet:  ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["http://www.jbpub.com/",
    ButtonData:>{
      URL[ "http://www.jbpub.com/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox["  ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n",
    FontSize->14],
  StyleBox["This free software is compliments of the authors.\n",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  ButtonBox["John H. Mathews",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[",   ",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["mathews@fullerton.edu \n",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  ButtonBox["Russell W. Howell",
    ButtonData:>{
      URL[ "http://www.westmont.edu/~howell"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[", ",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["howell@westmont.edu ",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CHAPTER 4",
    FontSize->18,
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["  ",
    FontSize->18],
  StyleBox["SEQUENCES, JULIA and MANDELBROT SETS, and POWER SERIES",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 4"],

Cell[BoxData[{
    \(\(c = \(q = \(S = \(t = \(x = \(y = \(z = 
                    0\)\)\)\)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[a, absZn, c, cx, cy, dot, i, juliaC, k, lim, limX, limY, limZ, 
        list, mandelbrotC, n, newton, Pn, q, Qn, R, s, S, Sn, set, sum, sumN, 
        sumX, sumY, sumZ, t, table, x, Xn, y, Yn, z, Z, 
        Zn];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Section 4",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".1",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Sequences and Series",
    ButtonData:>{"ca0401.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["Section 4",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".2",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Julia and Mandelbrot Sets",
    ButtonData:>{"ca0402.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Section 4.3",
    FontSize->18,
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["  ",
    FontSize->18],
  StyleBox["Geometric Series and Convergence Theorems",
    FontSize->18,
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001f80@0006@000000000000001D0000E0000
00000000001?0`00C`<00215CDH00040R1d001@00002000000000000002l000080<005P200100@00
l000000000000000000004H0003H3000bP`004M4BD<1002000<00393]ST00000/P`000402@000eT6
00010284000000T0000V1Pl0201OATeBBE@Y80<0000N00D0000;0P0000050000308O01l01@800?L0
00<00@00001gMgL0EEEE0<`0b`3^k^h0IP1U0?g;0028R8P006Gm0?ooo`14A4@08R8R000000000000
00000000003k:O00M`400000e03b4P00b8/G002ni@110;`0lQ800:Cc4P00/?l04P140;OcM`0hc_<0
Mooo0?oob02;5`00^o530038G@0H01P0o18006H00000b8/05`2600:D0@3P_AX000400000b01M6000
C00000260P2D0@0004000<QM6000000000000000000100000>Bn01X0100100000000000000000>00
_AX0063c4P00K000200A000P000000000<R;01L0H01c@000e098001?L01UKP0000<000800000g?<0
4P100>i20004000001810000n00JG`00@cYL06Q_K@1UL640IfEL06MYIP1c04d0HGAX06E]H@1dJF<0
HD9Y06L^I`1YIP00g?<B0007PP3WM`000000000000008000003L0?<B000lm18004mR0?Mgc03c4P00
<0000000000300800000043^@P00kB40igND004200000P000000000060000@00dLjR00lH00000480
000000800000Ha40igN600:D0@0B0@0009G`00004P007`000000002N0P00004000000:QSG`00n1X0
G`3@00PF000C000002H0000000000000G?DB0002<`3]M`00000000PTG`00QP80U04B0040002El000
00000000P03d4P00OUSW07L8901O0000000000040000000000000000003RF>L0M`PT05l000000000
00@00030>P3XMd<0>UaX06m]I@1`HFL0IEaW06UVL`1LCF40M6QU06eQM01YHf40@VUW02iWJ@1V08H0
0Y@100000000RDX0mWM800DD001V000000P00000QP02U040>aM500260P2D0I@00@8001810000@aL0
A@2600:D0@30ma800080000000000000n1YO0007002:0A00mA8009XAk@1ge`@00GD7002:0@0N0`00
00000000J0035P000001003Hm@0B06@0BZ]g09810P00G?D04P0>05_WM`30RaL00000000000005000
8040000800000040000008Se4P00/bP0l7L0000D000800@001P10000IP000000IP0000260P2D0ML0
105e00000000208000000000001f0P00053e018000000000/?lB0014]`3cMlP0cO=g0?ooo`3o1HH0
@`2600:D0@040000=08000<0000e00D000070@<0000R1000@`lP0<`0000P02000000020080000000
:0000200000P00000@08000000001000a0h00<@>00000@0000000000001gMgL0EEEE0</0c03^k^h0
I@1V003;o@28R8P0oFD00?ooo`14A4@08R8R00000000000000000000003`:O/0005g0=@000004_80
5h_80>Fn002l044001;b01;cY03o/000A00B07Oc]`3ccSP0oomg0<Soo`005h/0@o6k05g8000H01P0
01;l0000IP2;b000QP0G006D0P0J_N0000400<P0000065d0001<00:600000I@0040001QMb0000000
0000000000000040_^@000@06P00004000000000003P000001Zm01;cH000K0004@08000P00000000
RlP006005`00@7<0B0;D071?0000KVD000<000000P3cg000@00B0012kP0000@00A800?P00000GaX0
G3Y306e_J01QL6D0G6EW06IYI`1=07<0J7AQ065]I@1SJG@0JD9Q06L^I`00IVT04_?L08870000MnL0
0000000000008000g000000Bl`0Bm3`0HTl00<agm`004_<0000`0000000200<0000004;^@00Qk@00
U7OW00020@000P00000001P000000@00X/kA000H3`120000000000000P0AH`00QWOW006D0P000A80
l9D0018000007`00000000:N00010000000005mSZ00Jn000d01O000F200001<002H0000000000000
4_EL03<20000Mnd0000005lT2002QP004P6D00000@00l9D00000080000004_@0ieQn02@8M`0005l0
000000040000000000000000003WF>8090Qg0000G`00000000@003[00013MnP0J5`j06E]K`1WHG00
IeaU07=VJ@1QCE`0IFQd07AQK@1QHfT0IfU206UW;P2606H00I@20000001:R@00B7Of000D1@0006H0
00P008H00001U080AALk00:6002D0I@0008100014P0G@`00QP15006D0P0Bml000080000000000000
Ga[h0007000@0HX001;e0>dAVP04egL01gD1006:00000ah0000006P000005P<00@000?GH001T0180
Mj]:0081TP3eG0003P0B07OWF`0GRl000000000000005000004P000800010000000001;eR00X/`00
07O`000D000400P00AP006H000000000001V00:6003G0I@0M@440000000220000000000000000WH0
mE0000004P0000004_n`0;M40038Mo<0Mo?=0?ooo`261Ol0QP13006D0P092@T00000000000000000
0000000000000000000000T000071`L71`L71`L71`L71`L71`L71`L71`L71`L000T0000000000000
0000000000000000000000001`002@0410@410@410@410@410@410@410@410@4100700T0000410@4
10@410@410@410@410@410@410@400L000T010@410@400000P4410@41040004410@410@01`002@04
10@410@02000000:100000D0000010@4100700T0000410@4100820011P0000D500030`0410@400L0
00T010@410@400P820001P051@070P0300@410@01`002@0410@4104020P8208000D01`L72`0210@4
100700T0000410@40@0820P8208000L71`L200@410@400L000T010@4104000P820P820071`L71`80
0@@410@01`002@0410@400D5000000000000000000000@@4100700T000040@0000002`X21`080P05
1@0000L000@400L000T010@000L71`L71`L000P820801@0000L000@01`002@0400<300L71`L70006
00P820P000030004100700T000000`<300L71`0000H600P820P00`<010@400L000T010800`<300L0
00D01PH600P800<30`<010@01`002@0410X0000000051@061PH600030`<30`<0100700T0000410@2
0000000000H61PH:00<30`0000@400L000T010@410@:00<30P000000000000000@@410@01`002@04
10@4100500830`<30`<300H6004410@4100700T0000410@1000700<30`<30`001PH010@410@400L0
00T010@410001`L00P<30`<020P01P0410@410@01`002@0410@400L:00000`<30P0020P000@410@4
100700T0000410@0000110400`80108000P010@410@400L000T010@410@410@4100300@410@10004
10@410@01`002@0410@410@410@4100410@410@40P@410@4100700T0000410@410@410@410@410@4
10@410@410@400L000T010@410@410@410@410@410@410@410@410@01`002@0410@410@410@410@4
10@410@410@410@410002@T000000000000000000000000000000000000000T9100002L1ool30000
00000140000<0000200000/0000@00005@0001D000090000400001D0000E00008@0000P0000:0000
40000000000000002@000100000O00007`000340000@10000@00000300400000MgMg05EEE@3<0</0
k^k^06H0I@3mb`00R8R8001Uo@3oool0A4A4028R8P0000000000000000000000nbW`07L100000=@0
lQ800<R;5`00_^D0@@2l0?8B002Tla800;3o0180A02glgL0><kc07Ooo`3oolP0RaL00;_a@`00b5d0
600H0?`B001V00000<R;01L0QP02U040h;dJ000100000<P0GAP004`00000QP80U04000100038GAP0
00000000000000000@00003T_P0J00@00@00000000000000003P0;dJ001Pla8006`000P04@008000
00000038R`0G0600Ld000=@2B000Cg00IFh00003000200000=cc0180@03^@P001000000B0@000?P0
6Ul004<jG01XKfd0IG1Q06MUG01WJFH0L`1=065dJ01UKF40M6US0652J@1W;VL0JFH00=cc4P001h80
igL000000000000002000000g03c4P00??@B001?HP3gMl`0la800300000000000`0200000010kT80
0>dQ0>MgU0010P0000800000000001P000400=7>XP0?6000001200000002000006<A0>MgQP02U040
4P40002El000018001l000000000WP8000010000002XHel00?PJ05l0d0085P004`00000V00000000
000005ce4P000S<0kGL00000000895l008H209@14P010000UO00000000000800m18007iHi`1g22@0
G`000000000010000000000000000000hUSW07L8901O0000000000040000`3X0j7M303YLJ01_KFD0
L65W06ELI`1YIW<0G4eQ07AXI@1]HG@0JF=Q049YI`0^IfT0IP2600:D0@00000008U:0?IgB0055000
IP000008000008H00Y@103/GA@00QP80U06D0042000B0@0004<G04D0QP02U040`?LB000200000000
00000?PJG`001`00RP4@0?DB002J4Nd0MmL4005e1`00RP407P<00000000006P00aH000000@00f?D0
4P1T04Z[M`2B0@8005ce01803P1KigL0`8/G00000000000001@0020100002000000100000028mA80
0;<X0?1g000050002004000H0@0006H0000006H00000QP80U07G00@1M@00000000P2000000000000
MP80001@m@0B000000000;3o4P00A;L0lgO80<gcM`3oool0o`F604<0QP02U040<00000`000010000
=00000P0000E0000300000<0001A0000N0P00000000000005@0001D0000000000000000000000000
80000200001@0000:0@007P40000100000000200c00P0000800002P0000P00008000004020000000
00@00<@>00343P000040000000000000MgMg05EEE@3;0<`0k^k^06D0IP00bod0R8R80?eU003oool0
A4A4028R8P0000000000000000000000l2Wk0001M`3D000001;b01N;b03U_P00_011000BlP0Blj@0
ok0004@04P1glkL0llhh0?ooM`38ool001N;04?a^`1Mb000600H000Bo00006H0RlP008H05`01U080
6[gP00010038000001QM0000C002QP00006D0010000HGLP0000000000000000000010;kT000401X0
0001000000000000h000000J_@0Blf0006`0014020008000000008_8001P01L0041c04P2e01`C`00
06iU000300000080lm`004004P00@^h00004004B003h000005lJ05`j@`1]KfP0HG1U05aUI`1VJFL0
C@1c06QdH@1QKFD0HfUd06U2H@1W;VL006IY01;cg0221`0007OW00000000000002000=`000004_<0
4_@l069?003<MoL001;c0000<00000000P0300000012kT008Nd009Agi`000P4000800000000H0000
00400:;>d@0060l0@P000000000000804F<008Igi`01U080004B0?2E000B000001l000000002WP00
0@000000001OHjP06_P00=00G`005PP0000C000V00000000000001;eG00c0P0007O]0000001O90P0
0XH00181U00000400?2E00000020000001;d0>MHOP0T27L0001O0000000010000000000000000000
ieSR02@8M`0005l000000004000j`000@gOX06QL>P1UKFl0If5`06MLI@1cIVT0HDeL06EXM01dHFd0
HF=Y06MY@P1YIbh0QP1V006D0P000000BXT004QgmP0050D0001V0008002600000I@204DG>`02QP00
U06D00020@000A805d<008H0A@01U0804_O0000200000000000005lJn0001`00406:000Bm@3]4IX0
1=Mg00Me0@01RP0000<N0000001X000001H30040003ef000I00B07N[BP020I80mE`000h04P1gie/0
5h_000000000000001@00001800020000@000000000BmHP0:;<0001gl00050001008004H001V0000
00000000IP02QP00e`6D07D1100000000PP0000000000000009f0?E@00000180000001;o/02gA000
b7Oc07Occ@3oool0QPGo08H0@`01U0802@T900000000000000000000000000000000000000090000
1`L71`L71`L71`L71`L71`L71`L71`L71`L7000900000000000000000000000000000000000000L0
00T010@410@410@410@410@410@410@410@410@01`09000010@410@410@410@410@410@410@410@4
1007000900@410@41000008110@410@1000110@410@400L000T010@410@400P000002P@000050000
00@410@01`09000010@410@020P00@H000051@000`<010@41007000900@410@4100820P000H01@D0
1`800`0410@400L000T010@410@100P820P2000500L71`/00P@410@01`09000010@4104020P820P2
00071`L70P0410@41007000900@410@1000820P820P01`L71`L2004410@400L000T010@410051@00
0000000000000000004410@01`0900001040000000/:0PL020801@D0000700041007000900@40007
1`L71`L7000820P200D00007000400L000T010030`071`L71`001P0820P800000`0010@01`090000
00<30`071`L000061P0820P800<300@41007000900@200<30`07000500H61P0820030`<300@400L0
00T010@:000000001@D01PH61P000`<30`<300@01`09000010@40P00000000061PH62P030`<00004
1007000900@410@42P030`80000000000000004410@400L000T010@410@01@020`<30`<30`061P01
10@410@01`09000010@40@001`030`<30`<000H600@410@41007000900@410@000L700830`<300P8
00H010@410@400L000T010@410072P0000<30`8000P8000410@410@01`09000010@400000@@100<2
00@2000800@410@41007000900@410@410@410@00`0410@40@0010@410@400L000T010@410@410@4
10@010@410@4108410@410@01`09000010@410@410@410@410@410@410@410@41007000900@410@4
10@410@410@410@410@410@410@400L000T010@410@410@410@410@410@410@410@410@000T90000
0000000000000000000000000000000000092B80000<0000ooooobD0000<00001`00P2D0000<0000
0000P300000<00003`00P4/0000@0000000000D0000X000030000040000>000010<00;`0000@0000
000007MgM`1EEED0c03;0>k^kP1V06D0oL/008R8R000IOd0oooo04A4A00R8R80nbW`07L100000=@0
lQ800<R;5`00_^D0@@2l0:Cc4P00/?l04P140;OcM`0hc_<0Mooo0?oob02;5`00^o530038G@0H01P0
o18006H00000b8/05`2600:D0@3P_AX000400000b01M6000C00000260P2D0@0004000<QM60010000
0>Bn01X010000>00_AX0063c4P00K000200A000P000G0600Ld000=@2B000Cg00IFh0000300020000
0=cc0180@03^@P001000000B0@000?P06Ul004<jG01XKfd0IG1Q06MUG01WJFH0L`1=065dJ01UKF40
M6US0652J@1W;VL0JFH00=cc4P001h80igL00000g03c4P00??@B001?HP3gMl`0<00000<00P10kT80
0>dQ0>MgU0010P0000800000603AcZ803aP00000@P00Ha40igN601810000UO00000B000O0000WP80
00010:QSG`00n1X0G`3@00PF000C000002H005ce4P000S<0kGL000PTG`2D0A80UO000000P03d4P00
OUSW07L8901O000000@00>9Hi`00`3X0j7M303YLJ01_KFD0L65W06ELI`1YIW<0G4eQ07AXI@1]HG@0
JF=Q049YI`0^IfT0IP260029BP3fMdP01A@00008000008H0>aM509@1U000@aL0A@260<3g4P3h6Ul0
00L008X1403e4P00VQ7]07OG1001M@L008X101h3000006P00aH0003Hm@0B06@0BZ]g09810P00G?D0
4P0>05_WM`30RaL001@002010028mA800;<X0?1g000800@001P10000IP2D0ML0105e00080P1f0P00
053e0180002`oa8004Bg0?=gb03=lgL0o`F604<0QP040`00
\>"], "Graphics",
    ImageSize->{21, 21}],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"Section 4.3"],

Cell[TextData[{
  "\n\tWe begin this section by studying series of the form ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity] z\^n\)]],
  ", which is called a ",
  StyleBox["geometric series",
    FontSlant->"Italic"],
  ", one of the most important series in mathematics."
}], "Text"],

Cell[TextData[{
  StyleBox["\nTheorem 4.11,  Page 144.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ButtonBox["Geometric Series",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/GeometricSeries.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  " If  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ",  the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity] z\^n\)]],
  "  ",
  StyleBox["converges",
    FontSlant->"Italic"],
  " to  ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(1\  - \ z\)\)]],
  ".  That is, if ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  " then  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(\[Sum]\+\(n = 0\)\%\[Infinity] z\^n\)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(\(1 + z + z\^2 +  ... \) + z\^k +  ... \)]],
  " ",
  Cell[BoxData[
      \(\(\(=\)\(1\/\(1\  - \ z\)\)\)\)]],
  ".  \n\nIf  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(\[GreaterEqual]\)\(1\)\)\)\)]],
  ",  the ",
  StyleBox["series diverges",
    FontSlant->"Italic"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Proof of Theorem 4.11,  see text Page 144.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\nCorollary 4.2,  Page 145. ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  " If  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(1\)\)\)\)]],
  ",  the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] z\^\(-n\)\)]],
  "  ",
  StyleBox["converges",
    FontSlant->"Italic"],
  " to  ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(z - \ 1\)\)]],
  ".  That is, if ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(1\)\)\)\)]],
  " then  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(\[Sum]\+\(n = 1\)\%\[Infinity] z\^\(-n\)\)\(=\)\)\)]],
  Cell[BoxData[
      \(\(z\^\(-1\) + z\^\(-2\) +  ... \) + z\^\(-4\) +  ... \)]],
  " ",
  Cell[BoxData[
      \(\(\(=\)\(1\/\(z - \ 1\)\)\)\)]],
  ",  \nor equivalently,\n\t\t\t",
  Cell[BoxData[
      \(\(\(-\(\[Sum]\+\(n = 1\)\%\[Infinity] z\^\(-n\)\)\)\(=\)\)\)]],
  Cell[BoxData[
      \(\(z\^\(-1\) - z\^\(-2\) -  ... \) - z\^\(-4\) -  ... \)]],
  " ",
  Cell[BoxData[
      \(\(\(=\)\(1\/\(1 - z\)\)\)\)]],
  ".  \n\nIf  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(\[LessEqual]\)\(1\)\)\)\)]],
  ",  the ",
  StyleBox["series diverges",
    FontSlant->"Italic"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Proof of Corollary 4.2,  see text Page 145.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\nCorollary 4.3,  Page 146. ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  " If  ",
  Cell[BoxData[
      \(z \[NotEqual] 1\)]],
  ", then for all n,  \n\n\t\t\t",
  Cell[BoxData[
      \(1\/\(1\  - \ z\) = \(1 + z + z\^2 +  ... \) + z\^\(n - 1\) + 
          z\^n\/\(1\  - \ z\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Proof of Corollary 4.3,  see text Page 146.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.13,  Page 146.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\((1\  - \ \[ImaginaryI])\)\^n\/2\^n = 
        1 - \[ImaginaryI]\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
We can use the definition of convergence of a series and find the \
limit of the partial sums.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", \(Remove[S, z];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Clear[k, lim, n, sum, Z];\), " "}], "\n", 
    RowBox[{\(z\_k_\  = \ \((1\  - \ \[ImaginaryI])\)\^k\/2\^k;\), 
      " "}], "\n", 
    RowBox[{
      RowBox[{\(S\_n_\  = \[Sum]\+\(k = 0\)\%n\((1 - \
\[ImaginaryI])\)\^k\/2\^k\), 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{
      RowBox[{\(sum\  = \[Sum]\+\(k = 0\)\%\[Infinity]\((1 - \[ImaginaryI])\)\
\^k\/2\^k\), 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"lim", " ", "=", " ", 
          RowBox[{"Limit", "[", 
            RowBox[{\(S\_n\), ",", 
              RowBox[{"n", 
                StyleBox["\[Rule]",
                  FontWeight->"Plain"], 
                StyleBox["\[Infinity]",
                  FontWeight->"Plain"]}]}], "]"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(z\_k\) = \>\"", z\_k];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(S\_n\) = \!\(\[Sum]\+\(k = 0\)\%n\)\!\(\((1 - \
\[ImaginaryI])\)\^k\/2\^k\) = \>\"", S\_n];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", \
\*"\"\<\!\(S\_n\) = \>\"", lim];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^k\/2\^k\) = \>\"", sum];\), " "}], "\[IndentingNewLine]", 
  "Null"}], "Input"],

Cell[TextData[{
  "\nOr we can see that this is an infinite geometric series with ratio  ",
  Cell[BoxData[
      \(Z = 1\/2 - \[ImaginaryI]\/2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Z\  = \ 
        z\_\(k + 1\)\/z\_k;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(z\_k\) = \>\"", z\_k];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_\(k + 1\)\) = \>\"", z\_\(k + 1\)];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<  Z = \!\(z\_\(k + 1\)\/z\_k\) = \>\"", 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\

The sum of the infinite geometric series is now found.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print["\<          Z = \>", Z];\)\ \), "\n", 
    \(\(Print["\<        |Z| = \>", Abs[Z]];\)\ \), "\n", 
    \(\(Print["\<     Is |Z| < 1 ?  \>", Abs[Z] < \ 1];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<      \!\(1\/\(1 - Z\)\) = \!\(1\/\(1 - \((1\/2 - \
\[ImaginaryI]\/2)\)\)\)\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<      \!\(1\/\(1 - Z\)\) = \>\"", \ 
        1\/\(1 - \((1\/2 - \(\(\ \)\(\[ImaginaryI]\)\)\/2)\)\)];\)\ \), "\n", \

    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^k\/2\^k\) = \>\"", \[Sum]\+\(k = 0\)\%\[Infinity]\((1 - \
\[ImaginaryI])\)\^k\/2\^k];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nThe series of absolute values converges, therefore the series converges.\
\n\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(S\_n_\  = \ \[Sum]\+\(k = 0\)\%n\((1 - \
\[ImaginaryI])\)\^k\/2\^k;\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Table[FullSimplify[S\_n], {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^k\/2\^k\) = \>\"", \[Sum]\+\(k = 0\)\%\[Infinity]\((1 - \
\[ImaginaryI])\)\^k\/2\^k];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(set\  = \ \ Table[{Re[S\_n], Im[S\_n]}, {n, 0, 
            15}];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[set, 
        Prolog \[Rule] {PointSize[0.021], 
            Blue}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
              1.55}, {\(-1.3\), 
              0.0}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1.6, 0.2], 
            Range[\(-1.4\), 0, 0.2]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^k\/2\^k\) = \>\"", sum];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the sum of the infinite geometric series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\((1\  - \ \
\[ImaginaryI])\)\^n\/2\^n\ \ \ is\ \ \ 1 - \[ImaginaryI]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.14,  Page 146.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate  ",
  Cell[BoxData[
      StyleBox[\(\[Sum]\+\(n = 3\)\%\[Infinity]\(\(\ \)\(\[ImaginaryI]\^n\)\)\
\/2\^n\),
        FontSize->14]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
We can use the definition of convergence of a series and find the \
limit of the partial sums.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", \(Remove[S, z];\), " "}], "\n", 
    RowBox[{\(Clear[k, lim, n, sum, Z];\), " "}], "\n", 
    RowBox[{\(z\_k_\  = \(\(\ \)\(\[ImaginaryI]\^k\)\)\/2\^k;\), " "}], "\n", 
  
    RowBox[{
      RowBox[{
        RowBox[{\(S\_n_\), " ", "=", " ", 
          StyleBox[\(\[Sum]\+\(k = 3\)\%\[Infinity] \[ImaginaryI]\^k\/2\^k\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"sum", " ", "=", " ", 
          
          StyleBox[\(\[Sum]\+\(k = 3\)\%\[Infinity]\(\(\ \)\(\[ImaginaryI]\^k\
\)\)\/2\^k\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"lim", " ", "=", " ", 
          RowBox[{"Limit", "[", 
            RowBox[{\(S\_n\), ",", 
              RowBox[{"n", 
                StyleBox["\[Rule]",
                  FontWeight->"Plain"], 
                StyleBox["\[Infinity]",
                  FontWeight->"Plain"]}]}], "]"}]}], ";"}], " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(z\_k\) = \>\"", z\_k];\), " "}], "\n", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(S\_n\) = \!\(\[Sum]\+\(k = 3\)\%n\)\!\(\
\[ImaginaryI]\^k\/2\^k\) = \>\"", S\_n];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<      \!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", \
\*"\"\<\!\(S\_n\) = \>\"", lim];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<     \!\(\[Sum]\+\(k = 3\)\%\[Infinity]\)\!\(\
\[ImaginaryI]\^k\/2\^k\) = \>\"", sum];\), " "}]}], "Input"],

Cell[TextData[{
  "\nOr we can see that this is an infinite geometric series with ratio  ",
  Cell[BoxData[
      \(Z = \[ImaginaryI]\/2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Z\  = \ 
        z\_\(k + 1\)\/z\_k;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(z\_k\) = \>\"", z\_k];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_\(k + 1\)\) = \>\"", z\_\(k + 1\)];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<  Z = \!\(z\_\(k + 1\)\/z\_k\) = \>\"", 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\

The sum of the infinite geometric series is now found.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", \(a\  = \ z\_3;\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<        a = (\!\(\[ImaginaryI]\/2\)\!\(\()\^3\)\) \
= \>\"", a];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print["\<        Z = \>", Z];\), " "}], "\n", 
    RowBox[{\(Print["\<      |Z| = \>", Abs[Z]];\), " "}], "\n", 
    RowBox[{\(Print["\<   Is |Z| < 1 ?  \>", Abs[Z] < \ 1];\), " "}], "\n", 
    RowBox[{\(Print["\< \>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<     \!\(a\/\(1 - Z\)\) = \!\(\((\[ImaginaryI]\/2)\
\)\^3\/\(1 - \[ImaginaryI]\/2\)\)\>\""];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<     \!\(a\/\(1 - Z\)\) = \>\"", a\/\(1 - Z\)];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<    \!\(\[Sum]\+\(k = \
3\)\%\[Infinity]\)\!\(\[ImaginaryI]\^k\/2\^k\) = \>\"", ",", 
            
            StyleBox[\(\[Sum]\+\(k = 3\)\%\[Infinity] \
\[ImaginaryI]\^k\/2\^k\),
              FontSize->14]}], "]"}], ";"}], " "}]}], "Input"],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\(S\_n_\), " ", "=", " ", 
          StyleBox[\(\[Sum]\+\(k = 3\)\%n \[ImaginaryI]\^k\/2\^k\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\[IndentingNewLine]", 
    RowBox[{\(table = Table[FullSimplify[S\_n], {n, 0, 10}];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(table = Append[table, "\<...\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", table];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", N[table]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(\[Sum]\+\(k = 3\)\%\[Infinity]\)\!\(\[ImaginaryI]\^k\/2\^k\
\) = \>\"", ",", 
            StyleBox["sum",
              FontSize->14]}], "]"}], ";"}], " "}]}], "Input"],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      "\[IndentingNewLine]", \(set\  = \ \ Table[{Re[S\_n], Im[S\_n]}, {n, 0, 
              10}];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(ListPlot[set, 
          Prolog \[Rule] {PointSize[0.02], 
              Magenta}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.05\), 
                0.55}, {\(-0.55\), 
                0.05}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", \
"\<y\>"}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 0.5, 0.1], 
              Range[\(-0.5\), 0, 0.1]}];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", N[table]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(\[Sum]\+\(k = 3\)\%\[Infinity]\)\!\(\[ImaginaryI]\^k\/2\^k\
\) = \>\"", ",", 
            StyleBox["sum",
              FontSize->14]}], "]"}], ";"}], " "}]}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the sum of the infinite geometric series  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Sum]\+\(n = 3\)\%\[Infinity]\),
            FontSize->14], 
          RowBox[{
            StyleBox[\(\(\(\ \)\(\[ImaginaryI]\^n\)\)\/2\^n\),
              FontSize->14], 
            StyleBox["  ",
              FontSize->14], 
            StyleBox["is",
              FontSize->14], 
            StyleBox["  ",
              FontSize->14], \(1\/20\)}]}], "-", \(\[ImaginaryI]\/10\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Remark 4.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The equality given by this example illustrates an important point when \
evaluating a geometric series whose beginning index is other than zero. The \
value of ",
  Cell[BoxData[
      \(\[Sum]\+\(n = r\)\%\[Infinity] z\^n\)]],
  " equals",
  Cell[BoxData[
      \(z\^r\/\(1\  - \ z\)\)]],
  ". If we think of z as the \"ratio'' by which a given term of the series is \
multiplied to generate successive terms, we see that the sum of a geometric \
series equals ",
  Cell[BoxData[
      \(\(first\ term\)\/\(1\  - \ ratio\)\)]],
  ", provided  ",
  Cell[BoxData[
      \(\(\(|\)\(ratio\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\n\tThe geometric series is used in the proof of theorem 4.12 and is known \
as the ",
  StyleBox["ratio test",
    FontSlant->"Italic"],
  ". It is one of the most commonly used tests for determining the \
convergence or divergence of series. The proof is similar to the one used for \
real series, and is left for the reader to establish."
}], "Text"],

Cell[TextData[{
  StyleBox["\nTheorem 4.12,  Page 147.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ButtonBox["d'Alembert's Ratio Test",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RatioTest.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] \[Zeta]\_n\)]],
  "  is a complex series with the property that  \n\n\t\t\t",
  Cell[BoxData[
      \(lim\+\(n\  \[Rule] \ \[Infinity]\)\ \(\(|\)\(\[Zeta]\_\(n + \
1\)\)\(|\)\)\/\(\(|\)\(\[Zeta]\_n\)\(|\)\) = L\)]],
  ",  \n\nthen the series converges absolutely if  ",
  Cell[BoxData[
      \(TraditionalForm\`L < 1\)]],
  "  and diverges if  ",
  Cell[BoxData[
      \(TraditionalForm\`L > 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Proof of Theorem 4.12,  see text Page 147.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.15,  Page 147.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\(\(\ \)\(\[Sum]\+\(n = 0\)\%\[Infinity]\((1\  - \ \
\[ImaginaryI])\)\^n\/\(n!\)\)\)\)]],
  "  converges."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.15.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the formula for the terms in the series.", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[L, n, sum, r];\)\ \), "\n", 
    \(\(z\_n_\  = \ \(\(\((1\  - \ \[ImaginaryI])\)\^n\)\(\ \)\)\/\(n!\);\)\ \
\), "\n", 
    \(\(Print[\*"\"\<\!\(z\_n\) = \>\"", 
        z\_n];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
  
Use d'Alembert's ratio test. First, find the ratio of consecutive \
terms.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print[\*"\"\<         \!\(z\_\(n + 1\)\) = \>\"", 
        z\_\(n + 1\)];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_n\) = \>\"", z\_n];\)\ \), "\n", 
    \(\(r\  = \ z\_\(n + 1\)\/z\_n;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<        \!\(z\_\(n + 1\)\/z\_n\) = \>\"", 
        r];\)\ \), "\[IndentingNewLine]", 
    \(\(r\  = \ FullSimplify[r];\)\ \), "\n", 
    \(\(Print[\*"\"\<        \!\(z\_\(n + 1\)\/z\_n\) = \>\"", 
        r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<       |\!\(z\_\(n + 1\)\/z\_n\)| = \>\"", 
        Abs[Numerator[r]]\/Denominator[r]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(L\  = \ Limit[\ r\ , \ n \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(Print[\*"\"\<L = \!\(lim\+\(n \[Rule] \[Infinity]\)\) |\!\(z\_\(n + 1\
\)\/z\_n\)| = \>\"", L];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nSince L < 1, the series converges.   \n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the sum of series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(sum\ \  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\((1 - \
\[ImaginaryI])\)\^n\/\(n!\);\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^n\/\(n!\)\) = \>\"", sum];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(S\_n_\  = \ \[Sum]\+\(k = 0\)\%n\((1 - \
\[ImaginaryI])\)\^k\/\(k!\);\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Table[FullSimplify[S\_n], {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^n\/\(n!\)\) = \>\"", sum];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(set\  = \ \ Table[{Re[S\_n], Im[S\_n]}, {n, 0, 
            10}];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[set, 
        Prolog \[Rule] {PointSize[0.022], 
            Orange}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.05\), 
              2.35}, {\(-2.35\), 
              0.05}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", \
"\<y\>"}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2.5, 0.5], 
            Range[\(-2.5\), 0, 0.5]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^n\/\(n!\)\) = \>\"", sum];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the infinite series  ",
  Cell[BoxData[
      \(\(\(\ \)\(\[Sum]\+\(n = 0\)\%\[Infinity]\((1\  - \ \
\[ImaginaryI])\)\^n\/\(n!\)\)\)\)]],
  "  converges and that its sum is  ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(1 - \[ImaginaryI]\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.16,  Page 147.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\((z\  - \ \
\[ImaginaryI])\)\^n\/2\^n\)]],
  " converges for all  z  in the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the formula for the terms in the series.", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[L, n, sum, r, Z];\)\ \), "\n", 
    \(\(z\_n_\  = \ \((z\  - \ \[ImaginaryI])\)\^n\/2\^n;\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_n\) = \>\"", 
        z\_n];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\

Use d'Alembert's ratio test. First, find the ratio of consecutive \
terms.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(r\  = \ 
        z\_\(n + 1\)\/z\_n;\)\ \), "\[IndentingNewLine]", 
    \(\(L\  = \ 
        Limit[\ r\ , \ n \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<         \!\(z\_\(n + 1\)\) = \>\"", 
        z\_\(n + 1\)];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_n\) = \>\"", 
        z\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<        \!\(z\_\(n + 1\)\/z\_n\) = \>\"", 
        r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<L = \!\(lim\+\(n \[Rule] \[Infinity]\)\) |\!\(z\_\(n + 1\
\)\/z\_n\)| = \>\"", Abs[L]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nWhen  L < 1, the series will converge.  Solve ",
  Cell[BoxData[
      \(\(\(|\)\(\(z\  - \ \[ImaginaryI]\)\/2\)\(|\)\(\(<\)\(1\)\)\)\)]],
  "  and obtain the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  ".  \n\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the sum of the infinite series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\(f[z_]\), " ", "=", " ", 
          
          StyleBox[\(\[Sum]\+\(n = 0\)\%\[Infinity]\((z - \[ImaginaryI])\)\^n\
\/2\^n\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{\(Print[\*"\"\<f[z] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(\((z - \[ImaginaryI])\)\^n\/2\^n\) = \>\"", f[z]];\), 
      " "}]}], "Input"],

Cell[TextData[{
  "\nWe can investigate the convergence by plotting several partial sums of \
this series.\n\nSince convergence will be more rapid in a smaller disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(r\)\)\)\)]],
  ",  the following plot will be a smaller disk with  ",
  Cell[BoxData[
      \(r = 1\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", \(Clear[F, G, m];\), " "}], "\n", 
    RowBox[{\(F[z_]\  = \ f[z + \[ImaginaryI]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(S[z_, n_]\), "=", 
          StyleBox[\(\[Sum]\+\(n = 0\)\%n\((z - \[ImaginaryI])\)\^n\/2\^n\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\[IndentingNewLine]", \(For\ [m = 3, 
      m \[LessEqual] 5, \(m++\), \nG[z_]\  = \ S[z + \[ImaginaryI], m]; \ \n
      PolarMap[G\ , {0, 1.0, 0.2}, {0, 
          2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
              2}, {\(-0.7\), 0.7}}, 
        AspectRatio \[Rule] 
          7\/10, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2, 1], 
            Range[\(-1\), 1, 1\/2]}, AxesLabel \[Rule] {"\<u\>", "\<u\>"}, 
        PlotStyle \[Rule] {Green, 
            DarkGreen}]; \ \[IndentingNewLine]Print["\<S[z,\>", 
        m, "\<] = \>", S[z, m]];\ \ ]\), "\[IndentingNewLine]", 
    RowBox[{\(PolarMap[
          F\ , {0, 1.0, 0.2}, {0, 
            2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
                2}, {\(-0.7\), 0.7}}, 
          AspectRatio \[Rule] 
            7\/10, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2, 1], 
              Range[\(-1\), 1, 1\/2]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, Magenta}];\), " "}], "\[IndentingNewLine]", 
  
    RowBox[{\(Print["\<f[z] = \>", f[z]];\), " "}]}], "Input"],

Cell[TextData[{
  "\nConvergence will be slower in a larger disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(r\)\)\)\)]],
  ",  the following plot will be from a larger disk with  ",
  Cell[BoxData[
      \(r = 1.6\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", \(Clear[F, G, j, m];\), " "}], "\n", 
    RowBox[{\(F[z_]\  = \ f[z + \[ImaginaryI]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(S[z_, n_]\), "=", 
          StyleBox[\(\[Sum]\+\(n = 0\)\%n\((z - \[ImaginaryI])\)\^n\/2\^n\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\[IndentingNewLine]", \(For\ [j = 3, 
      j \[LessEqual] 5, \(j++\), \[IndentingNewLine]m = 
        5*j; \ \[IndentingNewLine]G[z_]\  = \ 
        S[z + \[ImaginaryI], m]; \ \[IndentingNewLine]PolarMap[
        G\ , {0, 1.6, 0.2}, {0, 
          2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
              2}, {\(-0.7\), 0.7}}, 
        AspectRatio \[Rule] 
          7\/10, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2, 1], 
            Range[\(-1\), 1, 1\/2]}, AxesLabel \[Rule] {"\<u\>", "\<u\>"}, 
        PlotStyle \[Rule] {Cyan, 
            Blue}]; \ \[IndentingNewLine]Print["\<S[z,\>", m, "\<] = \>", 
        S[z, m]];\ \ ]\), "\[IndentingNewLine]", 
    RowBox[{\(PolarMap[
          F\ , {0, 1.6, 0.2}, {0, 
            2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
                2}, {\(-0.7\), 0.7}}, 
          AspectRatio \[Rule] 
            7\/10, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2, 1], 
              Range[\(-1\), 1, 1\/2]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, Magenta}];\), " "}], "\[IndentingNewLine]", 
  
    RowBox[{\(Print["\<f[z] = \>", f[z]];\), " "}]}], "Input"],

Cell["\<\

We see that the sequence of functions {S[x,n]} is converging to f[z].\
\>", \
"Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(funs = 
        Table[{s\_m[z], "\<=\>", S[z, m]}, {m, 1, 
            5}];\)\ \), "\[IndentingNewLine]", 
    \(\(funs = 
        Append[funs, {"\<...\>", "\<\>", "\<...\>"}];\)\ \), "\
\[IndentingNewLine]", 
    \(\(funs = 
        Append[funs, {"\<f[z]\>", "\<=\>", 
            f[z]}];\)\ \), "\[IndentingNewLine]", 
    \(\(\(TableForm[funs]\)\(\[IndentingNewLine]\)
    \)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\n\tOur next result, known as the ",
  StyleBox["root test",
    FontSlant->"Italic"],
  ", is slightly more powerful than the ratio test. Before we state this \
test, we need to discuss a rather sophisticated idea that it uses---the ",
  StyleBox["limit supremum",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 4.9 (Limit Supremum), Page 148.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \({t\_n}\)]],
  "  be a sequence of positive real numbers.  The ",
  StyleBox["limit supremum",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " of the sequence  (denoted by ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n\  \[Rule] \ \[Infinity]\)\ t\_n\)]],
  ")  is the smallest real number  L  with the property that for any  ",
  Cell[BoxData[
      \(\[Epsilon] > 0\)]],
  "  there are at most finitely many terms in the sequence that are larger \
than  ",
  Cell[BoxData[
      \(L + \[Epsilon]\)]],
  ".  If there is no such number  L,  then we set  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n\  \[Rule] \ \[Infinity]\)\ t\_n = \[Infinity]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.17,  Page 148.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The limit supremum of the sequence ",
  Cell[BoxData[
      \({t\_n} = {4.1, 5.1, 4.01, 5.01, 4.001, 5.001,  ... }\)]],
  "  is  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n = 5\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "In this case the even terms  ",
  Cell[BoxData[
      \(t\_\(2\ k\) = 4 + 10\^\(\(-1\) - k\)\)]],
  "  tend to the limit 4 and the odd terms  ",
  Cell[BoxData[
      \(t\_\(2\ k + 1\) = 5 + 10\^\(\(-1\) - k\)\)]],
  "  tend to the limit 5."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[limsup, k, n, table];\)\ \), "\[IndentingNewLine]", 
    \(\(t\_\(even, k_\) = 
        4 + 1\/10\^\(k + 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(t\_\(odd, k_\) = 5 + 1\/10\^\(k + 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(lim1 = 
        Limit[t\_\(even, k\), 
          k \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim2 = Limit[t\_\(odd, k\), k \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(limsup = Max[lim1, lim2];\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Flatten[Table[{t\_\(even, k\), t\_\(odd, k\)}, {k, 0, 
              4}]];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(t\_\(2  k\)\) = (\>\"", 
        t\_\(even, k\), "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(t\_\(2  k + 1\)\) = (\>\"", 
        t\_\(odd, k\)\ , "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(k \[Rule] \[Infinity]\)\) \!\(t\_\(2  k\)\) \
= \!\(lim\+\(k \[Rule] \[Infinity]\)\) (\>\"", t\_\(even, k\)\ , "\<) = \>", 
        lim1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(k \[Rule] \[Infinity]\)\) \!\(t\_\(2  k + 1\)\
\) = \!\(lim\+\(k \[Rule] \[Infinity]\)\) (\>\"", 
        t\_\(odd, k\)\ , "\<) = \>", lim2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \
Max[\>\"", lim1, "\<,\>", lim2, "\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \
\>\"", limsup];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nThe limit superior is the largest limit point of a subsequence of  ",
  Cell[BoxData[
      \({t\_n}\)]],
  ".  \n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the sequence and look for the largest limit point of a \
subsequence."
}], "Text"],

Cell[BoxData[{
    \(\(pts0 = 
        Table[{Green, Point[N[{2  k, t\_\(even, 2  k\)}]]}, {k, 0, 
            10}];\)\ \), "\[IndentingNewLine]", 
    \(\(pts1 = 
        Table[{Magenta, Point[N[{2  k + 1, t\_\(odd, 2  k + 1\)}]]}, {k, 0, 
            10}];\)\ \), "\[IndentingNewLine]", 
    \(\(pts = Union[pts0, pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[Graphics[pts], Axes \[Rule] Automatic, 
        Prolog \[Rule] PointSize[0.02], PlotRange \[Rule] {{0, 20}, {0, 6}}, 
        AxesLabel \[Rule] {"\<k\>", \*"\"\<\!\(t\_k\)\>\""}, \
\[IndentingNewLine]Ticks \[Rule] {Range[0, 20, 2], 
            Range[0, 6, 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nWe see that the limit supremum of the sequence ",
  Cell[BoxData[
      \({t\_n} = {4.1, 5.1, 4.01, 5.01, 4.001, 5.001,  ... }\)]],
  "  is  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n = 5\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.18,  Page 148.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The limit supremum of the sequence ",
  Cell[BoxData[
      \({t\_n} = {1, 2, 3, 1, 2, 3, 1, 2, 3,  ... }\)]],
  "  is  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n = 3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
In this case there are only three different values for the terms in \
the sequence.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[k];\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Table[1 + Mod[k, 3], {k, 0, 15}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \
Max[1,2,3]\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \
\>\"", Max[1, 2, 3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nThe limit superior is the largest limit point of a subsequence of  ",
  Cell[BoxData[
      \({t\_n}\)]],
  ".  \n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the sequence and look for the largest limit point of a \
subsequence."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(pts0 = 
        Table[{Green, Point[N[{3  k, 1}]]}, {k, 0, 
            10}];\)\ \), "\[IndentingNewLine]", 
    \(\(pts1 = 
        Table[{Blue, Point[N[{3  k + 1, 2}]]}, {k, 0, 
            10}];\)\ \), "\[IndentingNewLine]", 
    \(\(pts2 = 
        Table[{Magenta, Point[N[{3  k + 2, 3}]]}, {k, 0, 
            10}];\)\ \), "\[IndentingNewLine]", 
    \(\(pts = Union[pts0, pts1, pts2];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[Graphics[pts], Axes \[Rule] Automatic, 
        Prolog \[Rule] PointSize[0.02], 
        PlotRange \[Rule] {{0, 30}, {0, 3.5}}, 
        AxesLabel \[Rule] {"\<k\>", \*"\"\<\!\(t\_k\)\>\""}, \
\[IndentingNewLine]Ticks \[Rule] {Range[0, 30, 3], 
            Range[0, 4, 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nWe see that the limit supremum of the sequence ",
  Cell[BoxData[
      \({t\_n} = {1, 2, 3, 1, 2, 3, 1, 2, 3,  ... }\)]],
  "  is  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n = 3\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.19,  Page 148.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The limit supremum of the Fibonacci sequence ",
  Cell[BoxData[
      \(\(\({t\_n}\)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \({1, 1, 2, 3, 5, 8, 13, 21, 34,  ... }\)]],
  " is  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n = \[Infinity]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "In this case the sequence has  ",
  Cell[BoxData[
      \(\[Infinity]\)]],
  "  as its limit, and hence the limit supremum  is also  ",
  Cell[BoxData[
      \(\[Infinity]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[n];\)\ \), "\n", 
    \(\(t\_n_ = \(-\@5\)\/5\ 2\^\(\(-1\) - n\)\ \((1 - \@5)\)\^\(n + 1\)\  + \
\((2\/\(1 + \@5\))\)\^\(\(-1\) - n\)\/\@5;\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Table[Simplify[t\_n], {n, 0, 12}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(t\_n\) = \>\"", 
        t\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \>\"", 
        Limit[t\_n, n \[Rule] \[Infinity]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \
\>\"", Limit[t\_n, n \[Rule] \[Infinity]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the terms in the sequence."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(set\  = \ \ Table[{n, Simplify[t\_n]}, {n, 1, 
            12}];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[set, Prolog \[Rule] {PointSize[0.02], Blue}, 
        PlotRange \[Rule] {{0, 12}, {0, 250}}, 
        AxesLabel \[Rule] {"\<n\>", \*"\"\<\!\(t\_n\)\>\""}, \
\[IndentingNewLine]Ticks \[Rule] {Range[0, 12, 1], 
            Range[0, 250, 50]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the limit supremum of the Fibonacci sequence ",
  Cell[BoxData[
      \({t\_n} = {1, 1, 2, 3, 5, 8, 13, 21, 34,  ... }\)]],
  " is  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n = \[Infinity]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell["\<\

\tThe limit supremum is a powerful idea because the limit supremum of a \
sequence always exists, which is not true for the ordinary limit. However, \
our next example illustrates the fact that if the limit of a sequence does \
exist, it will be the same as the limit supremum.\
\>", "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.29,  Page 149.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The sequence  ",
  Cell[BoxData[
      \({t\_n} = \(\({1 + 1\/n}\)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \({2, 1.5, 1.3 \( \(3\)\(\ \)\)\&_, 1.25, 1.2,  ... }\)]],
  "  has  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n = 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
In this case the sequence has  1  as its limit, and hence the limit \
supremum  is also  1.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[n];\)\ \), "\n", 
    \(\(t\_n_ = 1 + 1\/n;\)\ \), "\[IndentingNewLine]", 
    \(\(table = Table[t\_n, {n, 1, 20}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(t\_n\) = \>\"", 
        t\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \>\"", 
        Limit[t\_n, n \[Rule] \[Infinity]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \
\>\"", Limit[t\_n, n \[Rule] \[Infinity]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the terms in the sequence."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(set\  = \ \ Table[{n, Simplify[t\_n]}, {n, 1, 
            20}];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[set, Prolog \[Rule] {PointSize[0.02], Green}, 
        PlotRange \[Rule] {{0, 20}, {0, 2}}, 
        AxesLabel \[Rule] {"\<n\>", \*"\"\<\!\(t\_n\)\>\""}, \
\[IndentingNewLine]Ticks \[Rule] {Range[0, 20, 2], 
            Range[0, 2, 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
In this case the sequence has  1  as its limit, and hence the limit \
supremum  is also  1.\
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["\n Theorem 4.13,  Page 149.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ButtonBox["Root Test",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RootTest.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] \[Zeta]\_n\)]],
  ",  has  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(lim\ sup\)\+\(n\  \[Rule] \ \[Infinity]\)\), "  ", 
          RadicalBox[
            
            StyleBox[\(\(\[VerticalSeparator]\)\(\(\[Zeta]\_n\)\(\
\[VerticalSeparator]\)\)\),
              FontSize->12], "n"]}], "=", "L"}]]],
  ".  \nThen the series is absolutely convergent if  ",
  Cell[BoxData[
      \(TraditionalForm\`L < 1\)]],
  "  and divergent if  ",
  Cell[BoxData[
      \(TraditionalForm\`L > 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Proof of Theorem 4.10,  Page 149.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  " We leave verification of this as an exercise."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\

\tNote that in applying either Theorems 4.12 or 4.13, if L=1 the convergence \
or divergence of the series is unknown, and further analysis is required to \
determine the true state of affairs.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Section 4.1",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["  ",
    FontSize->16,
    FontWeight->"Bold"],
  StyleBox["Exercises for Geometric Series and Convergence Theorems\n",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0.500008, 0.996109]],
  StyleBox["See textbook page 150.",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Section 4",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".4",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Power Series Functions",
    ButtonData:>{"ca0404.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["GO TO  THE",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox["  ",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox[ButtonBox["Table of Contents",
    ButtonData:>{"content.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "\n"
}], "Text"]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{753, 598},
WindowMargins->{{32, Automatic}, {Automatic, 7}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
CellLabelAutoDelete->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->16,
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 4"->{
    Cell[4362, 144, 355, 12, 35, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 4"]},
  "Section 4.3"->{
    Cell[6464, 216, 10704, 143, 41, "Text",
      Evaluatable->False,
      CellTags->"Section 4.3"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 4", 89534, 2674},
  {"Section 4.3", 89651, 2678}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 615, 20, 109, "Text",
  Evaluatable->False],
Cell[2345, 74, 1980, 65, 248, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4362, 144, 355, 12, 35, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 4"],
Cell[4720, 158, 546, 9, 110, "Input",
  InitializationCell->True]
}, Closed]],
Cell[5281, 170, 575, 20, 32, "Text"],
Cell[5859, 192, 580, 20, 35, "Text"],

Cell[CellGroupData[{
Cell[6464, 216, 10704, 143, 41, "Text",
  Evaluatable->False,
  CellTags->"Section 4.3"],
Cell[17171, 361, 293, 8, 71, "Text"],
Cell[17467, 371, 1240, 45, 156, "Text",
  Evaluatable->False],
Cell[18710, 418, 180, 4, 33, "Text",
  Evaluatable->False],
Cell[18893, 424, 1290, 46, 175, "Text",
  Evaluatable->False],
Cell[20186, 472, 181, 4, 33, "Text",
  Evaluatable->False],
Cell[20370, 478, 448, 16, 93, "Text",
  Evaluatable->False],
Cell[20821, 496, 181, 4, 33, "Text",
  Evaluatable->False],
Cell[21005, 502, 285, 10, 55, "Text"],

Cell[CellGroupData[{
Cell[21315, 516, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[21471, 522, 118, 3, 33, "Text"],
Cell[21592, 527, 1679, 41, 433, "Input"],
Cell[23274, 570, 216, 7, 55, "Text",
  Evaluatable->False],
Cell[23493, 579, 413, 8, 178, "Input"],
Cell[23909, 589, 127, 5, 52, "Text",
  Evaluatable->False],
Cell[24039, 596, 737, 13, 277, "Input"],
Cell[24779, 611, 236, 6, 90, "Text"],
Cell[25018, 619, 810, 15, 280, "Input"],
Cell[25831, 636, 153, 5, 52, "Text"],
Cell[25987, 643, 867, 17, 234, "Input"],
Cell[26857, 662, 274, 8, 55, "Text",
  Evaluatable->False]
}, Closed]],
Cell[27146, 673, 337, 13, 53, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[27508, 690, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[27664, 696, 118, 3, 33, "Text"],
Cell[27785, 701, 1671, 42, 380, "Input"],
Cell[29459, 745, 209, 7, 55, "Text",
  Evaluatable->False],
Cell[29671, 754, 413, 8, 178, "Input"],
Cell[30087, 764, 127, 5, 52, "Text",
  Evaluatable->False],
Cell[30217, 771, 1158, 23, 341, "Input"],
Cell[31378, 796, 158, 5, 52, "Text"],
Cell[31539, 803, 1090, 27, 241, "Input"],
Cell[32632, 832, 153, 5, 52, "Text"],
Cell[32788, 839, 1043, 24, 212, "Input"],
Cell[33834, 865, 605, 19, 56, "Text",
  Evaluatable->False]
}, Closed]],
Cell[34454, 887, 746, 22, 93, "Text"],
Cell[35203, 911, 372, 8, 71, "Text"],
Cell[35578, 921, 881, 27, 137, "Text",
  Evaluatable->False],
Cell[36462, 950, 180, 4, 33, "Text",
  Evaluatable->False],
Cell[36645, 956, 331, 12, 55, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[37001, 972, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[37157, 978, 62, 0, 33, "Text"],
Cell[37222, 980, 325, 7, 145, "Input"],
Cell[37550, 989, 101, 4, 52, "Text"],
Cell[37654, 995, 1022, 18, 362, "Input"],
Cell[38679, 1015, 219, 7, 90, "Text",
  Evaluatable->False],
Cell[38901, 1024, 304, 5, 136, "Input"],
Cell[39208, 1031, 158, 5, 52, "Text"],
Cell[39369, 1038, 753, 14, 268, "Input"],
Cell[40125, 1054, 153, 5, 52, "Text"],
Cell[40281, 1061, 883, 18, 233, "Input"],
Cell[41167, 1081, 345, 11, 55, "Text",
  Evaluatable->False]
}, Closed]],
Cell[41527, 1095, 433, 15, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[41985, 1114, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[42141, 1120, 62, 0, 33, "Text"],
Cell[42206, 1122, 310, 6, 145, "Input"],
Cell[42519, 1130, 99, 4, 52, "Text"],
Cell[42621, 1136, 740, 15, 252, "Input"],
Cell[43364, 1153, 447, 13, 93, "Text",
  Evaluatable->False],
Cell[43814, 1168, 495, 14, 120, "Input"],
Cell[44312, 1184, 365, 9, 90, "Text"],
Cell[44680, 1195, 1545, 32, 443, "Input"],
Cell[46228, 1229, 271, 8, 52, "Text"],
Cell[46502, 1239, 1626, 34, 442, "Input"],
Cell[48131, 1275, 96, 4, 52, "Text"],
Cell[48230, 1281, 434, 11, 130, "Input"]
}, Closed]],
Cell[48679, 1295, 330, 9, 68, "Text"],
Cell[49012, 1306, 850, 25, 87, "Text"],
Cell[49865, 1333, 405, 14, 79, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[50295, 1351, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[50451, 1357, 272, 8, 33, "Text"],
Cell[50726, 1367, 1912, 34, 494, "Input"],
Cell[52641, 1403, 298, 9, 90, "Text"],
Cell[52942, 1414, 775, 15, 170, "Input"],
Cell[53720, 1431, 263, 8, 60, "Text"]
}, Closed]],
Cell[53998, 1442, 396, 14, 57, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[54419, 1460, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[54575, 1466, 107, 3, 33, "Text"],
Cell[54685, 1471, 648, 12, 210, "Input"],
Cell[55336, 1485, 298, 9, 90, "Text"],
Cell[55637, 1496, 893, 19, 210, "Input"],
Cell[56533, 1517, 254, 8, 60, "Text"]
}, Closed]],
Cell[56802, 1528, 464, 16, 76, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[57291, 1548, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[57447, 1554, 215, 8, 33, "Text"],
Cell[57665, 1564, 995, 18, 327, "Input"],
Cell[58663, 1584, 139, 5, 52, "Text"],
Cell[58805, 1591, 565, 11, 150, "Input"],
Cell[59373, 1604, 276, 8, 60, "Text"]
}, Closed]],
Cell[59664, 1615, 302, 6, 68, "Text"],
Cell[59969, 1623, 452, 16, 60, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[60446, 1643, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[60602, 1649, 115, 3, 33, "Text"],
Cell[60720, 1654, 1082, 20, 362, "Input"],
Cell[61805, 1676, 139, 5, 52, "Text"],
Cell[61947, 1683, 561, 11, 150, "Input"],
Cell[62511, 1696, 115, 3, 33, "Text"]
}, Closed]],
Cell[62641, 1702, 989, 32, 79, "Text",
  Evaluatable->False],
Cell[63633, 1736, 233, 7, 33, "Text",
  Evaluatable->False],
Cell[63869, 1745, 218, 5, 71, "Text"],
Cell[64090, 1752, 494, 16, 60, "Text"]
}, Open  ]],
Cell[64599, 1771, 577, 20, 35, "Text"],
Cell[65179, 1793, 339, 13, 57, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

