(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     67586,       1703]*)
(*NotebookOutlinePosition[     91945,       2588]*)
(*  CellTagsIndexPosition[     91837,       2581]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["COMPLEX ANALYSIS: ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Mathematica 4.1",
    FontSize->18,
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" Notebooks\n(c) John H. Mathews, and\nRussell W. Howell, 2002",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Complimentary software to accompany our textbook:",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]]
}], "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["COMPLEX ANALYSIS: for Mathematics and Engineering, \n4th Edition, \
 2001,  ISBN: ",
    FontSize->18,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["0-7637-1425-9",
    FontFamily->"Times New Roman",
    FontSize->18,
    FontColor->RGBColor[0, 0, 0.996109]],
  StyleBox["\n",
    FontSize->18,
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[ButtonBox["Jones & Bartlett Publishers, Inc.",
    ButtonData:>{
      URL[ "http://www.jbpub.com/"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" \n",
    FontSize->18,
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["40 Tall Pine Drive, Sudbury, MA 01776  \nTele.  (800) 832-0034, \
FAX:  (508)  443-8000  \nE-mail:  mkt@jbpub.com  \nInternet:  ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["http://www.jbpub.com/",
    ButtonData:>{
      URL[ "http://www.jbpub.com/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox["  ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n",
    FontSize->14],
  StyleBox["This free software is compliments of the authors.\n",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  ButtonBox["John H. Mathews",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[",   ",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["mathews@fullerton.edu \n",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  ButtonBox["Russell W. Howell",
    ButtonData:>{
      URL[ "http://www.westmont.edu/~howell"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[", ",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["howell@westmont.edu ",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CHAPTER 9",
    FontSize->18,
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["  ",
    FontSize->18],
  StyleBox["CONFORMAL MAPPING",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 9"],

Cell[BoxData[{
    \(\(S = \(T = \(w = \(W = \(x = \(y = \(z = \(Z = 
                      0\)\)\)\)\)\)\);\)\ \), "\n", 
    \(\(Clear[cos, f, F, g, graphs, Iden, S, set, sin, T, tan, w, W, w1, w2, 
        w3, wdot, wdots, wplane, z, z1, z2, z3, zdot, zdots, zplane, Z, 
        Zplane];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Section 9",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".1",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Basic Properties of Conformal Mappings",
    ButtonData:>{"ca0901.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Section 9.2",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  "  ",
  StyleBox["Bilinear Transformations",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001f80@0006@000000000000001D0000E0000
00000000001?0`00C`<00215CDH00040R1d001@00002000000000000002l000080<005P200100@00
l000000000000000000004H0003H3000bP`004M4BD<1002000<00393]ST00000/P`000402@000eT6
00010284000000T0000V1Pl0201OATeBBE@Y80<0000N00D0000;0P0000050000308O01l01@800?L0
00<00@00001gMgL0EEEE0<`0b`3^k^h0IP1U0?g;0028R8P006Gm0?ooo`14A4@08R8R000000000000
00000000003k:O00M`400000e03b4P00b8/G002ni@110;`0lQ800:Cc4P00/?l04P140;OcM`0hc_<0
Mooo0?oob02;5`00^o530038G@0H01P0o18006H00000b8/05`2600:D0@3P_AX000400000b01M6000
C00000260P2D0@0004000<QM6000000000000000000100000>Bn01X0100100000000000000000>00
_AX0063c4P00K000200A000P000000000<R;01L0H01c@000e098001?L01UKP0000<000800000g?<0
4P100>i20004000001810000n00JG`00@cYL06Q_K@1UL640IfEL06MYIP1c04d0HGAX06E]H@1dJF<0
HD9Y06L^I`1YIP00g?<B0007PP3WM`000000000000008000003L0?<B000lm18004mR0?Mgc03c4P00
<0000000000300800000043^@P00kB40igND004200000P000000000060000@00dLjR00lH00000480
000000800000Ha40igN600:D0@0B0@0009G`00004P007`000000002N0P00004000000:QSG`00n1X0
G`3@00PF000C000002H0000000000000G?DB0002<`3]M`00000000PTG`00QP80U04B0040002El000
00000000P03d4P00OUSW07L8901O0000000000040000000000000000003RF>L0M`PT05l000000000
00@00030>P3XMd<0>UaX06m]I@1`HFL0IEaW06UVL`1LCF40M6QU06eQM01YHf40@VUW02iWJ@1V08H0
0Y@100000000RDX0mWM800DD001V000000P00000QP02U040>aM500260P2D0I@00@8001810000@aL0
A@2600:D0@30ma800080000000000000n1YO0007002:0A00mA8009XAk@1ge`@00GD7002:0@0N0`00
00000000J0035P000001003Hm@0B06@0BZ]g09810P00G?D04P0>05_WM`30RaL00000000000005000
8040000800000040000008Se4P00/bP0l7L0000D000800@001P10000IP000000IP0000260P2D0ML0
105e00000000208000000000001f0P00053e018000000000/?lB0014]`3cMlP0cO=g0?ooo`3o1HH0
@`2600:D0@040000=08000<0000e00D000070@<0000R1000@`lP0<`0000P02000000020080000000
:0000200000P00000@08000000001000a0h00<@>00000@0000000000001gMgL0EEEE0</0c03^k^h0
I@1V003;o@28R8P0oFD00?ooo`14A4@08R8R00000000000000000000003`:O/0005g0=@000004_80
5h_80>Fn002l044001;b01;cY03o/000A00B07Oc]`3ccSP0oomg0<Soo`005h/0@o6k05g8000H01P0
01;l0000IP2;b000QP0G006D0P0J_N0000400<P0000065d0001<00:600000I@0040001QMb0000000
0000000000000040_^@000@06P00004000000000003P000001Zm01;cH000K0004@08000P00000000
RlP006005`00@7<0B0;D071?0000KVD000<000000P3cg000@00B0012kP0000@00A800?P00000GaX0
G3Y306e_J01QL6D0G6EW06IYI`1=07<0J7AQ065]I@1SJG@0JD9Q06L^I`00IVT04_?L08870000MnL0
0000000000008000g000000Bl`0Bm3`0HTl00<agm`004_<0000`0000000200<0000004;^@00Qk@00
U7OW00020@000P00000001P000000@00X/kA000H3`120000000000000P0AH`00QWOW006D0P000A80
l9D0018000007`00000000:N00010000000005mSZ00Jn000d01O000F200001<002H0000000000000
4_EL03<20000Mnd0000005lT2002QP004P6D00000@00l9D00000080000004_@0ieQn02@8M`0005l0
000000040000000000000000003WF>8090Qg0000G`00000000@003[00013MnP0J5`j06E]K`1WHG00
IeaU07=VJ@1QCE`0IFQd07AQK@1QHfT0IfU206UW;P2606H00I@20000001:R@00B7Of000D1@0006H0
00P008H00001U080AALk00:6002D0I@0008100014P0G@`00QP15006D0P0Bml000080000000000000
Ga[h0007000@0HX001;e0>dAVP04egL01gD1006:00000ah0000006P000005P<00@000?GH001T0180
Mj]:0081TP3eG0003P0B07OWF`0GRl000000000000005000004P000800010000000001;eR00X/`00
07O`000D000400P00AP006H000000000001V00:6003G0I@0M@440000000220000000000000000WH0
mE0000004P0000004_n`0;M40038Mo<0Mo?=0?ooo`261Ol0QP13006D0P092@T00000000000000000
0000000000000000000000T000071`L71`L71`L71`L71`L71`L71`L71`L71`L000T0000000000000
0000000000000000000000001`002@0410@410@410@410@410@410@410@410@4100700T0000410@4
10@410@410@410@410@410@410@400L000T010@410@400000P4410@41040004410@410@01`002@04
10@410@02000000:100000D0000010@4100700T0000410@4100820011P0000D500030`0410@400L0
00T010@410@400P820001P051@070P0300@410@01`002@0410@4104020P8208000D01`L72`0210@4
100700T0000410@40@0820P8208000L71`L200@410@400L000T010@4104000P820P820071`L71`80
0@@410@01`002@0410@400D5000000000000000000000@@4100700T000040@0000002`X21`080P05
1@0000L000@400L000T010@000L71`L71`L000P820801@0000L000@01`002@0400<300L71`L70006
00P820P000030004100700T000000`<300L71`0000H600P820P00`<010@400L000T010800`<300L0
00D01PH600P800<30`<010@01`002@0410X0000000051@061PH600030`<30`<0100700T0000410@2
0000000000H61PH:00<30`0000@400L000T010@410@:00<30P000000000000000@@410@01`002@04
10@4100500830`<30`<300H6004410@4100700T0000410@1000700<30`<30`001PH010@410@400L0
00T010@410001`L00P<30`<020P01P0410@410@01`002@0410@400L:00000`<30P0020P000@410@4
100700T0000410@0000110400`80108000P010@410@400L000T010@410@410@4100300@410@10004
10@410@01`002@0410@410@410@4100410@410@40P@410@4100700T0000410@410@410@410@410@4
10@410@410@400L000T010@410@410@410@410@410@410@410@410@01`002@0410@410@410@410@4
10@410@410@410@410002@T000000000000000000000000000000000000000T9100002L1ool30000
00000140000<0000200000/0000@00005@0001D000090000400001D0000E00008@0000P0000:0000
40000000000000002@000100000O00007`000340000@10000@00000300400000MgMg05EEE@3<0</0
k^k^06H0I@3mb`00R8R8001Uo@3oool0A4A4028R8P0000000000000000000000nbW`07L100000=@0
lQ800<R;5`00_^D0@@2l0?8B002Tla800;3o0180A02glgL0><kc07Ooo`3oolP0RaL00;_a@`00b5d0
600H0?`B001V00000<R;01L0QP02U040h;dJ000100000<P0GAP004`00000QP80U04000100038GAP0
00000000000000000@00003T_P0J00@00@00000000000000003P0;dJ001Pla8006`000P04@008000
00000038R`0G0600Ld000=@2B000Cg00IFh00003000200000=cc0180@03^@P001000000B0@000?P0
6Ul004<jG01XKfd0IG1Q06MUG01WJFH0L`1=065dJ01UKF40M6US0652J@1W;VL0JFH00=cc4P001h80
igL000000000000002000000g03c4P00??@B001?HP3gMl`0la800300000000000`0200000010kT80
0>dQ0>MgU0010P0000800000000001P000400=7>XP0?6000001200000002000006<A0>MgQP02U040
4P40002El000018001l000000000WP8000010000002XHel00?PJ05l0d0085P004`00000V00000000
000005ce4P000S<0kGL00000000895l008H209@14P010000UO00000000000800m18007iHi`1g22@0
G`000000000010000000000000000000hUSW07L8901O0000000000040000`3X0j7M303YLJ01_KFD0
L65W06ELI`1YIW<0G4eQ07AXI@1]HG@0JF=Q049YI`0^IfT0IP2600:D0@00000008U:0?IgB0055000
IP000008000008H00Y@103/GA@00QP80U06D0042000B0@0004<G04D0QP02U040`?LB000200000000
00000?PJG`001`00RP4@0?DB002J4Nd0MmL4005e1`00RP407P<00000000006P00aH000000@00f?D0
4P1T04Z[M`2B0@8005ce01803P1KigL0`8/G00000000000001@0020100002000000100000028mA80
0;<X0?1g000050002004000H0@0006H0000006H00000QP80U07G00@1M@00000000P2000000000000
MP80001@m@0B000000000;3o4P00A;L0lgO80<gcM`3oool0o`F604<0QP02U040<00000`000010000
=00000P0000E0000300000<0001A0000N0P00000000000005@0001D0000000000000000000000000
80000200001@0000:0@007P40000100000000200c00P0000800002P0000P00008000004020000000
00@00<@>00343P000040000000000000MgMg05EEE@3;0<`0k^k^06D0IP00bod0R8R80?eU003oool0
A4A4028R8P0000000000000000000000l2Wk0001M`3D000001;b01N;b03U_P00_011000BlP0Blj@0
ok0004@04P1glkL0llhh0?ooM`38ool001N;04?a^`1Mb000600H000Bo00006H0RlP008H05`01U080
6[gP00010038000001QM0000C002QP00006D0010000HGLP0000000000000000000010;kT000401X0
0001000000000000h000000J_@0Blf0006`0014020008000000008_8001P01L0041c04P2e01`C`00
06iU000300000080lm`004004P00@^h00004004B003h000005lJ05`j@`1]KfP0HG1U05aUI`1VJFL0
C@1c06QdH@1QKFD0HfUd06U2H@1W;VL006IY01;cg0221`0007OW00000000000002000=`000004_<0
4_@l069?003<MoL001;c0000<00000000P0300000012kT008Nd009Agi`000P4000800000000H0000
00400:;>d@0060l0@P000000000000804F<008Igi`01U080004B0?2E000B000001l000000002WP00
0@000000001OHjP06_P00=00G`005PP0000C000V00000000000001;eG00c0P0007O]0000001O90P0
0XH00181U00000400?2E00000020000001;d0>MHOP0T27L0001O0000000010000000000000000000
ieSR02@8M`0005l000000004000j`000@gOX06QL>P1UKFl0If5`06MLI@1cIVT0HDeL06EXM01dHFd0
HF=Y06MY@P1YIbh0QP1V006D0P000000BXT004QgmP0050D0001V0008002600000I@204DG>`02QP00
U06D00020@000A805d<008H0A@01U0804_O0000200000000000005lJn0001`00406:000Bm@3]4IX0
1=Mg00Me0@01RP0000<N0000001X000001H30040003ef000I00B07N[BP020I80mE`000h04P1gie/0
5h_000000000000001@00001800020000@000000000BmHP0:;<0001gl00050001008004H001V0000
00000000IP02QP00e`6D07D1100000000PP0000000000000009f0?E@00000180000001;o/02gA000
b7Oc07Occ@3oool0QPGo08H0@`01U0802@T900000000000000000000000000000000000000090000
1`L71`L71`L71`L71`L71`L71`L71`L71`L7000900000000000000000000000000000000000000L0
00T010@410@410@410@410@410@410@410@410@01`09000010@410@410@410@410@410@410@410@4
1007000900@410@41000008110@410@1000110@410@400L000T010@410@400P000002P@000050000
00@410@01`09000010@410@020P00@H000051@000`<010@41007000900@410@4100820P000H01@D0
1`800`0410@400L000T010@410@100P820P2000500L71`/00P@410@01`09000010@4104020P820P2
00071`L70P0410@41007000900@410@1000820P820P01`L71`L2004410@400L000T010@410051@00
0000000000000000004410@01`0900001040000000/:0PL020801@D0000700041007000900@40007
1`L71`L7000820P200D00007000400L000T010030`071`L71`001P0820P800000`0010@01`090000
00<30`071`L000061P0820P800<300@41007000900@200<30`07000500H61P0820030`<300@400L0
00T010@:000000001@D01PH61P000`<30`<300@01`09000010@40P00000000061PH62P030`<00004
1007000900@410@42P030`80000000000000004410@400L000T010@410@01@020`<30`<30`061P01
10@410@01`09000010@40@001`030`<30`<000H600@410@41007000900@410@000L700830`<300P8
00H010@410@400L000T010@410072P0000<30`8000P8000410@410@01`09000010@400000@@100<2
00@2000800@410@41007000900@410@410@410@00`0410@40@0010@410@400L000T010@410@410@4
10@010@410@4108410@410@01`09000010@410@410@410@410@410@410@410@41007000900@410@4
10@410@410@410@410@410@410@400L000T010@410@410@410@410@410@410@410@410@000T90000
0000000000000000000000000000000000092B80000<0000ooooobD0000<00001`00P2D0000<0000
0000P300000<00003`00P4/0000@0000000000D0000X000030000040000>000010<00;`0000@0000
000007MgM`1EEED0c03;0>k^kP1V06D0oL/008R8R000IOd0oooo04A4A00R8R80nbW`07L100000=@0
lQ800<R;5`00_^D0@@2l0:Cc4P00/?l04P140;OcM`0hc_<0Mooo0?oob02;5`00^o530038G@0H01P0
o18006H00000b8/05`2600:D0@3P_AX000400000b01M6000C00000260P2D0@0004000<QM60010000
0>Bn01X010000>00_AX0063c4P00K000200A000P000G0600Ld000=@2B000Cg00IFh0000300020000
0=cc0180@03^@P001000000B0@000?P06Ul004<jG01XKfd0IG1Q06MUG01WJFH0L`1=065dJ01UKF40
M6US0652J@1W;VL0JFH00=cc4P001h80igL00000g03c4P00??@B001?HP3gMl`0<00000<00P10kT80
0>dQ0>MgU0010P0000800000603AcZ803aP00000@P00Ha40igN601810000UO00000B000O0000WP80
00010:QSG`00n1X0G`3@00PF000C000002H005ce4P000S<0kGL000PTG`2D0A80UO000000P03d4P00
OUSW07L8901O000000@00>9Hi`00`3X0j7M303YLJ01_KFD0L65W06ELI`1YIW<0G4eQ07AXI@1]HG@0
JF=Q049YI`0^IfT0IP260029BP3fMdP01A@00008000008H0>aM509@1U000@aL0A@260<3g4P3h6Ul0
00L008X1403e4P00VQ7]07OG1001M@L008X101h3000006P00aH0003Hm@0B06@0BZ]g09810P00G?D0
4P0>05_WM`30RaL001@002010028mA800;<X0?1g000800@001P10000IP2D0ML0105e00080P1f0P00
053e0180002`oa8004Bg0?=gb03=lgL0o`F604<0QP040`00
\>"], "Graphics",
    ImageSize->{21, 21}],
  StyleBox["  ",
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->18,
  CellTags->"Section 9.2"],

Cell[TextData[{
  "\tThe prerequisite for this section is ",
  ButtonBox["Section 2.6",
    ButtonData:>{"ca0206.nb", None},
    ButtonStyle->"Hyperlink"],
  " ",
  ButtonBox["The Reciprocal Transformation w = 1/z.",
    ButtonData:>{"ca0206.nb", None},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[TextData[{
  "\tAnother important class of elementary mappings was studied by ",
  ButtonBox["August Ferdinand M\[ODoubleDot]bius",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Mobius.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " (1790-1868).  These mappings are conveniently expressed as the quotient \
of two linear expressions and are commonly known as linear fractional or \
bilinear transformations.  They arise naturally in mapping problems involving \
the function  arctan(z).  In this section we will show how they are used to \
map a disk one-to-one and onto a half-plane.\n\n\tLet  a,  b,  c,  and  d  \
denote four complex constants with the restriction that ",
  Cell[BoxData[
      \(a\ d \[NotEqual] b\ c\)]],
  ".  Then the function\n\n\t",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(a\ z\  + \ b\)\/\(c\ z\  + \ d\)\)\)]],
  "\n\nis called a ",
  StyleBox["bilinear transformation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " or ",
  ButtonBox["M\[ODoubleDot]bius Transformation",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/MoebiusTransformation.html"], None},
    ButtonStyle->"Hyperlink"],
  " ",
  " or ",
  StyleBox["linear fractional transformation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ".  If the expression for  S(z)  is multiplied through by the quantity  ",
  Cell[BoxData[
      \(c\ z\  + \ d\)]],
  ",  then the resulting expression has the bilinear form  ",
  Cell[BoxData[
      \(c\ w\ z\  - \ a\ z\  + \ d\ w\  - \ b\  = \ 0\)]],
  ".  We can collect terms involving  z  and write  ",
  Cell[BoxData[
      \(z \((c\ w\  - a\ )\)\  = \ \(-d\)\ w\  + \ b\)]],
  ".  For values of  ",
  Cell[BoxData[
      \(w \[NotEqual] a\/c\)]],
  "  the inverse transformation is given by\n\n\t",
  Cell[BoxData[
      \(z = \(\(S\^\(-1\)\) \((w)\) = \(\(-d\)\ w + b\)\/\(c\ w - a\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe can extend  ",
  Cell[BoxData[
      \(S\ \ and\ \ S\^\(-1\)\)]],
  "  to mappings in the extended complex plane.  The value  ",
  Cell[BoxData[
      \(S \((\[Infinity])\)\)]],
  "  should be chosen to equal the limit of ",
  Cell[BoxData[
      \(S \((\[Infinity])\)\)]],
  "  as  ",
  Cell[BoxData[
      \(z \[Rule] \[Infinity]\)]],
  ".  Therefore we define\n\n\t",
  Cell[BoxData[
      \(S \((\[Infinity])\)\  = \ \(lim\+\(z\  \[Rule] \ \[Infinity]\)\ \ S \
\((z)\)\  = \ \(lim\+\(z\  \[Rule] \ \[Infinity]\)\ \ \(a\ \  + \ b\/z\)\/\(c\
\ \  + \ d\/z\)\  = \ \ a\/c\)\)\)]],
  ",  \n\nand the inverse is  ",
  Cell[BoxData[
      \(\(S\^\(-1\)\) \((a\/c)\)\  = \ \[Infinity]\)]],
  ".  Similarly, the value  ",
  Cell[BoxData[
      \(\(S\^\(-1\)\) \((\[Infinity])\)\)]],
  "  is obtained by a limit\n\n\t",
  Cell[BoxData[
      \(\(S\^\(-1\)\) \((\[Infinity])\)\  \[Equal] \ 
        lim\+\(w \[Rule] \ \[Infinity]\)\ \ \(S\^\(-1\)\) \((w)\)\  \[Equal] \
\ lim\+\(w\  \[Rule] \ \[Infinity]\)\ \ \(\(-d\)\  + b\/w\)\/\(c\  - a\/w\)\  \
\[Equal] \ \ \(-\ d\)\/c\)]],
  ",\n\nand the inverse is  ",
  Cell[BoxData[
      \(S \((\(-\ d\)\/c)\)\  = \ \[Infinity]\)]],
  ".  With these extensions we conclude that the transformation  ",
  Cell[BoxData[
      \(w = S \((z)\)\)]],
  "  is a one-to-one mapping of the extended complex z-plane onto the \
extended complex w-plane.  "
}], "Text"],

Cell[TextData[{
  StyleBox["\n",
    FontWeight->"Bold"],
  StyleBox["Example 9.3,  Page 364.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\[ImaginaryI]\ \((1\  - \ z)\)\)\/\(1\  + \ z\)\)\
\)],
    AspectRatioFixed->True],
  "  maps the unit disk ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  " one-to-one and onto the upper half plane ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(S \((z)\) = \ \(\[ImaginaryI]\ \((1\  - \ z)\)\)\/\(1\  + \ z\)\)],
    AspectRatioFixed->True],
  "."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[eqn, Iden, solset, S, w, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(S[z_]\  = \ \(\[ImaginaryI]\ \((1 - z)\)\)\/\(1 + z\);\)\ \), "\n", 
    \(\(Print["\<S(z) = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

To show  S(z)  is one-to-one, find the inverse function.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\[IndentingNewLine]\(eqn = 
        w \[Equal] S[z];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[eqn, z];\)\ \), "\[IndentingNewLine]", 
    \(\(S1[w_] = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<z = \!\(S\^\(-1\)\)[w] = \>\"", 
        S1[w]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

Check out the inverse function.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print["\<w = S(z) = \>", S[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\<z = \!\(S\^\(-1\)\)[w] = \>\"", S1[w]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\^\(-1\)\)[S[z]] = \>\"", S1[S[z]], "\< = \>", 
        Together[S1[S[z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(S\^\(-1\)\)[w]] = \>\"", S[S1[w]], "\< = \>", 
        Together[S[S1[w]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nConsider the unit circle C: |z| = 1.  Since  ",
  Cell[BoxData[
      \(z = \(\(S\^\(-1\)\) \((w)\) = \(\[ImaginaryI]\  - \ w\)\/\(\
\[ImaginaryI]\  + \ w\)\)\)]],
  ",  the image of these points will satisfy  ",
  Cell[BoxData[
      \(\(\(\ \)\(\(\(|\)\(w + \[ImaginaryI]\)\(|\)\) = \(\(|\)\(w + \
\[ImaginaryI]\)\(|\)\)\)\)\)]],
  ".  ",
  "\n",
  "Square both sides of the above equation and obtain ",
  Cell[BoxData[
      \(\(\(|\)\(u + \[ImaginaryI]\ v + \[ImaginaryI]\)\( | \^2\)\) = \(\(|\)\
\(\(-u\) - \[ImaginaryI]\ v + \[ImaginaryI]\)\( | \^2\)\)\)]],
  "  which can be simplified."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(eqn = 
        u\^2 + \((v + 1)\)\^2 == 
          u\^2 + \((\(-v\) + 1)\)\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Simplify[eqn]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\

The circle  C  divides the z-plane into two portions, and its image, v = 0, \
is the u-axis which divides the w-plane into two portions. The image of a \
point interior to  C  will determine which half plane is the image of the \
unit disk.  For example\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\(Print["\<S[0] = \>", 
        S[0]];\)\(\ \)\(\[IndentingNewLine]\)
    \)\)\)], "Input"],

Cell[TextData[{
  "\nTherefore, the image of the unit disk ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  " is the upper half plane ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  ".  \n\nTo visualize that  S(z)  is onto we will consider a graph. The \
graph is not conclusive, but it appears to confirm our suspicion."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[f, Iden, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(S[
          z_]\  = \(\(\ \)\(\[ImaginaryI]\ \((1 - z)\)\)\)\/\(1 + z\);\)\ \), \
"\n", 
    \(\(PolarMap[
        Iden, {0.000005, 0.999995, 0.11111}, {0, 2  \[Pi], \[Pi]\/12}, 
        PlotRange \[Rule] {{\(-1.05\), 1.05}, {\(-1.05\), 
              1.05}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 1, 1], 
            Range[1, 1, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Pink, Magenta}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The disk |z| < 1.\>"];\)\ \), "\n", 
    \(\(PolarMap[
        S\ \ \ , {0.000005, 0.999995, 0.11111}, {0, 2  \[Pi], \[Pi]\/12}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[0, 3, 1]}, 
        AspectRatio \[Rule] 1\/2, 
        PlotRange \[Rule] {{\(-3\), 3}, {0, 
              3}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Pink, Magenta}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image half-plane Im[w] > 0,\>"];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the transformation  ",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\[ImaginaryI]\ \((1\  - \ z)\)\)\/\(1\  + \ z\)\)\
\)],
    AspectRatioFixed->True],
  "  maps the unit disk ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  " one-to-one and onto the upper half plane ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["\nTheorem 9.3 (The Implicit Formula), Page 365.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " There exists a unique bilinear transformation that maps three distinct \
points ",
  Cell[BoxData[
      RowBox[{\(z\_1\), ",", \(z\_2\), ",", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", \(z\_3\)}]}]]],
  "  onto three distinct points ",
  Cell[BoxData[
      RowBox[{\(w\_1\), ",", \(w\_2\), ",", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", \(w\_3\)}]}]]],
  ", respectively.  An implicit formula for the mapping is given by the \
equation    \n\n\t",
  Cell[BoxData[
      \(\(\((z\  - \ z\_1)\)\ \((z\_2\  - \ z\_3)\)\)\/\(\(\ \)\(\((z\  - \ z\
\_3)\) \((z\_2\  - \ z\_1)\)\)\) = \(\((w\  - \ w\_1)\)\ \((w\_2\  - \ \
w\_3)\)\)\/\(\((w\  - \ w\_3)\) \((w\_2\  - \ w\_1)\)\(\ \)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Proof of Theorem 9.3, see text Page 365.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Example 9.4,  Page 366.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Construct the bilinear transformation  w = S(z)  that maps the points  \
",
  Cell[BoxData[
      \(z\_1 = \(-\[ImaginaryI]\), \ z\_2 = 1, \ z\_3 = \[ImaginaryI]\)]],
  "  onto the points  ",
  Cell[BoxData[
      \(w\_1 = \(-1\), \ \ w\_2 = 0, \ \ w\_3 = 1\)]],
  ",  respectively."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the three points and their images and solve for  w = S(z).  \
\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[w, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[formula, solset, S];\)\ \), "\n", 
    \(\(formula\  = \ \(\((z - z\_1)\)\ \((z\_2 - z\_3)\)\)\/\(\(\ \)\(\((z - \
z\_3)\) \((z\_2 - z\_1)\)\)\) \[Equal] \(\((w - w\_1)\)\ \((w\_2 - \
w\_3)\)\)\/\(\(\((w - w\_3)\) \((w\_2 - w\_1)\)\)\(\ \)\);\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(z\_1\  = \ \(-\[ImaginaryI]\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(z\_2\  = \ 1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(z\_3\  = \ \[ImaginaryI];\)\ \ \ \), "\n", 
    \(\(w\_1\  = \ \(-1\);\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(w\_2\  = \ 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_3\  = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute the values\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,      \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,      \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,      \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,      \!\(w\_3\) = \>\"", 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(solset\  = \ Solve[formula, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S(z) = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nCheck our work and by looking at the images of  ",
  Cell[BoxData[
      \(z\_1, \ z\_2, \ z\_3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,      \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,      \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,      \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,      \!\(w\_3\) = \>\"", w\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(z\_1\)] = \>\"", 
        S[z\_1], \*"\"\<,   S[\!\(z\_2\)] = \>\"", 
        S[z\_2], \*"\"\<,   S[\!\(z\_3\)] = \>\"", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

To visualize the mapping  w = S(z)  we will consider a graph. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[f, Iden, wplane, z, zplane];\)\ \), "\n", 
    \(\(Iden[z_] = z;\)\ \), "\n", 
    \(\(S[
          z_] = \(-\(\(\[ImaginaryI]\ \((\(-1\) + z)\)\)\/\(1 + 
                z\)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{0, \(-1\)}, {1, 0}, {0, 
            1}};\)\ \), "\[IndentingNewLine]", 
    \(\(zdots = 
        Graphics[{{Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{\(-1\), 0}, {0, 0}, {1, 
            0}};\)\ \), "\[IndentingNewLine]", 
    \(\(wdots = 
        Graphics[{{Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(zplane = 
        CartesianMap[
          Iden, {0, 1, 0.125}, {\(-1\), 1, 
            0.125}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.1\), 
                1.1}, {\(-1.1\), 1.1}}, 
          AspectRatio \[Rule] 
            2, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1, 1], 
              Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {DarkGreen, Green}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(wplane = 
        CartesianMap[
          S, {0, 1, 0.125}, {\(-1\), 1, 
            0.125}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1.2\), 
                1.2}, {\(-0.2\), 1.0}}, 
          AspectRatio \[Rule] 
            1\/2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 1, 1], 
              Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {DarkGreen, Green}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, zdots, 
        PlotRange \[Rule] {{\(-0.1\), 1.1}, {\(-1.1\), 1.1}}, 
        AspectRatio \[Rule] 
          2, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1, 1], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The points \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<, \!\(z\_2\) = \>\"", z\_2, \*"\"\<, \!\(z\_3\) = \>\"", 
        z\_3, "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<in the z-plane.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[wplane, 
        wdots, \[IndentingNewLine]PlotRange \[Rule] {{\(-1.2\), 
              1.2}, {\(-0.2\), 1.0}}, 
        AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 1, 1], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The images \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<, \!\(w\_2\) = \>\"", w\_2, \*"\"\<, \!\(w\_3\) = \>\"", 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping w = S[z] = \>"\ , 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", z\_1, "\<] = \>", 
        S[z\_1], \[IndentingNewLine]"\<,   S[\>", z\_2, "\<] = \>", 
        S[z\_2], \[IndentingNewLine]"\<,   S[\>", z\_3, "\<] = \>", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Example 9.5,  Page 366.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the bilinear transformation  w = S(z)  that maps the points  ",
  Cell[BoxData[
      \(z\_1 = \(-2\), \ \ z\_2 = \(-1\) - \[ImaginaryI], \ \ z\_3 = 0\)]],
  "  onto the points  ",
  Cell[BoxData[
      \(w\_1 = \(-1\), \ \ w\_2 = 0, \ \ w\_3 = 1\)]],
  ",  respectively."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the three points and their images and solve for  w = S(z).  \
\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[w, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[formula, solset, S];\)\ \), "\n", 
    \(\(formula\  = \ \(\((z - z\_1)\)\ \((z\_2 - z\_3)\)\)\/\(\(\ \)\(\((z - \
z\_3)\) \((z\_2 - z\_1)\)\)\) \[Equal] \(\((w - w\_1)\)\ \((w\_2 - \
w\_3)\)\)\/\(\(\((w - w\_3)\) \((w\_2 - w\_1)\)\)\(\ \)\);\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(z\_1\  = \ \(-2\);\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(z\_2\  = \ \(-1\) - \[ImaginaryI];\)\ \ \), "\[IndentingNewLine]", 
    \(\(z\_3\  = \ 0;\)\ \), "\n", 
    \(\(w\_1\  = \ \(-1\);\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(w\_2\  = \ 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_3\  = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute the values\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,      \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,      \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,      \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,      \!\(w\_3\) = \>\"", 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(solset\  = \ Solve[formula, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S(z) = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nThis is equivalent to the formula  ",
  Cell[BoxData[
      \(S \((z)\) = \(\((1 - \[ImaginaryI])\) z\ \  + \ \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\ \  + \ \ 2\)\)]],
  ",  and can be verified by a computation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print[
        S[z], "\< = \>", \(\((1 - \[ImaginaryI])\) z\  + \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\  + \ 2\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[S[z], "\< = \>", 
        Simplify[\(\((1 - \[ImaginaryI])\) z\  + \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\  + \ 2\)]];\)\ \), "\n", 
    \(\(Print["\<Are they equal ?  \>", 
        S[z]\  \[Equal] \ 
          Simplify[\(\((1 - \[ImaginaryI])\) z\  + \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\  + \ 2\)]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nCheck our work and look at the images of  ",
  Cell[BoxData[
      \(z\_1, \ z\_2, \ z\_3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,    \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,  \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,    \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,      \!\(w\_3\) = \>\"", w\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(z\_1\)] = \>\"", 
        S[z\_1], \*"\"\<, S[\!\(z\_2\)] = \>\"", 
        S[z\_2], \*"\"\<,   S[\!\(z\_3\)] = \>\"", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

To visualize the mapping  w = S(z)  we will consider a graph. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[f, Iden, wplane, z, zplane];\)\ \), "\n", 
    \(\(Iden[z_] = z;\)\ \), "\n", 
    \(\(S[
          z_] = \(-\(\(\[ImaginaryI]\ \((\((1 + \[ImaginaryI])\) + 
                    z)\)\)\/\(\((1 - \[ImaginaryI])\) + 
                z\)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{\(-2\), 0}, {\(-1\), \(-1\)}, {0, 
            0}};\)\ \), "\[IndentingNewLine]", 
    \(\(zdots = 
        Graphics[{{Magenta, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Magenta, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Magenta, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{\(-1\), 0}, {0, 0}, {1, 
            0}};\)\ \), "\[IndentingNewLine]", 
    \(\(wdots = 
        Graphics[{{Magenta, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Magenta, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Magenta, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(zplane = 
        CartesianMap[
          Iden, {\(-2\), 0, 0.125}, {\(-1\), 1, 
            0.125}, \[IndentingNewLine]PlotRange \[Rule] {{\(-2.1\), 
                0.1}, {\(-1.1\), 1.1}}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 0, 1], 
              Range[\(-1\), 1, 
                1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Cyan}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(wplane = 
        CartesianMap[
          S, {\(-2\), 0, 0.125}, {\(-1\), 1, 
            0.125}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1.2\), 
                1.2}, {\(-0.4\), 2.0}}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 1, 1], 
              Range[\(-1\), 2, 
                1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Blue, Cyan}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, zdots, 
        PlotRange \[Rule] {{\(-2.1\), 0.1}, {\(-1.1\), 
              1.1}}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-2\), 0, 1], 
            Range[\(-1\), 1, 
              1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The points \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<, \!\(z\_2\) = \>\"", z\_2, \*"\"\<, \!\(z\_3\) = \>\"", 
        z\_3, "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<in the z-plane.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[wplane, wdots, 
        PlotRange \[Rule] {{\(-1.2\), 1.2}, {\(-0.4\), 
              2.0}}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], 
            Range[\(-1\), 2, 
              1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The image points \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<, \!\(w\_2\) = \>\"", w\_2, \*"\"\<, \!\(w\_3\) = \>\"", 
        w\_3, "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping w = S[z] = \>"\ , 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", z\_1, "\<] = \>", 
        S[z\_1], \[IndentingNewLine]"\<,   S[\>", z\_2, "\<] = \>", 
        S[z\_2], \[IndentingNewLine]"\<,   S[\>", z\_3, "\<] = \>", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Example 9.6,  Page 367.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  the mapping  ",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\((1 - \[ImaginaryI])\) z\ \  + \ \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\ \  + \ \ 2\)\)\)],
    AspectRatioFixed->True],
  "  maps the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z + 1\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  one-to-one and onto the upper half plane  ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(S \((z)\) = \(\((1 - \[ImaginaryI])\) z\ \  + \ \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\ \  + \ \ 2\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[S, w, W, z, 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[d, g, solset, w1, w2, w3, z1, z2, z3];\)\ \), "\n", 
    \(\(S[
          z_]\  = \ \(\((1 - \[ImaginaryI])\) z\  + \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\  + \ 2\);\)\ \), "\n", 
    \(\(Print["\<S(z) = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

To show  S(z)  is one-to-one, find the inverse function.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(solset\  = \ 
        Solve[w \[Equal] S[z], z];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<z = \!\(S\^\(-1\)\)[w] = \>\"", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

To show  S(z)  is onto, use the method of oriented points on the boundary \
curve.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(z\_1\  = \ \(-2\);\)\ \ \), "\[IndentingNewLine]", \

    \(\(z\_2\  = \ \(-1\) - \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_3\  = \ 0;\)\ \ \), "\n", 
    \(\(w\_1\  = \ \(-1\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_2\  = \ 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_3\  = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,      \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,      \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,      \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,          \!\(w\_3\) = \>\"", w\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(z\_1\)] = \>\"", 
        S[z\_1], \*"\"\<,   S[\!\(z\_2\)] = \>\"", 
        S[z\_2], \*"\"\<,       S[\!\(z\_3\)] = \>\"", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nTherefore, the image of the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z + 1\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  is the upper half plane  ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  ".  In order to graph the image of the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z + 1\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  under  w = S(z)  we use the change of variable and find the image of  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  under  ",
  Cell[BoxData[
      \(w = \(g \((z)\) = S \((z - 1)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\n\(g[z_]\  = \ S[z - 1];\)\ \), "\n", 
    \(\(Print["\<         S(z) = \>", S[z]];\)\ \), "\n", 
    \(\(Print["\<g(z) = S(z-1) = \>", g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

To plot the graph we use the shifted disk and the functions d[z] = z-1  and  \
g[z] = S[z-1].\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[S, z];\)\ \), "\[IndentingNewLine]", 
    \(\(d[z_]\  = \ z - 1;\)\ \), "\n", 
    \(\(S[
          z_]\  = \ \(\((1 - \[ImaginaryI])\) z\  + \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\  + \ 2\);\)\ \), "\[IndentingNewLine]", 
    \(\(g[z_]\  = \ S[z - 1];\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{\(-2\), 0}, {\(-1\), \(-1\)}, {0, 
            0}};\)\ \), "\[IndentingNewLine]", 
    \(\(zdots = 
        Graphics[{{Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{\(-1\), 0}, {0, 0}, {1, 
            0}};\)\ \), "\[IndentingNewLine]", 
    \(\(wdots = 
        Graphics[{{Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(zplane = 
        PolarMap[
          d\ \ \ , {0.00005, 0.99995, 0.1111}, {0, 
            2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] \
{{\(-2.05\), 0.05}, {\(-1.05\), 
                1.05}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 1, 
                1], Range[1, 1, 
                1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Magenta, Pink}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(wplane = 
        PolarMap[
          g\ \ \ , {0.00005, 0.99995, 0.1111}, {0, 
            2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]Ticks \[Rule] \
{Range[\(-3\), 3, 1], Range[0, 3, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 
            1\/2, PlotRange \[Rule] {{\(-3\), 3}, {0, 
                3}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Magenta, Pink}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, zdots, 
        PlotRange \[Rule] {{\(-2.05\), 0.05}, {\(-1.05\), 
              1.05}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 1, 1], 
            Range[1, 1, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The disk |z+1| < 1.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[wplane, wdots, PlotRange \[Rule] {{\(-3\), 3}, {0, 3}}, 
        AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 3, 1], 
            Range[0, 3, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image half-plane Im[w] > 0,\>"];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", z\_1, "\<] = \>", 
        S[z\_1], \[IndentingNewLine]"\<,   S[\>", z\_2, "\<] = \>", 
        S[z\_2], \[IndentingNewLine]"\<,   S[\>", z\_3, "\<] = \>", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the transformation  ",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\((1 - \[ImaginaryI])\) z\ \  + \ \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\ \  + \ \ 2\)\)\)],
    AspectRatioFixed->True],
  "  maps the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z + 1\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  one-to-one and onto the upper half plane  ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["\nCorollary 9.1 (The Implicit Formula with a point at Infinity), \
Page 367.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " In equation (9-18) the point at infinity can be introduced as one of the \
prescribed points in either the z plane or the w plane."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Proof of Corollary 9.1, see text Page 367.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Example 9.7,  Page 368.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the bilinear transformation  w = S(z)  that maps the \
crescent-shaped region that lies inside the disk ",
  Cell[BoxData[
      \(\(\(|\)\(z - 2\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  "  and outside the circle ",
  Cell[BoxData[
      \(\(\(|\)\(z - 1\)\(|\)\) = \ 1\)]],
  "  onto a horizontal strip."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter three points and their images and solve for  w = S(z).  For \
convenience we choose  ",
  Cell[BoxData[
      \(z\_1 = 4, \ z\_2 = 2 + 2  \[ImaginaryI], \ z\_3 = 0\)],
    AspectRatioFixed->True],
  "  which are mapped onto the points  ",
  Cell[BoxData[
      \(w\_1 = 0, \ w\_2 = 1, \ w\_3 = \[Infinity]\)],
    AspectRatioFixed->True],
  ",  respectively.  In this case we remove the terms involving  ",
  Cell[BoxData[
      \(w\_3\  = \ \[Infinity]\)],
    AspectRatioFixed->True],
  ",  in the implicit formula, because this implies that  ",
  Cell[BoxData[
      \(\(w\_2\  - \ w\_3\)\/\(w\  - \ w\_3\) = \(\(w\_2\  - \ \
\[Infinity]\)\/\(w\  - \ \[Infinity]\) = 1\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[S, T, w, W, z, 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[formula, Iden, solset];\)\ \), "\n", 
    \(\(formula\  = \ \(\((z - z\_1)\) \((z\_2 - z\_3)\)\)\/\(\((z - z\_3)\) \
\((z\_2 - z\_1)\)\)\  \[Equal] \ \(w - w\_1\)\/\(w\_2 - w\_1\);\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(z\_1\  = \ 4;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(z\_2\  = \ 2 + 2  \[ImaginaryI];\)\ \ \), "\[IndentingNewLine]", 
    \(\(z\_3\  = \ 0;\)\ \ \), "\n", 
    \(\(w\_1\  = \ 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_2\  = \ 1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_3\  = \ \[Infinity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute the values\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,    \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,   \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,    \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,       \!\(w\_3\) = \>\"", 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(solset\  = \ Solve[formula, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S(z) = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nCheck our work and look at the images of  ",
  Cell[BoxData[
      \(z\_1, \ z\_2, \ z\_3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,      \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,    \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,      \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,        \!\(w\_3\) = \>\"", w\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(z\_1\)] = \>\"", 
        S[z\_1], \*"\"\<,   S[\!\(z\_2\)] = \>\"", 
        S[z\_2], \*"\"\<,     S[\!\(z\_3\)] = \>\"", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nAnd we need to look at the images of three more points",
  "; ",
  "  ",
  Cell[BoxData[
      \(z\_4 = 1 - \[ImaginaryI], \ z\_5 = 2, \ z\_6 = 1 + \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "  and  ",
  Cell[BoxData[
      \(w\_4 = \(-2\) + \[ImaginaryI], \ w\_5 = \[ImaginaryI], \ 
      w\_6 = 2 + \[ImaginaryI]\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]z\_4\  = \ \ 1 - \[ImaginaryI]; \ \ \ \ \ z\_5\  = \ 
      2; \ \ \ \ z\_6\  = \ 1 + \[ImaginaryI];\ \), "\n", 
    \(w\_4\  = \ \(-2\) + \[ImaginaryI]; \ \ \ w\_5\  = \ \[ImaginaryI]; \ \ \
\ w\_6\  = \ 2 + \[ImaginaryI];\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(z\_4\) = \>\"", 
        z\_4, \*"\"\<,       \!\(z\_5\) = \>\"", 
        z\_5, \*"\"\<,       \!\(z\_6\) = \>\"", z\_6];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_4\) = \>\"", 
        w\_4, \*"\"\<,      \!\(w\_5\) = \>\"", 
        w\_5, \*"\"\<,       \!\(w\_6\) = \>\"", w\_6];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(z\_4\)] = \>\"", 
        S[z\_4], \*"\"\<,   S[\!\(z\_5\)] = \>\"", 
        S[z\_5], \*"\"\<,    S[\!\(z\_6\)] = \>\"", 
        S[z\_6]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

To illustrate the mapping, consider the inverse image of the horizontal \
strip.  We will need to use the inverse function.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Iden[w_]\  = \ w;\)\ \), "\n", 
    \(\(solset\  = \ Solve[formula, z];\)\ \), "\n", 
    \(\(T[w_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<w = S[z] = \>", S[z]];\)\ \), "\n", 
    \(\(Print["\<z = T[w] = \>", T[w]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<T[S[z]] = \>", T[S[z]], "\< = \>", 
        Simplify[T[S[z]]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<S[T[w]] = \>", S[T[w]], "\< = \>", 
        Simplify[S[T[w]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

Now plot the graphs using T[w] then the identity map.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(set\  = \ \ {{4, 0}, {2, 2}, {1, \(-1\)}, {2, 
            0}, {1, 1}};\)\ \), "\[IndentingNewLine]", 
    \(\(zdots = 
        Graphics[{{Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(4\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(5\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{0, 0}, {1, 0}, {\(-2\), 1}, {0, 1}, {2, 
            1}};\)\ \), "\[IndentingNewLine]", 
    \(\(wdots = 
        Graphics[{{Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(4\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(5\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(zplane = 
        CartesianMap[
          T\ \ \ , {\(-9\), 9, 0.3}, {0.005, 0.995, 
            0.09}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.05\), 
                4.05}, {\(-2.05\), 
                2.05}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 4, 1], 
              Range[2, 2, 
                1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {DarkGreen, Green}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(wplane = 
        CartesianMap[
          Iden, {\(-9\), 9, 0.9}, {0.005, 0.995, 
            0.09}, \[IndentingNewLine]PlotRange \[Rule] {{\(-9\), 9}, {0, 
                1}}, 
          AspectRatio \[Rule] 
            1\/3, \[IndentingNewLine]Ticks \[Rule] {Range[\(-9\), 9, 3], 
              Range[0, 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {DarkGreen, Green}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, zdots, 
        PlotRange \[Rule] {{\(-0.05\), 4.05}, {\(-2.05\), 2.05}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 4, 1], 
            Range[2, 2, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The the crescent-shaped region that lies inside\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<the disk |z-2| < 2 and outside the circle |z-1| = 1.\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Show[wplane, wdots, PlotRange \[Rule] {{\(-9\), 9}, {0, 1}}, 
        AspectRatio \[Rule] 
          1\/3, \[IndentingNewLine]Ticks \[Rule] {Range[\(-9\), 9, 3], 
            Range[0, 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image is the horizontal strip 0 < v < 1,\>"];\)\ \), "\n\
", 
    \(\(Print["\<under the mapping  w = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", z\_1, "\<] = \>", 
        S[z\_1], \[IndentingNewLine]"\<,      S[\>", z\_2, "\<] = \>", 
        S[z\_2], \[IndentingNewLine]"\<,   S[\>", z\_3, "\<] = \>", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", z\_4, "\<] = \>", 
        S[z\_4], \[IndentingNewLine]"\<,   S[\>", z\_5, "\<] = \>", 
        S[z\_5], \[IndentingNewLine]"\<,   S[\>", z\_6, "\<] = \>", 
        S[z\_6]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe have constructed the transformation ",
  Cell[BoxData[
      \(w = \(S[
            z] = \(-\(\(\[ImaginaryI]\ \((\(-4\)\  + \ z)\)\)\/z\)\)\)\)]],
  "  and see that the image of the crescent-shaped region that lies inside \
the disk ",
  Cell[BoxData[
      \(\(\(|\)\(z - 2\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  "  and outside the circle ",
  Cell[BoxData[
      \(\(\(|\)\(z - 1\)\(|\)\) = \ 1\)]],
  "  is the horizontal strip  ",
  Cell[BoxData[
      \(0 < v < 1\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Library Research Experience for Undergraduates",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox["Project I. Write a report on bilinear transformations.",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0, 0.996109]],
  "\n\n",
  StyleBox["1.",
    FontWeight->"Bold"],
  " Avital, Shmuel and Shlomo Libeskind ''An Algebraic and Geometric Approach \
to Two Step Iteration of Bilinear Functions (in The Teaching of Math.),'' Am. \
Math. M., Vol. 91, No. 1. (Jan., 1984), pp. 53-56, ",
  StyleBox[ButtonBox["Jstor.",
    ButtonData:>{
      URL[ "http://www.jstor.org/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "   \n\n",
  StyleBox["2.",
    FontWeight->"Bold"],
  " Beardon, Alan F., ''Curvature, Circles, and Conformal Maps (in Notes),'' \
Am. Math. M., Vol. 94, No. 1. (Jan., 1987), pp. 48-53, ",
  StyleBox[ButtonBox["Jstor.",
    ButtonData:>{
      URL[ "http://www.jstor.org/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "   \n\n",
  StyleBox["3.",
    FontWeight->"Bold"],
  " Booker, T. Hoy, (1989), ''Bilinear Basics,'' Math. Mag., V. 62, No. 4, \
pp. 262-267.\n\n",
  StyleBox["4.",
    FontWeight->"Bold"],
  " Boyd, James N., (1985), ''A Property of Inversion in Polar Coordinates, \
The Math. Teach., V. 78, No. 1, pp. 60-61.\n\n",
  StyleBox["5.",
    FontWeight->"Bold"],
  " Brickman, Louis, ''The Symmetry Principle for Mobius Transformations (in \
Notes),'' Am. Math. M., Vol. 100, No. 8. (Oct., 1993), pp. 781-782., ",
  StyleBox[ButtonBox["Jstor.",
    ButtonData:>{
      URL[ "http://www.jstor.org/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "   \n\n",
  StyleBox["6.",
    FontWeight->"Bold"],
  " Budden, F. J. (1969), ''Transformation Geometry in the Plane by Complex \
Number Methods,'' The Math. Gazette, V. 53, No. 383, pp. 19-31.\n\n",
  StyleBox["7.",
    FontWeight->"Bold"],
  " Cohen, Martin P., (1983), ''Inversion in a Circle: A Different Kind of \
Transformation,'' The Math. Teach., V. 86, No. 8, pp. 620-623.\n\n",
  StyleBox["8.",
    FontWeight->"Bold"],
  " Eljoseph, Nathan, ''On the Iteration of Linear Fractional \
Transformations,'' Am. Math. M., Vol. 75, No. 4. (Apr., 1968), pp. 362-366, \
",
  StyleBox[ButtonBox["Jstor.",
    ButtonData:>{
      URL[ "http://www.jstor.org/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "   \n\n",
  StyleBox["9.",
    FontWeight->"Bold"],
  " Amir-Moez, (1967), ''Conformal Linear Transformations,'' Math. Mag., Vol. \
40, pp. 268-270."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Section 9.2",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["  ",
    FontSize->16,
    FontWeight->"Bold"],
  StyleBox["Exercises for Bilinear Transformations\n",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0.500008, 0.996109]],
  StyleBox["See textbook page 370.",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Section 9",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".3",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Mappings Involving Elementary Functions",
    ButtonData:>{"ca0903.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["Section 9",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".4",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Mappings by Trigonometric Functions",
    ButtonData:>{"ca0904.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["GO TO  THE",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox["  ",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox[ButtonBox["Table of Contents",
    ButtonData:>{"content.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "\n"
}], "Text"]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{756, 598},
WindowMargins->{{31, Automatic}, {Automatic, 6}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->16,
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 9"->{
    Cell[4362, 144, 318, 12, 35, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 9"]},
  "Section 9.2"->{
    Cell[5796, 193, 10697, 142, 41, "Text",
      Evaluatable->False,
      CellTags->"Section 9.2"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 9", 91592, 2569},
  {"Section 9.2", 91709, 2573}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 615, 20, 109, "Text",
  Evaluatable->False],
Cell[2345, 74, 1980, 65, 248, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4362, 144, 318, 12, 35, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 9"],
Cell[4683, 158, 480, 8, 110, "Input",
  InitializationCell->True]
}, Closed]],
Cell[5178, 169, 593, 20, 32, "Text"],

Cell[CellGroupData[{
Cell[5796, 193, 10697, 142, 41, "Text",
  Evaluatable->False,
  CellTags->"Section 9.2"],
Cell[16496, 337, 295, 9, 37, "Text"],
Cell[16794, 348, 1949, 49, 298, "Text"],
Cell[18746, 399, 1419, 38, 260, "Text"],
Cell[20168, 439, 547, 20, 56, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20740, 463, 103, 2, 33, "Text"],
Cell[20846, 467, 180, 6, 37, "Text"],
Cell[21029, 475, 371, 7, 165, "Input"],
Cell[21403, 484, 129, 5, 52, "Text",
  Evaluatable->False],
Cell[21535, 491, 596, 13, 211, "Input"],
Cell[22134, 506, 104, 5, 52, "Text",
  Evaluatable->False],
Cell[22241, 513, 525, 9, 173, "Input"],
Cell[22769, 524, 675, 18, 75, "Text",
  Evaluatable->False],
Cell[23447, 544, 284, 6, 110, "Input"],
Cell[23734, 552, 326, 8, 71, "Text",
  Evaluatable->False],
Cell[24063, 562, 138, 3, 70, "Input"],
Cell[24204, 567, 396, 11, 90, "Text",
  Evaluatable->False],
Cell[24603, 580, 1234, 24, 325, "Input"],
Cell[25840, 606, 381, 13, 56, "Text"]
}, Closed]],
Cell[26236, 622, 1424, 38, 112, "Text",
  Evaluatable->False],
Cell[27663, 662, 178, 4, 33, "Text",
  Evaluatable->False],
Cell[27844, 668, 469, 15, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[28338, 687, 103, 2, 33, "Text"],
Cell[28444, 691, 92, 3, 33, "Text"],
Cell[28539, 696, 1712, 32, 486, "Input"],
Cell[30254, 730, 189, 7, 52, "Text",
  Evaluatable->False],
Cell[30446, 739, 604, 12, 110, "Input"],
Cell[31053, 753, 135, 5, 52, "Text",
  Evaluatable->False],
Cell[31191, 760, 3826, 76, 677, "Input"]
}, Closed]],
Cell[35032, 839, 463, 14, 68, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[35520, 857, 103, 2, 33, "Text"],
Cell[35626, 861, 92, 3, 33, "Text"],
Cell[35721, 866, 1707, 32, 486, "Input"],
Cell[37431, 900, 291, 8, 57, "Text",
  Evaluatable->False],
Cell[37725, 910, 614, 13, 182, "Input"],
Cell[38342, 925, 183, 7, 52, "Text",
  Evaluatable->False],
Cell[38528, 934, 594, 12, 110, "Input"],
Cell[39125, 948, 135, 5, 52, "Text",
  Evaluatable->False],
Cell[39263, 955, 4043, 80, 667, "Input"]
}, Closed]],
Cell[43321, 1038, 569, 19, 54, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[43915, 1061, 103, 2, 33, "Text"],
Cell[44021, 1065, 217, 7, 38, "Text"],
Cell[44241, 1074, 410, 9, 147, "Input"],
Cell[44654, 1085, 129, 5, 52, "Text",
  Evaluatable->False],
Cell[44786, 1092, 412, 9, 131, "Input"],
Cell[45201, 1103, 155, 6, 52, "Text",
  Evaluatable->False],
Cell[45359, 1111, 954, 19, 230, "Input"],
Cell[46316, 1132, 618, 19, 71, "Text",
  Evaluatable->False],
Cell[46937, 1153, 242, 5, 110, "Input"],
Cell[47182, 1160, 166, 6, 52, "Text",
  Evaluatable->False],
Cell[47351, 1168, 3611, 70, 702, "Input"],
Cell[50965, 1240, 472, 15, 57, "Text",
  Evaluatable->False]
}, Closed]],
Cell[51452, 1258, 361, 9, 68, "Text",
  Evaluatable->False],
Cell[51816, 1269, 180, 4, 33, "Text",
  Evaluatable->False],
Cell[51999, 1275, 491, 15, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[52515, 1294, 103, 2, 33, "Text"],
Cell[52621, 1298, 771, 21, 58, "Text",
  Evaluatable->False],
Cell[53395, 1321, 1660, 32, 486, "Input"],
Cell[55058, 1355, 183, 7, 52, "Text",
  Evaluatable->False],
Cell[55244, 1364, 606, 12, 110, "Input"],
Cell[55853, 1378, 442, 15, 52, "Text",
  Evaluatable->False],
Cell[56298, 1395, 867, 16, 150, "Input"],
Cell[57168, 1413, 196, 6, 52, "Text",
  Evaluatable->False],
Cell[57367, 1421, 684, 15, 230, "Input"],
Cell[58054, 1438, 126, 5, 52, "Text",
  Evaluatable->False],
Cell[58183, 1445, 4154, 81, 681, "Input"],
Cell[62340, 1528, 515, 16, 74, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[62892, 1549, 166, 3, 34, "Text"],
Cell[63061, 1554, 2485, 68, 414, "Text"]
}, Closed]],
Cell[65561, 1625, 477, 16, 57, "Text"]
}, Open  ]],
Cell[66053, 1644, 594, 20, 35, "Text"],
Cell[66650, 1666, 590, 20, 35, "Text"],
Cell[67243, 1688, 339, 13, 57, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

