(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    210176,       7805]*)
(*NotebookOutlinePosition[    234537,       8690]*)
(*  CellTagsIndexPosition[    234427,       8683]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["COMPLEX ANALYSIS: ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Mathematica 4.1",
    FontSize->18,
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" Notebooks\n(c) John H. Mathews, and\nRussell W. Howell, 2002",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Complimentary software to accompany our textbook:",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]]
}], "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["COMPLEX ANALYSIS: for Mathematics and Engineering, \n4th Edition, \
 2001,  ISBN: ",
    FontSize->18,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["0-7637-1425-9",
    FontFamily->"Times New Roman",
    FontSize->18,
    FontColor->RGBColor[0, 0, 0.996109]],
  StyleBox["\n",
    FontSize->18,
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[ButtonBox["Jones & Bartlett Publishers, Inc.",
    ButtonData:>{
      URL[ "http://www.jbpub.com/"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" \n",
    FontSize->18,
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["40 Tall Pine Drive, Sudbury, MA 01776  \nTele.  (800) 832-0034, \
FAX:  (508)  443-8000  \nE-mail:  mkt@jbpub.com  \nInternet:  ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["http://www.jbpub.com/",
    ButtonData:>{
      URL[ "http://www.jbpub.com/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox["  ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n",
    FontSize->14],
  StyleBox["This free software is compliments of the authors.\n",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  ButtonBox["John H. Mathews",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[",   ",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["mathews@fullerton.edu \n",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  ButtonBox["Russell W. Howell",
    ButtonData:>{
      URL[ "http://www.westmont.edu/~howell"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[", ",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["howell@westmont.edu ",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CHAPTER 9",
    FontSize->18,
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["  ",
    FontSize->18],
  StyleBox["CONFORMAL MAPPING",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 9"],

Cell[BoxData[{
    \(\(S = \(T = \(w = \(W = \(x = \(y = \(z = \(Z = 
                      0\)\)\)\)\)\)\);\)\ \), "\n", 
    \(\(Clear[cos, f, F, g, graphs, Iden, S, set, sin, T, tan, w, W, w1, w2, 
        w3, wdot, wdots, wplane, z, z1, z2, z3, zdot, zdots, zplane, Z, 
        Zplane];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Section 9",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".1",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Basic Properties of Conformal Mappings",
    ButtonData:>{"ca0901.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["Section 9",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".2",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Bilinear Transformations",
    ButtonData:>{"ca0902.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Section 9.3",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  "  ",
  StyleBox["Mapping Involving Elementary Functions",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001f80@0006@000000000000001D0000E0000
00000000001?0`00C`<00215CDH00040R1d001@00002000000000000002l000080<005P200100@00
l000000000000000000004H0003H3000bP`004M4BD<1002000<00393]ST00000/P`000402@000eT6
00010284000000T0000V1Pl0201OATeBBE@Y80<0000N00D0000;0P0000050000308O01l01@800?L0
00<00@00001gMgL0EEEE0<`0b`3^k^h0IP1U0?g;0028R8P006Gm0?ooo`14A4@08R8R000000000000
00000000003k:O00M`400000e03b4P00b8/G002ni@110;`0lQ800:Cc4P00/?l04P140;OcM`0hc_<0
Mooo0?oob02;5`00^o530038G@0H01P0o18006H00000b8/05`2600:D0@3P_AX000400000b01M6000
C00000260P2D0@0004000<QM6000000000000000000100000>Bn01X0100100000000000000000>00
_AX0063c4P00K000200A000P000000000<R;01L0H01c@000e098001?L01UKP0000<000800000g?<0
4P100>i20004000001810000n00JG`00@cYL06Q_K@1UL640IfEL06MYIP1c04d0HGAX06E]H@1dJF<0
HD9Y06L^I`1YIP00g?<B0007PP3WM`000000000000008000003L0?<B000lm18004mR0?Mgc03c4P00
<0000000000300800000043^@P00kB40igND004200000P000000000060000@00dLjR00lH00000480
000000800000Ha40igN600:D0@0B0@0009G`00004P007`000000002N0P00004000000:QSG`00n1X0
G`3@00PF000C000002H0000000000000G?DB0002<`3]M`00000000PTG`00QP80U04B0040002El000
00000000P03d4P00OUSW07L8901O0000000000040000000000000000003RF>L0M`PT05l000000000
00@00030>P3XMd<0>UaX06m]I@1`HFL0IEaW06UVL`1LCF40M6QU06eQM01YHf40@VUW02iWJ@1V08H0
0Y@100000000RDX0mWM800DD001V000000P00000QP02U040>aM500260P2D0I@00@8001810000@aL0
A@2600:D0@30ma800080000000000000n1YO0007002:0A00mA8009XAk@1ge`@00GD7002:0@0N0`00
00000000J0035P000001003Hm@0B06@0BZ]g09810P00G?D04P0>05_WM`30RaL00000000000005000
8040000800000040000008Se4P00/bP0l7L0000D000800@001P10000IP000000IP0000260P2D0ML0
105e00000000208000000000001f0P00053e018000000000/?lB0014]`3cMlP0cO=g0?ooo`3o1HH0
@`2600:D0@040000=08000<0000e00D000070@<0000R1000@`lP0<`0000P02000000020080000000
:0000200000P00000@08000000001000a0h00<@>00000@0000000000001gMgL0EEEE0</0c03^k^h0
I@1V003;o@28R8P0oFD00?ooo`14A4@08R8R00000000000000000000003`:O/0005g0=@000004_80
5h_80>Fn002l044001;b01;cY03o/000A00B07Oc]`3ccSP0oomg0<Soo`005h/0@o6k05g8000H01P0
01;l0000IP2;b000QP0G006D0P0J_N0000400<P0000065d0001<00:600000I@0040001QMb0000000
0000000000000040_^@000@06P00004000000000003P000001Zm01;cH000K0004@08000P00000000
RlP006005`00@7<0B0;D071?0000KVD000<000000P3cg000@00B0012kP0000@00A800?P00000GaX0
G3Y306e_J01QL6D0G6EW06IYI`1=07<0J7AQ065]I@1SJG@0JD9Q06L^I`00IVT04_?L08870000MnL0
0000000000008000g000000Bl`0Bm3`0HTl00<agm`004_<0000`0000000200<0000004;^@00Qk@00
U7OW00020@000P00000001P000000@00X/kA000H3`120000000000000P0AH`00QWOW006D0P000A80
l9D0018000007`00000000:N00010000000005mSZ00Jn000d01O000F200001<002H0000000000000
4_EL03<20000Mnd0000005lT2002QP004P6D00000@00l9D00000080000004_@0ieQn02@8M`0005l0
000000040000000000000000003WF>8090Qg0000G`00000000@003[00013MnP0J5`j06E]K`1WHG00
IeaU07=VJ@1QCE`0IFQd07AQK@1QHfT0IfU206UW;P2606H00I@20000001:R@00B7Of000D1@0006H0
00P008H00001U080AALk00:6002D0I@0008100014P0G@`00QP15006D0P0Bml000080000000000000
Ga[h0007000@0HX001;e0>dAVP04egL01gD1006:00000ah0000006P000005P<00@000?GH001T0180
Mj]:0081TP3eG0003P0B07OWF`0GRl000000000000005000004P000800010000000001;eR00X/`00
07O`000D000400P00AP006H000000000001V00:6003G0I@0M@440000000220000000000000000WH0
mE0000004P0000004_n`0;M40038Mo<0Mo?=0?ooo`261Ol0QP13006D0P092@T00000000000000000
0000000000000000000000T000071`L71`L71`L71`L71`L71`L71`L71`L71`L000T0000000000000
0000000000000000000000001`002@0410@410@410@410@410@410@410@410@4100700T0000410@4
10@410@410@410@410@410@410@400L000T010@410@400000P4410@41040004410@410@01`002@04
10@410@02000000:100000D0000010@4100700T0000410@4100820011P0000D500030`0410@400L0
00T010@410@400P820001P051@070P0300@410@01`002@0410@4104020P8208000D01`L72`0210@4
100700T0000410@40@0820P8208000L71`L200@410@400L000T010@4104000P820P820071`L71`80
0@@410@01`002@0410@400D5000000000000000000000@@4100700T000040@0000002`X21`080P05
1@0000L000@400L000T010@000L71`L71`L000P820801@0000L000@01`002@0400<300L71`L70006
00P820P000030004100700T000000`<300L71`0000H600P820P00`<010@400L000T010800`<300L0
00D01PH600P800<30`<010@01`002@0410X0000000051@061PH600030`<30`<0100700T0000410@2
0000000000H61PH:00<30`0000@400L000T010@410@:00<30P000000000000000@@410@01`002@04
10@4100500830`<30`<300H6004410@4100700T0000410@1000700<30`<30`001PH010@410@400L0
00T010@410001`L00P<30`<020P01P0410@410@01`002@0410@400L:00000`<30P0020P000@410@4
100700T0000410@0000110400`80108000P010@410@400L000T010@410@410@4100300@410@10004
10@410@01`002@0410@410@410@4100410@410@40P@410@4100700T0000410@410@410@410@410@4
10@410@410@400L000T010@410@410@410@410@410@410@410@410@01`002@0410@410@410@410@4
10@410@410@410@410002@T000000000000000000000000000000000000000T9100002L1ool30000
00000140000<0000200000/0000@00005@0001D000090000400001D0000E00008@0000P0000:0000
40000000000000002@000100000O00007`000340000@10000@00000300400000MgMg05EEE@3<0</0
k^k^06H0I@3mb`00R8R8001Uo@3oool0A4A4028R8P0000000000000000000000nbW`07L100000=@0
lQ800<R;5`00_^D0@@2l0?8B002Tla800;3o0180A02glgL0><kc07Ooo`3oolP0RaL00;_a@`00b5d0
600H0?`B001V00000<R;01L0QP02U040h;dJ000100000<P0GAP004`00000QP80U04000100038GAP0
00000000000000000@00003T_P0J00@00@00000000000000003P0;dJ001Pla8006`000P04@008000
00000038R`0G0600Ld000=@2B000Cg00IFh00003000200000=cc0180@03^@P001000000B0@000?P0
6Ul004<jG01XKfd0IG1Q06MUG01WJFH0L`1=065dJ01UKF40M6US0652J@1W;VL0JFH00=cc4P001h80
igL000000000000002000000g03c4P00??@B001?HP3gMl`0la800300000000000`0200000010kT80
0>dQ0>MgU0010P0000800000000001P000400=7>XP0?6000001200000002000006<A0>MgQP02U040
4P40002El000018001l000000000WP8000010000002XHel00?PJ05l0d0085P004`00000V00000000
000005ce4P000S<0kGL00000000895l008H209@14P010000UO00000000000800m18007iHi`1g22@0
G`000000000010000000000000000000hUSW07L8901O0000000000040000`3X0j7M303YLJ01_KFD0
L65W06ELI`1YIW<0G4eQ07AXI@1]HG@0JF=Q049YI`0^IfT0IP2600:D0@00000008U:0?IgB0055000
IP000008000008H00Y@103/GA@00QP80U06D0042000B0@0004<G04D0QP02U040`?LB000200000000
00000?PJG`001`00RP4@0?DB002J4Nd0MmL4005e1`00RP407P<00000000006P00aH000000@00f?D0
4P1T04Z[M`2B0@8005ce01803P1KigL0`8/G00000000000001@0020100002000000100000028mA80
0;<X0?1g000050002004000H0@0006H0000006H00000QP80U07G00@1M@00000000P2000000000000
MP80001@m@0B000000000;3o4P00A;L0lgO80<gcM`3oool0o`F604<0QP02U040<00000`000010000
=00000P0000E0000300000<0001A0000N0P00000000000005@0001D0000000000000000000000000
80000200001@0000:0@007P40000100000000200c00P0000800002P0000P00008000004020000000
00@00<@>00343P000040000000000000MgMg05EEE@3;0<`0k^k^06D0IP00bod0R8R80?eU003oool0
A4A4028R8P0000000000000000000000l2Wk0001M`3D000001;b01N;b03U_P00_011000BlP0Blj@0
ok0004@04P1glkL0llhh0?ooM`38ool001N;04?a^`1Mb000600H000Bo00006H0RlP008H05`01U080
6[gP00010038000001QM0000C002QP00006D0010000HGLP0000000000000000000010;kT000401X0
0001000000000000h000000J_@0Blf0006`0014020008000000008_8001P01L0041c04P2e01`C`00
06iU000300000080lm`004004P00@^h00004004B003h000005lJ05`j@`1]KfP0HG1U05aUI`1VJFL0
C@1c06QdH@1QKFD0HfUd06U2H@1W;VL006IY01;cg0221`0007OW00000000000002000=`000004_<0
4_@l069?003<MoL001;c0000<00000000P0300000012kT008Nd009Agi`000P4000800000000H0000
00400:;>d@0060l0@P000000000000804F<008Igi`01U080004B0?2E000B000001l000000002WP00
0@000000001OHjP06_P00=00G`005PP0000C000V00000000000001;eG00c0P0007O]0000001O90P0
0XH00181U00000400?2E00000020000001;d0>MHOP0T27L0001O0000000010000000000000000000
ieSR02@8M`0005l000000004000j`000@gOX06QL>P1UKFl0If5`06MLI@1cIVT0HDeL06EXM01dHFd0
HF=Y06MY@P1YIbh0QP1V006D0P000000BXT004QgmP0050D0001V0008002600000I@204DG>`02QP00
U06D00020@000A805d<008H0A@01U0804_O0000200000000000005lJn0001`00406:000Bm@3]4IX0
1=Mg00Me0@01RP0000<N0000001X000001H30040003ef000I00B07N[BP020I80mE`000h04P1gie/0
5h_000000000000001@00001800020000@000000000BmHP0:;<0001gl00050001008004H001V0000
00000000IP02QP00e`6D07D1100000000PP0000000000000009f0?E@00000180000001;o/02gA000
b7Oc07Occ@3oool0QPGo08H0@`01U0802@T900000000000000000000000000000000000000090000
1`L71`L71`L71`L71`L71`L71`L71`L71`L7000900000000000000000000000000000000000000L0
00T010@410@410@410@410@410@410@410@410@01`09000010@410@410@410@410@410@410@410@4
1007000900@410@41000008110@410@1000110@410@400L000T010@410@400P000002P@000050000
00@410@01`09000010@410@020P00@H000051@000`<010@41007000900@410@4100820P000H01@D0
1`800`0410@400L000T010@410@100P820P2000500L71`/00P@410@01`09000010@4104020P820P2
00071`L70P0410@41007000900@410@1000820P820P01`L71`L2004410@400L000T010@410051@00
0000000000000000004410@01`0900001040000000/:0PL020801@D0000700041007000900@40007
1`L71`L7000820P200D00007000400L000T010030`071`L71`001P0820P800000`0010@01`090000
00<30`071`L000061P0820P800<300@41007000900@200<30`07000500H61P0820030`<300@400L0
00T010@:000000001@D01PH61P000`<30`<300@01`09000010@40P00000000061PH62P030`<00004
1007000900@410@42P030`80000000000000004410@400L000T010@410@01@020`<30`<30`061P01
10@410@01`09000010@40@001`030`<30`<000H600@410@41007000900@410@000L700830`<300P8
00H010@410@400L000T010@410072P0000<30`8000P8000410@410@01`09000010@400000@@100<2
00@2000800@410@41007000900@410@410@410@00`0410@40@0010@410@400L000T010@410@410@4
10@010@410@4108410@410@01`09000010@410@410@410@410@410@410@410@41007000900@410@4
10@410@410@410@410@410@410@400L000T010@410@410@410@410@410@410@410@410@000T90000
0000000000000000000000000000000000092B80000<0000ooooobD0000<00001`00P2D0000<0000
0000P300000<00003`00P4/0000@0000000000D0000X000030000040000>000010<00;`0000@0000
000007MgM`1EEED0c03;0>k^kP1V06D0oL/008R8R000IOd0oooo04A4A00R8R80nbW`07L100000=@0
lQ800<R;5`00_^D0@@2l0:Cc4P00/?l04P140;OcM`0hc_<0Mooo0?oob02;5`00^o530038G@0H01P0
o18006H00000b8/05`2600:D0@3P_AX000400000b01M6000C00000260P2D0@0004000<QM60010000
0>Bn01X010000>00_AX0063c4P00K000200A000P000G0600Ld000=@2B000Cg00IFh0000300020000
0=cc0180@03^@P001000000B0@000?P06Ul004<jG01XKfd0IG1Q06MUG01WJFH0L`1=065dJ01UKF40
M6US0652J@1W;VL0JFH00=cc4P001h80igL00000g03c4P00??@B001?HP3gMl`0<00000<00P10kT80
0>dQ0>MgU0010P0000800000603AcZ803aP00000@P00Ha40igN601810000UO00000B000O0000WP80
00010:QSG`00n1X0G`3@00PF000C000002H005ce4P000S<0kGL000PTG`2D0A80UO000000P03d4P00
OUSW07L8901O000000@00>9Hi`00`3X0j7M303YLJ01_KFD0L65W06ELI`1YIW<0G4eQ07AXI@1]HG@0
JF=Q049YI`0^IfT0IP260029BP3fMdP01A@00008000008H0>aM509@1U000@aL0A@260<3g4P3h6Ul0
00L008X1403e4P00VQ7]07OG1001M@L008X101h3000006P00aH0003Hm@0B06@0BZ]g09810P00G?D0
4P0>05_WM`30RaL001@002010028mA800;<X0?1g000800@001P10000IP2D0ML0105e00080P1f0P00
053e0180002`oa8004Bg0?=gb03=lgL0o`F604<0QP040`00
\>"], "Graphics",
    ImageSize->{21, 21}],
  StyleBox["  ",
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->18,
  CellTags->"Section 9.3"],

Cell[TextData[{
  "\tIn ",
  ButtonBox["Section 5.1",
    ButtonData:>{"ca0501.nb", None},
    ButtonStyle->"Hyperlink"],
  " we saw that the function  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \[ExponentialE]\^z\)\)]],
  "  is a one-to-one mapping of the fundamental period strip  ",
  Cell[BoxData[
      \(\(-\[Pi]\) < y \[LessEqual] \[Pi]\)]],
  "  in the z-plane onto the w-plane with the point  ",
  Cell[BoxData[
      \(w = 0\)]],
  "  deleted.  Since  ",
  Cell[BoxData[
      \(f' \((z)\) \[NotEqual] 0\)]],
  ",  the mapping  ",
  Cell[BoxData[
      \(w = \[ExponentialE]\^z\)]],
  "  is a conformal mapping at each point  z  in the complex plane.  The \
family of horizontal lines  ",
  Cell[BoxData[
      \(y = c\ \ and\ \  - \[Pi] < c \[LessEqual] \[Pi]\)]],
  ",  and segments  ",
  Cell[BoxData[
      \(x = a\ \ and\ \  - \[Pi] < y \[LessEqual] \[Pi]\)]],
  "  form an orthogonal grid in the fundamental period strip.  Their images \
under the mapping  ",
  Cell[BoxData[
      \(w = \[ExponentialE]\^z\)]],
  "  are the rays  ",
  Cell[BoxData[
      \(\[Rho]\  > 0\ \ and\ \ \[Phi] = c\)]],
  "  and the circles  ",
  Cell[BoxData[
      \(\(\(|\)\(w\)\(|\)\) = \[ExponentialE]\^a\)]],
  ",  respectively.  These images form an orthogonal curvilinear grid in the \
w-plane."
}], "Text"],

Cell[TextData[{
  StyleBox["\nExample 9.8,  Page 372.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \(\[ExponentialE]\^z\  - \ \[ImaginaryI]\)\/\(\
\[ExponentialE]\^z\  + \ \[ImaginaryI]\)\)\)],
    AspectRatioFixed->True],
  "  is a one-to-one conformal mapping of the horizontal strip  ",
  Cell[BoxData[
      \(0 < y < \[Pi]\)]],
  "  onto the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(w\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ".  Furthermore, the x-axis is mapped onto the lower semicircle bounding \
the disk, and the line  ",
  Cell[BoxData[
      \(y = \[Pi]\)]],
  "  is mapped onto the upper semicircle."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f \((z)\) = \(\[ExponentialE]\^z\  - \ \[ImaginaryI]\)\/\(\
\[ExponentialE]\^z\  + \ \[ImaginaryI]\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[w, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, solset];\)\ \), "\n", 
    \(\(f[
          z_]\  = \ \ \(\[ExponentialE]\^z - \[ImaginaryI]\)\/\(\
\[ExponentialE]\^z + \[ImaginaryI]\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nTo show  ",
  Cell[BoxData[
      \(f \((z)\) = \(\[ExponentialE]\^z\  - \ \[ImaginaryI]\)\/\(\
\[ExponentialE]\^z\  + \ \[ImaginaryI]\)\)],
    AspectRatioFixed->True],
  "  is one-to-one conformal we need to find the inverse function"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(solset\  = \ 
        Solve[w\  \[Equal] \ f[z], z];\)\ \), "\n", 
    \(\(g[w_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\<g[w] = \>", g[w]];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", f[g[w]], "\< = \>", 
        Simplify[f[g[w]]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", g[f[z]]];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", 
        Simplify[g[f[z]]], "\< = \>", \[IndentingNewLine]PowerExpand[
          Simplify[g[f[z]]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

The image is traced using a graph.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[f, z];\)\ \), "\n", 
    \(\(f[
          z_]\  = \ \ \(\[ExponentialE]\^z - \[ImaginaryI]\)\/\(\
\[ExponentialE]\^z + \[ImaginaryI]\);\)\ \), "\n", 
    \(\(CartesianMap[
        Identity, {\(-6\), 6, 
          0.5}, {0, \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] \
{{\(-6.4\), 6.4}, {0, 3.2}}, 
        AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-6\), 6, 2], 
            Range[0, 3, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Magenta, Pink}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The horizontal strip 0 < y < \[Pi].\>"];\)\ \), "\n", 
    \(\(CartesianMap[f, {\(-6\), 6, 0.5}, {0, \[Pi], \[Pi]\/12}, 
        PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-1.1\), 
              1.1}}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Magenta, Pink}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image is the disk |w|< 1,\>"];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \(\[ExponentialE]\^z\  - \ \[ImaginaryI]\)\/\(\
\[ExponentialE]\^z\  + \ \[ImaginaryI]\)\)\)],
    AspectRatioFixed->True],
  "  maps the horizontal strip  ",
  Cell[BoxData[
      \(0 < y < \[Pi]\)]],
  "  onto the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(w\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Example 9.9,  Page 373.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = Log \((\(1\  + \ z\)\/\(1\  - \ z\))\)\)\)],
    AspectRatioFixed->True],
  "  is a one-to-one conformal mapping of the unit disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  onto the horizontal strip  ",
  Cell[BoxData[
      \(\(\(|\)\(v\)\(|\)\(\(<\)\(\ \)\(\[Pi]\/2\)\)\)\)]],
  ".  Furthermore, the upper semicircle of the disk is mapped onto the line  \
",
  Cell[BoxData[
      \(v = \[Pi]\/2\)]],
  "  and the lower semicircle onto  ",
  Cell[BoxData[
      \(v = \(-\ \[Pi]\)\/2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f \((z)\) = Log \((\(1\  + \ z\)\/\(1\  - \ z\))\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[w, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, solset, w, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ \ Log[\(1 + z\)\/\(1 - z\)];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nTo show  ",
  Cell[BoxData[
      \(f \((z)\) = Log \((\(1\  + \ z\)\/\(1\  - \ z\))\)\)],
    AspectRatioFixed->True],
  "  is one-to-one conformal we need to find the inverse function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(solset\  = \ 
        Solve[w\  \[Equal] \ f[z], z];\)\ \), "\n", 
    \(\(g[w_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\<g[w] = \>", g[w]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", g[f[z]], "\< = \>", 
        Simplify[g[f[z]]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", f[g[w]]];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", 
        Simplify[f[g[w]]], "\< = \>", \[IndentingNewLine]PowerExpand[
          Simplify[f[g[w]]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

The image is traced using a graph.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[f, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ \ \ Log[\(1 + z\)\/\(1 - z\)];\)\ \), "\n", 
    \(\(PolarMap[
        Identity, {0.000005, 0.999995, 0.11111}, \[IndentingNewLine]{0, 
          2  \[Pi], \[Pi]\/12}, 
        PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-1.1\), 1.1}}, 
        PlotRegion \[Rule] {{0.15, 0.85}, {0.15, 0.85}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Green, 
            DarkGreen}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The unit disk |z| < 1.\>"];\)\ \), "\n", 
    \(\(PolarMap[
        f, {0.000005, 0.999995, 0.11111}, \[IndentingNewLine]{0, 
          2  \[Pi], \[Pi]\/12}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-1.6\), 1.6}}, 
        AspectRatio \[Rule] 1.6\/3, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], 
            Range[\(-\[Pi]\)\/2, \[Pi]\/2, \[Pi]\/2]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Green, 
            DarkGreen}];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The image is the horizontal strip |v| < \
\!\(\[Pi]\/2\),\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = Log \((\(1\  + \ z\)\/\(1\  - \ z\))\)\)\)],
    AspectRatioFixed->True],
  "  maps the unit disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  onto the horizontal strip  ",
  Cell[BoxData[
      \(\(\(|\)\(v\)\(|\)\(\(<\)\(\ \)\(\[Pi]\/2\)\)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Example 9.10,  Page 373.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \((1\  + \ z)\)\^2\/\((1\  - \ z)\)\^2\)\)],
    AspectRatioFixed->True],
  "  is a one-to-one conformal mapping of the portion of the unit disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  that lies in the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  onto the upper half-plane  ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  ".  Furthermore, the upper semicircular portion of the boundary is mapped \
onto the line negative u-axis, and the segment  ",
  Cell[BoxData[
      \(\(-1\) < x < 1, y = 0\)]],
  "  is mapped onto the positive u-axis."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f \((z)\) = \((1\  + \ z)\)\^2\/\((1\  - \ z)\)\^2\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[w, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, solset];\)\ \), "\n", 
    \(\(f[z_]\  = \ \ \((1 + z)\)\^2\/\((1 - z)\)\^2;\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nTo show  ",
  Cell[BoxData[
      \(f \((z)\) = \((1\  + \ z)\)\^2\/\((1\  - \ z)\)\^2\)],
    AspectRatioFixed->True],
  "  is one-to-one conformal we need to find the inverse function.  Since \
there is two branches, one of them is appropriate for this problem."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(solset\  = \ 
        Solve[w\  \[Equal] \ f[z], z];\)\ \), "\n", 
    \(\(g[w_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\<g[w] = \>", g[w]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", f[g[w]], "\< = \>", 
        Simplify[f[g[w]]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", g[f[z]]];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", 
        PowerExpand[g[f[z]]], "\< = \>", \[IndentingNewLine]Simplify[
          PowerExpand[g[f[z]]]]];\)\ \), "\n", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

The image is traced using a graph.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[f, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ \ \((1 + z)\)\^2\/\((1 - z)\)\^2;\)\ \), "\n", 
    \(\(PolarMap[
        Identity, {0.000005, 0.999995, 0.11111}, \n{0, \[Pi], \[Pi]\/12}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Cyan, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The portion of the unit disk |z| < 1,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<that lies in the upper half-plane Im[z] > 0.\>"];\)\ \), "\n\
", 
    \(\(PolarMap[f, {0.000005, 0.999995, 0.11111}, {0, \[Pi], \[Pi]\/12}, 
        PlotRange \[Rule] {{\(-4.2\), 4.2}, {0, 4.5}}, 
        AspectRatio \[Rule] 4.5\/8, 
        Ticks \[Rule] {Range[\(-4\), 4, 2], Range[0, 4, 2]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Cyan, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image is the upper half-plane Im[w] > 0,\>"];\)\ \), "\n\
", 
    \(\(Print["\<under the mapping w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \((1\  + \ z)\)\^2\/\((1\  - \ z)\)\^2\)\)],
    AspectRatioFixed->True],
  "  maps the portion of the unit disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  that lies in the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  onto the upper half-plane  ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Example 9.11,  Page 374.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the function  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \@\(z\^2\  - \ 1\)\)\)],
    AspectRatioFixed->True],
  ",  which is the composition of the functions  ",
  Cell[BoxData[
      \(Z = z\^2 - 1\)]],
  "  and  ",
  Cell[BoxData[
      \(w = \@Z\)]],
  "  where the branch of the square root is  ",
  Cell[BoxData[
      \(\@Z = \(\(\@R\) \((cos \((\[Theta]\/2)\)\  + \ \[ImaginaryI]\ sin \((\
\[Theta]\/2)\))\)\ \ \ where\ \ \[Theta] = 
          arg \((Z)\)\ \ and\ \ 0 \[LessEqual] \[Theta] < 2  \[Pi]\)\)]],
  ".  Then the transformation  ",
  Cell[BoxData[
      \(w = f \((z)\)\)],
    AspectRatioFixed->True],
  "  maps the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  one-to-one and onto the upper-half plane  ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  "  slit along the segment  ",
  Cell[BoxData[
      \(u = 0, 0 < v \[LessEqual] 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f \((z)\) = \@\(z\^2\  - \ 1\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[w, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, solset];\)\ \), "\n", 
    \(\(f[z_]\  = \ \@\(z\^2\  - \ 1\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nTo show  w = f(z) = ",
  Cell[BoxData[
      SqrtBox[
        RowBox[{
          StyleBox[\(z\^2\),
            FontSize->14], " ", "-", " ", "1"}]]]],
  "  is one-to-one conformal we need to find the inverse function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(f[
          z_]\  = \ \@\(z\^2\  - \ 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[w\  \[Equal] \ f[z], z];\)\ \), "\n", 
    \(\(g[w_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\<g[w] = \>", g[w]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", f[g[w]], "\< = \>", 
        PowerExpand[f[g[w]]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", g[f[z]], "\< = \>", 
        PowerExpand[g[f[z]]]];\)\ \), "\n", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nHowever, in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  the branch cut for square root is along the negative x-axis.  For \
graphing purposes, we need the version of the function f(z) with a branch cut \
along the positive x-axis  ",
  Cell[BoxData[
      \(f \((z)\) = \[ImaginaryI] \@\( 1 - z\^2\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(f[
          z_]\  = \ \ \[ImaginaryI]\ \@\(1\  - \ z\^2\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", \@\(z\^2\  - \ 1\)];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The branch we will use for graphing\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

The image is traced using a graph.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[f, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ \ \[ImaginaryI]\ \@\(1\  - \ z\^2\);\)\ \), "\n", 
    \(\(CartesianMap[
        Identity, {\(-3\), 3, 0.5}, {0.00005, 1.35005, 
          0.09}, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 3}, {0, 
              1.5}}, AspectRatio \[Rule] 
          1.35\/6, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 3, 1], 
            Range[0, 1, 0.5]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Magenta, Pink}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The upper half-plane Im[z] > 0.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(CartesianMap[f, {\(-3\), 3, 0.5}, {\(-0.00005\), 1.35005, 0.09}, 
        PlotRange \[Rule] {{\(-3\), 3}, {0, 2}}, AspectRatio \[Rule] 1\/3, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[0, 2, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Magenta, Pink}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image is the upper-half plane Im[w] > 0,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<slit along the segment u = 0, 0 < v \[LessEqual] 1,\>"];\)\ \
\), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \[ImaginaryI]\ \@\(1\  - \ z\^2\)\)\)],
    AspectRatioFixed->True],
  "  maps the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  one-to-one and onto the upper-half plane  ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  "  slit along the segment  ",
  Cell[BoxData[
      \(u = 0, 0 < v \[LessEqual] 1\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["The Riemann Surface for  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(w = \((z\^2\  - \ 1)\)\^\(1/2\)\)],
    AspectRatioFixed->True,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "\n\tUsing the other branch of the square root, we find that ",
  Cell[BoxData[
      \(w = \(\(f\_2\) \((z)\) = \(-f\_1\) \((z)\)\)\)]],
  ", is a one-to-one conformal mapping from the domain set ",
  Cell[BoxData[
      \(D\_2\)]],
  " consisting of the z-plane slit along the segment ",
  Cell[BoxData[
      \(\(-1\) \[LessEqual] x \[LessEqual] 1, y = 0\)]],
  ", onto the range set ",
  Cell[BoxData[
      \(H\_2\)]],
  " consisting of the w-plane slit along the segment ",
  Cell[BoxData[
      \(u = 0, \(-1\) \[LessEqual] v \[LessEqual] 1\)]],
  ". The sets ",
  Cell[BoxData[
      \(D\_1\)]],
  " and ",
  Cell[BoxData[
      \(H\_1\)]],
  " for ",
  Cell[BoxData[
      \(\(f\_1\) \((z)\)\)]],
  " and ",
  Cell[BoxData[
      \(D\_2\)]],
  " and ",
  Cell[BoxData[
      \(H\_2\)]],
  " form the ",
  ButtonBox["Riemann Surface",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RiemannSurface.html"], None},
    ButtonStyle->"Hyperlink"],
  " for the mapping, as shown below.\n\n",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .79324 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-016 1.09033 -0.0920072 1.09033 [
[ 0 0 0 0 ]
[ 1 .79324 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .79324 L
0 .79324 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.39215 .41332 m .35405 .4124 L p .33848 .38592 L 1 1 1 r
F P
0 g
s
.30977 .3925 m .33848 .38592 L p .35405 .4124 L 1 1 1 r
F P
0 g
s
.35405 .4124 m .34323 .41051 L .30977 .3925 L p 1 1 1 r
F P
0 g
s
.4381 .40347 m .42187 .41397 L .39215 .41332 L p 1 1 1 r
F P
0 g
s
.33848 .38592 m .4381 .40347 L p .39215 .41332 L 1 1 1 r
F P
0 g
s
.47531 .41233 m .42187 .41397 L .4381 .40347 L p 1 1 1 r
F P
0 g
s
.54472 .40894 m .54481 .4101 L .47531 .41233 L p 1 1 1 r
F P
0 g
s
.4381 .40347 m .54472 .40894 L p .47531 .41233 L 1 1 1 r
F P
0 g
s
.55129 .40951 m .54481 .4101 L .54472 .40894 L p 1 1 1 r
F P
0 g
s
.54472 .40894 m .58523 .40638 L .55129 .40951 L p 1 1 1 r
F P
0 g
s
.58523 .40638 m .54472 .40894 L .54291 .39858 L p .963 1 1 r
F P
0 g
s
.54472 .40894 m .4381 .40347 L .46039 .39461 L p .904 1 1 r
F P
0 g
s
.46039 .39461 m .54291 .39858 L .54472 .40894 L p .904 1 1 r
F P
0 g
s
.64098 .40183 m .58523 .40638 L p .54291 .39858 L .963 1 1 r
F P
0 g
s
.25918 .35896 m .33848 .38592 L .30977 .3925 L closepath p 1 1 1 r
F P
0 g
s
.4381 .40347 m .33848 .38592 L .38414 .38143 L p .887 1 1 r
F P
0 g
s
.38414 .38143 m .46039 .39461 L .4381 .40347 L p .887 1 1 r
F P
0 g
s
.62575 .39316 m .64869 .40119 L .64098 .40183 L p .963 1 1 r
F P
0 g
s
.54291 .39858 m .62575 .39316 L p .64098 .40183 L .963 1 1 r
F P
0 g
s
.75161 .38336 m .71305 .39061 L .64869 .40119 L p 1 1 1 r
F P
0 g
s
.64869 .40119 m .62575 .39316 L p .75161 .38336 L 1 1 1 r
F P
0 g
s
.71305 .39061 m .75161 .38336 L .7551 .38413 L closepath p 1 1 1 r
F P
0 g
s
.33848 .38592 m .25918 .35896 L .25576 .35698 L p .915 1 1 r
F P
0 g
s
.25576 .35698 m .32015 .35968 L p .33848 .38592 L .915 1 1 r
F P
0 g
s
.32015 .35968 m .38414 .38143 L .33848 .38592 L p .915 1 1 r
F P
0 g
s
.77372 .38015 m .7551 .38413 L .75161 .38336 L p 1 1 1 r
F P
0 g
s
.83779 .35314 m .88806 .35574 L .77372 .38015 L p 1 1 1 r
F P
0 g
s
.75161 .38336 m .83779 .35314 L p .77372 .38015 L 1 1 1 r
F P
0 g
s
.83779 .35314 m .75161 .38336 L .70291 .3786 L p 1 1 1 r
F P
0 g
s
.62575 .39316 m .70291 .3786 L .75161 .38336 L p 1 1 1 r
F P
0 g
s
.38374 .78302 m .34324 .7926 L p .32776 .73328 L 1 1 1 r
F P
0 g
s
.29694 .75799 m .32776 .73328 L p .34324 .7926 L 1 1 1 r
F P
0 g
s
.34324 .7926 m .33179 .79135 L .29694 .75799 L p 1 1 1 r
F P
0 g
s
.43265 .74558 m .41524 .77563 L .38374 .78302 L p 1 1 1 r
F P
0 g
s
.32776 .73328 m .43265 .74558 L p .38374 .78302 L 1 1 1 r
F P
0 g
s
.47164 .7655 m .41524 .77563 L .43265 .74558 L p 1 1 1 r
F P
0 g
s
.9723 .33091 m .96488 .33536 L .88806 .35574 L p 1 1 1 r
F P
0 g
s
.96416 .31867 m .9723 .33091 L p .88806 .35574 L 1 1 1 r
F P
0 g
s
.88806 .35574 m .83779 .35314 L p .96416 .31867 L 1 1 1 r
F P
0 g
s
.62575 .39316 m .54291 .39858 L .54079 .39643 L p .78 1 1 r
F P
0 g
s
.54079 .39643 m .54291 .39858 L p .51171 .39631 L .695 1 1 r
F P
0 g
s
.47693 .39378 m .54079 .39643 L p .51171 .39631 L .695 1 1 r
F P
0 g
s
.54079 .39643 m .54062 .39673 L p .54449 .39645 L .751 .65 .65 r
F P
0 g
s
.60516 .39205 m .62575 .39316 L p .58541 .39472 L .78 1 1 r
F P
0 g
s
.54079 .39643 m .60516 .39205 L p .58541 .39472 L .78 1 1 r
F P
0 g
s
.70291 .3786 m .62575 .39316 L .60516 .39205 L p .907 1 1 r
F P
0 g
s
.60516 .39205 m .58869 .39718 L p .6256 .3893 L .65 .65 .65 r
F P
0 g
s
.66496 .38089 m .70291 .3786 L p .65625 .38502 L .907 1 1 r
F P
0 g
s
.60516 .39205 m .66496 .38089 L p .65625 .38502 L .907 1 1 r
F P
0 g
s
.66496 .38089 m .60516 .39205 L p .6256 .3893 L .65 .65 .65 r
F P
0 g
s
.6357 .38866 m .66496 .38089 L p .62852 .38867 L .65 .65 .65 r
F P
0 g
s
.58869 .39718 m .6357 .38866 L p .62852 .38867 L .65 .65 .65 r
F P
0 g
s
.6357 .38866 m .61334 .40053 L p .64311 .38865 L .668 .65 .65 r
F P
0 g
s
.66496 .38089 m .6357 .38866 L p .67398 .3766 L .888 1 1 r
F P
0 g
s
.67507 .37588 m .71513 .36364 L p .67702 .37565 L .888 1 1 r
F P
0 g
s
.6357 .38866 m .67507 .37588 L p .67702 .37565 L .888 1 1 r
F P
0 g
s
.67507 .37588 m .6357 .38866 L p .64311 .38865 L .668 .65 .65 r
F P
0 g
s
.71513 .36364 m .66496 .38089 L p .67398 .3766 L .888 1 1 r
F P
0 g
s
.76827 .35561 m .70291 .3786 L .66496 .38089 L p 1 1 1 r
F P
0 g
s
.66496 .38089 m .71513 .36364 L .76827 .35561 L p 1 1 1 r
F P
0 g
s
.61334 .40053 m .64539 .39119 L .67507 .37588 L p .668 .65 .65 r
F P
0 g
s
.67507 .37588 m .64539 .39119 L p .67307 .37612 L .65 .65 .65 r
F P
0 g
s
.70299 .35983 m .67507 .37588 L p .67307 .37612 L .65 .65 .65 r
F P
0 g
s
.60516 .39205 m .54079 .39643 L p .54449 .39645 L .751 .65 .65 r
F P
0 g
s
.54291 .39858 m .48874 .39598 L p .51171 .39631 L .695 1 1 r
F P
0 g
s
.54062 .39673 m .53818 .40082 L p .56655 .39711 L .751 .65 .65 r
F P
0 g
s
.56655 .39711 m .60516 .39205 L .54062 .39673 L .751 .65 .65 r
F
.46039 .39461 m .47693 .39378 L p .51171 .39631 L .695 1 1 r
F P
0 g
s
.48874 .39598 m .46039 .39461 L p .51171 .39631 L .695 1 1 r
F P
0 g
s
.5447 .7494 m .54479 .75249 L .47164 .7655 L p 1 1 1 r
F P
0 g
s
.43265 .74558 m .5447 .7494 L p .47164 .7655 L 1 1 1 r
F P
0 g
s
.46039 .39461 m .38414 .38143 L .41266 .38375 L p .666 1 1 r
F P
0 g
s
.42399 .38558 m .46039 .39461 L .41266 .38375 L .666 1 1 r
F
.4186 .38424 m .47693 .39378 L .46039 .39461 L p F P
0 g
s
.4436 .39281 m .48843 .39933 L .4779 .39424 L p .92 .65 .65 r
F P
0 g
s
.4779 .39424 m .47693 .39378 L p .47458 .39371 L .92 .65 .65 r
F P
0 g
s
.4436 .39281 m .4779 .39424 L .47458 .39371 L .92 .65 .65 r
F
.41266 .38375 m .4186 .38424 L p .42399 .38558 L .666 1 1 r
F P
0 g
s
.5516 .7517 m .54479 .75249 L .5447 .7494 L p 1 1 1 r
F P
0 g
s
.5447 .7494 m .58727 .74761 L .5516 .7517 L p 1 1 1 r
F P
0 g
s
.58727 .74761 m .5447 .7494 L .54281 .69915 L p 1 1 1 r
F P
0 g
s
.5447 .7494 m .43265 .74558 L .45658 .69621 L p 1 1 1 r
F P
0 g
s
.45658 .69621 m .54281 .69915 L .5447 .7494 L p 1 1 1 r
F P
0 g
s
.32015 .35968 m .25576 .35698 L .25401 .35562 L p .978 1 1 r
F P
0 g
s
.64581 .74023 m .58727 .74761 L p .54281 .69915 L 1 1 1 r
F P
0 g
s
.25401 .35562 m .20909 .32056 L .27436 .33059 L p .978 1 1 r
F P
0 g
s
.27436 .33059 m .32015 .35968 L p .25401 .35562 L .978 1 1 r
F P
0 g
s
.38414 .38143 m .32015 .35968 L .37068 .3684 L p .712 1 1 r
F P
0 g
s
.37068 .3684 m .4186 .38424 L .38414 .38143 L p .712 1 1 r
F P
0 g
s
.83779 .35314 m .90228 .31281 L p .96416 .31867 L 1 1 1 r
F P
0 g
s
.90228 .31281 m .83779 .35314 L .76827 .35561 L p 1 1 1 r
F P
0 g
s
.70291 .3786 m .76827 .35561 L .83779 .35314 L p 1 1 1 r
F P
0 g
s
.43265 .74558 m .32776 .73328 L .3768 .68645 L p 1 1 1 r
F P
0 g
s
.3768 .68645 m .45658 .69621 L .43265 .74558 L p 1 1 1 r
F P
0 g
s
.24394 .71436 m .32776 .73328 L .29694 .75799 L closepath p 1 1 1 r
F P
0 g
s
.62938 .69514 m .65391 .73922 L .64581 .74023 L p 1 1 1 r
F P
0 g
s
.54281 .69915 m .62938 .69514 L p .64581 .74023 L 1 1 1 r
F P
0 g
s
.76235 .73149 m .72172 .73657 L .65391 .73922 L p 1 1 1 r
F P
0 g
s
.65391 .73922 m .62938 .69514 L p .76235 .73149 L 1 1 1 r
F P
0 g
s
.54079 .39643 m .47693 .39378 L .48843 .39933 L p .858 .65 .65 r
F P
0 g
s
.48843 .39933 m .53818 .40082 L .54079 .39643 L p .858 .65 .65 r
F P
0 g
s
.90228 .31281 m .9575 .30873 L .96416 .31867 L p 1 1 1 r
F P
0 g
s
.72172 .73657 m .76235 .73149 L .76609 .73436 L closepath p 1 1 1 r
F P
0 g
s
.47693 .39378 m .4186 .38424 L .4436 .39281 L p .92 .65 .65 r
F P
0 g
s
.53818 .40082 m .58869 .39718 L .60516 .39205 L p .751 .65 .65 r
F P
0 g
s
.32776 .73328 m .24394 .71436 L .24039 .71113 L p 1 1 1 r
F P
0 g
s
.24039 .71113 m .30968 .67033 L p .32776 .73328 L 1 1 1 r
F P
0 g
s
.30968 .67033 m .3768 .68645 L .32776 .73328 L p 1 1 1 r
F P
0 g
s
.78583 .7346 m .76609 .73436 L .76235 .73149 L p 1 1 1 r
F P
0 g
s
.32015 .35968 m .27436 .33059 L .33771 .34732 L p .831 1 1 r
F P
0 g
s
.33771 .34732 m .37068 .3684 L .32015 .35968 L p .831 1 1 r
F P
0 g
s
.76235 .73149 m .85348 .71027 L p .78583 .7346 L 1 1 1 r
F P
0 g
s
.85348 .71027 m .76235 .73149 L .71012 .68435 L p 1 1 1 r
F P
0 g
s
.62938 .69514 m .71012 .68435 L .76235 .73149 L p 1 1 1 r
F P
0 g
s
.85348 .71027 m .90762 .73606 L .78583 .7346 L p 1 1 1 r
F P
0 g
s
.76827 .35561 m .81573 .32554 L .90228 .31281 L p 1 1 1 r
F P
0 g
s
.81573 .32554 m .76827 .35561 L .71513 .36364 L p 1 1 1 r
F P
0 g
s
.40848 .38089 m .37068 .3684 L .40762 .38173 L p .895 .65 .65 r
F P
0 g
s
.38393 .36692 m .40762 .38173 L .37068 .3684 L p .65 1 1 r
F P
0 g
s
.40762 .38173 m .38393 .36692 L .40697 .38235 L p 1 .65 .65 r
F P
0 g
s
.40697 .38235 m .41653 .38875 L p .40762 .38173 L 1 .65 .65 r
F P
0 g
s
.4186 .38424 m .40848 .38089 L p .40762 .38173 L .895 .65 .65 r
F P
0 g
s
.40762 .38173 m .4436 .39281 L .4186 .38424 L p .895 .65 .65 r
F P
0 g
s
.62938 .69514 m .54281 .69915 L .54063 .65265 L p 1 1 1 r
F P
0 g
s
.54281 .69915 m .45658 .69621 L .47432 .65058 L p 1 1 1 r
F P
0 g
s
.47432 .65058 m .54063 .65265 L .54281 .69915 L p 1 1 1 r
F P
0 g
s
.94827 .29244 m .9575 .30873 L .90228 .31281 L p 1 1 1 r
F P
0 g
s
.45658 .69621 m .3768 .68645 L .41371 .64313 L p 1 1 1 r
F P
0 g
s
.41371 .64313 m .47432 .65058 L .45658 .69621 L p 1 1 1 r
F P
0 g
s
.71012 .68435 m .62938 .69514 L .60747 .64923 L p 1 1 1 r
F P
0 g
s
.54063 .65265 m .60747 .64923 L .62938 .69514 L p 1 1 1 r
F P
0 g
s
.27436 .33059 m .20909 .32056 L .20175 .31328 L p 1 1 1 r
F P
0 g
s
.58869 .39718 m .53818 .40082 L .53484 .41024 L p .948 .65 .65 r
F P
0 g
s
.53818 .40082 m .48843 .39933 L .49543 .40983 L p 1 .65 .65 r
F P
0 g
s
.49543 .40983 m .53484 .41024 L .53818 .40082 L p 1 .65 .65 r
F P
0 g
s
.90228 .31281 m .93448 .26822 L .94827 .29244 L p 1 1 1 r
F P
0 g
s
.93448 .26822 m .90228 .31281 L .81573 .32554 L p 1 1 1 r
F P
0 g
s
.48843 .39933 m .4436 .39281 L .46056 .40585 L p 1 .65 .65 r
F P
0 g
s
.46056 .40585 m .49543 .40983 L .48843 .39933 L p 1 .65 .65 r
F P
0 g
s
.99851 .73851 m .99052 .74147 L .90762 .73606 L p 1 1 1 r
F P
0 g
s
.98938 .71769 m .99851 .73851 L p .90762 .73606 L 1 1 1 r
F P
0 g
s
.90762 .73606 m .85348 .71027 L p .98938 .71769 L 1 1 1 r
F P
0 g
s
.37068 .3684 m .33771 .34732 L .38393 .36692 L p .65 1 1 r
F P
0 g
s
.6357 .38866 m .58869 .39718 L .57534 .40706 L p .828 .65 .65 r
F P
0 g
s
.53484 .41024 m .57534 .40706 L .58869 .39718 L p .948 .65 .65 r
F P
0 g
s
.25228 .29613 m .27436 .33059 L p .20175 .31328 L 1 1 1 r
F P
0 g
s
.20175 .31328 m .15919 .27118 L .25228 .29613 L p 1 1 1 r
F P
0 g
s
.71513 .36364 m .75089 .3415 L .81573 .32554 L p 1 1 1 r
F P
0 g
s
.75089 .3415 m .71513 .36364 L .67507 .37588 L p 1 1 1 r
F P
0 g
s
.4436 .39281 m .40762 .38173 L .43339 .39863 L p 1 .65 .65 r
F P
0 g
s
.43339 .39863 m .46056 .40585 L .4436 .39281 L p 1 .65 .65 r
F P
0 g
s
.3768 .68645 m .30968 .67033 L .36383 .63075 L p 1 1 1 r
F P
0 g
s
.36383 .63075 m .41371 .64313 L .3768 .68645 L p 1 1 1 r
F P
0 g
s
.71012 .68435 m .77871 .66731 L .85348 .71027 L p 1 1 1 r
F P
0 g
s
.77871 .66731 m .71012 .68435 L .6696 .64051 L p 1 1 1 r
F P
0 g
s
.60747 .64923 m .6696 .64051 L .71012 .68435 L p 1 1 1 r
F P
0 g
s
.32357 .32262 m .33771 .34732 L .27436 .33059 L p .973 1 1 r
F P
0 g
s
.27436 .33059 m .25228 .29613 L .32357 .32262 L p .973 1 1 r
F P
0 g
s
.57534 .40706 m .61334 .40053 L .6357 .38866 L p .828 .65 .65 r
F P
0 g
s
.30968 .67033 m .24039 .71113 L .23854 .70983 L p 1 1 1 r
F P
0 g
s
.60747 .64923 m .54063 .65265 L .53797 .60942 L p 1 1 1 r
F P
0 g
s
.54063 .65265 m .47432 .65058 L .48666 .60819 L p 1 1 1 r
F P
0 g
s
.48666 .60819 m .53797 .60942 L .54063 .65265 L p 1 1 1 r
F P
0 g
s
.23854 .70983 m .19104 .67663 L .26138 .64872 L p 1 1 1 r
F P
0 g
s
.26138 .64872 m .30968 .67033 L p .23854 .70983 L 1 1 1 r
F P
0 g
s
.93341 .26651 m .93448 .26822 L p .81573 .32554 L 1 1 1 r
F P
0 g
s
.81573 .32554 m .83952 .29047 L p .93341 .26651 L 1 1 1 r
F P
0 g
s
.83952 .29047 m .81573 .32554 L .75089 .3415 L p 1 1 1 r
F P
0 g
s
.85348 .71027 m .92217 .68185 L p .98938 .71769 L 1 1 1 r
F P
0 g
s
.92217 .68185 m .85348 .71027 L .77871 .66731 L p 1 1 1 r
F P
0 g
s
.47432 .65058 m .41371 .64313 L .44042 .60284 L p 1 1 1 r
F P
0 g
s
.44042 .60284 m .48666 .60819 L .47432 .65058 L p 1 1 1 r
F P
0 g
s
.6696 .64051 m .60747 .64923 L .59005 .60642 L p 1 1 1 r
F P
0 g
s
.53797 .60942 m .59005 .60642 L .60747 .64923 L p 1 1 1 r
F P
0 g
s
.41653 .38875 m .43339 .39863 L .40762 .38173 L p 1 .65 .65 r
F P
0 g
s
.57534 .40706 m .53484 .41024 L .53046 .42338 L p 1 .65 .65 r
F P
0 g
s
.53484 .41024 m .49543 .40983 L .49826 .42402 L p 1 .663 .683 r
F P
0 g
s
.49826 .42402 m .53046 .42338 L .53484 .41024 L p 1 .663 .683 r
F P
0 g
s
.49543 .40983 m .46056 .40585 L .47051 .42227 L p 1 .773 .747 r
F P
0 g
s
.47051 .42227 m .49826 .42402 L .49543 .40983 L p 1 .773 .747 r
F P
0 g
s
.61334 .40053 m .57534 .40706 L .56419 .4204 L p .987 .65 .65 r
F P
0 g
s
.53046 .42338 m .56419 .4204 L .57534 .40706 L p 1 .65 .65 r
F P
0 g
s
.37524 .34958 m .38393 .36692 L .33771 .34732 L p .851 1 1 r
F P
0 g
s
.33771 .34732 m .32357 .32262 L .37524 .34958 L p .851 1 1 r
F P
0 g
s
.46056 .40585 m .43339 .39863 L .44977 .41828 L p 1 .879 .773 r
F P
0 g
s
.44977 .41828 m .47051 .42227 L .46056 .40585 L p 1 .879 .773 r
F P
0 g
s
.67507 .37588 m .70299 .35983 L p .71435 .35807 L 1 1 1 r
F P
0 g
s
.66834 .37982 m .70299 .35983 L p .67527 .37492 L .65 .65 .65 r
F P
0 g
s
.64539 .39119 m .66834 .37982 L p .67527 .37492 L .65 .65 .65 r
F P
0 g
s
.62393 .40863 m .64421 .40089 L .66834 .37982 L p .766 .65 .65 r
F P
0 g
s
.66834 .37982 m .64421 .40089 L p .66126 .38483 L .65 .65 .65 r
F P
0 g
s
.66834 .37982 m .64539 .39119 L .62393 .40863 L p .766 .65 .65 r
F P
0 g
s
.6797 .36745 m .66834 .37982 L p .66126 .38483 L .65 .65 .65 r
F P
0 g
s
.70299 .35983 m .66834 .37982 L p .69132 .36164 L 1 1 1 r
F P
0 g
s
.7163 .34188 m .70299 .35983 L p .69132 .36164 L 1 1 1 r
F P
0 g
s
.70299 .35983 m .75089 .3415 L p .71435 .35807 L 1 1 1 r
F P
0 g
s
.41371 .64313 m .36383 .63075 L .40326 .59372 L p 1 1 1 r
F P
0 g
s
.40326 .59372 m .44042 .60284 L .41371 .64313 L p 1 1 1 r
F P
0 g
s
.75089 .3415 m .76805 .31621 L .83952 .29047 L p 1 1 1 r
F P
0 g
s
.76805 .31621 m .75089 .3415 L .70299 .35983 L p 1 1 1 r
F P
0 g
s
.64539 .39119 m .61334 .40053 L .59636 .41533 L p .907 .65 .65 r
F P
0 g
s
.56419 .4204 m .59636 .41533 L .61334 .40053 L p .987 .65 .65 r
F P
0 g
s
.6696 .64051 m .72184 .62703 L .77871 .66731 L p 1 1 1 r
F P
0 g
s
.72184 .62703 m .6696 .64051 L .63855 .59942 L p 1 1 1 r
F P
0 g
s
.59005 .60642 m .63855 .59942 L .6696 .64051 L p 1 1 1 r
F P
0 g
s
.30968 .67033 m .26138 .64872 L .32939 .61427 L p 1 1 1 r
F P
0 g
s
.32939 .61427 m .36383 .63075 L .30968 .67033 L p 1 1 1 r
F P
0 g
s
.59005 .60642 m .53797 .60942 L .5346 .56885 L p 1 1 1 r
F P
0 g
s
.53797 .60942 m .48666 .60819 L .49426 .56849 L p 1 1 1 r
F P
0 g
s
.49426 .56849 m .5346 .56885 L .53797 .60942 L p 1 1 1 r
F P
0 g
s
.43339 .39863 m .41653 .38875 L .43804 .41239 L p 1 .893 .65 r
F P
0 g
s
.43804 .41239 m .44977 .41828 L .43339 .39863 L p 1 .893 .65 r
F P
0 g
s
.48666 .60819 m .44042 .60284 L .45856 .56506 L p 1 1 1 r
F P
0 g
s
.45856 .56506 m .49426 .56849 L .48666 .60819 L p 1 1 1 r
F P
0 g
s
.41185 .37706 m .41653 .38875 L .38393 .36692 L p .678 1 1 r
F P
0 g
s
.38393 .36692 m .37524 .34958 L .41185 .37706 L p .678 1 1 r
F P
0 g
s
.77871 .66731 m .82875 .64496 L .92217 .68185 L p 1 1 1 r
F P
0 g
s
.82875 .64496 m .77871 .66731 L .72184 .62703 L p 1 1 1 r
F P
0 g
s
.63855 .59942 m .59005 .60642 L .57605 .5661 L p 1 1 1 r
F P
0 g
s
.5346 .56885 m .57605 .5661 L .59005 .60642 L p 1 1 1 r
F P
0 g
s
.92217 .68185 m .98192 .70061 L .98938 .71769 L p 1 1 1 r
F P
0 g
s
.53046 .42338 m .49826 .42402 L .49696 .44088 L p 1 .732 .804 r
F P
0 g
s
.49826 .42402 m .47051 .42227 L .47401 .4412 L p 1 .839 .893 r
F P
0 g
s
.47401 .4412 m .49696 .44088 L .49826 .42402 L p 1 .839 .893 r
F P
0 g
s
.56419 .4204 m .53046 .42338 L .52462 .43912 L p 1 .667 .758 r
F P
0 g
s
.49696 .44088 m .52462 .43912 L .53046 .42338 L p 1 .732 .804 r
F P
0 g
s
.47051 .42227 m .44977 .41828 L .45791 .44004 L p 1 .972 .989 r
F P
0 g
s
.45791 .44004 m .47401 .4412 L .47051 .42227 L p 1 .972 .989 r
F P
0 g
s
.59636 .41533 m .62393 .40863 L .64539 .39119 L p .907 .65 .65 r
F P
0 g
s
.25228 .29613 m .15919 .27118 L .15801 .26978 L p 1 1 1 r
F P
0 g
s
.44042 .60284 m .40326 .59372 L .43072 .55882 L p 1 1 1 r
F P
0 g
s
.43072 .55882 m .45856 .56506 L .44042 .60284 L p 1 1 1 r
F P
0 g
s
.25829 .25913 m .25228 .29613 L p .15801 .26978 L 1 1 1 r
F P
0 g
s
.15801 .26978 m .15529 .26657 L p .25829 .25913 L 1 1 1 r
F P
0 g
s
.70299 .35983 m .7163 .34188 L .76805 .31621 L p 1 1 1 r
F P
0 g
s
.59636 .41533 m .56419 .4204 L .5544 .43609 L p 1 .65 .767 r
F P
0 g
s
.52462 .43912 m .5544 .43609 L .56419 .4204 L p 1 .667 .758 r
F P
0 g
s
.43659 .40512 m .43804 .41239 L .41653 .38875 L p .65 .833 1 r
F P
0 g
s
.41653 .38875 m .41185 .37706 L .43659 .40512 L p .65 .833 1 r
F P
0 g
s
.15529 .26657 m .15771 .21813 L .25829 .25913 L p 1 1 1 r
F P
0 g
s
.15771 .21813 m .15529 .26657 L .1184 .22585 L p 1 1 1 r
F P
0 g
s
.44977 .41828 m .43804 .41239 L .45018 .43753 L p 1 1 .987 r
F P
0 g
s
.45018 .43753 m .45791 .44004 L .44977 .41828 L p 1 1 .987 r
F P
0 g
s
.36383 .63075 m .32939 .61427 L .37875 .58153 L p 1 1 1 r
F P
0 g
s
.37875 .58153 m .40326 .59372 L .36383 .63075 L p 1 1 1 r
F P
0 g
s
.33089 .29643 m .32357 .32262 L .25228 .29613 L p 1 1 1 r
F P
0 g
s
.25228 .29613 m .25829 .25913 L .33089 .29643 L p 1 1 1 r
F P
0 g
s
.83952 .29047 m .93294 .26578 L .93341 .26651 L p 1 1 1 r
F P
0 g
s
.63855 .59942 m .67921 .58891 L .72184 .62703 L p 1 1 1 r
F P
0 g
s
.67921 .58891 m .63855 .59942 L .61497 .56046 L p 1 1 1 r
F P
0 g
s
.57605 .5661 m .61497 .56046 L .63855 .59942 L p 1 1 1 r
F P
0 g
s
.57605 .5661 m .5346 .56885 L .53023 .53029 L p 1 1 1 r
F P
0 g
s
.5346 .56885 m .49426 .56849 L .49751 .53087 L p 1 1 1 r
F P
0 g
s
.49751 .53087 m .53023 .53029 L .5346 .56885 L p 1 1 1 r
F P
0 g
s
.91455 .22907 m .93294 .26578 L .83952 .29047 L p 1 1 1 r
F P
0 g
s
.49426 .56849 m .45856 .56506 L .46932 .52929 L p 1 1 1 r
F P
0 g
s
.46932 .52929 m .49751 .53087 L .49426 .56849 L p 1 1 1 r
F P
0 g
s
.62393 .40863 m .59636 .41533 L .5835 .43204 L p 1 .672 .827 r
F P
0 g
s
.5544 .43609 m .5835 .43204 L .59636 .41533 L p 1 .65 .767 r
F P
0 g
s
.38312 .33128 m .37524 .34958 L .32357 .32262 L p 1 1 1 r
F P
0 g
s
.32357 .32262 m .33089 .29643 L .38312 .33128 L p 1 1 1 r
F P
0 g
s
.61497 .56046 m .57605 .5661 L .56449 .52758 L p 1 1 1 r
F P
0 g
s
.53023 .53029 m .56449 .52758 L .57605 .5661 L p 1 1 1 r
F P
0 g
s
.72184 .62703 m .75919 .60971 L .82875 .64496 L p 1 1 1 r
F P
0 g
s
.75919 .60971 m .72184 .62703 L .67921 .58891 L p 1 1 1 r
F P
0 g
s
.83952 .29047 m .83503 .2534 L p .91455 .22907 L 1 1 1 r
F P
0 g
s
.83503 .2534 m .83952 .29047 L .76805 .31621 L p 1 1 1 r
F P
0 g
s
.45164 .43387 m .45018 .43753 L .43804 .41239 L p .65 .65 1 r
F P
0 g
s
.43804 .41239 m .43659 .40512 L .45164 .43387 L p .65 .65 1 r
F P
0 g
s
.45856 .56506 m .43072 .55882 L .44825 .52567 L p 1 1 1 r
F P
0 g
s
.44825 .52567 m .46932 .52929 L .45856 .56506 L p 1 1 1 r
F P
0 g
s
.4202 .36462 m .41185 .37706 L .37524 .34958 L p .994 1 1 r
F P
0 g
s
.37524 .34958 m .38312 .33128 L .4202 .36462 L p .994 1 1 r
F P
0 g
s
.49696 .44088 m .47401 .4412 L .47117 .46191 L p 1 .798 .928 r
F P
0 g
s
.47401 .4412 m .45791 .44004 L .45832 .46343 L p 1 .901 1 r
F P
0 g
s
.45832 .46343 m .47117 .46191 L .47401 .4412 L p 1 .901 1 r
F P
0 g
s
.66834 .37982 m .6797 .36745 L .7163 .34188 L p 1 1 1 r
F P
0 g
s
.97196 .68048 m .98192 .70061 L .92217 .68185 L p 1 1 1 r
F P
0 g
s
.52462 .43912 m .49696 .44088 L .49127 .45953 L p 1 .724 .84 r
F P
0 g
s
.47117 .46191 m .49127 .45953 L .49696 .44088 L p 1 .798 .928 r
F P
0 g
s
.40326 .59372 m .37875 .58153 L .41342 .55027 L p 1 1 1 r
F P
0 g
s
.41342 .55027 m .43072 .55882 L .40326 .59372 L p 1 1 1 r
F P
0 g
s
.45791 .44004 m .45018 .43753 L .4539 .46395 L p 1 1 1 r
F P
0 g
s
.4539 .46395 m .45832 .46343 L .45791 .44004 L p 1 1 1 r
F P
0 g
s
.64421 .40089 m .62393 .40863 L .6091 .42737 L p 1 .707 .913 r
F P
0 g
s
.5835 .43204 m .6091 .42737 L .62393 .40863 L p 1 .672 .827 r
F P
0 g
s
.5544 .43609 m .52462 .43912 L .51674 .45652 L p 1 .697 .808 r
F P
0 g
s
.49127 .45953 m .51674 .45652 L .52462 .43912 L p 1 .724 .84 r
F P
0 g
s
.76805 .31621 m .76362 .29004 L .83503 .2534 L p 1 1 1 r
F P
0 g
s
.76362 .29004 m .76805 .31621 L .7163 .34188 L p 1 1 1 r
F P
0 g
s
.53023 .53029 m .49751 .53087 L .49658 .49475 L p 1 1 1 r
F P
0 g
s
.49751 .53087 m .46932 .52929 L .47344 .49505 L p 1 1 1 r
F P
0 g
s
.47344 .49505 m .49658 .49475 L .49751 .53087 L p 1 1 1 r
F P
0 g
s
.44576 .39715 m .43659 .40512 L .41185 .37706 L p .973 1 1 r
F P
0 g
s
.41185 .37706 m .4202 .36462 L .44576 .39715 L p .973 1 1 r
F P
0 g
s
.26138 .64872 m .19104 .67663 L .18311 .67281 L p 1 1 1 r
F P
0 g
s
.56449 .52758 m .53023 .53029 L .52445 .49308 L p 1 1 1 r
F P
0 g
s
.49658 .49475 m .52445 .49308 L .53023 .53029 L p 1 1 1 r
F P
0 g
s
.61497 .56046 m .6478 .55238 L .67921 .58891 L p 1 1 1 r
F P
0 g
s
.6478 .55238 m .61497 .56046 L .59717 .52299 L p 1 1 1 r
F P
0 g
s
.56449 .52758 m .59717 .52299 L .61497 .56046 L p 1 1 1 r
F P
0 g
s
.45832 .46343 m .4539 .46395 L .45018 .43753 L p .65 .65 1 r
F P
0 g
s
.45018 .43753 m .45164 .43387 L .45832 .46343 L p .65 .65 1 r
F P
0 g
s
.46932 .52929 m .44825 .52567 L .45721 .49396 L p 1 1 1 r
F P
0 g
s
.45721 .49396 m .47344 .49505 L .46932 .52929 L p 1 1 1 r
F P
0 g
s
.5835 .43204 m .5544 .43609 L .54516 .45316 L p 1 .724 .84 r
F P
0 g
s
.51674 .45652 m .54516 .45316 L .5544 .43609 L p 1 .697 .808 r
F P
0 g
s
.46223 .42942 m .45164 .43387 L .43659 .40512 L p 1 1 1 r
F P
0 g
s
.43659 .40512 m .44576 .39715 L .46223 .42942 L p 1 1 1 r
F P
0 g
s
.43072 .55882 m .41342 .55027 L .43632 .52032 L p 1 1 1 r
F P
0 g
s
.43632 .52032 m .44825 .52567 L .43072 .55882 L p 1 1 1 r
F P
0 g
s
.92217 .68185 m .9571 .6503 L .97196 .68048 L p 1 1 1 r
F P
0 g
s
.9571 .6503 m .92217 .68185 L .82875 .64496 L p 1 1 1 r
F P
0 g
s
.59717 .52299 m .56449 .52758 L .55447 .49018 L p 1 1 1 r
F P
0 g
s
.52445 .49308 m .55447 .49018 L .56449 .52758 L p 1 1 1 r
F P
0 g
s
.67921 .58891 m .7081 .5757 L .75919 .60971 L p 1 1 1 r
F P
0 g
s
.7081 .5757 m .67921 .58891 L .6478 .55238 L p 1 1 1 r
F P
0 g
s
.7163 .34188 m .71297 .32371 L .76362 .29004 L p 1 1 1 r
F P
0 g
s
.71297 .32371 m .7163 .34188 L .6797 .36745 L p 1 1 1 r
F P
0 g
s
.47117 .46191 m .45832 .46343 L .45164 .43387 L p 1 1 1 r
F P
0 g
s
.45164 .43387 m .46223 .42942 L .47117 .46191 L p 1 1 1 r
F P
0 g
s
.49658 .49475 m .47344 .49505 L .47117 .46191 L p 1 1 1 r
F P
0 g
s
.47344 .49505 m .45721 .49396 L .45832 .46343 L p 1 1 1 r
F P
0 g
s
.45832 .46343 m .47117 .46191 L .47344 .49505 L p 1 1 1 r
F P
0 g
s
.44942 .49156 m .43632 .52032 L p .44332 .50482 L 1 1 1 r
F P
0 g
s
.44942 .49156 m .4539 .46395 L p .45549 .47837 L 1 1 1 r
F P
0 g
s
.4539 .46395 m .45832 .46343 L .45721 .49396 L p 1 1 1 r
F P
0 g
s
.45832 .46343 m .4539 .46395 L .44942 .49156 L p .65 .65 .65 r
F P
0 g
s
.45089 .48808 m .45832 .46343 L p .45405 .47693 L .65 .65 .65 r
F P
0 g
s
.44942 .49156 m .45089 .48808 L p .45405 .47693 L .65 .65 .65 r
F P
0 g
s
.45089 .48808 m .44942 .49156 L p .44332 .50482 L 1 1 1 r
F P
0 g
s
.45721 .49396 m .44942 .49156 L p .45549 .47837 L 1 1 1 r
F P
0 g
s
.44825 .52567 m .43632 .52032 L .44942 .49156 L p 1 1 1 r
F P
0 g
s
.44942 .49156 m .45721 .49396 L .44825 .52567 L p 1 1 1 r
F P
0 g
s
.43483 .51372 m .45089 .48808 L p .44388 .50359 L 1 1 1 r
F P
0 g
s
.43632 .52032 m .43483 .51372 L p .44388 .50359 L 1 1 1 r
F P
0 g
s
.41342 .55027 m .40859 .54016 L .43483 .51372 L p 1 1 1 r
F P
0 g
s
.43483 .51372 m .40859 .54016 L p .42567 .52398 L 1 1 1 r
F P
0 g
s
.43483 .51372 m .43632 .52032 L .41342 .55027 L p 1 1 1 r
F P
0 g
s
.44414 .50647 m .43483 .51372 L p .42567 .52398 L 1 1 1 r
F P
0 g
s
.45089 .48808 m .43483 .51372 L p .44769 .49933 L .65 .65 .65 r
F P
0 g
s
.46156 .48383 m .45089 .48808 L p .44769 .49933 L .65 .65 .65 r
F P
0 g
s
.52445 .49308 m .49658 .49475 L .49127 .45953 L p 1 1 1 r
F P
0 g
s
.47117 .46191 m .49127 .45953 L .49658 .49475 L p 1 1 1 r
F P
0 g
s
.47117 .46191 m .45832 .46343 L .45089 .48808 L p .901 .65 .888 r
F P
0 g
s
.31447 .5949 m .32939 .61427 L .26138 .64872 L p 1 1 1 r
F P
0 g
s
.26138 .64872 m .23778 .62304 L .31447 .5949 L p 1 1 1 r
F P
0 g
s
.23778 .62304 m .26138 .64872 L p .18311 .67281 L 1 1 1 r
F P
0 g
s
.6091 .42737 m .5835 .43204 L .57378 .44977 L p 1 .798 .928 r
F P
0 g
s
.54516 .45316 m .57378 .44977 L .5835 .43204 L p 1 .724 .84 r
F P
0 g
s
.18311 .67281 m .13694 .65041 L .23778 .62304 L p 1 1 1 r
F P
0 g
s
.64019 .41796 m .65504 .39284 L p .64237 .4071 L .953 .673 .962 r
F P
0 g
s
.62867 .42252 m .64019 .41796 L p .64237 .4071 L .953 .673 .962 r
F P
0 g
s
.64019 .41796 m .63388 .44266 L p .63798 .42894 L 1 1 1 r
F P
0 g
s
.65504 .39284 m .64019 .41796 L p .64738 .40226 L .65 .65 .65 r
F P
0 g
s
.64239 .41416 m .64019 .41796 L p .63798 .42894 L 1 1 1 r
F P
0 g
s
.64421 .40089 m .65504 .39284 L p .66261 .38355 L .65 .65 .65 r
F P
0 g
s
.65504 .39284 m .64421 .40089 L .62867 .42252 L p .953 .673 .962 r
F P
0 g
s
.65515 .38529 m .65504 .39284 L p .64738 .40226 L .65 .65 .65 r
F P
0 g
s
.65504 .39284 m .6797 .36745 L p .66261 .38355 L .65 .65 .65 r
F P
0 g
s
.6091 .42737 m .62867 .42252 L .64421 .40089 L p 1 .707 .913 r
F P
0 g
s
.55447 .49018 m .52445 .49308 L .51674 .45652 L p 1 1 1 r
F P
0 g
s
.49127 .45953 m .51674 .45652 L .52445 .49308 L p 1 1 1 r
F P
0 g
s
.49127 .45953 m .47117 .46191 L .46223 .42942 L p 1 1 1 r
F P
0 g
s
.49127 .45953 m .47117 .46191 L .46156 .48383 L p 1 .65 .845 r
F P
0 g
s
.45089 .48808 m .46156 .48383 L .47117 .46191 L p .901 .65 .888 r
F P
0 g
s
.59717 .52299 m .6252 .5169 L .6478 .55238 L p 1 1 1 r
F P
0 g
s
.6252 .5169 m .59717 .52299 L .58381 .48633 L p 1 1 1 r
F P
0 g
s
.55447 .49018 m .58381 .48633 L .59717 .52299 L p 1 1 1 r
F P
0 g
s
.46223 .42942 m .48105 .42459 L .49127 .45953 L p 1 1 1 r
F P
0 g
s
.48105 .42459 m .46223 .42942 L .44576 .39715 L p 1 1 1 r
F P
0 g
s
.6797 .36745 m .67795 .35527 L .71297 .32371 L p 1 1 1 r
F P
0 g
s
.67795 .35527 m .6797 .36745 L .65504 .39284 L p 1 1 1 r
F P
0 g
s
.51674 .45652 m .49127 .45953 L .48105 .42459 L p 1 1 1 r
F P
0 g
s
.51674 .45652 m .49127 .45953 L .48053 .47922 L p 1 .65 .799 r
F P
0 g
s
.46156 .48383 m .48053 .47922 L .49127 .45953 L p 1 .65 .845 r
F P
0 g
s
.6478 .55238 m .67133 .54255 L .7081 .5757 L p 1 1 1 r
F P
0 g
s
.67133 .54255 m .6478 .55238 L .6252 .5169 L p 1 1 1 r
F P
0 g
s
.44576 .39715 m .46489 .38923 L .48105 .42459 L p 1 1 1 r
F P
0 g
s
.46489 .38923 m .44576 .39715 L .4202 .36462 L p 1 1 1 r
F P
0 g
s
.58381 .48633 m .55447 .49018 L .54516 .45316 L p 1 1 1 r
F P
0 g
s
.51674 .45652 m .54516 .45316 L .55447 .49018 L p 1 1 1 r
F P
0 g
s
.36969 .56725 m .37875 .58153 L .32939 .61427 L p 1 1 1 r
F P
0 g
s
.32939 .61427 m .31447 .5949 L .36969 .56725 L p 1 1 1 r
F P
0 g
s
.95591 .64771 m .9571 .6503 L p .82875 .64496 L 1 1 1 r
F P
0 g
s
.82875 .64496 m .85416 .61882 L p .95591 .64771 L 1 1 1 r
F P
0 g
s
.85416 .61882 m .82875 .64496 L .75919 .60971 L p 1 1 1 r
F P
0 g
s
.62867 .42252 m .6091 .42737 L .59977 .4467 L p 1 .901 1 r
F P
0 g
s
.57378 .44977 m .59977 .4467 L .6091 .42737 L p 1 .798 .928 r
F P
0 g
s
.4202 .36462 m .44121 .35266 L .46489 .38923 L p 1 1 1 r
F P
0 g
s
.44121 .35266 m .4202 .36462 L .38312 .33128 L p 1 1 1 r
F P
0 g
s
.40859 .54016 m .41342 .55027 L .37875 .58153 L p 1 1 1 r
F P
0 g
s
.37875 .58153 m .36969 .56725 L .40859 .54016 L p 1 1 1 r
F P
0 g
s
.54516 .45316 m .51674 .45652 L .50636 .41984 L p 1 1 1 r
F P
0 g
s
.48105 .42459 m .50636 .41984 L .51674 .45652 L p 1 1 1 r
F P
0 g
s
.54516 .45316 m .51674 .45652 L .50604 .4747 L p 1 .675 .797 r
F P
0 g
s
.48053 .47922 m .50604 .4747 L .51674 .45652 L p 1 .65 .799 r
F P
0 g
s
.38312 .33128 m .40759 .31383 L .44121 .35266 L p 1 1 1 r
F P
0 g
s
.40759 .31383 m .38312 .33128 L .33089 .29643 L p 1 1 1 r
F P
0 g
s
.50636 .41984 m .48105 .42459 L .46489 .38923 L p 1 1 1 r
F P
0 g
s
.58381 .48633 m .60962 .48188 L .6252 .5169 L p 1 1 1 r
F P
0 g
s
.60962 .48188 m .58381 .48633 L .57378 .44977 L p 1 1 1 r
F P
0 g
s
.54516 .45316 m .57378 .44977 L .58381 .48633 L p 1 1 1 r
F P
0 g
s
.65504 .39284 m .65515 .38529 L .67795 .35527 L p 1 1 1 r
F P
0 g
s
.6252 .5169 m .64582 .50987 L .67133 .54255 L p 1 1 1 r
F P
0 g
s
.64582 .50987 m .6252 .5169 L .60962 .48188 L p 1 1 1 r
F P
0 g
s
.75919 .60971 m .77725 .58988 L .85416 .61882 L p 1 1 1 r
F P
0 g
s
.77725 .58988 m .75919 .60971 L .7081 .5757 L p 1 1 1 r
F P
0 g
s
.64019 .41796 m .62867 .42252 L .62051 .44425 L p 1 1 1 r
F P
0 g
s
.59977 .4467 m .62051 .44425 L .62867 .42252 L p 1 .901 1 r
F P
0 g
s
.1184 .22585 m .09125 .19598 L .15771 .21813 L p 1 1 1 r
F P
0 g
s
.57378 .44977 m .54516 .45316 L .53574 .41567 L p 1 1 1 r
F P
0 g
s
.50636 .41984 m .53574 .41567 L .54516 .45316 L p 1 1 1 r
F P
0 g
s
.57378 .44977 m .54516 .45316 L .53566 .47072 L p 1 .743 .848 r
F P
0 g
s
.50604 .4747 m .53566 .47072 L .54516 .45316 L p 1 .675 .797 r
F P
0 g
s
.48053 .47922 m .46156 .48383 L .44414 .50647 L p .78 .65 .65 r
F P
0 g
s
.43483 .51372 m .44414 .50647 L .46156 .48383 L p .65 .65 .65 r
F P
0 g
s
.33089 .29643 m .36045 .27137 L .40759 .31383 L p 1 1 1 r
F P
0 g
s
.36045 .27137 m .33089 .29643 L .25829 .25913 L p 1 1 1 r
F P
0 g
s
.46489 .38923 m .4923 .38218 L .50636 .41984 L p 1 1 1 r
F P
0 g
s
.4923 .38218 m .46489 .38923 L .44121 .35266 L p 1 1 1 r
F P
0 g
s
.53574 .41567 m .50636 .41984 L .4923 .38218 L p 1 1 1 r
F P
0 g
s
.60962 .48188 m .62935 .47725 L .64582 .50987 L p 1 1 1 r
F P
0 g
s
.62935 .47725 m .60962 .48188 L .59977 .4467 L p 1 1 1 r
F P
0 g
s
.57378 .44977 m .59977 .4467 L .60962 .48188 L p 1 1 1 r
F P
0 g
s
.7081 .5757 m .72193 .56091 L .77725 .58988 L p 1 1 1 r
F P
0 g
s
.72193 .56091 m .7081 .5757 L .67133 .54255 L p 1 1 1 r
F P
0 g
s
.59977 .4467 m .57378 .44977 L .56626 .41248 L p 1 1 1 r
F P
0 g
s
.53574 .41567 m .56626 .41248 L .57378 .44977 L p 1 1 1 r
F P
0 g
s
.59977 .4467 m .57378 .44977 L .56644 .46769 L p 1 .847 .942 r
F P
0 g
s
.53566 .47072 m .56644 .46769 L .57378 .44977 L p 1 .743 .848 r
F P
0 g
s
.62051 .44425 m .63388 .44266 L .64019 .41796 L p 1 1 1 r
F P
0 g
s
.63388 .44266 m .6385 .44212 L .64239 .41416 L p 1 1 1 r
F P
0 g
s
.64239 .41416 m .6385 .44212 L p .63679 .42739 L 1 1 1 r
F P
0 g
s
.64019 .41796 m .64239 .41416 L p .64795 .40101 L .65 .65 .65 r
F P
0 g
s
.63494 .41151 m .64239 .41416 L p .63679 .42739 L 1 1 1 r
F P
0 g
s
.64239 .41416 m .65515 .38529 L p .64795 .40101 L .65 .65 .65 r
F P
0 g
s
.66282 .34453 m .67795 .35527 L .65515 .38529 L p 1 1 1 r
F P
0 g
s
.67795 .35527 m .66282 .34453 L .69252 .30719 L p 1 1 1 r
F P
0 g
s
.69252 .30719 m .71297 .32371 L .67795 .35527 L p 1 1 1 r
F P
0 g
s
.71297 .32371 m .69252 .30719 L .73658 .2657 L p 1 1 1 r
F P
0 g
s
.73658 .2657 m .76362 .29004 L .71297 .32371 L p 1 1 1 r
F P
0 g
s
.67133 .54255 m .68301 .53184 L .72193 .56091 L p 1 1 1 r
F P
0 g
s
.68301 .53184 m .67133 .54255 L .64582 .50987 L p 1 1 1 r
F P
0 g
s
.64427 .37901 m .65515 .38529 L .64239 .41416 L p 1 1 1 r
F P
0 g
s
.65515 .38529 m .64427 .37901 L .66282 .34453 L p 1 1 1 r
F P
0 g
s
.50604 .4747 m .48053 .47922 L .46358 .49928 L p .942 .65 .679 r
F P
0 g
s
.44414 .50647 m .46358 .49928 L .48053 .47922 L p .78 .65 .65 r
F P
0 g
s
.25829 .25913 m .2945 .22331 L .36045 .27137 L p 1 1 1 r
F P
0 g
s
.2945 .22331 m .25829 .25913 L .15771 .21813 L p 1 1 1 r
F P
0 g
s
.76362 .29004 m .73658 .2657 L .80001 .21813 L p 1 1 1 r
F P
0 g
s
.80001 .21813 m .83503 .2534 L .76362 .29004 L p 1 1 1 r
F P
0 g
s
.56626 .41248 m .53574 .41567 L .52531 .37672 L p 1 1 1 r
F P
0 g
s
.4923 .38218 m .52531 .37672 L .53574 .41567 L p 1 1 1 r
F P
0 g
s
.64582 .50987 m .65684 .50256 L .68301 .53184 L p 1 1 1 r
F P
0 g
s
.65684 .50256 m .64582 .50987 L .62935 .47725 L p 1 1 1 r
F P
0 g
s
.44121 .35266 m .47312 .34242 L .4923 .38218 L p 1 1 1 r
F P
0 g
s
.47312 .34242 m .44121 .35266 L .40759 .31383 L p 1 1 1 r
F P
0 g
s
.62051 .44425 m .59977 .4467 L .59485 .41062 L p 1 1 1 r
F P
0 g
s
.56626 .41248 m .59485 .41062 L .59977 .4467 L p 1 1 1 r
F P
0 g
s
.59977 .4467 m .62051 .44425 L .62935 .47725 L p 1 1 1 r
F P
0 g
s
.62051 .44425 m .59977 .4467 L .59525 .46592 L p 1 .974 1 r
F P
0 g
s
.56644 .46769 m .59525 .46592 L .59977 .4467 L p 1 .847 .942 r
F P
0 g
s
.37773 .55217 m .41712 .52939 L p .39423 .54767 L 1 1 1 r
F P
0 g
s
.36969 .56725 m .37773 .55217 L p .39423 .54767 L 1 1 1 r
F P
0 g
s
.37773 .55217 m .32188 .57434 L p .36077 .55679 L 1 1 1 r
F P
0 g
s
.41712 .52939 m .37773 .55217 L p .40699 .53624 L 1 1 1 r
F P
0 g
s
.40293 .53776 m .37773 .55217 L p .36077 .55679 L 1 1 1 r
F P
0 g
s
.40859 .54016 m .41712 .52939 L p .42702 .52269 L 1 1 1 r
F P
0 g
s
.41712 .52939 m .40859 .54016 L .36969 .56725 L p 1 1 1 r
F P
0 g
s
.43862 .51903 m .41712 .52939 L p .40699 .53624 L 1 1 1 r
F P
0 g
s
.41712 .52939 m .44414 .50647 L p .42702 .52269 L 1 1 1 r
F P
0 g
s
.62935 .47725 m .64096 .47291 L .65684 .50256 L p 1 1 1 r
F P
0 g
s
.64096 .47291 m .62935 .47725 L .62051 .44425 L p 1 1 1 r
F P
0 g
s
.64239 .41416 m .63494 .41151 L .64427 .37901 L p 1 1 1 r
F P
0 g
s
.52531 .37672 m .4923 .38218 L .47312 .34242 L p 1 1 1 r
F P
0 g
s
.63388 .44266 m .62051 .44425 L .61855 .41029 L p 1 1 1 r
F P
0 g
s
.59485 .41062 m .61855 .41029 L .62051 .44425 L p 1 1 1 r
F P
0 g
s
.62051 .44425 m .63388 .44266 L .64096 .47291 L p 1 1 1 r
F P
0 g
s
.63388 .44266 m .62051 .44425 L .61915 .46559 L p 1 1 1 r
F P
0 g
s
.59525 .46592 m .61915 .46559 L .62051 .44425 L p 1 .974 1 r
F P
0 g
s
.59485 .41062 m .56626 .41248 L .5606 .37345 L p 1 1 1 r
F P
0 g
s
.52531 .37672 m .5606 .37345 L .56626 .41248 L p 1 1 1 r
F P
0 g
s
.46358 .49928 m .44414 .50647 L .41712 .52939 L p .65 .65 .65 r
F P
0 g
s
.83503 .2534 m .91111 .22222 L .91455 .22907 L p 1 1 1 r
F P
0 g
s
.53566 .47072 m .50604 .4747 L .49142 .49287 L p 1 .65 .726 r
F P
0 g
s
.46358 .49928 m .49142 .49287 L .50604 .4747 L p .942 .65 .679 r
F P
0 g
s
.6385 .44212 m .63388 .44266 L .63494 .41151 L p 1 1 1 r
F P
0 g
s
.61855 .41029 m .63494 .41151 L .63388 .44266 L p 1 1 1 r
F P
0 g
s
.63494 .41151 m .61855 .41029 L .62336 .37467 L p 1 1 1 r
F P
0 g
s
.62336 .37467 m .64427 .37901 L .63494 .41151 L p 1 1 1 r
F P
0 g
s
.83503 .2534 m .80001 .21813 L p .88774 .16639 L 1 1 1 r
F P
0 g
s
.88774 .16639 m .91111 .22222 L .83503 .2534 L p 1 1 1 r
F P
0 g
s
.64318 .46929 m .64096 .47291 L .63388 .44266 L p 1 1 1 r
F P
0 g
s
.63388 .44266 m .6385 .44212 L .64318 .46929 L p 1 1 1 r
F P
0 g
s
.6385 .44212 m .63388 .44266 L .63568 .46676 L p 1 1 1 r
F P
0 g
s
.61915 .46559 m .63568 .46676 L .63388 .44266 L p 1 1 1 r
F P
0 g
s
.61855 .41029 m .59485 .41062 L .59447 .37274 L p 1 1 1 r
F P
0 g
s
.5606 .37345 m .59447 .37274 L .59485 .41062 L p 1 1 1 r
F P
0 g
s
.64427 .37901 m .62336 .37467 L .63552 .33641 L p 1 1 1 r
F P
0 g
s
.63552 .33641 m .66282 .34453 L .64427 .37901 L p 1 1 1 r
F P
0 g
s
.63568 .46676 m .64318 .46929 L .6385 .44212 L p 1 1 1 r
F P
0 g
s
.59447 .37274 m .62336 .37467 L .61855 .41029 L p 1 1 1 r
F P
0 g
s
.65696 .4957 m .65684 .50256 L .64096 .47291 L p .725 .831 1 r
F P
0 g
s
.64096 .47291 m .64318 .46929 L .65696 .4957 L p .725 .831 1 r
F P
0 g
s
.37773 .55217 m .36969 .56725 L .31447 .5949 L p 1 1 1 r
F P
0 g
s
.40759 .31383 m .44682 .29913 L .47312 .34242 L p 1 1 1 r
F P
0 g
s
.44682 .29913 m .40759 .31383 L .36045 .27137 L p 1 1 1 r
F P
0 g
s
.5606 .37345 m .52531 .37672 L .51286 .33504 L p 1 1 1 r
F P
0 g
s
.47312 .34242 m .51286 .33504 L .52531 .37672 L p 1 1 1 r
F P
0 g
s
.15771 .21813 m .20176 .16678 L .2945 .22331 L p 1 1 1 r
F P
0 g
s
.15771 .21813 m .09125 .19598 L .07006 .17023 L p 1 1 1 r
F P
0 g
s
.20176 .16678 m .15771 .21813 L p .07006 .17023 L 1 1 1 r
F P
0 g
s
.66282 .34453 m .63552 .33641 L .65641 .29418 L p 1 1 1 r
F P
0 g
s
.65641 .29418 m .69252 .30719 L .66282 .34453 L p 1 1 1 r
F P
0 g
s
.68126 .52129 m .68301 .53184 L .65684 .50256 L p .65 .901 1 r
F P
0 g
s
.65684 .50256 m .65696 .4957 L .68126 .52129 L p .65 .901 1 r
F P
0 g
s
.56644 .46769 m .53566 .47072 L .52498 .48791 L p 1 .709 .795 r
F P
0 g
s
.49142 .49287 m .52498 .48791 L .53566 .47072 L p 1 .65 .726 r
F P
0 g
s
.62336 .37467 m .59447 .37274 L .59871 .33185 L p 1 1 1 r
F P
0 g
s
.59871 .33185 m .63552 .33641 L .62336 .37467 L p 1 1 1 r
F P
0 g
s
.64318 .46929 m .63568 .46676 L .64592 .48999 L p 1 1 .895 r
F P
0 g
s
.64592 .48999 m .65696 .4957 L .64318 .46929 L p 1 1 .895 r
F P
0 g
s
.51286 .33504 m .47312 .34242 L .44682 .29913 L p 1 1 1 r
F P
0 g
s
.59447 .37274 m .5606 .37345 L .55629 .33137 L p 1 1 1 r
F P
0 g
s
.51286 .33504 m .55629 .33137 L .5606 .37345 L p 1 1 1 r
F P
0 g
s
.71859 .54592 m .72193 .56091 L .68301 .53184 L p .719 1 1 r
F P
0 g
s
.68301 .53184 m .68126 .52129 L .71859 .54592 L p .719 1 1 r
F P
0 g
s
.55629 .33137 m .59871 .33185 L .59447 .37274 L p 1 1 1 r
F P
0 g
s
.31447 .5949 m .32188 .57434 L .37773 .55217 L p 1 1 1 r
F P
0 g
s
.32188 .57434 m .31447 .5949 L .23778 .62304 L p 1 1 1 r
F P
0 g
s
.59525 .46592 m .56644 .46769 L .56086 .48494 L p 1 .829 .886 r
F P
0 g
s
.52498 .48791 m .56086 .48494 L .56644 .46769 L p 1 .709 .795 r
F P
0 g
s
.49142 .49287 m .46358 .49928 L .43862 .51903 L p .788 .65 .65 r
F P
0 g
s
.41712 .52939 m .43862 .51903 L .46358 .49928 L p .65 .65 .65 r
F P
0 g
s
.63568 .46676 m .61915 .46559 L .62466 .48604 L p 1 1 1 r
F P
0 g
s
.62466 .48604 m .64592 .48999 L .63568 .46676 L p 1 1 1 r
F P
0 g
s
.69252 .30719 m .65641 .29418 L .6885 .24602 L p 1 1 1 r
F P
0 g
s
.6885 .24602 m .73658 .2657 L .69252 .30719 L p 1 1 1 r
F P
0 g
s
.61915 .46559 m .59525 .46592 L .59529 .48429 L p 1 .958 .977 r
F P
0 g
s
.56086 .48494 m .59529 .48429 L .59525 .46592 L p 1 .829 .886 r
F P
0 g
s
.59529 .48429 m .62466 .48604 L .61915 .46559 L p 1 .958 .977 r
F P
0 g
s
.77287 .56932 m .77725 .58988 L .72193 .56091 L p .834 1 1 r
F P
0 g
s
.72193 .56091 m .71859 .54592 L .77287 .56932 L p .834 1 1 r
F P
0 g
s
.63552 .33641 m .59871 .33185 L .60814 .28626 L p 1 1 1 r
F P
0 g
s
.60814 .28626 m .65641 .29418 L .63552 .33641 L p 1 1 1 r
F P
0 g
s
.65696 .4957 m .64592 .48999 L .66578 .51199 L p 1 .854 .65 r
F P
0 g
s
.66578 .51199 m .68126 .52129 L .65696 .4957 L p 1 .854 .65 r
F P
0 g
s
.23778 .62304 m .24361 .59539 L .32188 .57434 L p 1 1 1 r
F P
0 g
s
.23778 .62304 m .13694 .65041 L .13563 .65003 L p 1 1 1 r
F P
0 g
s
.24361 .59539 m .23778 .62304 L p .13563 .65003 L 1 1 1 r
F P
0 g
s
.36045 .27137 m .41042 .25028 L .44682 .29913 L p 1 1 1 r
F P
0 g
s
.41042 .25028 m .36045 .27137 L .2945 .22331 L p 1 1 1 r
F P
0 g
s
.55629 .33137 m .51286 .33504 L .49706 .2889 L p 1 1 1 r
F P
0 g
s
.44682 .29913 m .49706 .2889 L .51286 .33504 L p 1 1 1 r
F P
0 g
s
.84995 .5911 m .85416 .61882 L .77725 .58988 L p .923 1 1 r
F P
0 g
s
.77725 .58988 m .77287 .56932 L .84995 .5911 L p .923 1 1 r
F P
0 g
s
.52498 .48791 m .49142 .49287 L .47131 .51016 L p .962 .65 .65 r
F P
0 g
s
.43862 .51903 m .47131 .51016 L .49142 .49287 L p .788 .65 .65 r
F P
0 g
s
.59871 .33185 m .55629 .33137 L .55294 .28442 L p 1 1 1 r
F P
0 g
s
.55294 .28442 m .60814 .28626 L .59871 .33185 L p 1 1 1 r
F P
0 g
s
.49706 .2889 m .55294 .28442 L .55629 .33137 L p 1 1 1 r
F P
0 g
s
.49706 .2889 m .44682 .29913 L .41042 .25028 L p 1 1 1 r
F P
0 g
s
.13563 .65003 m .13261 .64913 L p .24361 .59539 L 1 1 1 r
F P
0 g
s
.9362 .61243 m .9554 .64658 L .85416 .61882 L p .986 1 1 r
F P
0 g
s
.85416 .61882 m .84995 .5911 L p .9362 .61243 L .986 1 1 r
F P
0 g
s
.85416 .61882 m .9554 .64658 L .95591 .64771 L p 1 1 1 r
F P
0 g
s
.73658 .2657 m .6885 .24602 L .73582 .18896 L p 1 1 1 r
F P
0 g
s
.73582 .18896 m .80001 .21813 L .73658 .2657 L p 1 1 1 r
F P
0 g
s
.64592 .48999 m .62466 .48604 L .63781 .50496 L p 1 .931 .776 r
F P
0 g
s
.63781 .50496 m .66578 .51199 L .64592 .48999 L p 1 .931 .776 r
F P
0 g
s
.68126 .52129 m .66578 .51199 L .69753 .53228 L p 1 .65 .65 r
F P
0 g
s
.62749 .5248 m .69481 .53465 L .66897 .52484 L p 1 .65 .65 r
F P
0 g
s
.66897 .52484 m .66024 .52153 L p .62749 .5248 L 1 .65 .65 r
F P
0 g
s
.54808 .5239 m .56781 .52473 L p .62749 .5248 L .738 .65 .65 r
F P
0 g
s
.69481 .53465 m .62749 .5248 L .65409 .52838 L p .76 .65 .65 r
F P
0 g
s
.56781 .52473 m .65409 .52838 L .62749 .5248 L p .738 .65 .65 r
F P
0 g
s
.65409 .52838 m .67278 .53129 L p .69481 .53465 L .76 .65 .65 r
F P
0 g
s
.69481 .53465 m .70565 .53801 L p .70257 .53583 L .956 .65 .65 r
F P
0 g
s
.69753 .53228 m .71859 .54592 L .69207 .52843 L p 1 .65 .65 r
F P
0 g
s
.71859 .54592 m .69753 .53228 L .74486 .55016 L p .65 1 1 r
F P
0 g
s
.70565 .53801 m .74486 .55016 L .69753 .53228 L p .956 .65 .65 r
F P
0 g
s
.74486 .55016 m .69481 .53465 L .7462 .54271 L p .65 1 1 r
F P
0 g
s
.67278 .53129 m .7462 .54271 L .69481 .53465 L p .76 .65 .65 r
F P
0 g
s
.69481 .53465 m .70257 .53583 L .69753 .53228 L .956 .65 .65 r
F
.69207 .52843 m .68126 .52129 L p .69753 .53228 L 1 .65 .65 r
F P
0 g
s
.13261 .64913 m .13417 .61468 L .24361 .59539 L p 1 1 1 r
F P
0 g
s
.13417 .61468 m .13261 .64913 L .09175 .63392 L p 1 1 1 r
F P
0 g
s
.56086 .48494 m .52498 .48791 L .51204 .50376 L p 1 .65 .675 r
F P
0 g
s
.47131 .51016 m .51204 .50376 L .52498 .48791 L p .962 .65 .65 r
F P
0 g
s
.3525 .55463 m .40293 .53776 L p .36387 .55539 L 1 1 1 r
F P
0 g
s
.32188 .57434 m .3525 .55463 L p .36387 .55539 L 1 1 1 r
F P
0 g
s
.3525 .55463 m .28126 .56854 L p .34065 .55383 L .986 1 1 r
F P
0 g
s
.40293 .53776 m .3525 .55463 L p .39634 .54064 L .866 1 1 r
F P
0 g
s
.37773 .55217 m .40293 .53776 L p .40932 .53497 L 1 1 1 r
F P
0 g
s
.44345 .52562 m .40293 .53776 L p .39634 .54064 L .866 1 1 r
F P
0 g
s
.40451 .53801 m .3525 .55463 L p .34065 .55383 L .986 1 1 r
F P
0 g
s
.40293 .53776 m .43862 .51903 L p .40932 .53497 L 1 1 1 r
F P
0 g
s
.65641 .29418 m .60814 .28626 L .62398 .23354 L p 1 1 1 r
F P
0 g
s
.62398 .23354 m .6885 .24602 L .65641 .29418 L p 1 1 1 r
F P
0 g
s
.47131 .51016 m .43862 .51903 L .40293 .53776 L p .65 .65 .65 r
F P
0 g
s
.62466 .48604 m .59529 .48429 L .60007 .501 L p 1 .856 .808 r
F P
0 g
s
.60007 .501 m .63781 .50496 L .62466 .48604 L p 1 .856 .808 r
F P
0 g
s
.59529 .48429 m .56086 .48494 L .55657 .50058 L p 1 .743 .755 r
F P
0 g
s
.51204 .50376 m .55657 .50058 L .56086 .48494 L p 1 .65 .675 r
F P
0 g
s
.55657 .50058 m .60007 .501 L .59529 .48429 L p 1 .743 .755 r
F P
0 g
s
.07006 .17023 m .04234 .13667 L .04667 .13044 L p 1 1 1 r
F P
0 g
s
.04667 .13044 m .20176 .16678 L .07006 .17023 L 1 1 1 r
F
.55294 .28442 m .49706 .2889 L .47611 .23583 L p F P
0 g
s
.41042 .25028 m .47611 .23583 L .49706 .2889 L p 1 1 1 r
F P
0 g
s
.2945 .22331 m .35948 .19291 L .41042 .25028 L p 1 1 1 r
F P
0 g
s
.35948 .19291 m .2945 .22331 L .20176 .16678 L p 1 1 1 r
F P
0 g
s
.74486 .55016 m .77287 .56932 L .71859 .54592 L p .65 1 1 r
F P
0 g
s
.60814 .28626 m .55294 .28442 L .55024 .22997 L p 1 1 1 r
F P
0 g
s
.55024 .22997 m .62398 .23354 L .60814 .28626 L p 1 1 1 r
F P
0 g
s
.66578 .51199 m .63781 .50496 L .66024 .52153 L p 1 .661 .65 r
F P
0 g
s
.66024 .52153 m .69753 .53228 L .66578 .51199 L p 1 .661 .65 r
F P
0 g
s
.47611 .23583 m .55024 .22997 L .55294 .28442 L p 1 1 1 r
F P
0 g
s
.80001 .21813 m .88675 .16403 L .88774 .16639 L p 1 1 1 r
F P
0 g
s
.80001 .21813 m .73582 .18896 L .80495 .11842 L p 1 1 1 r
F P
0 g
s
.88675 .16403 m .80001 .21813 L p .80495 .11842 L 1 1 1 r
F P
0 g
s
.47611 .23583 m .41042 .25028 L .35948 .19291 L p 1 1 1 r
F P
0 g
s
.51204 .50376 m .47131 .51016 L .44345 .52562 L p .833 .65 .65 r
F P
0 g
s
.40293 .53776 m .44345 .52562 L .47131 .51016 L p .65 .65 .65 r
F P
0 g
s
.3525 .55463 m .32188 .57434 L .24361 .59539 L p 1 1 1 r
F P
0 g
s
.6885 .24602 m .62398 .23354 L .64838 .16996 L p 1 1 1 r
F P
0 g
s
.64838 .16996 m .73582 .18896 L .6885 .24602 L p 1 1 1 r
F P
0 g
s
.63781 .50496 m .60007 .501 L .61032 .51497 L p 1 .661 .65 r
F P
0 g
s
.61032 .51497 m .66024 .52153 L .63781 .50496 L p 1 .661 .65 r
F P
0 g
s
.77287 .56932 m .74486 .55016 L .81354 .56465 L p .754 1 1 r
F P
0 g
s
.81354 .56465 m .84995 .5911 L .77287 .56932 L p .754 1 1 r
F P
0 g
s
.55657 .50058 m .51204 .50376 L .4954 .51716 L p .994 .65 .65 r
F P
0 g
s
.44345 .52562 m .4954 .51716 L .51204 .50376 L p .833 .65 .65 r
F P
0 g
s
.60007 .501 m .55657 .50058 L .55321 .51345 L p 1 .65 .65 r
F P
0 g
s
.55321 .51345 m .61032 .51497 L .60007 .501 L p 1 .65 .65 r
F P
0 g
s
.4954 .51716 m .55321 .51345 L .55657 .50058 L p .994 .65 .65 r
F P
0 g
s
.69753 .53228 m .66024 .52153 L .69481 .53465 L p .956 .65 .65 r
F P
0 g
s
.55024 .22997 m .47611 .23583 L .44734 .1721 L p 1 1 1 r
F P
0 g
s
.35948 .19291 m .44734 .1721 L .47611 .23583 L p 1 1 1 r
F P
0 g
s
.62398 .23354 m .55024 .22997 L .54793 .16402 L p 1 1 1 r
F P
0 g
s
.54793 .16402 m .64838 .16996 L .62398 .23354 L p 1 1 1 r
F P
0 g
s
.20176 .16678 m .2871 .12244 L .35948 .19291 L p 1 1 1 r
F P
0 g
s
.20176 .16678 m .12965 .12884 L .25965 .11927 L p 1 1 1 r
F P
0 g
s
.2871 .12244 m .20176 .16678 L p .25965 .11927 L 1 1 1 r
F P
0 g
s
.04667 .13044 m .12965 .12884 L .20176 .16678 L p 1 1 1 r
F P
0 g
s
.24361 .59539 m .28126 .56854 L .3525 .55463 L p 1 1 1 r
F P
0 g
s
.28126 .56854 m .24361 .59539 L .13417 .61468 L p 1 1 1 r
F P
0 g
s
.44734 .1721 m .54793 .16402 L .55024 .22997 L p 1 1 1 r
F P
0 g
s
.80495 .11842 m .88478 .15866 L .88675 .16403 L p 1 1 1 r
F P
0 g
s
.40451 .53801 m .44345 .52562 L p .39982 .53953 L .866 1 1 r
F P
0 g
s
.3525 .55463 m .40451 .53801 L p .39982 .53953 L .866 1 1 r
F P
0 g
s
.40451 .53801 m .34941 .54568 L p .4094 .53643 L .8 1 1 r
F P
0 g
s
.4954 .51716 m .44345 .52562 L .40451 .53801 L p .665 .65 .65 r
F P
0 g
s
.47304 .52661 m .4954 .51716 L p .45201 .52711 L .665 .65 .65 r
F P
0 g
s
.40451 .53801 m .47304 .52661 L p .45201 .52711 L .665 .65 .65 r
F P
0 g
s
.47304 .52661 m .40451 .53801 L p .4094 .53643 L .8 1 1 r
F P
0 g
s
.44194 .53 m .47304 .52661 L p .41413 .5357 L .8 1 1 r
F P
0 g
s
.34941 .54568 m .44194 .53 L p .41413 .5357 L .8 1 1 r
F P
0 g
s
.41283 .52404 m .47131 .52398 L .44194 .53 L .813 1 1 r
F
.47304 .52661 m .44194 .53 L p .49494 .52608 L .65 .65 .65 r
F P
0 g
s
.55047 .52198 m .47304 .52661 L p .49494 .52608 L .65 .65 .65 r
F P
0 g
s
.55321 .51345 m .4954 .51716 L .47304 .52661 L p .835 .65 .65 r
F P
0 g
s
.47304 .52661 m .55047 .52198 L .55321 .51345 L p .835 .65 .65 r
F P
0 g
s
.54808 .5239 m .55047 .52198 L p .49909 .52578 L .65 .65 .65 r
F P
0 g
s
.44194 .53 m .54808 .5239 L p .49909 .52578 L .65 .65 .65 r
F P
0 g
s
.61032 .51497 m .55321 .51345 L .55047 .52198 L p .949 .65 .65 r
F P
0 g
s
.55047 .52198 m .62749 .5248 L .61032 .51497 L p .949 .65 .65 r
F P
0 g
s
.62749 .5248 m .55047 .52198 L .54817 .52383 L p .738 .65 .65 r
F P
0 g
s
.54817 .52383 m .54808 .5239 L p .55088 .52393 L .738 .65 .65 r
F P
0 g
s
.55088 .52393 m .62749 .5248 L .54817 .52383 L .738 .65 .65 r
F
.66024 .52153 m .61032 .51497 L .62749 .5248 L p 1 .65 .65 r
F P
0 g
s
.54579 .51563 m .69452 .52247 L .65669 .528 L p .748 1 1 r
F P
0 g
s
.65669 .528 m .65409 .52838 L p .64804 .52767 L .748 1 1 r
F P
0 g
s
.54579 .51563 m .65669 .528 L .64804 .52767 L .748 1 1 r
F
.54808 .5239 m .54579 .51563 L p .59935 .52194 L F P
0 g
s
.65409 .52838 m .54808 .5239 L p .59935 .52194 L .748 1 1 r
F P
0 g
s
.54808 .5239 m .44194 .53 L p .47131 .52398 L .813 1 1 r
F P
0 g
s
.09175 .63392 m .06149 .62256 L .13417 .61468 L p 1 1 1 r
F P
0 g
s
.84995 .5911 m .93261 .60602 L .9362 .61243 L p .986 1 1 r
F P
0 g
s
.84995 .5911 m .81354 .56465 L p .90936 .57517 L .88 1 1 r
F P
0 g
s
.90936 .57517 m .93261 .60602 L .84995 .5911 L p .88 1 1 r
F P
0 g
s
.44734 .1721 m .35948 .19291 L .2871 .12244 L p 1 1 1 r
F P
0 g
s
.88478 .15866 m .80495 .11842 L .85267 .07552 L closepath p 1 1 1 r
F P
0 g
s
.73582 .18896 m .64838 .16996 L .68506 .0896 L p 1 1 1 r
F P
0 g
s
.68506 .0896 m .80495 .11842 L .73582 .18896 L p 1 1 1 r
F P
0 g
s
.7462 .54271 m .81354 .56465 L .74486 .55016 L p .65 1 1 r
F P
0 g
s
.13417 .61468 m .17995 .57798 L .28126 .56854 L p 1 1 1 r
F P
0 g
s
.13417 .61468 m .06149 .62256 L .03737 .61615 L p 1 1 1 r
F P
0 g
s
.17995 .57798 m .13417 .61468 L p .03737 .61615 L 1 1 1 r
F P
0 g
s
.44734 .1721 m .41136 .10116 L .42106 .09919 L p 1 1 1 r
F P
0 g
s
.54793 .16402 m .44734 .1721 L p .42106 .09919 L 1 1 1 r
F P
0 g
s
.41136 .10116 m .44734 .1721 L p .2871 .12244 L 1 1 1 r
F P
0 g
s
.64838 .16996 m .54793 .16402 L .54575 .08014 L p 1 1 1 r
F P
0 g
s
.54575 .08014 m .68506 .0896 L .64838 .16996 L p 1 1 1 r
F P
0 g
s
.28126 .56854 m .34941 .54568 L .40451 .53801 L p .986 1 1 r
F P
0 g
s
.42106 .09919 m .49246 .08461 L p .54793 .16402 L 1 1 1 r
F P
0 g
s
.49246 .08461 m .54575 .08014 L .54793 .16402 L p 1 1 1 r
F P
0 g
s
.34941 .54568 m .28126 .56854 L .17995 .57798 L p 1 1 1 r
F P
0 g
s
.25965 .11927 m .28159 .11766 L .2871 .12244 L p 1 1 1 r
F P
0 g
s
.2871 .12244 m .33198 .11094 L .41136 .10116 L p 1 1 1 r
F P
0 g
s
.33198 .11094 m .2871 .12244 L .28159 .11766 L closepath p 1 1 1 r
F P
0 g
s
.81354 .56465 m .90837 .57386 L .90936 .57517 L p .88 1 1 r
F P
0 g
s
.81354 .56465 m .7462 .54271 L .82211 .54325 L p .787 1 1 r
F P
0 g
s
.90837 .57386 m .81354 .56465 L p .82211 .54325 L .787 1 1 r
F P
0 g
s
.80495 .11842 m .68506 .0896 L p .75772 .01882 L 1 1 1 r
F P
0 g
s
.82752 .00563 m .80495 .11842 L .75772 .01882 L 1 1 1 r
F
.82752 .00563 m .85267 .07552 L .80495 .11842 L p F P
0 g
s
.03737 .61615 m .00562 .60758 L .01007 .60334 L p 1 1 1 r
F P
0 g
s
.01007 .60334 m .17995 .57798 L .03737 .61615 L 1 1 1 r
F
.44194 .53 m .34941 .54568 L .27011 .54614 L p .922 1 1 r
F P
0 g
s
.17995 .57798 m .27011 .54614 L .34941 .54568 L p 1 1 1 r
F P
0 g
s
.68506 .0896 m .71499 .03166 L .75772 .01882 L p 1 1 1 r
F P
0 g
s
.68506 .0896 m .54575 .08014 L p .63992 .05062 L 1 1 1 r
F P
0 g
s
.63992 .05062 m .71499 .03166 L .68506 .0896 L p 1 1 1 r
F P
0 g
s
.17995 .57798 m .10057 .57946 L .2405 .55048 L p 1 1 1 r
F P
0 g
s
.27011 .54614 m .17995 .57798 L p .2405 .55048 L 1 1 1 r
F P
0 g
s
.01007 .60334 m .10057 .57946 L .17995 .57798 L p 1 1 1 r
F P
0 g
s
.7462 .54271 m .65409 .52838 L .69452 .52247 L p .738 1 1 r
F P
0 g
s
.69452 .52247 m .82211 .54325 L .7462 .54271 L p .738 1 1 r
F P
0 g
s
.54575 .08014 m .49246 .08461 L .53703 .07596 L p 1 1 1 r
F P
0 g
s
.82211 .54325 m .90649 .57216 L .90837 .57386 L p .787 1 1 r
F P
0 g
s
.54575 .08014 m .54563 .07429 L .63992 .05062 L p 1 1 1 r
F P
0 g
s
.53703 .07596 m .54563 .07429 L .54575 .08014 L p 1 1 1 r
F P
0 g
s
.90649 .57216 m .82211 .54325 L .87495 .53814 L closepath p .902 1 1 r
F P
0 g
s
.44194 .53 m .40252 .52476 L .41283 .52404 L p .813 1 1 r
F P
0 g
s
.40252 .52476 m .44194 .53 L p .27011 .54614 L .922 1 1 r
F P
0 g
s
.41283 .52404 m .48889 .51886 L p .54808 .5239 L .813 1 1 r
F P
0 g
s
.48889 .51886 m .54579 .51563 L .54808 .5239 L p .813 1 1 r
F P
0 g
s
.75772 .01882 m .81359 .00191 L .82752 .00563 L p 1 1 1 r
F P
0 g
s
.27011 .54614 m .31781 .53786 L .40252 .52476 L p .922 1 1 r
F P
0 g
s
.31781 .53786 m .27011 .54614 L .26404 .54559 L closepath p .998 1 1 r
F P
0 g
s
.2405 .55048 m .26404 .54559 L .27011 .54614 L p 1 1 1 r
F P
0 g
s
.82211 .54325 m .69452 .52247 L p .77431 .51282 L .87 1 1 r
F P
0 g
s
.85041 .51762 m .82211 .54325 L .77431 .51282 L .87 1 1 r
F
.85041 .51762 m .87495 .53814 L .82211 .54325 L p F P
0 g
s
.69452 .52247 m .72783 .51122 L .77431 .51282 L p .87 1 1 r
F P
0 g
s
.69452 .52247 m .54579 .51563 L p .6468 .51255 L .877 1 1 r
F P
0 g
s
.6468 .51255 m .72783 .51122 L .69452 .52247 L p .877 1 1 r
F P
0 g
s
.54579 .51563 m .48889 .51886 L .53647 .5151 L p .923 1 1 r
F P
0 g
s
.54579 .51563 m .54567 .51438 L .6468 .51255 L p .877 1 1 r
F P
0 g
s
.53647 .5151 m .54567 .51438 L .54579 .51563 L p .923 1 1 r
F P
0 g
s
.77431 .51282 m .83541 .51505 L .85041 .51762 L p .87 1 1 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    ImageSize->{288, 228.438},
    ImageMargins->{{40, 0}, {0, 31}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000i1000`40O003h00Oogoo8Goo003XOol3
000eOol00>Aoo`@000=oo`<0039oo`00h7oo10002Goo00<007ooOol0<7oo003LOol4000>Ool00`00
Oomoo`0_Ool00=Qoo`@0019oo`03001oogoo02moo`00eGoo0`005Woo00<007ooOol0;goo003BOol3
000JOol00`00Oomoo`0^Ool00<moo`<001eoo`03001oogoo02ioo`00c7oo0`0087oo00<007ooOol0
;Woo0038Ool5000SOol00`00Oomoo`0]Ool00<Aoo`@000Aoo`03001oogoo025oo`03001oogoo02eo
o`00`Goo0`001goo00<007ooOol08Woo00<007ooOol0;Goo002mOol4000:Ool00`00Oomoo`0SOol0
0`00Oomoo`0/Ool00;Uoo`@000eoo`03001oogoo02Aoo`03001oogoo02aoo`00]Goo10004Goo00<0
07ooOol09Goo00<007ooOol0:goo002aOol4000DOol00`00Oomoo`0VOol00`00Oomoo`0[Ool00:ao
o`D001Qoo`03001oogoo02Ioo`03001oogoo02]oo`00Z7oo100077oo00<007ooOol0:7oo00<007oo
Ool0:Woo002SOol5000POol00`00Oomoo`0XOol00`00Oomoo`0ZOol009moo`@002Aoo`03001oogoo
02Uoo`03001oogoo02Yoo`00W7oo0`00:7oo00<007ooOol0:Woo00<007ooOol0:Goo002GOol6000Y
Ool00`00Oomoo`0[Ool00`00Oomoo`0YOol0095ooa8002=oo`03001oogoo02Yoo`8002]oo`00Rgoo
2P001goo00<007ooOol017oo3@005Goo00<007ooOol0:Woo00@007ooOol002Yoo`00Qgoo10004Goo
00<007ooOol04Goo3P001goo00<007ooOol0:7oo0P000goo00<007ooOol0:7oo0023Ool4000EOol0
0`00Oomoo`0OOol9000XOol00`00Oomoo`03Ool00`00Oomoo`0XOol007moo`@001Uoo`03001oogoo
02Eoo`03001oogoo00@002=oo`03001oogoo00Eoo`03001oogoo02Moo`00Ngoo10007Goo00<007oo
Ool097oo00<007ooOol01Goo10007Woo00<007ooOol01Woo00<007ooOol09goo001cOol8000QOol0
0`00Oomoo`0TOol00`00Oomoo`09Ool4000IOol00`00Oomoo`08Ool00`00Oomoo`0VOol006]oo`P0
00=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo00ioo`D001=oo`03001oogoo00Uoo`03
001oogoo02Ioo`00Hgoo200037oo00<007ooOol08Woo00<007ooOol08goo00<007ooOol04goo1000
3Goo0P0037oo00<007ooOol09Woo001LOol7000DOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00
Oomoo`0HOol40008Ool00`00Oomoo`0=Ool00`00Oomoo`0UOol005Aoo`T001]oo`03001oogoo025o
o`03001oogoo029oo`03001oogoo01aoo`@000=oo`03001oogoo00ioo`03001oogoo02Eoo`00A7oo
400000=oo`0000000P007goo00<007ooOol08Goo00<007ooOol08Woo00<007ooOol087oo0`004Goo
00<007ooOol09Goo000hOol<000=Ool4000TOol00`00Oomoo`0POol00`00Oomoo`0QOol00`00Oomo
o`0ROol01000Ool0000047oo00<007ooOol097oo000/Ool<000HOol200000goo001oo`0TOol00`00
Oomoo`0QOol00`00Oomoo`0POol00`00Oomoo`0QOol00`00Oomoo`02Ool2000>Ool00`00Oomoo`0T
Ool000eooal0029oo`8000Aoo`03001oogoo02=oo`03001oogoo021oo`03001oogoo01moo`03001o
ogoo025oo`03001oogoo00Eoo`8000eoo`03001oogoo02=oo`0037oo00<007ooOol05goo0P0097oo
0P001goo00<007ooOol08Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol087oo00<007oo
Ool027oo0P002goo00<007ooOol08goo000<Ool00`00Oomoo`0IOol2000POol2000:Ool00`00Oomo
o`0ROol00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0;Ool20009Ool0
0`00Oomoo`0SOol000eoo`03001oogoo01Yoo`8001aoo`8000eoo`03001oogoo025oo`03001oogoo
01moo`03001oogoo01ioo`03001oogoo01moo`03001oogoo00ioo`8000Qoo`03001oogoo029oo`00
3Woo00<007ooOol06goo0P0067oo0P0047oo00<007ooOol08Goo00<007ooOol07Woo00<007ooOol0
7Goo00<007ooOol07goo00<007ooOol04Goo0P001Woo00<007ooOol08Woo000>Ool00`00Oomoo`0M
Ool00`00Oomoo`0COol2000COol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00
Oomoo`0NOol00`00Oomoo`0DOol20004Ool00`00Oomoo`0ROol000moo`03001oogoo01eoo`80015o
o`8001Ioo`03001oogoo021oo`03001oogoo01eoo`03001oogoo01eoo`03001oogoo01eoo`03001o
ogoo01Moo`8000=oo`03001oogoo025oo`0047oo00<007ooOol07Woo0P003Goo0P006Goo00<007oo
Ool07goo00<007ooOol07Goo00<007ooOol077oo00<007ooOol07Goo00<007ooOol06Woo0P0000=o
o`00Ool08Woo000AOol00`00Oomoo`0OOol20009Ool2000LOol2000POol00`00Oomoo`0LOol00`00
Oomoo`0LOol00`00Oomoo`0MOol00`00Oomoo`0LOol3000ROol0019oo`03001oogoo021oo`8000Eo
o`80021oo`03001oogoo01eoo`03001oogoo01aoo`03001oogoo01]oo`03001oogoo01eoo`03001o
ogoo01moo`03001oogoo021oo`004Woo00<007ooOol08Woo0P0000=oo`0000008goo00<007ooOol0
7Goo00<007ooOol057oo3`005Woo00<007ooOol077oo00<007ooOol08Goo00<007ooOol07goo000C
Ool00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`0LOol00`00Oomoo`06Ool>0007Ool00`00
Oomoo`05Ool>0007Ool00`00Oomoo`0LOol00`00Oomoo`0POol3000QOol001Aoo`03001oogoo025o
o`04001oo`00000UOol00`00Oomoo`0JOol:000EOol00`00Oomoo`0COol:000KOol00`00Oomoo`0P
Ool01000Oomoo`008Goo000EOol00`00Oomoo`0OOol00`00Oomoo`02Ool2000TOol00`00Oomoo`0E
Ool40002Ool00`00Oomoo`0JOol00`00Oomoo`0JOol00`00Oomoo`05000EOol00`00Oomoo`0OOol2
0004Ool00`00Oomoo`0NOol001Ioo`03001oogoo01ioo`03001oogoo00Aoo`03001oogoo029oo`03
001oogoo011oo`@000Moo`03001oogoo01Uoo`03001oogoo01Uoo`03001oogoo00Ioo`D000moo`03
001oogoo01ioo`8000Ioo`03001oogoo01ioo`005goo00<007ooOol077oo00<007ooOol01Woo0P00
8goo00<007ooOol02goo10002goo00<007ooOol06Goo00<007ooOol06Goo00<007ooOol02goo1@00
2Goo00<007ooOol07Woo00<007ooOol01goo00<007ooOol07Goo000GOol00`00Oomoo`0KOol00`00
Oomoo`09Ool2000ROol00`00Oomoo`06Ool4000@Ool00`00Oomoo`0HOol00`00Oomoo`0HOol00`00
Oomoo`0AOol50003Ool00`00Oomoo`0MOol2000:Ool00`00Oomoo`0MOol001Qoo`03001oogoo01Uo
o`03001oogoo00aoo`03001oogoo021oo`04001oogooOol4000DOol00`00Oomoo`0HOol00`00Oomo
o`0HOol00`00Oomoo`0FOol3000OOol00`00Oomoo`0;Ool00`00Oomoo`0LOol001Uoo`03001oogoo
01Moo`03001oogoo00ioo`80021oo`@001Uoo`03001oogoo01Moo`03001oogoo01Qoo`03001oogoo
01Moo`04001oo`00000KOol2000>Ool00`00Oomoo`0LOol001Yoo`8001Moo`03001oogoo011oo`80
01aoo`80009oo`03001oogoo01Qoo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo01Moo`03
001oogoo009oo`8001Qoo`03001oogoo00ioo`03001oogoo01aoo`006goo10004goo00<007ooOol0
4goo0P0067oo0P001Goo00<007ooOol05goo00<007ooOol05goo00<007ooOol05goo00<007ooOol0
5goo00<007ooOol017oo0P0057oo0P004Woo00<007ooOol06goo000LOol00`00Oomoo`02000@Ool0
0`00Oomoo`0FOol00`00Oomoo`0COol20007Ool00`00Oomoo`0HOol00`00Oomoo`0FOol00`00Oomo
o`0FOol00`00Oomoo`0GOol00`00Oomoo`07Ool2000AOol00`00Oomoo`0BOol00`00Oomoo`0KOol0
01eoo`04001oogooOol3000<Ool00`00Oomoo`0HOol2000AOol2000:Ool00`00Oomoo`0GOol00`00
Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0:Ool2000=Ool2000FOol00`00
Oomoo`0JOol001ioo`03001oogoo00=oo`<000Qoo`03001oogoo01]oo`8000eoo`8000eoo`03001o
ogoo01Moo`03001oogoo01Eoo`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo00eoo`8000Uo
o`8001Qoo`03001oogoo01Yoo`007Woo00<007ooOol01Woo0P001Woo00<007ooOol07Goo00<007oo
Ool027oo0P0047oo00<007ooOol05Woo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol05Goo
00<007ooOol047oo0P001Woo00<007ooOol06Goo00<007ooOol06Goo000OOol00`00Oomoo`07Ool3
0002Ool00`00Oomoo`0OOol20006Ool2000COol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomo
o`0EOol00`00Oomoo`0DOol00`00Oomoo`0COol20002Ool2000LOol00`00Oomoo`0IOol0021oo`03
001oogoo00Uoo`8002Aoo`80009oo`8001Ioo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo
01Eoo`03001oogoo01Aoo`03001oogoo01Eoo`8001moo`03001oogoo01Qoo`008Goo00<007ooOol0
2Goo00@007oo000002=oo`8001Qoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03
001oogoo01Aoo`03001oogoo01Eoo`800003Ool007oo01aoo`8001Yoo`008Woo00<007ooOol027oo
00@007ooOomoo`<001moo`04001oo`00000HOol00`00Oomoo`0EOol00`00Oomoo`0COol00`00Oomo
o`0DOol00`00Oomoo`0COol00`00Oomoo`0EOol00`00Oomoo`02Ool00`00Oomoo`0HOol200000goo
001oo`0IOol002=oo`03001oogoo00Moo`03001oogoo00Aoo`<001]oo`03001oogoo009oo`03001o
ogoo01Ioo`03001oogoo01Aoo`03001oogoo00iooa0000]oo`03001oogoo01=oo`03001oogoo01Eo
o`03001oogoo00Aoo`03001oogoo01Aoo`<000Aoo`03001oogoo01Moo`0097oo00<007ooOol01Woo
00<007ooOol01goo0P0067oo00<007ooOol017oo00<007ooOol05Woo00<007ooOol057oo00<007oo
Ool00goo2P001Goo00<007ooOol027oo3P004Woo00<007ooOol057oo0P0027oo00<007ooOol04Goo
0P001goo00<007ooOol05goo000UOol00`00Oomoo`05Ool00`00Oomoo`09Ool3000DOol00`00Oomo
o`06Ool2000GOol00`00Oomoo`0AOol8000?Ool00`00Oomoo`0COol00`00Oomoo`04000=Ool00`00
Oomoo`0DOol00`00Oomoo`09Ool00`00Oomoo`0>Ool2000:Ool00`00Oomoo`0FOol002Ioo`03001o
ogoo00Aoo`03001oogoo00aoo`<0011oo`03001oogoo00Uoo`03001oogoo01Eoo`03001oogoo00]o
o`D0009oo`03001oogoo019oo`03001oogoo019oo`03001oogoo00Eoo`D000Qoo`03001oogoo01=o
o`03001oogoo00]oo`03001oogoo00Yoo`<000aoo`03001oogoo01Ioo`009goo00<007ooOol00Woo
00<007ooOol047oo0P003Goo00<007ooOol02goo00<007ooOol057oo00<007ooOol01goo100027oo
00<007ooOol04Goo00<007ooOol04Woo00<007ooOol02Woo10000goo00<007ooOol04Woo0P003goo
00<007ooOol01goo0P0047oo00<007ooOol05Goo000WOol00`00Oomoo`02Ool00`00Oomoo`0BOol3
0009Ool00`00Oomoo`0=Ool2000EOol01000Oomoogoo1@0037oo00<007ooOol04Goo00<007ooOol0
4Woo00<007ooOol03Woo10004goo00<007ooOol047oo00<007ooOol00goo0`004Woo00<007ooOol0
5Goo000XOol01@00Oomoogoo00005goo0`001Goo00<007ooOol047oo00<007ooOol04Woo10004Woo
00<007ooOol047oo00<007ooOol04Goo00<007ooOol047oo00<007ooOol00`003Woo0P0057oo00<0
07ooOol00P005Woo00<007ooOol057oo000YOol01000Oomoo`006Woo0P000Woo00<007ooOol04Woo
00<007ooOol03goo0P000Woo00<007ooOol04Goo00<007ooOol047oo00<007ooOol04Goo00<007oo
Ool047oo00<007ooOol00goo0P002goo00<007ooOol05Goo0P0067oo00<007ooOol057oo000ZOol0
0`00Ool0000LOol2000FOol2000=Ool20005Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomo
o`0AOol00`00Oomoo`0?Ool00`00Oomoo`06Ool30007Ool00`00Oomoo`0DOol3000JOol00`00Oomo
o`0COol002]oo`8001eoo`<001Ioo`03001oogoo00Moo`<000Moo`03001oogoo015oo`03001oogoo
011oo`03001oogoo00moo`03001oogoo00moo`03001oogoo00Yoo`<0009oo`8001Eoo`80009oo`03
001oogoo01Qoo`03001oogoo01=oo`00;7oo00<007ooOol06goo00<007ooOol00P005Goo00<007oo
Ool017oo0P002goo00<007ooOol047oo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo
00<007ooOol03Goo0P005Goo0P0017oo00<007ooOol067oo0P0057oo000]Ool00`00Oomoo`0IOol0
0`00Oomoo`03Ool2000DOol20002Ool2000>Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomo
o`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Ool0000BOol20006Ool00`00Oomoo`0DOol4
0002Ool00`00Oomoo`0AOol002eoo`8001Yoo`03001oogoo00Eoo`8001Aoo`80015oo`03001oogoo
00moo`03001oogoo00moo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`05001oogoo
Ool0000?Ool20008Ool00`00Oomoo`0@Ool40005Ool00`00Ool0000BOol002ioo`D001Ioo`03001o
ogoo00Moo`80015oo`03001oo`00015oo`03001oogoo00moo`03001oogoo00moo`03001oogoo00io
o`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00Yoo`8000]oo`03001o
ogoo00]oo`@000Qoo`04001oogoo000BOol002moo`04001oogooOol4000BOol00`00Oomoo`09Ool2
000>Ool01@00Oomoogoo00004Goo00<007ooOol03goo00<007ooOol03Woo00<007ooOol03Woo00<0
07ooOol03Goo00<007ooOol03Goo00<007ooOol01Goo0P0027oo0P003Goo00<007ooOol01goo1000
37oo00D007ooOomoo`00015oo`00<7oo00<007ooOol017oo10003Woo00<007ooOol02goo0P002goo
00<007ooOol00goo0P0047oo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Goo00<007oo
Ool03Goo00<007ooOol03Goo00<007ooOol027oo00<007ooOol00goo0P003goo00<007ooOol00goo
10003goo00<007ooOol00Woo00<007ooOol03goo000aOol00`00Oomoo`07Ool3000;Ool00`00Oomo
o`0=Ool20007Ool20008Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`06OolK000;Ool0
0`00Oomoo`0<Ool2000<Ool00`00Oomoo`02000AOol00`00Ool00003000BOol00`00Oomoo`04Ool0
0`00Oomoo`0>Ool0039oo`03001oogoo00Yoo`<000Ioo`03001oogoo011oo`8000Aoo`03001oogoo
00Uoo`03001oogoo00ioo`03001oogoo00]oo`/000Moo`03001oogoo00eoo`04001oogooOol70004
Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool2000BOol3000EOol00`00Oomoo`05Ool00`00Oomoo`0>
Ool003=oo`03001oogoo00eoo`8000=oo`03001oogoo019oo`800003Ool007oo00aoo`03001oogoo
00eoo`03001oogoo00Moo`@0009oo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Qoo`D0
00aoo`03001oogoo00aoo`<0015oo`<001Moo`03001oogoo00Ioo`03001oogoo00eoo`00=7oo00<0
07ooOol047oo0P005Woo00<007ooOol03Goo00<007ooOol03Goo00@007ooOomoo`D000Moo`03001o
ogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`04001oo`000009Ool00`00Oomoo`0<Ool01000
Oomoo`003Woo0`000Woo00<007ooOol057oo00<007ooOol01goo00<007ooOol03Goo000eOol00`00
Oomoo`0AOol3000COol3000>Ool00`00Oomoo`0<Ool4000<Ool00`00Oomoo`0<Ool00`00Oomoo`0<
Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool30005Ool00`00Oomoo`0;Ool20003Ool00`00Oomoo`0:
Ool20004Ool00`00Oomoo`0DOol00`00Oomoo`09Ool00`00Oomoo`0<Ool003Ioo`03001oogoo011o
o`03001oogoo00<000moo`05001oogooOol0000>Ool20009Ool30002Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool20002Ool00`00Oomoo`0;
Ool00`00Oomoo`03Ool00`00Oomoo`07Ool30006Ool00`00Oomoo`0COol00`00Oomoo`0:Ool00`00
Oomoo`0<Ool003Moo`03001oogoo011oo`03001oogoo009oo`8000eoo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo00Aoo`8000Eoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00ao
o`03001oogoo00Yoo`03001oogoo00Qoo`8000aoo`8000Moo`03001oogoo00Aoo`8000Qoo`03001o
ogoo01Aoo`03001oogoo00]oo`03001oogoo00]oo`00>7oo00<007ooOol03goo00<007ooOol017oo
0`002Goo00<007ooOol017oo0P003Woo00<007ooOol00`0027oo00<007ooOol02goo00<007ooOol0
37oo00<007ooOol02Woo00<007ooOol02goo00<007ooOol027oo00<007oo00002Woo00<007ooOol0
1goo00@007ooOomoo`<000Uoo`03001oogoo01Aoo`03001oogoo00Eoo`P000eoo`00>Goo00<007oo
Ool03goo00<007ooOol01Woo0P001goo00<007ooOol01Woo00<007ooOol037oo0P002goo00<007oo
Ool037oo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00@007oo
Ool000Moo`8000Yoo`04001oo`00000<Ool00`00Oomoo`0@Ool<0008Ool00`00Oomoo`0:Ool003Yo
o`80011oo`03001oogoo00Moo`<000Aoo`03001oogoo00Moo`8000Yoo`800003Ool007oo00]oo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Qoo`03
001oogoo009oo`8000Aoo`03001oogoo00Uoo`<000eoo`03001oogoo00Uoo`P00003Ool00000019o
o`03001oogoo00Uoo`00?7oo0`003Goo00<007ooOol02Woo0P0000=oo`00Ool02goo00<007ooOol0
1Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01Goo00@007oo000000Yoo`<000moo`04
001oogooOol80007Ool2000DOol00`00Oomoo`09Ool003eoo`03001oo`0000D000Qoo`03001oogoo
00]oo`8000eoo`03001oogoo00=oo`8000Eoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Qoo`80009oo`03001oogoo00]oo`H000ioo`03001oogoo01Eoo`03001oogoo00Qoo`00?Woo00<0
07ooOol017oo1@000goo00<007ooOol03Goo0`002goo0P0000=oo`00000027oo00<007ooOol02Woo
00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo
00<007ooOol01Woo0P0027oo0P000goo00<007ooOol027oo1@004Goo0P0067oo00<007ooOol027oo
000oOol2000:Ool5000=Ool00`00Kom_o`02000;Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0;Ool00`00Oomoo`04OolD0009Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Ool00006
Ool20004Ool00`00Oomoo`05Ool40002Ool00`00Oomoo`0@Ool00`00Oomoo`0IOol00`00Oomoo`07
Ool0045oo`03001oogoo00]oo`D000Yoo`04001_ofooKol20009Ool2000;Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool90005Ool00`00Oomoo`09Ool00`00Oomoo`060002Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool01@00Oomoogoo00000goo0P001Goo00<007ooOol00Woo100017oo0P004Goo0P006Goo
0`002Woo0012Ool00`00Oomoo`0<Ool2000016_o000000001goo00<006ooKol00foo0P001Woo00@0
07ooOol000]oo`03001oogoo00Qoo`03001oogoo009oo`H0009oo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Ioo`@000Moo`03001oogoo00Ioo`03001oogoo009oo`04001oo`000007Ool5
0007Ool00`00Oomoo`0?Ool2000HOol3000=Ool004=oo`03001oogoo00eoo`04001[of_oJol40004
Ool00`00Kom_o`04Kol20004Ool01@00Oomoogoo00002goo00<007ooOol01goo1@0027oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol027oo00<007oo00000`000goo00<007ooOol017oo0P00
1Goo0P001goo0`002Goo0P004Goo00<007ooOol057oo0`004Goo0014Ool00`00Oomoo`0=Ool20005
Jol50008Kol200000goo001oo`04Ool00`00Oomoo`08Ool00`00Oomoo`04Ool300000goo001oo`0;
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`04Ool30006Ool00`00
Oomoo`03Ool20006Ool40009Ool2000AOol2000DOol2000EOol004Eoo`8000moo`03001[of_o00I[
o`8000U_o`8000Ioo`8000Uoo`03001oogoo00<000Eoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Eoo`03001oo`0000Aoo`03001oogoo00=oo`80
00Eoo`@000Yoo`03001oogoo00moo`80019oo`<001Qoo`00Agoo00<007ooOol03Goo0P0026_o1000
1foo0P001Woo00<007ooOol01goo0P0027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol00P0000=oo`00Ool017oo00<007oo0000
0Woo0`0000=oo`00Ool02Goo0P0027oo40002goo0P0077oo001IOol20008Jol40005Kol00`00Eol0
0006Ool00`00Oomoo`04Ool200000goo001oo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool20000
0goo000000020002Ool20007Ool>0005Ool30008Ool9000POol004Yoo`8000Igo``000M[o`03001C
o`00008000=_o`03001Go`0000Ioo`03001oogoo009oo`05001oogooOol00009Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool20003Ool00`00Oomoo`020003Ool200000goo00000008000?Ool2000;Ool5000TOol004]oo`@0
00igo`H000=[o`80009Co`@0009Go`8000Eoo`04001oo`000005Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool00`00Oomoo`0300000goo00000003Ool50005Ool2000?Ool30009Ool4000YOol004eoo`04
001oo`00000?Mol:0003Dol20003Eol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool01@00Oomoo`00Ool00P000Woo0`001goo0`003Woo0`001goo1@00;Goo001>Ool0
1000Oomoogoo0P003gOo100000=Ko`0000000P000e?o00D005OoEomGo`0000=oo`03001oo`0000Mo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo009oo`05001oogoo001oo`050007Ool3000>Ool30005Ool5000b
Ool004moo`8000Aoo`80011go`<0009Ko`<00003Dol00000009Go`800005Ool007ooOol00007Ool0
0`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`03OolH0005Ool00`00Oomoo`02Ool00`00Oomo
o`050008Ool2000>Ool30004Ool4000gOol0055oo`03001oogoo00=oo`80015go`<0009Ko`@000=G
o`05001oogooOol00007Ool00`00Oomoo`07Ool00`00Oomoo`05Ool80004Ool00`00Oomoo`07Ool0
0`00Oomoo`05Ool00`00Ool000020002Ool01@00Oomoogoo00000Woo0`0027oo0`003Woo0P000Woo
1@00>goo001BOol20006Ool2000?Mol90002Eol20003Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
1000Oomoogoo10000Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0
0Woo0P0017oo00<007oo000040002Goo0`0000Aoo`000000041oo`00E7oo00<007ooOol01Woo0P00
1WOo1P001W?o1P0000=CG`00Ool00Woo00<007ooOol01Goo00<007ooOol01Goo10001goo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00goo0`0000Ioo`00Ool007ooMol6
0009Ool;0015Ool005Eoo`03001oogoo00Moo`H0011co`<00003Del007oo009oo`03001oogoo00Ao
o`04001oogooOol400000goo001oo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool01@00Oomoo`00Ool010003Woo1`00BWoo001FOol20003Ool40005Ool6000=
Lol00`00Del00003Ool00`00Oomoo`04Ool40006Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoogoo0P003goo1000D7oo001HOol3
000?Ool50009Lol00`00Del00003Ool00`00Oomoo`0300000goo001oo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02000:
Ool4001FOol005Uoo`8001Aoo`H000Aco`03001CG`0000=oo`8000Eoo`03001oogoo00Ioo`03001o
ogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00=oo`04001o
ogoo0005Ool4001LOol005]oo`8001Qoo`H00006Del007oo001oo`001Goo00<007ooOol01Woo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00goo00<0
07oo00001000HWoo001MOol2000LOol00`00Del00002Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
1000Oomoo`00IWoo001OOol2000KOol20003Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomo
o`05Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`00IWoo001QOol:000?Ool200000goo00000002Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`02OolI00000goo001oo`1VOol006]ooa@000=oo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo009oo`P000Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
009oo`<006Moo`00OWoo0P000Woo00<007ooOol017oo00<007ooOol017oo1P000goo00<007ooOol0
1Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00<007oo0000Igoo001nOol20003
Ool00`00Oomoo`03Ool00`00Oomoo`0400000goo001oo`07Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Ool0001WOol007moo`80009oo`03001oogoo009o
o`@000Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00=oo`03001o
ogoo009oo`03001oo`0006Moo`00Ogoo0P000Woo1@000Woo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol017oo00H007ooOol007oo001XOol0081oo`<0
0003Ool007oo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eo
o`03001oogoo00Aoo`06001oogoo001oo`00J7oo0020Ool20003Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01P00Oomo
o`00Ool006Qoo`00PGoo00D007ooOomoo`0000Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00=oo`06001oogoo001oo`00J7oo0021Ool20002Ool0
0`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool0
1000Oomoogoo2000J7oo0021Ool20003Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`06Ool00`00Oomoo`02Ool70002Ool01P00Oomoo`00Ool006Qoo`00PGoo0P000goo
00<007ooOol00Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol00Woo20000gmn00<007oo
Ool00goo00H007ooOol007oo001XOol0089oo`05001oogooOol00005Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool80003O_/00`00OgioOP04Ogh00`00Oomoo`04Ool01P00Oomoo`00Ool006Qoo`00PWoo
0P000goo00<007ooOol00Woo00<007ooOol00Woo20000Wji00<007kkO_/01Gkk00<007mnOgh01Gmn
00<007ooOol00goo00<007ooOol00Woo0P00J7oo0022Ool20002Ool;0002OYT00`00O[Un^@05O[T0
0`00O_]nn`05O_/00`00OgioOP05Ogh00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Ool0001WOol0
089oo`@00003LY`007jK009nV`03001nVGjI00EnV@03001n^Gji00An^@03001nngkk00Enn`03001o
OWmn00EoOP03001oogoo00Aoo`03001oogoo009oo`03001oo`0006Moo`00PWoo0P000W:L00<007jK
OY/00WjK00<007jIOYT017jI00<007jiO[T01Gji00@007kkO_]nnaT00003Ool007oo06Ioo`00PGoo
0P000g:L00D007jKOY]nV`0000MnV@04001n^GjiO[T80004O]T00`00OeaoG005Oe`00`00Ommog`04
Oml00`00Oomoo`02Ool3001WOol0085oo`80009bW003001nVgjK009nV`04001nVGjIOYT80002OYL0
0`00O]Unf@06O]T00`00OeaoG006Oe`00`00Ommog`05Oml00`00Oomoo`02Ool00`00Oo`0001VOol0
085oo`80009bW003001nVgjK00H0009jU@03001nUgjG00EnU`03001nfGkI00Inf@03001oG7mL00Io
G003001oggoO00Eog`03001oogoo009oo`03001oo00006Ioo`00PGoo0P0000=bW000OY/00`001WZE
00<007jGOYL01GjG00<007kIO]T01WkI00<007mLOe`01gmL00<007oOOml01WoO00<007ooOol00Woo
00<007ol0000IGoo0020Ool2000017:L000000000V:D00<007ZENYD017ZE00<007jGOYL01GjG00<0
07kIO]T00WkI6@000goo00<007ol0000IGoo0020Ool40003HY@00`00NYEjU@04NYD01000OYMnUgjG
2P0017jE00<007khO_P01gkh00<007miOgT01gmi100000Aoo`00Oo`006Aoo`00P7oo00<005:D0000
0f:D00<007ZENYD00gZE1P000gZD00<007jEOYD027jE00<007khO_P027kh00<007miOgT01Wmi00@0
07nhOkQo^0@006Aoo`00P7oo0P0016:D00<007ZE00000P0000=VU000NY@01WZD00<007jEOYD027jE
00<007khO_P02Gkh00<007miOgT01gmi00<007nhOkP00Wnh0`00Hgoo001oOol00`00DY@00002HY@4
0003IY@00`00NYAjU005NY@00`00OYEnU@09OYD00`00O_Qnn00:O_P00`00OgUoN@07OgT00`00OkQo
^002OkP00`00Og@0001ROol007ioo`03001BU00000@000AVU08000EjU28000AoN@03001o^7nh00=o
^003001oM000065oo`00OGoo00D005:D000005:D008000AVU003001jU00000D00003JY@007jD00an
U003001nU7jD00]nU003001n]7jd009n]0L000Ao^003001oM000061oo`00OGoo0P000U:D00<006JD
IY@00VJD10001VZD00<007jDOY@02gjD00<007jDOY@037jD00<007jdO[@027jd1@0000=o^0000000
H7oo001lOol20002DY@00`00IYAVU0040008JY@00`00OYAnU005OY@@0004OY@l000iOol007]oo`80
0003DY@000000080009BU003001ZU6ZD00EZU1l0025co`<001Q_o`d002aoo`00NWoo0P0000=BU000
00000e:D4`001f_o00<005ooGol01Eoo0WZD00=Oo`000000500037?o0`00:6oo00<007ooOol0:Goo
001eOol=000KJol80006Gol5NY@=Gol=000[Kol2000YOol0071oo`T000e[oa00009oo`03001oogoo
009ooa`000=Oo`T000EOo`H002M_o`03001oogoo02Ioo`00J7oo20002GOo900017oo00<007ooOol0
27oo00<007ooOol040004Eoo1P008Voo00<007ooOol09Goo001POol8000?Mol700000goo001oo`05
Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool8000@Gol6000MKol2000UOol005Qoo`P0019go`H00003Ool007oo00=oo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00Moo`03001oogoo00Eoo`05001oogoo001oo`08000@Gol6000FKol4000TOol0051oo`T0
01=go`L0009oo`04001oogoo0005Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Ool00004Ool0
1000GomOoeoo2@003eoo1P0026oo200017?o00<007ooOol08Goo001:Ool;000BMol:0002Ool30002
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`04Ool20006Ool20003Gol50002DolM000=
Lol00`00Oomoo`0POol004Moo`<0009ooa/000=oo`D000=oo`04001oogooOol20005Ool00`00Oomo
o`04Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`040002Ool00`00Oomoo`05Ool00`00GomOo`02Gol2000015?o0000000015?o
0`004VOo0`003W?o00<007ooOol07goo0013Ool40002Ool3000DOol30004Ool300000goo00000004
Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`06Ool30007Ool20006Ool20002Gol01000Jol00000
0e?o0`000e?o0`004VOo0`0037?o00<007ooOol07Woo000nOol50003Ool3000COol40003Ool40002
Ool2000017oo001oogoo0P0017oo00<007ooOol00P000Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol00goo0`000Woo00<007oo
Ool01goo00<007ooOol01Goo00<005oo00000f_o0`0000=Co`0000001@0000=Co`0000000P004FOo
0`002G?o00<007ooOol07Woo000iOol50005Ool3000COol30002Ool70002Ool20002Ool01000Oomo
o`001Goo00<007ooOol00goo0`001goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol027oo
00<007ooOol02Goo00<007oo00000P001Woo00<007ooOol01goo00<007ooOol01Goo0`001F_o0P00
00=Co`00Hol00f?o20004FOo10001W?o00<007ooOol07Goo000dOol50008Ool2000COol80004Ool0
0`00Oomoo`020004Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`040002Ool00`00Oomo
o`07Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`03Ool70009Ool00`00Oomoo`08Ool0
0`00Oomoo`06Ool00`00Jom[o`05Jol40007Hol6000BIol30004Lol00`00Oomoo`0LOol002ioo`H0
00Yoo`<0015oo`H000Qoo`D000Eoo`<000Eoo`03001oogoo00Aoo`03001oogoo00Eoo`L000Eoo`03
001oogoo00Uoo`03001oogoo00Aoo`/000Ioo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Aoo`04001oo`000008Jol3000:Hol7000?Iol30002Lol00`00Oomoo`0KOol002Uoo`D000eoo`<0
00ioo`L000aoo`<000Qoo`03001oogoo00=oo`8000Moo`03001oogoo00Moo`03001oogoo009ooaP0
00Eoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`8000=oo`03001oogoo009oo`80
00Q[o`<000]So`04001cog?oLol90009Iol4000LOol002Aoo`D000moo`<000Moo`X0009oo`8000eo
o`<000Qoo`<000Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oo`0000Mo
o`8000M[o`03001go`00008000USo`8000Yco`T000=Wo`8001]oo`007goo1@004Goo0`0000=oo`00
00001`002goo00<007ooOol02goo0`0027oo0P000goo00@007ooOol000Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03
001oogoo00Qoo`8000Yoo`8000E[o`03001gogOo009go`<000QSo`03001cog?o011co`D001]oo`00
6goo7@0057oo00<007ooOol027oo100000=oo`00Ool01Woo0P001Goo00<007oo000027oo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007oo
Ool02Woo00<007ooOol01Goo0P000Woo0P002Woo0P000f_o00<007OoMol01GOo0`001V?o00<007?o
Lol057?o00<007ooOol067oo000GOol4000GOol00`00Oomoo`0EOol20007Ool40004Ool00`00Oomo
o`04Ool20008Ool20007Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomo
o`0;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`03Ool20006Ool00`00Oomoo`09Ool2
0002Jol00`00Momgo`07Mol40003Hol00`00Lomco`0DLol00`00Oomoo`0GOol001Aoo`<001Uoo`80
01Moo`03001oogoo00=oo`@000Qoo`03001oogoo009oo`8000Qoo`80009oo`8000Eoo`03001oogoo
00Qoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo008000Uoo`03001oogoo00Yoo`<000ego`<00003Hol0000001Aco`03001oogoo
01Moo`0047oo10006goo00<007ooOol05Woo00<007ooOol0100037oo00<007ooOol00P002Goo00<0
07ooOol017oo0P000Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
2goo00<007ooOol02goo00<007ooOol02Goo0`0037oo0P0037oo00<007OoMol03WOo100057?o00<0
07ooOol05Woo000<Ool4000NOol00`00Oomoo`0EOol5000?Ool01000Ool000002Goo0P002Goo0`00
2Woo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol0
17oo10000Woo00<007ooOol037oo00<007ooOol027oo00<007ooOol00`003gOo10004W?o00<007oo
Ool05Goo0009Ool3000POol2000DOol5000BOol3000:Ool00`00Oomoo`09Ool00`00Oomoo`040006
Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`04
0007Ool00`00Oomoo`0<Ool20007Ool00`00Oomoo`04Ool3000=Mol00`00Oomoo`06000=Lol00`00
Oomoo`0DOol000Eoo`@0029oo`03001oogoo00ioo`H000=oo`03001oogoo00ioo`<0009oo`03001o
ogoo00Ioo`8000]oo`03001oogoo00Eoo`@00003Ool007oo00]oo`03001oogoo00aoo`03001oogoo
00]oo`03001oogoo00Uoo`D000aoo`8000ioo`03001oogoo00=oo`03001oogoo00Qoo`<000]go`03
001oogoo00Eoo`H000Mco`03001oogoo01Aoo`000goo0P009Goo00<007ooOol02Goo1P002Goo00<0
07ooOol037oo0P001Woo00<007ooOol00goo0P0037oo00<007ooOol02Woo20001Woo00<007ooOol0
37oo00<007ooOol037oo00@007ooOomoo`L000Aoo`03001oogoo00aoo`03001oogoo00aoo`03001o
ogoo009oo`03001oogoo00]oo`8000Ugo`03001oogoo00]oo`H0009co`03001oogoo01=oo`0000=o
o`0000009Goo0P001Woo1P003goo00<007ooOol02Goo0`0027oo00<007ooOol00Woo00<007ooOol0
2goo00<007ooOol02goo00<007ooOol01Goo3P001goo00<007ooOol01Goo2`002goo00<007ooOol0
3Goo00<007ooOol037oo0P0000=oo`00Ool03goo0`001WOo00<007ooOol04Goo100057oo0003Ool3
000QOol00`00Oomoo`06000DOol00`00Oomoo`07Ool3000<Ool01000Ool000003Goo00<007ooOol0
37oo00<007ooOol02goo00<007ooOol01Goo3`001goo00<007ooOol03Goo00<007ooOol03Goo00<0
07ooOol03Goo00<007ooOol04Woo0`000gOo00<007ooOol057oo00<007ooOol04Woo0006Ool3000M
Ool4000JOol00`00Oomoo`04Ool3000@Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<
Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0:
Ool200000goo0000000EOol300000gOo001oo`0EOol00`00Oomoo`0AOol000Uoo`<0011oo`L000=o
o`03001oogoo01]oo`03001oogoo009oo`80015oo`800003Ool0000000]oo`03001oogoo00aoo`03
001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00eoo`80
00Qoo`8000Eoo`8001Ioo`<001Ioo`03001oogoo011oo`0037oo10001Goo1`002Woo00<007ooOol0
6goo00<007oo00000P004Goo0P001Goo0P0027oo00<007ooOol037oo00<007ooOol03Goo00<007oo
Ool03Goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03goo00<007ooOol00goo0P002Goo
0P0057oo00<007ooOol010004Woo00<007ooOol047oo000@Ool5000AOol00`00Oomoo`0KOol2000B
Ool20009Ool20005Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0>
Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`02000=Ool2000AOol00`00Oomoo`05Ool4
000?Ool00`00Oomoo`0?Ool001=oo`<0011oo`03001oogoo01Moo`<0009oo`03001oogoo00ioo`80
00eoo`80009oo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00ioo`03
001oogoo00moo`03001oogoo00ioo`<0015oo`8000ioo`03001oogoo00Yoo`<000eoo`03001oogoo
00ioo`005Woo0`003Goo00<007ooOol04goo0`001goo00<007ooOol02goo0P004Goo10003Goo00<0
07ooOol03Woo00<007ooOol03Woo00<007ooOol03goo00<007ooOol03goo00<007ooOol02Goo1000
0Woo0P004Woo0P002goo00<007ooOol03Woo10002Goo00<007ooOol03Woo000IOol3000:Ool00`00
Oomoo`0?Ool3000<Ool00`00Oomoo`08Ool2000BOol20003Ool40008Ool00`00Oomoo`0?Ool00`00
Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool40008Ool00`00Oomoo`0A
Ool20008Ool00`00Oomoo`0COol30007Ool00`00Oomoo`0=Ool001aoo`<000Moo`03001oogoo00]o
o`@0011oo`03001oogoo00Eoo`8001=oo`03001oogoo00Moo`D000=oo`03001oogoo00moo`03001o
ogoo00moo`03001oogoo00moo`03001oogoo00moo`03001oogoo00@000eoo`8001=oo`8000Eoo`03
001oogoo01Moo`@000Aoo`03001oogoo00aoo`007goo0`0017oo00<007ooOol027oo0`005Goo00<0
07ooOol00Woo0P004goo0P003goo1@0047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol0
37oo1P004goo00<007ooOol04Woo0P000Woo00<007ooOol077oo1@003Woo000ROol300000goo001o
o`05Ool4000IOol01000Ool0000057oo00<007ooOol047oo00@007ooOomoo`H000Uoo`03001oogoo
011oo`03001oogoo011oo`03001oogoo009oo`T000Eoo`03001oogoo019oo`03001oogoo01=oo`80
02=oo`8000eoo`009Goo0`0000=oo`0000000P007Woo0P0057oo00<007ooOol047oo00<007ooOol0
27oo1P000goo00<007ooOol047oo00<007ooOol01goo3P003goo00<007ooOol04Woo0P004Goo0P00
0goo0P008Goo00<007ooOol02goo000WOol2000OOol20003Ool2000@Ool2000COol00`00Oomoo`0>
OolP0009Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0<Ool20007Ool3000NOol00`00
Oomoo`0;Ool002Uoo`8001Yoo`<000Moo`8000eoo`03001oogoo019oo`03001oogoo019oo`03001o
ogoo011oo`03001oogoo015oo`03001oogoo019oo`03001oogoo01=oo`8000Uoo`<000aoo`8001]o
o`8000eoo`00:goo0P005Goo0`0037oo0P002Goo0P0057oo00<007ooOol04Woo00<007ooOol04Goo
00<007ooOol04Goo00<007ooOol04goo00<007ooOol057oo00<007ooOol017oo0P004Goo0`005goo
00@007ooOol000aoo`00;Goo0P004Goo0P004Goo0P001Woo00<007ooOol04goo00<007ooOol04goo
00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol05Goo0P000Woo0P005Woo
0P0057oo00D007ooOomoo`0000aoo`00;goo0P0037oo0`005Goo0P000Woo0P005Woo00<007ooOol0
4Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04goo00<007ooOol05Goo0`006Woo0P00
4Goo00<007ooOol00goo00<007ooOol02Goo000aOol20007Ool3000JOol3000FOol00`00Oomoo`0C
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0@Ool40002Ool2000K
Ool3000<Ool20006Ool00`00Oomoo`09Ool003=oo`8000=oo`8001eoo`03001oogoo00@0015oo`03
001oogoo01Aoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo00]oo`@0
00Qoo`8001aoo`8000Uoo`03001oogoo00Moo`03001oogoo00Qoo`00=Goo0`007Goo00<007ooOol0
1Woo100037oo00<007ooOol057oo00<007ooOol04goo00<007ooOol057oo00<007ooOol057oo00<0
07ooOol01Woo10003Woo00<007ooOol06goo0`001Goo00<007ooOol027oo00<007ooOol027oo000g
Ool2000JOol2000=Ool40008Ool00`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0DOol00`00
Oomoo`0EOol01000Oomoogoo10004goo0P007Woo0P000Woo00<007ooOol02Woo00<007ooOol01goo
000iOol00`00Oomoo`0FOol00`00Oomoo`0AOol40003Ool00`00Oomoo`0EOol00`00Oomoo`0COol0
0`00Oomoo`0EOol00`00Oomoo`0BOol6000IOol00`00Oomoo`0MOol3000<Ool00`00Oomoo`07Ool0
03Yoo`03001oogoo01=oo`03001oogoo01Moo`H001Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03
001oogoo00Yoo`P000Aoo`03001oogoo01Uoo`8001]oo`8000=oo`@000Uoo`03001oogoo00Ioo`00
>goo0P004Goo0P006goo00<007ooOol00Woo200037oo00<007ooOol057oo00<007ooOol05Woo00@0
07ooOomoo`P000eoo`03001oogoo01Yoo`8001Ioo`<000Uoo`<000Ioo`03001oogoo00Ioo`00?Goo
00<007ooOol03Goo00<007ooOol06Woo00<007ooOol02goo20000goo00<007ooOol05Goo00<007oo
Ool047oo2P005Woo00<007ooOol06goo00<007ooOol04Goo0P003goo0`0017oo00<007ooOol01Goo
000nOol2000;Ool2000LOol00`00Oomoo`0DOol?000<Ool00`00Oomoo`04Ool<0007Ool00`00Oomo
o`0GOol00`00Oomoo`0KOol2000>Ool3000DOol50007Ool0041oo`03001oogoo00Ioo`8001eoo`03
001oogoo01Moo`03001oogoo00Yooa<001=oo`03001oogoo01Qoo`03001oogoo01aoo`03001oogoo
00Uoo`8001]oo`8000Ioo`00@Goo00<007ooOol017oo00<007ooOol077oo00<007ooOol067oo00<0
07ooOol05Woo00<007ooOol067oo00<007ooOol067oo00<007ooOol077oo0P001Woo0`007Woo00<0
07ooOol017oo0012Ool20002Ool2000NOol00`00Oomoo`0HOol00`00Oomoo`0GOol00`00Oomoo`0H
Ool00`00Oomoo`0IOol2000NOol20002Ool2000ROol00`00Oomoo`03Ool004Aoo`8001ioo`8001]o
o`03001oogoo01Moo`03001oogoo01Uoo`03001oogoo01Yoo`03001oogoo01]oo`@002Aoo`03001o
ogoo00=oo`00AWoo0`006Woo00<007ooOol06Woo00<007ooOol067oo00<007ooOol06Goo00<007oo
Ool06goo00<007ooOol05Woo100017oo0P008goo00<007ooOol00Woo0017Ool00`00Ool00004000D
Ool00`00Oomoo`0KOol00`00Oomoo`0HOol00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`0A
Ool4000:Ool2000QOol00`00Oomoo`02Ool004Qoo`8000Aoo`@000moo`03001oogoo01]oo`03001o
ogoo01Uoo`03001oogoo01Yoo`03001oogoo01aoo`03001oogoo00]oo`D0011oo`8001moo`03001o
ogoo009oo`00BWoo00<007ooOol01Goo10002Woo00<007ooOol077oo00<007ooOol06Goo00<007oo
Ool06goo00<007ooOol077oo00<007ooOol01Woo10005goo0`007Goo00<007ooOol00Goo001;Ool0
0`00Oomoo`09Ool30005Ool00`00Oomoo`0LOol00`00Oomoo`0KOol00`00Oomoo`0JOol00`00Oomo
o`0MOol01000Oomoogoo10007Woo0P006goo00<007ooOol00Goo001<Ool00`00Oomoo`0=Ool6000L
Ool00`00Oomoo`0KOol00`00Oomoo`0KOol00`00Oomoo`0HOol8000TOol2000JOol10001Ool1Ool0
04eoo`8000ioo`03001oogoo009oo`P001=oo`03001oogoo01aoo`03001oogoo01]oo`03001oogoo
00ioocX001Qoo`40005oo`5oo`00Cgoo00<007ooOol02Goo0P003Goo1`0037oo00<007ooOol077oo
00<007ooOol05Woo4@00A7oo300027oo0@000Goo001@Ool00`00Oomoo`07Ool00`00Oomoo`0DOol8
0003Ool00`00Oomoo`0MOol00`00Oomoo`0>Ool8001QOol80002Ool0055oo`03001oogoo00Eoo`03
001oogoo01eooa<0011oo`03001oogoo00Aoo`X007=oo`00DWoo0P000goo0P008Woo00<007ooOol0
3Woo6P00NWoo001DOol00`00Ool0000TOol00`00Oomoo`0LOol7001oOol005Eoo`03001oogoo029o
o`03001oogoo01Qoo`D008Ioo`00EWoo00<007ooOol087oo00<007ooOol057oo1@00Rgoo001GOol0
0`00Oomoo`0OOol00`00Oomoo`0@Ool3002AOol005Qoo`03001oogoo01eoo`03001oogoo00Uoo`H0
09Ioo`00FGoo00<007ooOol077oo00@007ooOomoo`P009aoo`00FWoo00<007ooOol06Goo1P00Y7oo
001KOol00`00Oomoo`0EOol3002ZOol005aoo`03001oogoo015oo`<00:eoo`00GGoo00<007ooOol0
37oo1000/7oo001NOol00`00Oomoo`05Ool6002dOol005moo`L00;Yoo`00\
\>"],
    ImageRangeCache->{{{0, 287}, {227.438, 0}} -> {0, 0, 0, 0}}],
  " ",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74551 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
-1.46584e-016 1.07329 -0.128889 1.07329 [
[ 0 0 0 0 ]
[ 1 .74551 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .74551 L
0 .74551 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.30786 .29891 m .25494 .29387 L .24308 .29177 L p .921 1 1 r
F P
0 g
s
.24308 .29177 m .26938 .28095 L .30786 .29891 L .921 1 1 r
F
.24308 .29177 m .22009 .28086 L .26938 .28095 L p F P
0 g
s
.37559 .30028 m .34996 .30301 L .30786 .29891 L p .921 1 1 r
F P
0 g
s
.26938 .28095 m .37559 .30028 L p .30786 .29891 L .921 1 1 r
F P
0 g
s
.40564 .30539 m .34996 .30301 L .37559 .30028 L p .877 1 1 r
F P
0 g
s
.37559 .30028 m .48548 .30894 L .40564 .30539 L p .877 1 1 r
F P
0 g
s
.49159 .30942 m .48548 .30894 L p .41738 .30349 L .65 1 1 r
F P
0 g
s
.33834 .28868 m .41738 .30349 L .37559 .30028 L p .691 1 1 r
F P
0 g
s
.41738 .30349 m .33834 .28868 L .38697 .30102 L p .931 .65 .65 r
F P
0 g
s
.44935 .30609 m .37559 .30028 L .41738 .30349 L p .65 1 1 r
F P
0 g
s
.38697 .30102 m .39227 .30237 L p .39072 .30133 L .931 .65 .65 r
F P
0 g
s
.34649 .28609 m .39227 .30237 L .33834 .28868 L p .65 1 1 r
F P
0 g
s
.39227 .30237 m .34649 .28609 L .39971 .30737 L p .985 .65 .65 r
F P
0 g
s
.39971 .30737 m .40164 .30814 L p .39227 .30237 L .985 .65 .65 r
F P
0 g
s
.41738 .30349 m .39072 .30133 L .39227 .30237 L .931 .65 .65 r
F
.48548 .30894 m .44935 .30609 L p .41738 .30349 L .65 1 1 r
F P
0 g
s
.50589 .31073 m .49424 .30964 L .49159 .30942 L p .65 1 1 r
F P
0 g
s
.41738 .30349 m .50589 .31073 L p .49159 .30942 L .65 1 1 r
F P
0 g
s
.59294 .3089 m .49424 .30964 L .50589 .31073 L p .692 .65 .65 r
F P
0 g
s
.59676 .30996 m .61074 .30879 L .59294 .3089 L p .692 .65 .65 r
F P
0 g
s
.50589 .31073 m .59676 .30996 L p .59294 .3089 L .692 .65 .65 r
F P
0 g
s
.7238 .29749 m .61074 .30879 L .59676 .30996 L p .737 1 1 r
F P
0 g
s
.37559 .30028 m .26938 .28095 L .33834 .28868 L p .691 1 1 r
F P
0 g
s
.26938 .28095 m .22009 .28086 L .18367 .25633 L p .997 1 1 r
F P
0 g
s
.6828 .30122 m .72839 .29703 L .7238 .29749 L p .737 1 1 r
F P
0 g
s
.7238 .29749 m .66658 .30311 L .6828 .30122 L .737 1 1 r
F
.72839 .29703 m .6828 .30122 L p .83109 .27543 L .957 1 1 r
F P
0 g
s
.6828 .30122 m .64609 .3125 L p .6995 .29928 L .65 .65 .65 r
F P
0 g
s
.75697 .28505 m .83109 .27543 L p .75993 .28781 L .957 1 1 r
F P
0 g
s
.6828 .30122 m .75697 .28505 L p .75993 .28781 L .957 1 1 r
F P
0 g
s
.75697 .28505 m .6828 .30122 L p .6995 .29928 L .65 .65 .65 r
F P
0 g
s
.69986 .30036 m .75697 .28505 L p .70374 .29823 L .65 .65 .65 r
F P
0 g
s
.64609 .3125 m .69986 .30036 L p .70374 .29823 L .65 .65 .65 r
F P
0 g
s
.69986 .30036 m .65583 .32012 L p .6959 .30254 L .999 1 1 r
F P
0 g
s
.75697 .28505 m .69986 .30036 L p .75392 .28221 L 1 1 1 r
F P
0 g
s
.69986 .30036 m .73931 .28349 L .81257 .26252 L p 1 1 1 r
F P
0 g
s
.73931 .28349 m .69986 .30036 L p .6959 .30254 L .999 1 1 r
F P
0 g
s
.81257 .26252 m .75697 .28505 L p .75392 .28221 L 1 1 1 r
F P
0 g
s
.59676 .30996 m .6828 .30122 L p .66658 .30311 L .737 1 1 r
F P
0 g
s
.83109 .27543 m .73734 .29537 L .72839 .29703 L p .957 1 1 r
F P
0 g
s
.73734 .29537 m .83109 .27543 L .87748 .27427 L closepath p 1 1 1 r
F P
0 g
s
.30203 .73488 m .24749 .74517 L .23531 .74381 L p 1 1 1 r
F P
0 g
s
.23531 .74381 m .263 .68844 L .30203 .73488 L 1 1 1 r
F
.23531 .74381 m .21203 .71537 L .263 .68844 L p F P
0 g
s
.37181 .70175 m .34533 .72662 L .30203 .73488 L p 1 1 1 r
F P
0 g
s
.263 .68844 m .37181 .70175 L p .30203 .73488 L 1 1 1 r
F P
0 g
s
.87748 .27427 m .83109 .27543 L p .98669 .25068 L 1 1 1 r
F P
0 g
s
.98669 .25068 m .97775 .25402 L .87748 .27427 L p 1 1 1 r
F P
0 g
s
.40247 .7189 m .34533 .72662 L .37181 .70175 L p 1 1 1 r
F P
0 g
s
.37181 .70175 m .48429 .70771 L .40247 .7189 L p 1 1 1 r
F P
0 g
s
.98188 .24395 m .98669 .25068 L p .83109 .27543 L 1 1 1 r
F P
0 g
s
.27572 .26726 m .33834 .28868 L .26938 .28095 L p .844 1 1 r
F P
0 g
s
.26938 .28095 m .18403 .25265 L .27572 .26726 L p .844 1 1 r
F P
0 g
s
.18403 .25265 m .26938 .28095 L p .18367 .25633 L .997 1 1 r
F P
0 g
s
.49054 .70663 m .48429 .70771 L p .41493 .65438 L 1 1 1 r
F P
0 g
s
.48429 .70771 m .37181 .70175 L .41493 .65438 L p 1 1 1 r
F P
0 g
s
.50527 .65964 m .49326 .70616 L .49054 .70663 L p 1 1 1 r
F P
0 g
s
.41493 .65438 m .50527 .65964 L p .49054 .70663 L 1 1 1 r
F P
0 g
s
.4505 .31377 m .51592 .31945 L .50589 .31073 L p 1 .65 .65 r
F P
0 g
s
.50589 .31073 m .41738 .30349 L .4505 .31377 L p 1 .65 .65 r
F P
0 g
s
.59676 .30996 m .50589 .31073 L .51592 .31945 L p 1 .65 .65 r
F P
0 g
s
.59422 .69771 m .49326 .70616 L .50527 .65964 L p 1 1 1 r
F P
0 g
s
.51592 .31945 m .58297 .31901 L .59676 .30996 L p 1 .65 .65 r
F P
0 g
s
.6828 .30122 m .59676 .30996 L .58297 .31901 L p .876 .65 .65 r
F P
0 g
s
.83109 .27543 m .90837 .24537 L p .98188 .24395 L 1 1 1 r
F P
0 g
s
.90837 .24537 m .83109 .27543 L .75697 .28505 L p 1 1 1 r
F P
0 g
s
.59798 .65908 m .61242 .69616 L .59422 .69771 L p 1 1 1 r
F P
0 g
s
.50527 .65964 m .59798 .65908 L p .59422 .69771 L 1 1 1 r
F P
0 g
s
.72818 .69741 m .61242 .69616 L .59798 .65908 L p 1 1 1 r
F P
0 g
s
.39227 .30237 m .4505 .31377 L .41738 .30349 L p .931 .65 .65 r
F P
0 g
s
.33422 .6436 m .41493 .65438 L .37181 .70175 L p 1 1 1 r
F P
0 g
s
.37181 .70175 m .263 .68844 L .33422 .6436 L p 1 1 1 r
F P
0 g
s
.58297 .31901 m .64609 .3125 L .6828 .30122 L p .876 .65 .65 r
F P
0 g
s
.6858 .65273 m .73289 .69746 L .72818 .69741 L p 1 1 1 r
F P
0 g
s
.59798 .65908 m .6858 .65273 L p .72818 .69741 L 1 1 1 r
F P
0 g
s
.90837 .24537 m .97809 .23857 L .98188 .24395 L p 1 1 1 r
F P
0 g
s
.83816 .68464 m .74207 .69837 L .73289 .69746 L p 1 1 1 r
F P
0 g
s
.73289 .69746 m .6858 .65273 L p .83816 .68464 L 1 1 1 r
F P
0 g
s
.74207 .69837 m .83816 .68464 L .88613 .70736 L closepath p 1 1 1 r
F P
0 g
s
.263 .68844 m .21203 .71537 L .17494 .67779 L p 1 1 1 r
F P
0 g
s
.18367 .25633 m .17743 .25215 L .18403 .25265 L p .997 1 1 r
F P
0 g
s
.33834 .28868 m .27572 .26726 L .34649 .28609 L p .65 1 1 r
F P
0 g
s
.88613 .70736 m .83816 .68464 L p .999 .71706 L 1 1 1 r
F P
0 g
s
.999 .71706 m .98979 .71924 L .88613 .70736 L p 1 1 1 r
F P
0 g
s
.4771 .32959 m .52446 .33416 L .51592 .31945 L p 1 .763 .719 r
F P
0 g
s
.51592 .31945 m .4505 .31377 L .4771 .32959 L p 1 .763 .719 r
F P
0 g
s
.58297 .31901 m .51592 .31945 L .52446 .33416 L p 1 .768 .8 r
F P
0 g
s
.52446 .33416 m .57279 .33403 L .58297 .31901 L p 1 .768 .8 r
F P
0 g
s
.64609 .3125 m .58297 .31901 L .57279 .33403 L p 1 .65 .73 r
F P
0 g
s
.9711 .22518 m .97809 .23857 L .90837 .24537 L p 1 1 1 r
F P
0 g
s
.44901 .61043 m .51556 .6148 L .50527 .65964 L p 1 1 1 r
F P
0 g
s
.50527 .65964 m .41493 .65438 L .44901 .61043 L p 1 1 1 r
F P
0 g
s
.59798 .65908 m .50527 .65964 L .51556 .6148 L p 1 1 1 r
F P
0 g
s
.51556 .6148 m .58378 .61447 L .59798 .65908 L p 1 1 1 r
F P
0 g
s
.6858 .65273 m .59798 .65908 L .58378 .61447 L p 1 1 1 r
F P
0 g
s
.75697 .28505 m .81257 .26252 L .90837 .24537 L p 1 1 1 r
F P
0 g
s
.16313 .23937 m .18403 .25265 L .17743 .25215 L closepath p 1 1 1 r
F P
0 g
s
.23587 .24078 m .27572 .26726 L .18403 .25265 L p .991 1 1 r
F P
0 g
s
.18403 .25265 m .16313 .23937 L .14029 .21984 L p .991 1 1 r
F P
0 g
s
.14029 .21984 m .23587 .24078 L p .18403 .25265 L .991 1 1 r
F P
0 g
s
.43486 .32068 m .4771 .32959 L .4505 .31377 L p 1 .65 .65 r
F P
0 g
s
.4505 .31377 m .39227 .30237 L .43486 .32068 L p 1 .65 .65 r
F P
0 g
s
.2702 .628 m .33422 .6436 L .263 .68844 L p 1 1 1 r
F P
0 g
s
.263 .68844 m .17542 .66895 L .2702 .628 L p 1 1 1 r
F P
0 g
s
.17542 .66895 m .263 .68844 L p .17494 .67779 L 1 1 1 r
F P
0 g
s
.69986 .30036 m .64609 .3125 L .61791 .32923 L p .81 .65 .65 r
F P
0 g
s
.57279 .33403 m .61791 .32923 L .64609 .3125 L p 1 .65 .73 r
F P
0 g
s
.99381 .70026 m .999 .71706 L p .83816 .68464 L 1 1 1 r
F P
0 g
s
.38974 .60168 m .44901 .61043 L .41493 .65438 L p 1 1 1 r
F P
0 g
s
.41493 .65438 m .33422 .6436 L .38974 .60168 L p 1 1 1 r
F P
0 g
s
.83816 .68464 m .9175 .66393 L p .99381 .70026 L 1 1 1 r
F P
0 g
s
.9175 .66393 m .83816 .68464 L .76156 .64096 L p 1 1 1 r
F P
0 g
s
.6858 .65273 m .76156 .64096 L .83816 .68464 L p 1 1 1 r
F P
0 g
s
.90837 .24537 m .9538 .20866 L p .9711 .22518 L 1 1 1 r
F P
0 g
s
.9538 .20866 m .90837 .24537 L .81257 .26252 L p 1 1 1 r
F P
0 g
s
.76156 .64096 m .6858 .65273 L .64799 .60946 L p 1 1 1 r
F P
0 g
s
.58378 .61447 m .64799 .60946 L .6858 .65273 L p 1 1 1 r
F P
0 g
s
.49905 .34976 m .53214 .3536 L .52446 .33416 L p 1 .957 .955 r
F P
0 g
s
.52446 .33416 m .4771 .32959 L .49905 .34976 L p 1 .957 .955 r
F P
0 g
s
.57279 .33403 m .52446 .33416 L .53214 .3536 L p 1 .955 1 r
F P
0 g
s
.53214 .3536 m .56555 .35377 L .57279 .33403 L p 1 .955 1 r
F P
0 g
s
.61791 .32923 m .57279 .33403 L .56555 .35377 L p 1 .849 .978 r
F P
0 g
s
.40164 .30814 m .43486 .32068 L .39227 .30237 L p .985 .65 .65 r
F P
0 g
s
.65583 .32012 m .62161 .34338 L p .65108 .32611 L .65 .65 .65 r
F P
0 g
s
.65583 .32012 m .69986 .30036 L p .6605 .31423 L .81 .65 .65 r
F P
0 g
s
.68299 .30741 m .73931 .28349 L p .69909 .30114 L .999 1 1 r
F P
0 g
s
.65583 .32012 m .68299 .30741 L p .69909 .30114 L .999 1 1 r
F P
0 g
s
.68299 .30741 m .65583 .32012 L p .65108 .32611 L .65 .65 .65 r
F P
0 g
s
.6391 .33367 m .68299 .30741 L p .65343 .32474 L .65 .65 .65 r
F P
0 g
s
.62161 .34338 m .6391 .33367 L p .65343 .32474 L .65 .65 .65 r
F P
0 g
s
.6391 .33367 m .62161 .34338 L .59453 .36946 L p 1 1 1 r
F P
0 g
s
.6391 .33367 m .60401 .36182 L p .62459 .34272 L 1 1 1 r
F P
0 g
s
.61791 .32923 m .65583 .32012 L p .6605 .31423 L .81 .65 .65 r
F P
0 g
s
.65583 .32012 m .61791 .32923 L .59629 .35027 L p .94 .65 .711 r
F P
0 g
s
.59629 .35027 m .62161 .34338 L .65583 .32012 L p .94 .65 .711 r
F P
0 g
s
.64693 .32197 m .6391 .33367 L p .62459 .34272 L 1 1 1 r
F P
0 g
s
.68299 .30741 m .6391 .33367 L p .66662 .31379 L 1 1 1 r
F P
0 g
s
.69655 .29218 m .68299 .30741 L p .66662 .31379 L 1 1 1 r
F P
0 g
s
.9538 .20866 m .96183 .20728 L .9711 .22518 L p 1 1 1 r
F P
0 g
s
.31778 .26621 m .34649 .28609 L .27572 .26726 L p .865 1 1 r
F P
0 g
s
.27572 .26726 m .23587 .24078 L .31778 .26621 L p .865 1 1 r
F P
0 g
s
.47627 .56946 m .52429 .57316 L .51556 .6148 L p 1 1 1 r
F P
0 g
s
.51556 .6148 m .44901 .61043 L .47627 .56946 L p 1 1 1 r
F P
0 g
s
.58378 .61447 m .51556 .6148 L .52429 .57316 L p 1 1 1 r
F P
0 g
s
.52429 .57316 m .5733 .57306 L .58378 .61447 L p 1 1 1 r
F P
0 g
s
.64799 .60946 m .58378 .61447 L .5733 .57306 L p 1 1 1 r
F P
0 g
s
.46925 .34258 m .49905 .34976 L .4771 .32959 L p 1 .875 .759 r
F P
0 g
s
.4771 .32959 m .43486 .32068 L .46925 .34258 L p 1 .875 .759 r
F P
0 g
s
.56555 .35377 m .59629 .35027 L .61791 .32923 L p 1 .849 .978 r
F P
0 g
s
.9175 .66393 m .98972 .68712 L .99381 .70026 L p 1 1 1 r
F P
0 g
s
.34311 .58916 m .38974 .60168 L .33422 .6436 L p 1 1 1 r
F P
0 g
s
.33422 .6436 m .2702 .628 L .34311 .58916 L p 1 1 1 r
F P
0 g
s
.81257 .26252 m .84363 .2353 L .9538 .20866 L p 1 1 1 r
F P
0 g
s
.84363 .2353 m .81257 .26252 L .73931 .28349 L p 1 1 1 r
F P
0 g
s
.43342 .56224 m .47627 .56946 L .44901 .61043 L p 1 1 1 r
F P
0 g
s
.44901 .61043 m .38974 .60168 L .43342 .56224 L p 1 1 1 r
F P
0 g
s
.17494 .67779 m .1686 .67135 L .17542 .66895 L p 1 1 1 r
F P
0 g
s
.64799 .60946 m .70273 .60013 L .76156 .64096 L p 1 1 1 r
F P
0 g
s
.70273 .60013 m .64799 .60946 L .61905 .56917 L p 1 1 1 r
F P
0 g
s
.5733 .57306 m .61905 .56917 L .64799 .60946 L p 1 1 1 r
F P
0 g
s
.76156 .64096 m .81843 .62455 L .9175 .66393 L p 1 1 1 r
F P
0 g
s
.81843 .62455 m .76156 .64096 L .70273 .60013 L p 1 1 1 r
F P
0 g
s
.53957 .3768 m .56073 .37728 L .56555 .35377 L p 1 1 1 r
F P
0 g
s
.56555 .35377 m .53214 .3536 L .53957 .3768 L p 1 1 1 r
F P
0 g
s
.59629 .35027 m .56555 .35377 L .56073 .37728 L p 1 .957 1 r
F P
0 g
s
.51805 .37336 m .53957 .3768 L .53214 .3536 L p 1 1 1 r
F P
0 g
s
.53214 .3536 m .49905 .34976 L .51805 .37336 L p 1 1 1 r
F P
0 g
s
.44551 .33264 m .46925 .34258 L .43486 .32068 L p 1 .65 .65 r
F P
0 g
s
.43486 .32068 m .40164 .30814 L .44551 .33264 L p 1 .65 .65 r
F P
0 g
s
.15391 .65979 m .17542 .66895 L .1686 .67135 L closepath p 1 1 1 r
F P
0 g
s
.62161 .34338 m .59629 .35027 L .57962 .37476 L p .928 .65 .829 r
F P
0 g
s
.56073 .37728 m .57962 .37476 L .59629 .35027 L p 1 .957 1 r
F P
0 g
s
.98238 .667 m .98972 .68712 L .9175 .66393 L p 1 1 1 r
F P
0 g
s
.38077 .293 m .40164 .30814 L .34649 .28609 L p .689 1 1 r
F P
0 g
s
.34649 .28609 m .31778 .26621 L .38077 .293 L p .689 1 1 r
F P
0 g
s
.49815 .36725 m .51805 .37336 L .49905 .34976 L p 1 1 .908 r
F P
0 g
s
.49905 .34976 m .46925 .34258 L .49815 .36725 L p 1 1 .908 r
F P
0 g
s
.49866 .53103 m .5321 .53431 L .52429 .57316 L p 1 1 1 r
F P
0 g
s
.52429 .57316 m .47627 .56946 L .49866 .53103 L p 1 1 1 r
F P
0 g
s
.5733 .57306 m .52429 .57316 L .5321 .53431 L p 1 1 1 r
F P
0 g
s
.22937 .6087 m .2702 .628 L .17542 .66895 L p 1 1 1 r
F P
0 g
s
.17542 .66895 m .15391 .65979 L .13048 .64046 L p 1 1 1 r
F P
0 g
s
.13048 .64046 m .22937 .6087 L p .17542 .66895 L 1 1 1 r
F P
0 g
s
.5321 .53431 m .56585 .53446 L .5733 .57306 L p 1 1 1 r
F P
0 g
s
.61905 .56917 m .5733 .57306 L .56585 .53446 L p 1 1 1 r
F P
0 g
s
.73931 .28349 m .76027 .26323 L .84363 .2353 L p 1 1 1 r
F P
0 g
s
.76027 .26323 m .73931 .28349 L .68299 .30741 L p 1 1 1 r
F P
0 g
s
.54734 .40303 m .55798 .40385 L .56073 .37728 L p 1 1 1 r
F P
0 g
s
.56073 .37728 m .53957 .3768 L .54734 .40303 L p 1 1 1 r
F P
0 g
s
.57962 .37476 m .56073 .37728 L .55798 .40385 L p 1 .974 1 r
F P
0 g
s
.39971 .55206 m .43342 .56224 L .38974 .60168 L p 1 1 1 r
F P
0 g
s
.38974 .60168 m .34311 .58916 L .39971 .55206 L p 1 1 1 r
F P
0 g
s
.46853 .52489 m .49866 .53103 L .47627 .56946 L p 1 1 1 r
F P
0 g
s
.47627 .56946 m .43342 .56224 L .46853 .52489 L p 1 1 1 r
F P
0 g
s
.53563 .39969 m .54734 .40303 L .53957 .3768 L p 1 1 1 r
F P
0 g
s
.53957 .3768 m .51805 .37336 L .53563 .39969 L p 1 1 1 r
F P
0 g
s
.23587 .24078 m .14029 .21984 L .1375 .21663 L p 1 1 1 r
F P
0 g
s
.61905 .56917 m .65752 .56178 L .70273 .60013 L p 1 1 1 r
F P
0 g
s
.65752 .56178 m .61905 .56917 L .59693 .53147 L p 1 1 1 r
F P
0 g
s
.56585 .53446 m .59693 .53147 L .61905 .56917 L p 1 1 1 r
F P
0 g
s
.57962 .37476 m .59453 .36946 L .62161 .34338 L p .928 .65 .829 r
F P
0 g
s
.70273 .60013 m .74292 .58716 L .81843 .62455 L p 1 1 1 r
F P
0 g
s
.74292 .58716 m .70273 .60013 L .65752 .56178 L p 1 1 1 r
F P
0 g
s
.59453 .36946 m .57962 .37476 L .56659 .40208 L p .65 .65 .65 r
F P
0 g
s
.55798 .40385 m .56659 .40208 L .57962 .37476 L p 1 .974 1 r
F P
0 g
s
.48172 .359 m .49815 .36725 L .46925 .34258 L p 1 .815 .65 r
F P
0 g
s
.46925 .34258 m .44551 .33264 L .48172 .359 L p 1 .815 .65 r
F P
0 g
s
.9175 .66393 m .96436 .63859 L p .98238 .667 L 1 1 1 r
F P
0 g
s
.96436 .63859 m .9175 .66393 L .81843 .62455 L p 1 1 1 r
F P
0 g
s
.22397 .21141 m .23587 .24078 L p .1375 .21663 L 1 1 1 r
F P
0 g
s
.1375 .21663 m .11678 .19274 L p .22397 .21141 L 1 1 1 r
F P
0 g
s
.53959 .49793 m .5609 .49836 L .56585 .53446 L p 1 1 1 r
F P
0 g
s
.56585 .53446 m .5321 .53431 L .53959 .49793 L p 1 1 1 r
F P
0 g
s
.59693 .53147 m .56585 .53446 L .5609 .49836 L p 1 1 1 r
F P
0 g
s
.51792 .49483 m .53959 .49793 L .5321 .53431 L p 1 1 1 r
F P
0 g
s
.5321 .53431 m .49866 .53103 L .51792 .49483 L p 1 1 1 r
F P
0 g
s
.52393 .39411 m .53563 .39969 L .51805 .37336 L p 1 1 .948 r
F P
0 g
s
.51805 .37336 m .49815 .36725 L .52393 .39411 L p 1 1 .948 r
F P
0 g
s
.43022 .32081 m .44551 .33264 L .40164 .30814 L p .65 .995 1 r
F P
0 g
s
.40164 .30814 m .38077 .293 L .43022 .32081 L p .65 .995 1 r
F P
0 g
s
.68299 .30741 m .69655 .29218 L .76027 .26323 L p 1 1 1 r
F P
0 g
s
.56659 .40208 m .55798 .40385 L .55712 .43304 L p 1 1 1 r
F P
0 g
s
.55613 .43183 m .55712 .43304 L .55798 .40385 L p 1 1 1 r
F P
0 g
s
.55798 .40385 m .54734 .40303 L .55613 .43183 L p 1 1 1 r
F P
0 g
s
.55328 .4283 m .55613 .43183 L .54734 .40303 L p 1 1 1 r
F P
0 g
s
.54734 .40303 m .53563 .39969 L .55328 .4283 L p 1 1 1 r
F P
0 g
s
.96094 .20509 m .96183 .20728 L .9538 .20866 L p 1 1 1 r
F P
0 g
s
.59693 .53147 m .62252 .52558 L .65752 .56178 L p 1 1 1 r
F P
0 g
s
.62252 .52558 m .59693 .53147 L .57993 .4961 L p 1 1 1 r
F P
0 g
s
.5609 .49836 m .57993 .4961 L .59693 .53147 L p 1 1 1 r
F P
0 g
s
.9538 .20866 m .95626 .19352 L .96094 .20509 L p 1 1 1 r
F P
0 g
s
.95626 .19352 m .9538 .20866 L .84363 .2353 L p 1 1 1 r
F P
0 g
s
.30969 .24444 m .31778 .26621 L .23587 .24078 L p 1 1 1 r
F P
0 g
s
.23587 .24078 m .22397 .21141 L .30969 .24444 L p 1 1 1 r
F P
0 g
s
.55712 .43304 m .55613 .43183 L .56659 .40208 L p 1 1 1 r
F P
0 g
s
.57237 .39786 m .56659 .40208 L .55613 .43183 L p 1 1 1 r
F P
0 g
s
.57237 .39786 m .55328 .4283 L p .56358 .41067 L 1 1 1 r
F P
0 g
s
.56659 .40208 m .57237 .39786 L p .58109 .38515 L .65 .65 .65 r
F P
0 g
s
.57475 .39157 m .57237 .39786 L p .56358 .41067 L 1 1 1 r
F P
0 g
s
.57237 .39786 m .59453 .36946 L p .58109 .38515 L .65 .65 .65 r
F P
0 g
s
.31383 .57387 m .34311 .58916 L .2702 .628 L p 1 1 1 r
F P
0 g
s
.2702 .628 m .22937 .6087 L .31383 .57387 L p 1 1 1 r
F P
0 g
s
.49787 .48933 m .51792 .49483 L .49866 .53103 L p 1 1 1 r
F P
0 g
s
.49866 .53103 m .46853 .52489 L .49787 .48933 L p 1 1 1 r
F P
0 g
s
.59453 .36946 m .60401 .36182 L p .61763 .35091 L 1 1 1 r
F P
0 g
s
.60401 .36182 m .59453 .36946 L .57237 .39786 L p 1 1 1 r
F P
0 g
s
.60401 .36182 m .57475 .39157 L p .59025 .37284 L 1 1 1 r
F P
0 g
s
.60707 .35252 m .60401 .36182 L p .59025 .37284 L 1 1 1 r
F P
0 g
s
.60401 .36182 m .6391 .33367 L p .61763 .35091 L 1 1 1 r
F P
0 g
s
.57993 .4961 m .5609 .49836 L .55806 .46458 L p 1 1 1 r
F P
0 g
s
.54738 .4638 m .55806 .46458 L .5609 .49836 L p 1 1 1 r
F P
0 g
s
.5609 .49836 m .53959 .49793 L .54738 .4638 L p 1 1 1 r
F P
0 g
s
.53563 .46063 m .54738 .4638 L .53959 .49793 L p 1 1 1 r
F P
0 g
s
.53959 .49793 m .51792 .49483 L .53563 .46063 L p 1 1 1 r
F P
0 g
s
.5667 .46289 m .55806 .46458 L .55712 .43304 L p 1 1 .791 r
F P
0 g
s
.55613 .43183 m .55712 .43304 L .55806 .46458 L p 1 1 1 r
F P
0 g
s
.55712 .43304 m .55613 .43183 L .5667 .46289 L p 1 1 .791 r
F P
0 g
s
.44454 .51639 m .46853 .52489 L .43342 .56224 L p 1 1 1 r
F P
0 g
s
.43342 .56224 m .39971 .55206 L .44454 .51639 L p 1 1 1 r
F P
0 g
s
.65752 .56178 m .68508 .55147 L .74292 .58716 L p 1 1 1 r
F P
0 g
s
.68508 .55147 m .65752 .56178 L .62252 .52558 L p 1 1 1 r
F P
0 g
s
.55806 .46458 m .5667 .46289 L .57993 .4961 L p 1 1 1 r
F P
0 g
s
.55806 .46458 m .54738 .4638 L .55613 .43183 L p 1 1 1 r
F P
0 g
s
.54879 .42276 m .55328 .4283 L .53563 .39969 L p 1 1 .812 r
F P
0 g
s
.53563 .39969 m .52393 .39411 L .54879 .42276 L p 1 1 .812 r
F P
0 g
s
.51333 .38679 m .52393 .39411 L .49815 .36725 L p 1 .88 .65 r
F P
0 g
s
.49815 .36725 m .48172 .359 L .51333 .38679 L p 1 .88 .65 r
F P
0 g
s
.5725 .45889 m .5667 .46289 L .55613 .43183 L p 1 .932 .65 r
F P
0 g
s
.55328 .4283 m .55613 .43183 L .54738 .4638 L p 1 1 1 r
F P
0 g
s
.55613 .43183 m .55328 .4283 L .5725 .45889 L p 1 .932 .65 r
F P
0 g
s
.55613 .43183 m .55328 .4283 L .57237 .39786 L p 1 1 1 r
F P
0 g
s
.54738 .4638 m .53563 .46063 L .55328 .4283 L p 1 1 1 r
F P
0 g
s
.57993 .4961 m .59494 .49132 L .62252 .52558 L p 1 1 1 r
F P
0 g
s
.59494 .49132 m .57993 .4961 L .5667 .46289 L p 1 1 1 r
F P
0 g
s
.6391 .33367 m .64693 .32197 L .69655 .29218 L p 1 1 1 r
F P
0 g
s
.5667 .46289 m .5725 .45889 L .59494 .49132 L p 1 1 1 r
F P
0 g
s
.57237 .39786 m .57475 .39157 L .60401 .36182 L p 1 1 1 r
F P
0 g
s
.81843 .62455 m .8503 .60471 L .96436 .63859 L p 1 1 1 r
F P
0 g
s
.8503 .60471 m .81843 .62455 L .74292 .58716 L p 1 1 1 r
F P
0 g
s
.52389 .45533 m .53563 .46063 L .51792 .49483 L p 1 1 1 r
F P
0 g
s
.51792 .49483 m .49787 .48933 L .52389 .45533 L p 1 1 1 r
F P
0 g
s
.4704 .34934 m .48172 .359 L .44551 .33264 L p .65 .831 1 r
F P
0 g
s
.44551 .33264 m .43022 .32081 L .4704 .34934 L p .65 .831 1 r
F P
0 g
s
.94848 .17502 m .95626 .19352 L p .84363 .2353 L 1 1 1 r
F P
0 g
s
.84363 .2353 m .84564 .20568 L p .94848 .17502 L 1 1 1 r
F P
0 g
s
.84564 .20568 m .84363 .2353 L .76027 .26323 L p 1 1 1 r
F P
0 g
s
.96436 .63859 m .97267 .64049 L .98238 .667 L p 1 1 1 r
F P
0 g
s
.37473 .27664 m .38077 .293 L .31778 .26621 L p .964 1 1 r
F P
0 g
s
.31778 .26621 m .30969 .24444 L .37473 .27664 L p .964 1 1 r
F P
0 g
s
.57488 .45291 m .5725 .45889 L .55328 .4283 L p .65 .65 1 r
F P
0 g
s
.55328 .4283 m .54879 .42276 L .57475 .39157 L p 1 1 1 r
F P
0 g
s
.55328 .4283 m .54879 .42276 L .57488 .45291 L p .65 .65 1 r
F P
0 g
s
.54879 .42276 m .55328 .4283 L .53563 .46063 L p 1 1 1 r
F P
0 g
s
.62252 .52558 m .6402 .51727 L .68508 .55147 L p 1 1 1 r
F P
0 g
s
.6402 .51727 m .62252 .52558 L .59494 .49132 L p 1 1 1 r
F P
0 g
s
.53563 .46063 m .52389 .45533 L .54879 .42276 L p 1 1 1 r
F P
0 g
s
.48133 .48189 m .49787 .48933 L .46853 .52489 L p 1 1 1 r
F P
0 g
s
.46853 .52489 m .44454 .51639 L .48133 .48189 L p 1 1 1 r
F P
0 g
s
.60401 .36182 m .60707 .35252 L .64693 .32197 L p 1 1 1 r
F P
0 g
s
.37852 .53979 m .39971 .55206 L .34311 .58916 L p 1 1 1 r
F P
0 g
s
.34311 .58916 m .31383 .57387 L .37852 .53979 L p 1 1 1 r
F P
0 g
s
.54307 .41569 m .54879 .42276 L .52393 .39411 L p 1 .809 .65 r
F P
0 g
s
.52393 .39411 m .51333 .38679 L .54307 .41569 L p 1 .809 .65 r
F P
0 g
s
.60449 .48444 m .59494 .49132 L .5725 .45889 L p .874 1 1 r
F P
0 g
s
.5725 .45889 m .57488 .45291 L .60449 .48444 L p .874 1 1 r
F P
0 g
s
.59494 .49132 m .60449 .48444 L .6402 .51727 L p 1 1 1 r
F P
0 g
s
.76027 .26323 m .75983 .24136 L .84564 .20568 L p 1 1 1 r
F P
0 g
s
.75983 .24136 m .76027 .26323 L .69655 .29218 L p 1 1 1 r
F P
0 g
s
.74292 .58716 m .76431 .57158 L .8503 .60471 L p 1 1 1 r
F P
0 g
s
.76431 .57158 m .74292 .58716 L .68508 .55147 L p 1 1 1 r
F P
0 g
s
.51324 .44837 m .52389 .45533 L .49787 .48933 L p 1 1 1 r
F P
0 g
s
.49787 .48933 m .48133 .48189 L .51324 .44837 L p 1 1 1 r
F P
0 g
s
.50485 .37838 m .51333 .38679 L .48172 .359 L p .65 .726 1 r
F P
0 g
s
.48172 .359 m .4704 .34934 L .50485 .37838 L p .65 .726 1 r
F P
0 g
s
.57475 .39157 m .57345 .38376 L .60707 .35252 L p 1 1 1 r
F P
0 g
s
.57345 .38376 m .57475 .39157 L .54879 .42276 L p 1 1 1 r
F P
0 g
s
.42509 .30817 m .43022 .32081 L .38077 .293 L p .86 1 1 r
F P
0 g
s
.38077 .293 m .37473 .27664 L .42509 .30817 L p .86 1 1 r
F P
0 g
s
.54879 .42276 m .54307 .41569 L .57345 .38376 L p 1 1 1 r
F P
0 g
s
.57358 .4455 m .57488 .45291 L .54879 .42276 L p .65 .756 1 r
F P
0 g
s
.54879 .42276 m .54307 .41569 L .57358 .4455 L p .65 .756 1 r
F P
0 g
s
.54307 .41569 m .54879 .42276 L .52389 .45533 L p 1 1 1 r
F P
0 g
s
.52389 .45533 m .51324 .44837 L .54307 .41569 L p 1 1 1 r
F P
0 g
s
.69655 .29218 m .69469 .27578 L .75983 .24136 L p 1 1 1 r
F P
0 g
s
.69469 .27578 m .69655 .29218 L .64693 .32197 L p 1 1 1 r
F P
0 g
s
.42907 .50627 m .44454 .51639 L .39971 .55206 L p 1 1 1 r
F P
0 g
s
.39971 .55206 m .37852 .53979 L .42907 .50627 L p 1 1 1 r
F P
0 g
s
.11678 .19274 m .10953 .17724 L .22397 .21141 L p 1 1 1 r
F P
0 g
s
.10953 .17724 m .11678 .19274 L .10368 .17813 L p 1 1 1 r
F P
0 g
s
.68508 .55147 m .69886 .53911 L .76431 .57158 L p 1 1 1 r
F P
0 g
s
.69886 .53911 m .68508 .55147 L .6402 .51727 L p 1 1 1 r
F P
0 g
s
.60758 .47605 m .60449 .48444 L .57488 .45291 L p .7 1 1 r
F P
0 g
s
.57488 .45291 m .57358 .4455 L .60758 .47605 L p .7 1 1 r
F P
0 g
s
.64693 .32197 m .64408 .30936 L .69469 .27578 L p 1 1 1 r
F P
0 g
s
.64408 .30936 m .64693 .32197 L .60707 .35252 L p 1 1 1 r
F P
0 g
s
.53664 .40775 m .54307 .41569 L .51333 .38679 L p .65 .715 1 r
F P
0 g
s
.51333 .38679 m .50485 .37838 L .53664 .40775 L p .65 .715 1 r
F P
0 g
s
.6402 .51727 m .64813 .50727 L .69886 .53911 L p 1 1 1 r
F P
0 g
s
.64813 .50727 m .6402 .51727 L .60449 .48444 L p .926 1 1 r
F P
0 g
s
.46541 .33917 m .4704 .34934 L .43022 .32081 L p .728 1 1 r
F P
0 g
s
.43022 .32081 m .42509 .30817 L .46541 .33917 L p .728 1 1 r
F P
0 g
s
.60449 .48444 m .60758 .47605 L .64813 .50727 L p .926 1 1 r
F P
0 g
s
.46992 .47319 m .48133 .48189 L .44454 .51639 L p 1 1 1 r
F P
0 g
s
.44454 .51639 m .42907 .50627 L .46992 .47319 L p 1 1 1 r
F P
0 g
s
.60707 .35252 m .60328 .34241 L .64408 .30936 L p 1 1 1 r
F P
0 g
s
.60328 .34241 m .60707 .35252 L .57345 .38376 L p 1 1 1 r
F P
0 g
s
.57345 .38376 m .56852 .37514 L .60328 .34241 L p 1 1 1 r
F P
0 g
s
.56852 .37514 m .57345 .38376 L .54307 .41569 L p 1 1 1 r
F P
0 g
s
.50474 .44039 m .51324 .44837 L .48133 .48189 L p 1 1 1 r
F P
0 g
s
.48133 .48189 m .46992 .47319 L .50474 .44039 L p 1 1 1 r
F P
0 g
s
.54307 .41569 m .53664 .40775 L .56852 .37514 L p 1 1 1 r
F P
0 g
s
.56864 .43732 m .57358 .4455 L .54307 .41569 L p .65 .797 1 r
F P
0 g
s
.54307 .41569 m .53664 .40775 L .56864 .43732 L p .65 .797 1 r
F P
0 g
s
.53664 .40775 m .54307 .41569 L .51324 .44837 L p 1 1 1 r
F P
0 g
s
.51324 .44837 m .50474 .44039 L .53664 .40775 L p 1 1 1 r
F P
0 g
s
.49938 .36968 m .50485 .37838 L .4704 .34934 L p .65 .953 1 r
F P
0 g
s
.4704 .34934 m .46541 .33917 L .49938 .36968 L p .65 .953 1 r
F P
0 g
s
.22937 .6087 m .13048 .64046 L .12758 .63892 L p 1 1 1 r
F P
0 g
s
.60376 .46694 m .60758 .47605 L .57358 .4455 L p .65 .929 1 r
F P
0 g
s
.57358 .4455 m .56864 .43732 L .60376 .46694 L p .65 .929 1 r
F P
0 g
s
.21705 .58728 m .22937 .6087 L p .12758 .63892 L 1 1 1 r
F P
0 g
s
.12758 .63892 m .10603 .6276 L p .21705 .58728 L 1 1 1 r
F P
0 g
s
.53012 .3997 m .53664 .40775 L .50485 .37838 L p .65 .835 1 r
F P
0 g
s
.50485 .37838 m .49938 .36968 L .53012 .3997 L p .65 .835 1 r
F P
0 g
s
.30553 .55713 m .31383 .57387 L .22937 .6087 L p 1 1 1 r
F P
0 g
s
.22937 .6087 m .21705 .58728 L .30553 .55713 L p 1 1 1 r
F P
0 g
s
.10368 .17813 m .10114 .17529 L .10953 .17724 L p 1 1 1 r
F P
0 g
s
.64525 .49649 m .64813 .50727 L .60758 .47605 L p .686 1 1 r
F P
0 g
s
.60758 .47605 m .60376 .46694 L .64525 .49649 L p .686 1 1 r
F P
0 g
s
.38467 .26062 m .37473 .27664 L .30969 .24444 L p 1 1 1 r
F P
0 g
s
.30969 .24444 m .32408 .22288 L .38467 .26062 L p 1 1 1 r
F P
0 g
s
.32408 .22288 m .30969 .24444 L .22397 .21141 L p 1 1 1 r
F P
0 g
s
.22397 .21141 m .24311 .18191 L .32408 .22288 L p 1 1 1 r
F P
0 g
s
.24311 .18191 m .22397 .21141 L .10953 .17724 L p 1 1 1 r
F P
0 g
s
.43094 .29597 m .42509 .30817 L .37473 .27664 L p 1 1 1 r
F P
0 g
s
.37473 .27664 m .38467 .26062 L .43094 .29597 L p 1 1 1 r
F P
0 g
s
.37235 .5265 m .37852 .53979 L .31383 .57387 L p 1 1 1 r
F P
0 g
s
.31383 .57387 m .30553 .55713 L .37235 .5265 L p 1 1 1 r
F P
0 g
s
.10953 .17724 m .13329 .13645 L .24311 .18191 L p 1 1 1 r
F P
0 g
s
.10953 .17724 m .10114 .17529 L .07311 .13816 L p 1 1 1 r
F P
0 g
s
.13329 .13645 m .10953 .17724 L p .07311 .13816 L 1 1 1 r
F P
0 g
s
.67701 .25983 m .69469 .27578 L .64408 .30936 L p 1 1 1 r
F P
0 g
s
.64408 .30936 m .63049 .29707 L .67701 .25983 L p 1 1 1 r
F P
0 g
s
.63049 .29707 m .64408 .30936 L .60328 .34241 L p 1 1 1 r
F P
0 g
s
.60328 .34241 m .59281 .33247 L .63049 .29707 L p 1 1 1 r
F P
0 g
s
.59281 .33247 m .60328 .34241 L .56852 .37514 L p 1 1 1 r
F P
0 g
s
.56852 .37514 m .56037 .36656 L .59281 .33247 L p 1 1 1 r
F P
0 g
s
.56037 .36656 m .56852 .37514 L .53664 .40775 L p 1 1 1 r
F P
0 g
s
.69701 .52581 m .69886 .53911 L .64813 .50727 L p .823 1 1 r
F P
0 g
s
.64813 .50727 m .64525 .49649 L .69701 .52581 L p .823 1 1 r
F P
0 g
s
.73694 .22 m .75983 .24136 L .69469 .27578 L p 1 1 1 r
F P
0 g
s
.69469 .27578 m .67701 .25983 L .73694 .22 L p 1 1 1 r
F P
0 g
s
.53664 .40775 m .53012 .3997 L .56037 .36656 L p 1 1 1 r
F P
0 g
s
.56046 .42917 m .56864 .43732 L .53664 .40775 L p .65 .756 1 r
F P
0 g
s
.53664 .40775 m .53012 .3997 L .56046 .42917 L p .65 .756 1 r
F P
0 g
s
.53012 .3997 m .53664 .40775 L .50474 .44039 L p 1 1 1 r
F P
0 g
s
.42387 .49547 m .42907 .50627 L .37852 .53979 L p 1 1 1 r
F P
0 g
s
.37852 .53979 m .37235 .5265 L .42387 .49547 L p 1 1 1 r
F P
0 g
s
.4674 .3295 m .46541 .33917 L .42509 .30817 L p .986 1 1 r
F P
0 g
s
.42509 .30817 m .43094 .29597 L .4674 .3295 L p .986 1 1 r
F P
0 g
s
.50474 .44039 m .49925 .43214 L .53012 .3997 L p 1 1 1 r
F P
0 g
s
.49925 .43214 m .50474 .44039 L .46992 .47319 L p 1 1 1 r
F P
0 g
s
.97177 .63852 m .97267 .64049 L .96436 .63859 L p 1 1 1 r
F P
0 g
s
.46992 .47319 m .46489 .46403 L .49925 .43214 L p 1 1 1 r
F P
0 g
s
.46489 .46403 m .46992 .47319 L .42907 .50627 L p 1 1 1 r
F P
0 g
s
.42907 .50627 m .42387 .49547 L .46489 .46403 L p 1 1 1 r
F P
0 g
s
.96436 .63859 m .967 .62814 L .97177 .63852 L p 1 1 1 r
F P
0 g
s
.967 .62814 m .96436 .63859 L .8503 .60471 L p 1 1 1 r
F P
0 g
s
.81639 .17651 m .84564 .20568 L .75983 .24136 L p 1 1 1 r
F P
0 g
s
.75983 .24136 m .73694 .22 L .81639 .17651 L p 1 1 1 r
F P
0 g
s
.76393 .55475 m .76431 .57158 L .69886 .53911 L p .921 1 1 r
F P
0 g
s
.69886 .53911 m .69701 .52581 L .76393 .55475 L p .921 1 1 r
F P
0 g
s
.95904 .61001 m .967 .62814 L p .8503 .60471 L 1 1 1 r
F P
0 g
s
.8503 .60471 m .8525 .5831 L p .95904 .61001 L 1 1 1 r
F P
0 g
s
.8525 .5831 m .8503 .60471 L .76431 .57158 L p .991 1 1 r
F P
0 g
s
.76431 .57158 m .76393 .55475 L .8525 .5831 L p .991 1 1 r
F P
0 g
s
.49753 .36156 m .49938 .36968 L .46541 .33917 L p .843 1 1 r
F P
0 g
s
.46541 .33917 m .4674 .3295 L .49753 .36156 L p .843 1 1 r
F P
0 g
s
.94739 .17242 m .84564 .20568 L p .92385 .12777 L 1 1 1 r
F P
0 g
s
.84564 .20568 m .81639 .17651 L .92385 .12777 L p 1 1 1 r
F P
0 g
s
.84564 .20568 m .94739 .17242 L .94848 .17502 L p 1 1 1 r
F P
0 g
s
.59323 .45799 m .60376 .46694 L .56864 .43732 L p .65 .752 1 r
F P
0 g
s
.56864 .43732 m .56046 .42917 L .59323 .45799 L p .65 .752 1 r
F P
0 g
s
.52416 .39234 m .53012 .3997 L .49938 .36968 L p .65 .886 1 r
F P
0 g
s
.49938 .36968 m .49753 .36156 L .52416 .39234 L p .65 .886 1 r
F P
0 g
s
.92385 .12777 m .93802 .14344 L .94739 .17242 L p 1 1 1 r
F P
0 g
s
.63153 .48597 m .64525 .49649 L .60376 .46694 L p .65 .835 1 r
F P
0 g
s
.60376 .46694 m .59323 .45799 L .63153 .48597 L p .65 .835 1 r
F P
0 g
s
.57659 .32371 m .59281 .33247 L .56037 .36656 L p 1 1 1 r
F P
0 g
s
.56037 .36656 m .54975 .35887 L .57659 .32371 L p 1 1 1 r
F P
0 g
s
.54975 .35887 m .56037 .36656 L .53012 .3997 L p 1 1 1 r
F P
0 g
s
.53012 .3997 m .52416 .39234 L .54975 .35887 L p 1 1 1 r
F P
0 g
s
.5498 .42187 m .56046 .42917 L .53012 .3997 L p .65 .65 1 r
F P
0 g
s
.53012 .3997 m .52416 .39234 L .5498 .42187 L p .65 .65 1 r
F P
0 g
s
.52416 .39234 m .53012 .3997 L .49925 .43214 L p 1 1 1 r
F P
0 g
s
.60724 .28634 m .63049 .29707 L .59281 .33247 L p 1 1 1 r
F P
0 g
s
.59281 .33247 m .57659 .32371 L .60724 .28634 L p 1 1 1 r
F P
0 g
s
.49925 .43214 m .49739 .42443 L .52416 .39234 L p 1 1 1 r
F P
0 g
s
.49739 .42443 m .49925 .43214 L .46489 .46403 L p 1 1 1 r
F P
0 g
s
.4669 .45531 m .42977 .48503 L p .45192 .46722 L .65 .65 .65 r
F P
0 g
s
.4669 .45531 m .49739 .42443 L p .48171 .44353 L 1 1 1 r
F P
0 g
s
.49942 .41806 m .49739 .42443 L .4669 .45531 L p .65 .65 .65 r
F P
0 g
s
.4669 .45531 m .4759 .44794 L .49942 .41806 L p .65 .65 .65 r
F P
0 g
s
.4759 .44794 m .4669 .45531 L p .45192 .46722 L .65 .65 .65 r
F P
0 g
s
.46489 .46403 m .4669 .45531 L p .48171 .44353 L 1 1 1 r
F P
0 g
s
.4669 .45531 m .46489 .46403 L .42387 .49547 L p 1 1 1 r
F P
0 g
s
.64474 .24598 m .67701 .25983 L .63049 .29707 L p 1 1 1 r
F P
0 g
s
.63049 .29707 m .60724 .28634 L .64474 .24598 L p 1 1 1 r
F P
0 g
s
.49956 .35486 m .49753 .36156 L .4674 .3295 L p 1 1 1 r
F P
0 g
s
.4674 .3295 m .47635 .32132 L .49956 .35486 L p 1 1 1 r
F P
0 g
s
.47635 .32132 m .4674 .3295 L .43094 .29597 L p 1 1 1 r
F P
0 g
s
.67909 .51286 m .69701 .52581 L .64525 .49649 L p .65 .974 1 r
F P
0 g
s
.64525 .49649 m .63153 .48597 L .67909 .51286 L p .65 .974 1 r
F P
0 g
s
.43094 .29597 m .44751 .28546 L .47635 .32132 L p 1 1 1 r
F P
0 g
s
.44751 .28546 m .43094 .29597 L .38467 .26062 L p 1 1 1 r
F P
0 g
s
.57688 .45009 m .59323 .45799 L .56046 .42917 L p 1 .838 .65 r
F P
0 g
s
.56046 .42917 m .5498 .42187 L .57688 .45009 L p 1 .838 .65 r
F P
0 g
s
.38242 .5135 m .42977 .48503 L p .40205 .50505 L 1 1 1 r
F P
0 g
s
.37235 .5265 m .38242 .5135 L p .40205 .50505 L 1 1 1 r
F P
0 g
s
.38242 .5135 m .32011 .54052 L p .36243 .5221 L .65 .65 .65 r
F P
0 g
s
.42977 .48503 m .38242 .5135 L p .41319 .49551 L .65 .65 .65 r
F P
0 g
s
.42977 .48503 m .42387 .49547 L .37235 .5265 L p 1 1 1 r
F P
0 g
s
.42387 .49547 m .42977 .48503 L p .44614 .47469 L 1 1 1 r
F P
0 g
s
.38242 .5135 m .40829 .50213 L .44651 .47603 L p .65 .65 .65 r
F P
0 g
s
.40829 .50213 m .38242 .5135 L p .36243 .5221 L .65 .65 .65 r
F P
0 g
s
.44651 .47603 m .42977 .48503 L p .41319 .49551 L .65 .65 .65 r
F P
0 g
s
.42977 .48503 m .4669 .45531 L p .44614 .47469 L 1 1 1 r
F P
0 g
s
.51937 .38642 m .52416 .39234 L .49753 .36156 L p .736 .918 1 r
F P
0 g
s
.49753 .36156 m .49956 .35486 L .51937 .38642 L p .736 .918 1 r
F P
0 g
s
.38467 .26062 m .41019 .24662 L .44751 .28546 L p 1 1 1 r
F P
0 g
s
.41019 .24662 m .38467 .26062 L .32408 .22288 L p 1 1 1 r
F P
0 g
s
.69293 .20144 m .73694 .22 L .67701 .25983 L p 1 1 1 r
F P
0 g
s
.67701 .25983 m .64474 .24598 L .69293 .20144 L p 1 1 1 r
F P
0 g
s
.10603 .6276 m .09846 .61689 L .21705 .58728 L p 1 1 1 r
F P
0 g
s
.09846 .61689 m .10603 .6276 L .0924 .61994 L p 1 1 1 r
F P
0 g
s
.38242 .5135 m .37235 .5265 L .30553 .55713 L p 1 1 1 r
F P
0 g
s
.55614 .31707 m .57659 .32371 L .54975 .35887 L p 1 1 1 r
F P
0 g
s
.54975 .35887 m .53769 .35288 L .55614 .31707 L p 1 1 1 r
F P
0 g
s
.53769 .35288 m .54975 .35887 L .52416 .39234 L p 1 1 1 r
F P
0 g
s
.52416 .39234 m .51937 .38642 L .53769 .35288 L p 1 1 1 r
F P
0 g
s
.5377 .41618 m .5498 .42187 L .52416 .39234 L p 1 .932 .65 r
F P
0 g
s
.51937 .38642 m .52416 .39234 L .49739 .42443 L p 1 1 1 r
F P
0 g
s
.52416 .39234 m .51937 .38642 L .5377 .41618 L p 1 .932 .65 r
F P
0 g
s
.74069 .53831 m .76393 .55475 L .69701 .52581 L p .65 1 1 r
F P
0 g
s
.69701 .52581 m .67909 .51286 L .74069 .53831 L p .65 1 1 r
F P
0 g
s
.49942 .41806 m .4759 .44794 L p .48999 .43148 L 1 .804 1 r
F P
0 g
s
.49739 .42443 m .49942 .41806 L p .50878 .40474 L 1 1 1 r
F P
0 g
s
.5052 .41371 m .49942 .41806 L p .48999 .43148 L 1 .804 1 r
F P
0 g
s
.49942 .41806 m .51937 .38642 L p .50878 .40474 L 1 1 1 r
F P
0 g
s
.60803 .47679 m .63153 .48597 L .59323 .45799 L p 1 .811 .65 r
F P
0 g
s
.59323 .45799 m .57688 .45009 L .60803 .47679 L p 1 .811 .65 r
F P
0 g
s
.57652 .27836 m .60724 .28634 L .57659 .32371 L p 1 1 1 r
F P
0 g
s
.57659 .32371 m .55614 .31707 L .57652 .27836 L p 1 1 1 r
F P
0 g
s
.32408 .22288 m .36056 .20379 L .41019 .24662 L p 1 1 1 r
F P
0 g
s
.36056 .20379 m .32408 .22288 L .24311 .18191 L p 1 1 1 r
F P
0 g
s
.32011 .54052 m .23647 .56575 L p .29437 .5466 L .969 1 1 r
F P
0 g
s
.32011 .54052 m .38242 .5135 L p .34525 .53459 L 1 1 1 r
F P
0 g
s
.35722 .52581 m .40829 .50213 L p .3658 .52063 L .65 .65 .65 r
F P
0 g
s
.32011 .54052 m .35722 .52581 L p .3658 .52063 L .65 .65 .65 r
F P
0 g
s
.35722 .52581 m .32011 .54052 L p .29437 .5466 L .969 1 1 r
F P
0 g
s
.28768 .54641 m .35722 .52581 L p .29899 .54507 L .969 1 1 r
F P
0 g
s
.23647 .56575 m .28768 .54641 L p .29899 .54507 L .969 1 1 r
F P
0 g
s
.28768 .54641 m .19146 .56288 L p .27597 .54779 L .793 1 1 r
F P
0 g
s
.35722 .52581 m .28768 .54641 L p .34842 .53113 L .706 .65 .65 r
F P
0 g
s
.30553 .55713 m .32011 .54052 L p .34525 .53459 L 1 1 1 r
F P
0 g
s
.36678 .53157 m .41377 .51469 L p .35325 .52991 L .706 .65 .65 r
F P
0 g
s
.28768 .54641 m .36678 .53157 L p .35325 .52991 L .706 .65 .65 r
F P
0 g
s
.36678 .53157 m .28768 .54641 L p .27597 .54779 L .793 1 1 r
F P
0 g
s
.30363 .54231 m .36678 .53157 L p .19146 .56288 L .793 1 1 r
F P
0 g
s
.30912 .5418 m .38077 .53329 L .36678 .53157 L .724 .65 .65 r
F
.46568 .5232 m .36678 .53157 L p .38077 .53329 L F P
0 g
s
.41377 .51469 m .35722 .52581 L p .34842 .53113 L .706 .65 .65 r
F P
0 g
s
.32011 .54052 m .30553 .55713 L .21705 .58728 L p 1 1 1 r
F P
0 g
s
.50531 .35028 m .49956 .35486 L .47635 .32132 L p 1 1 1 r
F P
0 g
s
.47635 .32132 m .49145 .31552 L .50531 .35028 L p 1 1 1 r
F P
0 g
s
.49145 .31552 m .47635 .32132 L .44751 .28546 L p 1 1 1 r
F P
0 g
s
.51627 .38259 m .51937 .38642 L .49956 .35486 L p .984 .988 1 r
F P
0 g
s
.49956 .35486 m .50531 .35028 L .51627 .38259 L p .984 .988 1 r
F P
0 g
s
.55629 .4441 m .57688 .45009 L .5498 .42187 L p 1 1 .866 r
F P
0 g
s
.5498 .42187 m .5377 .41618 L .55629 .4441 L p 1 1 .866 r
F P
0 g
s
.75703 .15099 m .81639 .17651 L .73694 .22 L p 1 1 1 r
F P
0 g
s
.73694 .22 m .69293 .20144 L .75703 .15099 L p 1 1 1 r
F P
0 g
s
.60086 .23578 m .64474 .24598 L .60724 .28634 L p 1 1 1 r
F P
0 g
s
.60724 .28634 m .57652 .27836 L .60086 .23578 L p 1 1 1 r
F P
0 g
s
.53356 .31326 m .55614 .31707 L .53769 .35288 L p 1 1 1 r
F P
0 g
s
.53769 .35288 m .52543 .34923 L .53356 .31326 L p 1 1 1 r
F P
0 g
s
.52543 .34923 m .53769 .35288 L .51937 .38642 L p 1 1 1 r
F P
0 g
s
.44751 .28546 m .47331 .27778 L .49145 .31552 L p 1 1 1 r
F P
0 g
s
.47331 .27778 m .44751 .28546 L .41019 .24662 L p 1 1 1 r
F P
0 g
s
.52539 .41272 m .5377 .41618 L .51937 .38642 L p 1 1 .791 r
F P
0 g
s
.51627 .38259 m .51937 .38642 L .49942 .41806 L p .724 .65 .975 r
F P
0 g
s
.51937 .38642 m .51627 .38259 L .52539 .41272 L p 1 1 .791 r
F P
0 g
s
.51937 .38642 m .51627 .38259 L .52543 .34923 L p 1 1 1 r
F P
0 g
s
.82275 .56181 m .8525 .5831 L .76393 .55475 L p .777 1 1 r
F P
0 g
s
.76393 .55475 m .74069 .53831 L .82275 .56181 L p .777 1 1 r
F P
0 g
s
.07311 .13816 m .05038 .10793 L .13329 .13645 L p 1 1 1 r
F P
0 g
s
.21705 .58728 m .23647 .56575 L .32011 .54052 L p 1 1 1 r
F P
0 g
s
.23647 .56575 m .21705 .58728 L .09846 .61689 L p 1 1 1 r
F P
0 g
s
.64636 .50161 m .67909 .51286 L .63153 .48597 L p 1 .668 .65 r
F P
0 g
s
.63153 .48597 m .60803 .47679 L .64636 .50161 L p 1 .668 .65 r
F P
0 g
s
.54145 .27401 m .57652 .27836 L .55614 .31707 L p 1 1 1 r
F P
0 g
s
.55614 .31707 m .53356 .31326 L .54145 .27401 L p 1 1 1 r
F P
0 g
s
.24311 .18191 m .29329 .15544 L .36056 .20379 L p 1 1 1 r
F P
0 g
s
.29329 .15544 m .24311 .18191 L .13329 .13645 L p 1 1 1 r
F P
0 g
s
.49942 .41806 m .5052 .41371 L .51627 .38259 L p .724 .65 .975 r
F P
0 g
s
.5152 .38127 m .51627 .38259 L .50531 .35028 L p 1 1 1 r
F P
0 g
s
.50531 .35028 m .51425 .34833 L .5152 .38127 L p 1 1 1 r
F P
0 g
s
.51425 .34833 m .50531 .35028 L .49145 .31552 L p 1 1 1 r
F P
0 g
s
.42977 .48503 m .44651 .47603 L .4759 .44794 L p .65 .65 .65 r
F P
0 g
s
.49145 .31552 m .51121 .31272 L .51425 .34833 L p 1 1 1 r
F P
0 g
s
.51121 .31272 m .49145 .31552 L .47331 .27778 L p 1 1 1 r
F P
0 g
s
.51121 .31272 m .53356 .31326 L .52543 .34923 L p 1 1 1 r
F P
0 g
s
.52543 .34923 m .51425 .34833 L .51121 .31272 L p 1 1 1 r
F P
0 g
s
.51425 .34833 m .52543 .34923 L .51627 .38259 L p 1 1 1 r
F P
0 g
s
.51627 .38259 m .5152 .38127 L .51425 .34833 L p 1 1 1 r
F P
0 g
s
.51416 .41186 m .52539 .41272 L .51627 .38259 L p 1 1 1 r
F P
0 g
s
.5152 .38127 m .51627 .38259 L .5052 .41371 L p 1 1 1 r
F P
0 g
s
.51627 .38259 m .5152 .38127 L .51416 .41186 L p 1 1 1 r
F P
0 g
s
.57696 .46996 m .60803 .47679 L .57688 .45009 L p 1 1 .896 r
F P
0 g
s
.57688 .45009 m .55629 .4441 L .57696 .46996 L p 1 1 .896 r
F P
0 g
s
.53354 .44067 m .55629 .4441 L .5377 .41618 L p 1 1 1 r
F P
0 g
s
.5377 .41618 m .52539 .41272 L .53354 .44067 L p 1 1 1 r
F P
0 g
s
.41019 .24662 m .44905 .23619 L .47331 .27778 L p 1 1 1 r
F P
0 g
s
.44905 .23619 m .41019 .24662 L .36056 .20379 L p 1 1 1 r
F P
0 g
s
.0924 .61994 m .08976 .61845 L .09846 .61689 L p 1 1 1 r
F P
0 g
s
.63174 .18782 m .69293 .20144 L .64474 .24598 L p 1 1 1 r
F P
0 g
s
.64474 .24598 m .60086 .23578 L .63174 .18782 L p 1 1 1 r
F P
0 g
s
.5052 .41371 m .51416 .41186 L .5152 .38127 L p 1 1 1 r
F P
0 g
s
.50577 .27381 m .54145 .27401 L .53356 .31326 L p 1 1 1 r
F P
0 g
s
.53356 .31326 m .51121 .31272 L .50577 .27381 L p 1 1 1 r
F P
0 g
s
.93802 .14344 m .92385 .12777 L .9318 .12474 L closepath p 1 1 1 r
F P
0 g
s
.47331 .27778 m .50577 .27381 L .51121 .31272 L p 1 1 1 r
F P
0 g
s
.4759 .44794 m .49111 .4427 L .5052 .41371 L p 1 .804 1 r
F P
0 g
s
.49111 .4427 m .4759 .44794 L .44651 .47603 L p 1 .772 .997 r
F P
0 g
s
.54989 .23042 m .60086 .23578 L .57652 .27836 L p 1 1 1 r
F P
0 g
s
.57652 .27836 m .54145 .27401 L .54989 .23042 L p 1 1 1 r
F P
0 g
s
.84449 .09198 m .92385 .12777 L .81639 .17651 L p 1 1 1 r
F P
0 g
s
.81639 .17651 m .75703 .15099 L .84449 .09198 L p 1 1 1 r
F P
0 g
s
.51416 .41186 m .5052 .41371 L .49111 .4427 L p 1 1 1 r
F P
0 g
s
.95793 .60749 m .8525 .5831 L p .93426 .58265 L .891 1 1 r
F P
0 g
s
.8525 .5831 m .82275 .56181 L .93426 .58265 L p .891 1 1 r
F P
0 g
s
.8525 .5831 m .95793 .60749 L .95904 .61001 L p 1 1 1 r
F P
0 g
s
.09846 .61689 m .12251 .58866 L .23647 .56575 L p 1 1 1 r
F P
0 g
s
.09846 .61689 m .08976 .61845 L .06024 .60796 L p 1 1 1 r
F P
0 g
s
.12251 .58866 m .09846 .61689 L p .06024 .60796 L 1 1 1 r
F P
0 g
s
.50577 .27381 m .47331 .27778 L .44905 .23619 L p 1 1 1 r
F P
0 g
s
.51102 .44018 m .53354 .44067 L .52539 .41272 L p 1 1 1 r
F P
0 g
s
.52539 .41272 m .51416 .41186 L .51102 .44018 L p 1 1 1 r
F P
0 g
s
.49111 .4427 m .51102 .44018 L .51416 .41186 L p 1 1 1 r
F P
0 g
s
.67582 .52942 m .71184 .53515 L p .6959 .524 L 1 .65 .65 r
F P
0 g
s
.6959 .524 m .74069 .53831 L .6812 .51373 L p 1 .65 .65 r
F P
0 g
s
.76213 .54315 m .82275 .56181 L .74813 .54043 L p .65 1 1 r
F P
0 g
s
.74813 .54043 m .74069 .53831 L p .76213 .54315 L .65 1 1 r
F P
0 g
s
.82275 .56181 m .76213 .54315 L .85299 .55785 L p .697 1 1 r
F P
0 g
s
.73396 .53943 m .77855 .54633 L p .76213 .54315 L .78 .65 .65 r
F P
0 g
s
.77855 .54633 m .85299 .55785 L .76213 .54315 L p .78 .65 .65 r
F P
0 g
s
.74069 .53831 m .6959 .524 L .76213 .54315 L p .65 1 1 r
F P
0 g
s
.71184 .53515 m .76213 .54315 L .6959 .524 L p 1 .65 .65 r
F P
0 g
s
.6812 .51373 m .67909 .51286 L p .6959 .524 L 1 .65 .65 r
F P
0 g
s
.67909 .51286 m .64636 .50161 L .6959 .524 L p 1 .65 .65 r
F P
0 g
s
.5415 .46624 m .57696 .46996 L .55629 .4441 L p 1 1 1 r
F P
0 g
s
.55629 .4441 m .53354 .44067 L .5415 .46624 L p 1 1 1 r
F P
0 g
s
.49735 .23057 m .54989 .23042 L .54145 .27401 L p 1 1 1 r
F P
0 g
s
.54145 .27401 m .50577 .27381 L .49735 .23057 L p 1 1 1 r
F P
0 g
s
.44905 .23619 m .49735 .23057 L .50577 .27381 L p 1 1 1 r
F P
0 g
s
.13329 .13645 m .20069 .09924 L .29329 .15544 L p 1 1 1 r
F P
0 g
s
.13329 .13645 m .05038 .10793 L .03732 .08827 L p 1 1 1 r
F P
0 g
s
.20069 .09924 m .13329 .13645 L p .03732 .08827 L 1 1 1 r
F P
0 g
s
.60183 .49332 m .64636 .50161 L .60803 .47679 L p 1 .908 .777 r
F P
0 g
s
.60803 .47679 m .57696 .46996 L .60183 .49332 L p 1 .908 .777 r
F P
0 g
s
.51102 .44018 m .49111 .4427 L .4726 .46947 L p 1 .982 1 r
F P
0 g
s
.44651 .47603 m .4726 .46947 L .49111 .4427 L p 1 .772 .997 r
F P
0 g
s
.36056 .20379 m .41608 .18936 L .44905 .23619 L p 1 1 1 r
F P
0 g
s
.41608 .18936 m .36056 .20379 L .29329 .15544 L p 1 1 1 r
F P
0 g
s
.4726 .46947 m .44651 .47603 L .40829 .50213 L p 1 .65 .823 r
F P
0 g
s
.49735 .23057 m .44905 .23619 L .41608 .18936 L p 1 1 1 r
F P
0 g
s
.93426 .58265 m .94869 .59351 L .95793 .60749 L p .891 1 1 r
F P
0 g
s
.50542 .46607 m .5415 .46624 L .53354 .44067 L p 1 1 1 r
F P
0 g
s
.53354 .44067 m .51102 .44018 L .50542 .46607 L p 1 1 1 r
F P
0 g
s
.55975 .18083 m .63174 .18782 L .60086 .23578 L p 1 1 1 r
F P
0 g
s
.60086 .23578 m .54989 .23042 L .55975 .18083 L p 1 1 1 r
F P
0 g
s
.67263 .13222 m .75703 .15099 L .69293 .20144 L p 1 1 1 r
F P
0 g
s
.69293 .20144 m .63174 .18782 L .67263 .13222 L p 1 1 1 r
F P
0 g
s
.4726 .46947 m .50542 .46607 L .51102 .44018 L p 1 .982 1 r
F P
0 g
s
.54989 .23042 m .49735 .23057 L .48503 .18137 L p 1 1 1 r
F P
0 g
s
.41608 .18936 m .48503 .18137 L .49735 .23057 L p 1 1 1 r
F P
0 g
s
.92897 .11486 m .9318 .12474 L .92385 .12777 L p 1 1 1 r
F P
0 g
s
.92385 .12777 m .84449 .09198 L p .92897 .11486 L 1 1 1 r
F P
0 g
s
.48503 .18137 m .55975 .18083 L .54989 .23042 L p 1 1 1 r
F P
0 g
s
.55009 .48898 m .60183 .49332 L .57696 .46996 L p 1 .986 .975 r
F P
0 g
s
.57696 .46996 m .5415 .46624 L .55009 .48898 L p 1 .986 .975 r
F P
0 g
s
.50542 .46607 m .4726 .46947 L .44773 .49366 L p 1 .866 .992 r
F P
0 g
s
.40829 .50213 m .44773 .49366 L .4726 .46947 L p 1 .65 .823 r
F P
0 g
s
.44773 .49366 m .40829 .50213 L .35722 .52581 L p .902 .65 .65 r
F P
0 g
s
.63356 .5135 m .6959 .524 L .64636 .50161 L p 1 .703 .65 r
F P
0 g
s
.64636 .50161 m .60183 .49332 L .63356 .5135 L p 1 .703 .65 r
F P
0 g
s
.49676 .48909 m .55009 .48898 L .5415 .46624 L p 1 .965 1 r
F P
0 g
s
.5415 .46624 m .50542 .46607 L .49676 .48909 L p 1 .965 1 r
F P
0 g
s
.44773 .49366 m .49676 .48909 L .50542 .46607 L p 1 .866 .992 r
F P
0 g
s
.29329 .15544 m .37066 .13516 L .41608 .18936 L p 1 1 1 r
F P
0 g
s
.37066 .13516 m .29329 .15544 L .20069 .09924 L p 1 1 1 r
F P
0 g
s
.48503 .18137 m .41608 .18936 L .37066 .13516 L p 1 1 1 r
F P
0 g
s
.84449 .09198 m .9112 .0528 L .92897 .11486 L p 1 1 1 r
F P
0 g
s
.57215 .12268 m .67263 .13222 L .63174 .18782 L p 1 1 1 r
F P
0 g
s
.63174 .18782 m .55975 .18083 L .57215 .12268 L p 1 1 1 r
F P
0 g
s
.28768 .54641 m .23647 .56575 L .12251 .58866 L p 1 1 1 r
F P
0 g
s
.72856 .06545 m .84449 .09198 L .75703 .15099 L p 1 1 1 r
F P
0 g
s
.75703 .15099 m .67263 .13222 L .72856 .06545 L p 1 1 1 r
F P
0 g
s
.03732 .08827 m .02004 .06216 L .02744 .05774 L p 1 1 1 r
F P
0 g
s
.02744 .05774 m .20069 .09924 L .03732 .08827 L 1 1 1 r
F
.49676 .48909 m .44773 .49366 L .41377 .51469 L p 1 .681 .768 r
F P
0 g
s
.35722 .52581 m .41377 .51469 L .44773 .49366 L p .902 .65 .65 r
F P
0 g
s
.5602 .50811 m .63356 .5135 L .60183 .49332 L p 1 .808 .767 r
F P
0 g
s
.60183 .49332 m .55009 .48898 L .5602 .50811 L p 1 .808 .767 r
F P
0 g
s
.55975 .18083 m .48503 .18137 L .46732 .12371 L p 1 1 1 r
F P
0 g
s
.37066 .13516 m .46732 .12371 L .48503 .18137 L p 1 1 1 r
F P
0 g
s
.46732 .12371 m .57215 .12268 L .55975 .18083 L p 1 1 1 r
F P
0 g
s
.85299 .55785 m .93426 .58265 L .82275 .56181 L p .697 1 1 r
F P
0 g
s
.06024 .60796 m .03623 .59954 L .12251 .58866 L p 1 1 1 r
F P
0 g
s
.6959 .524 m .63356 .5135 L .67582 .52942 L p 1 .65 .65 r
F P
0 g
s
.94869 .59351 m .93426 .58265 L .94252 .58357 L closepath p .969 1 1 r
F P
0 g
s
.55009 .48898 m .49676 .48909 L .48403 .50853 L p 1 .794 .828 r
F P
0 g
s
.41377 .51469 m .48403 .50853 L .49676 .48909 L p 1 .681 .768 r
F P
0 g
s
.48403 .50853 m .5602 .50811 L .55009 .48898 L p 1 .794 .828 r
F P
0 g
s
.37066 .13516 m .30994 .07307 L .31527 .07298 L p 1 1 1 r
F P
0 g
s
.46732 .12371 m .37066 .13516 L p .31527 .07298 L 1 1 1 r
F P
0 g
s
.30994 .07307 m .37066 .13516 L p .20069 .09924 L 1 1 1 r
F P
0 g
s
.12251 .58866 m .19146 .56288 L .28768 .54641 L p 1 1 1 r
F P
0 g
s
.12251 .58866 m .03623 .59954 L .02226 .597 L p 1 1 1 r
F P
0 g
s
.19146 .56288 m .12251 .58866 L p .02226 .597 L 1 1 1 r
F P
0 g
s
.20069 .09924 m .29957 .07237 L .30994 .07307 L p 1 1 1 r
F P
0 g
s
.29957 .07237 m .20069 .09924 L .1394 .06721 L closepath p 1 1 1 r
F P
0 g
s
.02744 .05774 m .1394 .06721 L .20069 .09924 L p 1 1 1 r
F P
0 g
s
.59115 .0544 m .59858 .05296 L p .67263 .13222 L 1 1 1 r
F P
0 g
s
.59858 .05296 m .72856 .06545 L .67263 .13222 L p 1 1 1 r
F P
0 g
s
.67263 .13222 m .57215 .12268 L p .59115 .0544 L 1 1 1 r
F P
0 g
s
.48403 .50853 m .41377 .51469 L .36678 .53157 L p .955 .65 .65 r
F P
0 g
s
.9112 .0528 m .84449 .09198 L p .8184 .01489 L 1 1 1 r
F P
0 g
s
.84449 .09198 m .72856 .06545 L p .8184 .01489 L 1 1 1 r
F P
0 g
s
.57299 .52244 m .67582 .52942 L .63356 .5135 L p 1 .65 .65 r
F P
0 g
s
.63356 .5135 m .5602 .50811 L .57299 .52244 L p 1 .65 .65 r
F P
0 g
s
.93978 .58069 m .94252 .58357 L .93426 .58265 L p .846 1 1 r
F P
0 g
s
.93426 .58265 m .85299 .55785 L p .93978 .58069 L .846 1 1 r
F P
0 g
s
.46732 .12371 m .44804 .0705 L .4692 .06814 L p 1 1 1 r
F P
0 g
s
.57215 .12268 m .46732 .12371 L p .4692 .06814 L 1 1 1 r
F P
0 g
s
.31527 .07298 m .44804 .0705 L .46732 .12371 L p 1 1 1 r
F P
0 g
s
.4692 .06814 m .58792 .05504 L .57215 .12268 L p 1 1 1 r
F P
0 g
s
.57215 .12268 m .58792 .05504 L .59115 .0544 L p 1 1 1 r
F P
0 g
s
.5602 .50811 m .48403 .50853 L .46568 .5232 L p 1 .65 .65 r
F P
0 g
s
.36678 .53157 m .46568 .5232 L .48403 .50853 L p .955 .65 .65 r
F P
0 g
s
.46568 .5232 m .57299 .52244 L .5602 .50811 L p 1 .65 .65 r
F P
0 g
s
.76213 .54315 m .67582 .52942 L .73396 .53943 L p .78 .65 .65 r
F P
0 g
s
.85299 .55785 m .92254 .56244 L .93978 .58069 L p .846 1 1 r
F P
0 g
s
.88539 .00079 m .89868 .00399 L .9112 .0528 L p 1 1 1 r
F P
0 g
s
.8184 .01489 m .88539 .00079 L p .9112 .0528 L 1 1 1 r
F P
0 g
s
.02226 .597 m .00374 .59375 L .01132 .59084 L p 1 1 1 r
F P
0 g
s
.01132 .59084 m .19146 .56288 L .02226 .597 L 1 1 1 r
F
.36678 .53157 m .30363 .54231 L .30912 .5418 L p .724 .65 .65 r
F P
0 g
s
.69645 .03717 m .76562 .02612 L .72856 .06545 L p 1 1 1 r
F P
0 g
s
.72856 .06545 m .59858 .05296 L .69645 .03717 L p 1 1 1 r
F P
0 g
s
.72856 .06545 m .76562 .02612 L .8184 .01489 L p 1 1 1 r
F P
0 g
s
.59269 .53007 m .60033 .53076 L p .67582 .52942 L .867 .65 .65 r
F P
0 g
s
.60033 .53076 m .73396 .53943 L .67582 .52942 L p .867 .65 .65 r
F P
0 g
s
.67582 .52942 m .57299 .52244 L p .59269 .53007 L .867 .65 .65 r
F P
0 g
s
.19146 .56288 m .29293 .54423 L .30363 .54231 L p .793 1 1 r
F P
0 g
s
.29293 .54423 m .19146 .56288 L .1276 .56796 L closepath p .937 1 1 r
F P
0 g
s
.01132 .59084 m .1276 .56796 L .19146 .56288 L p 1 1 1 r
F P
0 g
s
.46568 .5232 m .44563 .52933 L .46736 .52942 L p .846 .65 .65 r
F P
0 g
s
.57299 .52244 m .46568 .5232 L p .46736 .52942 L .846 .65 .65 r
F P
0 g
s
.30912 .5418 m .44563 .52933 L .46568 .5232 L p .724 .65 .65 r
F P
0 g
s
.46736 .52942 m .58937 .52976 L .57299 .52244 L p .846 .65 .65 r
F P
0 g
s
.57299 .52244 m .58937 .52976 L .59269 .53007 L p .867 .65 .65 r
F P
0 g
s
.92254 .56244 m .85299 .55785 L p .82731 .54604 L .733 1 1 r
F P
0 g
s
.85299 .55785 m .73396 .53943 L p .82731 .54604 L .733 1 1 r
F P
0 g
s
.89687 .55339 m .91057 .5555 L .92254 .56244 L p .733 1 1 r
F P
0 g
s
.82731 .54604 m .89687 .55339 L p .92254 .56244 L .733 1 1 r
F P
0 g
s
.70119 .53632 m .77262 .54015 L .73396 .53943 L p .672 1 1 r
F P
0 g
s
.73396 .53943 m .60033 .53076 L .70119 .53632 L p .672 1 1 r
F P
0 g
s
.73396 .53943 m .77262 .54015 L .82731 .54604 L p .733 1 1 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 214.688},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eQ000`40O003h00Ongoo1@0087oo003f
Ool50005Ool2000NOol00?9oo`@000]oo`03001oogoo01aoo`00kGoo1@0047oo00<007ooOol06goo
003XOol5000EOol00`00Oomoo`0KOol00>=oo`D001Yoo`03001oogoo01]oo`00gWoo1@007goo00<0
07ooOol06goo003HOol6000UOol00`00Oomoo`0JOol00=5oo`L0009oo`03001oogoo02Ioo`03001o
ogoo01Yoo`00bgoo1P0027oo00<007ooOol09goo00<007ooOol06Woo0035Ool6000>Ool00`00Oomo
o`0XOol00`00Oomoo`0IOol00;moo`H001=oo`03001oogoo02Uoo`03001oogoo01Uoo`00^Goo1P00
67oo00<007ooOol0:Woo00<007ooOol06Goo002dOol5000MOol00`00Oomoo`0[Ool00`00Oomoo`0I
Ool00:ioo`H0025oo`03001oogoo02eoo`03001oogoo01Qoo`00ZGoo1`0097oo00<007ooOol0;Woo
00<007ooOol067oo0008Ool6002EOol60007Ool:000JOol00`00Oomoo`0/Ool3000JOol000Ioo`80
00Ioo`/007ioo``000Eoo`03001oogoo00moo`T0011oo`03001oogoo02]oo`8000=oo`03001oogoo
01Moo`001Goo00<007ooOol04Goo2P00JGoo2`004Goo00<007ooOol067oo2P001Goo00<007ooOol0
:Woo0P001Goo00<007ooOol05goo0006Ool00`00Oomoo`0JOolA001?Ool9000KOol00`00Oomoo`0S
Ool7000ZOol00`00Oomoo`05Ool00`00Oomoo`0GOol000Ioo`03001oogoo021oo`8000UooaL0029o
oaH002Aoo`03001oogoo02Ioo`04001oogooOol5000SOol20008Ool00`00Oomoo`0GOol000Moo`03
001oogoo025oo`8001ioob8001=oo`03001oogoo02Aoo`03001oogoo02Eoo`03001oogoo00Moo`@0
01eoo`8000]oo`03001oogoo01Ioo`0027oo00<007ooOol08Woo0P008Goo10001Woo00<007ooOol0
97oo00<007ooOol08goo00<007ooOol097oo00<007ooOol037oo1@005goo00<007ooOol02goo00<0
07ooOol05Woo0009Ool00`00Oomoo`0SOol2000KOol4000;Ool00`00Oomoo`0SOol00`00Oomoo`0S
Ool00`00Oomoo`0SOol00`00Oomoo`0BOol5000@Ool2000>Ool00`00Oomoo`0FOol000Uoo`03001o
ogoo02Eoo`8001Eoo`@0011oo`03001oogoo02=oo`03001oogoo025oo`03001oogoo02Aoo`03001o
ogoo01Moo`@000Yoo`80015oo`03001oogoo01Eoo`00<goo0P003goo10005Goo00<007ooOol08Woo
00<007ooOol08Goo00<007ooOol08goo00<007ooOol077oo1@000goo0P004goo00<007ooOol05Goo
000;Ool00`00Oomoo`0WOol20009Ool4000JOol00`00Oomoo`0QOol00`00Oomoo`0QOol00`00Oomo
o`0ROol00`00Oomoo`0ROol3000EOol00`00Oomoo`0EOol000]oo`03001oogoo02Uoo`8000=oo`@0
01moo`03001oogoo025oo`03001oogoo021oo`03001oogoo025oo`03001oogoo02=oo`8001Ioo`03
001oogoo01Eoo`0037oo00<007ooOol0:Woo0`0097oo00<007ooOol087oo00<007ooOol07goo00<0
07ooOol08Goo00<007ooOol08goo00<007ooOol017oo0P004Goo00<007ooOol057oo000=Ool00`00
Oomoo`0WOol200000goo0000000UOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol0
0`00Oomoo`0ROol20009Ool2000?Ool00`00Oomoo`0DOol000eoo`03001oogoo02Eoo`8000Eoo`80
02Aoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo01moo`03001oogoo029oo`03001oogoo
00]oo`8000eoo`03001oogoo01Aoo`003Woo0P008goo0P002Goo00<007ooOol08Goo00<007ooOol0
7goo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol08Goo0P0047oo0`002Woo00<007ooOol0
57oo000?Ool4000OOol00`00Oomoo`0:Ool2000ROol00`00Oomoo`0OOol00`00Oomoo`0MOol00`00
Oomoo`0MOol00`00Oomoo`0QOol00`00Oomoo`0COol20009Ool00`00Oomoo`0COol0011oo`03001o
ogoo00<001Yoo`8000moo`80025oo`03001oogoo01ioo`03001oogoo01aoo`03001oogoo01eoo`03
001oogoo021oo`8001Qoo`8000Moo`03001oogoo01=oo`004Goo00<007ooOol00Woo0`005Goo0P00
4goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol06goo00<007ooOol07Goo00<007ooOol0
7goo00<007ooOol06Woo0P001Goo00<007ooOol04goo000BOol00`00Oomoo`04Ool3000AOol00`00
Oomoo`0DOol2000POol00`00Oomoo`0JOolV000JOol00`00Oomoo`0OOol00`00Oomoo`0MOol20004
Ool00`00Oomoo`0BOol0019oo`03001oogoo00Moo`<000aoo`8001Uoo`8001moo`03001oogoo019o
o`L000=oo`03001oogoo01]oo`03001oogoo009oo`X000moo`03001oogoo01ioo`80029oo`D001Ao
o`004goo00<007ooOol02Goo0`001goo0P007Goo0P007Woo00<007ooOol02Woo1`002goo00<007oo
Ool06Woo00<007ooOol037oo2@001Goo00<007ooOol07Woo00<007ooOol087oo0P000Woo00<007oo
000057oo000DOol00`00Oomoo`0;Ool20003Ool2000QOol00`00Oomoo`0LOol00`00Oomoo`02Ool7
000BOol00`00Oomoo`0IOol00`00Oomoo`0FOol7000MOol2000QOol20005Ool00`00Ool0000COol0
01Eoo`03001oogoo00eoo`8002Aoo`8001]oo`H001Uoo`03001oogoo01Uoo`03001oogoo01Uoo`04
001oogooOol5000GOol00`00Oomoo`0OOol20008Ool2000COol002Eoo`03001oogoo008002=oo`80
01Eoo`@000=oo`03001oogoo01Uoo`03001oogoo01Uoo`03001oogoo01Uoo`03001oogoo00Ioo`D0
011oo`80021oo`8000]oo`80019oo`005Woo00<007ooOol037oo00<007ooOol00Woo0P008goo00<0
07ooOol03Goo1@0027oo00<007ooOol06Goo00<007ooOol067oo00<007ooOol067oo00<007ooOol0
37oo1@002Woo00<007ooOol07Woo0P003Woo00<007ooOol047oo000GOol00`00Oomoo`0:Ool00`00
Oomoo`05Ool3000QOol20009Ool4000>Ool00`00Oomoo`0HOol00`00Oomoo`0GOol00`00Oomoo`0H
Ool00`00Oomoo`0BOol50003Ool2000OOol2000@Ool00`00Oomoo`0@Ool002Aoo`03001oogoo00Qo
o`80025oo`8000=oo`@0019oo`03001oogoo01Qoo`03001oogoo01Moo`03001oogoo01Qoo`03001o
ogoo01Moo`@001eoo`<001=oo`03001oogoo00moo`008goo00<007ooOol02goo0`0087oo0`005goo
00<007ooOol067oo00<007ooOol05Woo00<007ooOol05goo00<007ooOol06Goo00<007ooOol00P00
6Goo0P005Woo00<007ooOol03goo000IOol00`00Oomoo`07Ool00`00Oomoo`0>Ool2000LOol20000
0goo001oo`0HOol00`00Oomoo`0GOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0HOol2
0005Ool3000DOol2000HOol00`00Oomoo`0?Ool001Yoo`03001oogoo00Eoo`03001oogoo015oo`80
01Qoo`8000Eoo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo01Moo`03
001oogoo01Moo`03001oogoo00Qoo`80011oo`8001Yoo`03001oogoo00moo`006goo00<007ooOol0
0goo00<007ooOol057oo0`004goo0P0027oo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol0
57oo00<007ooOol05Woo00<007ooOol05goo00<007ooOol02goo0P0037oo0P007Goo00<007ooOol0
3Woo000LOol00`00Oomoo`02Ool00`00Oomoo`0GOol2000?Ool2000;Ool2000GOol00`00Oomoo`0E
Ool00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0>Ool30007Ool2000O
Ool00`00Oomoo`0>Ool001aoo`05001oogooOol0000LOol3000:Ool2000?Ool00`00Oomoo`0EOol0
0`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0FOol2000DOol20003Ool2
000POol2000@Ool001eoo`04001oogoo000OOol20006Ool2000BOol00`00Oomoo`0EOol00`00Oomo
o`0COol00`00Oomoo`0COol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0FOol3000OOol3
0002Ool00`00Oomoo`0=Ool001eoo`03001oo`00029oo`80009oo`8001Eoo`8001Eoo`03001oogoo
01Aoo`03001oogoo019oo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Ioo`800003Ool0
07oo01]oo`<000Eoo`03001oogoo00eoo`007Woo00<007oo000010007goo0P006Goo00<007ooOol0
4goo00<007ooOol03Woo800047oo00<007ooOol057oo0P005goo0P0017oo00<007ooOol05Woo0`00
2Goo00<007ooOol037oo000OOol20004Ool4000KOol01000Oomoo`0067oo00<007ooOol04goo00<0
07ooOol00goo2P001Goo00<007ooOol04Woo00<007ooOol00goo2P001Woo00<007ooOol04goo00<0
07ooOol05Goo0P001goo00<007ooOol04Woo0`0037oo00<007ooOol037oo000POol20007Ool3000H
Ool00`00Oomoo`02Ool2000FOol2000BOol7000?Ool00`00Oomoo`0BOol00`00Oomoo`0=Ool8000C
Ool00`00Oomoo`0EOol00`00Oomoo`08Ool00`00Oomoo`0?Ool2000@Ool00`00Oomoo`0;Ool0025o
o`03001oogoo00Qoo`@001=oo`03001oogoo00Eoo`8001Ioo`03001oogoo00]oo`@001Moo`03001o
ogoo011oo`03001oogoo019oo`04001oogooOol4000>Ool00`00Oomoo`0DOol2000;Ool00`00Oomo
o`0<Ool3000BOol00`00Oomoo`0;Ool0029oo`03001oogoo00]oo`@000moo`03001oogoo00Moo`80
01Eoo`03001oogoo00Ioo`@000Moo`03001oogoo015oo`03001oogoo011oo`03001oogoo019oo`03
001oogoo00Eoo`@000Qoo`8001Eoo`8000ioo`03001oogoo00Qoo`<001Eoo`03001oogoo00]oo`00
8goo00<007ooOol03Woo0`002goo00<007ooOol02Woo0P0057oo0P000Woo100037oo00<007ooOol0
47oo00<007ooOol047oo00<007ooOol04Goo00<007ooOol02Woo10000goo00<007ooOol04goo0P00
4Goo00<007ooOol017oo0`0067oo0P0037oo000TOol00`00Oomoo`0@Ool40006Ool00`00Oomoo`0=
Ool2000DOol2000AOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0?
Ool4000COol2000DOol00`00Oomoo`03000JOol00`00Ool0000<Ool002Aoo`03001oogoo01Aoo`@0
009oo`03001oogoo00moo`80011oo`800003Ool007oo011oo`03001oogoo011oo`03001oogoo00mo
o`03001oogoo011oo`03001oogoo011oo`03001oogoo0080011oo`03001oogoo01Aoo`<001eoo`03
001oo`0000aoo`009Goo00<007ooOol05goo0P0057oo0P0037oo0P0017oo00<007ooOol03goo00<0
07ooOol03goo00<007ooOol03Woo00<007ooOol047oo00<007ooOol047oo00<007ooOol00goo0`00
2goo0P005Goo0P0000=oo`00Ool06goo0`000Woo00<007ooOol02Goo000VOol00`00Oomoo`0GOol0
1000Ool000004goo0P002Goo00<007ooOol01Goo00<007ooOol03goo00<007ooOol03Woo00<007oo
Ool03Woo00<007ooOol03goo00<007ooOol03goo0P002Goo0`001Woo0P0057oo0`000goo00<007oo
Ool05Woo100000=oo`00Ool00Woo00<007ooOol02Goo000WOol00`00Oomoo`0GOol00`00Oomoo`03
000BOol20005Ool20009Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomo
o`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool20002Ool2000DOol20006Ool00`00Oomoo`0AOol5
0003Ool20005Ool00`00Oomoo`08Ool002Qoo`8001Moo`03001oogoo00=oo`80019oo`800003Ool0
000000aoo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00ioo`03001o
ogoo00ioo`03001oogoo00moo`8001=oo`<000Qoo`03001oogoo00aoo`D000Moo`03001oogoo00Eo
o`03001oogoo00Qoo`00:Woo00Ako`00000001=oo`03001oogoo00Eoo`80019oo`03001oogoo00eo
o`8000ioo`03001oogoo00ioo`03001oogoo00aoo`03001oogoo00ioo`03001oogoo00ioo`03001o
ogoo00moo`800003Ool007oo00moo`8000Yoo`03001oogoo00Uoo`@000]oo`03001oogoo00Moo`03
001oogoo00Moo`00:Woo00D007_oOomkogoo00<0011oo`03001oogoo00Ioo`<000ioo`03001oo`00
011oo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo
00ioo`03001oogoo00moo`03001oogoo009oo`03001oogoo00Yoo`<000aoo`03001oogoo00Aoo`D0
00eoo`8000]oo`03001oogoo00Ioo`00;7oo00EkogooOomoog_o00=oo`8000aoo`03001oogoo00Uo
o`8000]oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00UooaX000Qo
o`03001oogoo00eoo`03001oogoo00ioo`8000Ioo`03001oogoo00Moo`8000moo`04001oogooOol3
000AOol00`00Oomoo`0;Ool00`00Oomoo`06Ool002eoo`0;Nomoog_oOomkogooNomoog_oOomko`02
0008Ool00`00Oomoo`0;Ool30008Ool00`00Oomoo`03Ool2000>Ool00`00Oomoo`0;Ool00`00Oomo
o`02Ool70003Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool:000<Ool2000@Ool00`00Oomoo`07Ool0
0`00Oomoo`03Ool3000@Ool4000DOol00`00Oomoo`0=Ool00`00Oomoo`05Ool002ioo`05001oogoo
Oomko`03Ool01G_oOomoogooNol00Woo00<007ooOol00goo00<007ooOol03Goo0P001Goo00<007oo
Ool01Woo00<007ooOol037oo00<007ooOol02Woo1@002goo00<007ooOol02goo00<007ooOol02goo
00@007ooOomoo`@000Moo`03001oogoo00ioo`8000]oo`03001oogoo0080011oo`@001Eoo`8000]o
o`H000Moo`00;goo018007ooNomoog_oOomkogooNomoog_oOomkogooNomoog_oOol3000AOol20002
Ool00`00Oomoo`08Ool2000=Ool00`00Oomoo`05Ool4000@Ool00`00Oomoo`0;Ool00`00Oomoo`0;
Ool00`00Oomoo`05Ool40002Ool00`00Oomoo`0=Ool2000>Ool2000?Ool30002Ool00`00Oomoo`0C
Ool01000Oomoogoo2P001Woo00<007ooOol017oo000`Ool01@00OomoogooNol00goo00EkogooOomo
og_o00=oo`04NomoogooOol5000>Ool2000=Ool2000<Ool00`00Oomoo`040006Ool00`00Oomoo`0;
Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool3000>Ool00`00Oomoo`0<Ool3000=
Ool30004Ool00`00Oomoo`0AOol7000@Ool00`00Oomoo`04Ool0039oo`0D001kogooNomoog_oOomk
ogooNomoog_oOomkogooNomoog_oOomko`800004Kol00000000=Ool2000=Ool00`00Oomoo`0:Ool2
000;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomo
o`02000:Ool2000=Ool20002Ool00`00Oomoo`09Ool20006Ool00`00Oomoo`0<Ool7000GOol00`00
Oomoo`03Ool003=oo`D0009oo`05NomoogooOomko`03Ool01W_oOomoogooNomoo`800003Jom_o`00
00<000Uoo`03001kog_o008000]oo`8000Qoo`800003Ool007oo00]oo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00=oo`<000Ioo`03001oogoo00]o
o`8000Eoo`03001oogoo00Eoo`<000Moo`03001oogoo00Qoo`D0009oo`<001Yoo`03001oogoo009o
o`00=7oo00<007oo00002000015kogooNomoog_oOomkogooNomoog_o001[ofooJom_of_o00<000Mo
o`04001gog_oMol2000;Ool00`00Oomoo`03Ool20004Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool20002Ool2000<Ool2
0007Ool00`00Oomoo`02Ool30009Ool00`00Oomoo`04Ool50005Ool2000IOol30006Ool003Eoo`04
001oogooOol30003Jol60003Ool00g_oOomoo`020003Kol00f_oKom_o`030004Ool00`00Nomko`03
Nol2000:Ool200000goo00000007Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool2000=Ool00`00Oomoo`07Ool00`00Ool0
0002000;Ool00`00Ool000050007Ool3000EOol5000:Ool003Moo`03001oogoo009oo`<000I[o`L0
000:Ool00000Jom_of_oKom[ofooJol4000027oo001kogOoNomgog_oMol2000:Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Ool0000:Ool20009Ool3000<Ool4000;Ool2000AOol6000@Ool003Qo
o`8000Eoo`@000U[o`@0009_o`05Jom_ofooKom[o`03Kol20008Nol20007Ool00`00Ool0000:Ool0
0`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool20003Ool00`00Oomoo`05Ool20009Ool3000:Ool4000=Ool2000=Ool6000FOol0
03Yoo`8000Moo`<000][o`@00007Jom_of_oKom[ofooJol00P0000QkogOoNomgog_oMomkogOo0P00
1Goo00<007ooOol00P002Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol017oo00<007ooOol00Woo0P002Goo
0P0000=oo`00Ool01goo1@0037oo0`002Goo1P0077oo000lOol00`00Oomoo`07Ool3000:Jol50000
1V_oKom_ofooJom_o`<000Mko`80009oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00=ooa8000Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Ioo`04001o
o`000009Ool20002Ool00`00Oomoo`03Ool7000<Ool20005Ool7000ROol003eoo`8000Yoo`<000Y[
o`D00006Jom_of_oKol005Oo0P0000Mgog_oMomkogOoNomgo`020007Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool60005Ool00`00Oomoo`07Ool00`00Oomoo`050003Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool2000:Ool00`00Oomoo`07Ool20003Ool01000Oomoogoo0`000Woo0P002Woo3@00:7oo000o
OolB0008Jol6000016oo000005Oo0`001G_o0P001goo0P0027oo00<007ooOol00goo0P002goo00<0
07ooOol01goo00<007ooOol01Goo1@0027oo00<007ooOol01goo00<007ooOol027oo0`001goo0P00
17oo00<007oo00000P000goo0P001Goo3@00;goo0011Ool200003G?oMomcogOoLomgog?oMomcogOo
Lomgog?o00P000=[o`<00003Dol00000008000=Go`800006Nomgog_oMol006_o0P001Woo00<007oo
Ool01Woo00<007ooOol00P0017oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00@0
07ooOomoo`@000=oo`03001oogoo00Moo`03001oogoo00Moo`80009oo`03001oogoo00=oo`8000Ao
o`<000Eoo`800003Ool0000000/003Eoo`00@goo0P000W?o00Egog?oLomcogOo00=co`06Momcog?o
Lomgog?o2`000U?o0P0015Oo0P000W_o00D006ooJom_o`0000Ioo`03001oogoo00Ioo`8000Moo`03
001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Eoo`@000Qoo`03001oogoo
00Moo`03001oogoo009oo`04001oogooOol20004Ool20004Ool=000lOol004Eoo`0E001gog?oMomc
ogOoLomgog?oMomcogOoLomgog?oMomcogOoLomgog?o00X00003Dol005Oo00=Go`800005Nol006oo
Jom_o`020005Ool20004Ool20009Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`020004Ool20008Ool20005Ool01000Ool000000goo0`0000=oo`00
00002@00@goo0018Ool20003Lol01GOoLomcog?oMol00g?o00Egog?oLomcogOo00=co`03Momco`00
00X0009Go`800005Jom_of_oKom[o`020005Ool01000Ool0000017oo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol00goo0P0000=o
o`00Ool01goo0P001goo0P000goo0P0000=oo`0000001P00BGoo001AOol7000037OoLomgog?oMomc
ogOoLomgog?oMomco`T00009Eol006_oKom[ofooJom_o`0000Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo
00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`8000=oo`P004ioo`00G7oo1P0000=cogOoLol00W?o
00=go`000000200000A[ofooJom_o`8000=oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`04001oo`00
0004Ool20006Ool300000goo00000002001EOol0069ooa800004Kom[ofooJol300000g_oOol00006
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Ool000001Woo0P0000Aoo`00000005Uoo`00LGoo
100000]_of_oKom[ofoo001oog_oOomko`0000Eoo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001VU7oo008005]oo`00M7oo0`0000=[ofooJol00P0000Eoog_oOomko`0000Eoo`03
001oogoo00=oo`04001oogooOol60003Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool20005Ool200000goo0000001MOol007Ioo`<00003Kom[o`0000800004Nomo
og_o0004Ool00`00Oomoo`03Ool40002Ool01000Oomoogoo1`000goo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol017oo00@007ooOol0009oo`800003IY@0000005moo`00N7oo100000MOoe_o
001kogooNol00004Ool00`00Oomoo`0200000goo001oo`03Ool00`00Oomoo`04Ool01000Oomoogoo
10001Woo00<007ooOol017oo00<007ooOol017oo00@007ooOomoo`<00003Ool00000065oo`00NWoo
0P000e_o00@007_oOomko`8000=oo`8000Qoo`03001oogoo00=oo`03001oogoo00Aoo`03001oo`00
0080009oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo001SOol007]o
o`80000;FomOoe_o001kogooNomoo`00Ool00006Ool01@00Oomoogoo00001Goo00<007ooOol00goo
00<007ooOol00goo0`001Goo00<007ooOol00goo0P0017oo00@007oo000006Aoo`00OGoo0P000U_o
00H007_oOomkogoo0002Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`020002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool4001VOol007moo`800006
Fol00000Oomko`000goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oo`0006Qoo`00P7oo00ACG`00
FomKo`80009[o`=oo`05001oogooOol00003Ool01@00Oomoogoo00001Goo00<007ooOol00goo00<0
07ooOol00goo00<007oo00000goo00<007ooOol00Woo00<007oo0000JGoo0022Ool200001Eoo001[
ofOoJol00goo00D007ooOomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool01`00Oomoogoo001oo`0000Aoo`<006Yoo`00Pgoo0P0000=Kof_oJol00V_o0Woo00D007oo
Oomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Ool0001[Ool008Aoo`@00003JomWo`00009oo`07001oogooOol007oo
00000Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo0P000Woo
1000K7oo0026Ool30002Jol01000Oomoo`000Woo20000Woo00D007ooOomoo`0000Eoo`03001oogoo
00=oo`03001oogoo00800003Ool007oo06eoo`00Qgoo00X005?O000006Oo001oo`00Ool0009oo`04
001oogoo0002Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0006mo
o`00R7oo0P0000MCg`00Jol007oo001ko`02Ool01000Oomoo`000goo0`0000=oo`00Ool00goo00<0
07ooOol00Woo0P000goo0`00L7oo002:Ool03000Ckl006Oo001KWgooNomoo`00Ool000=oo`05001o
ogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool3001aOol008]oo`06001Cg`00001O_g_o
0Woo00<007oo00000goo00D007ooOol007oo00800003Ool007oo00=oo`03001oogoo009oo`03001o
o`00079oo`00S7oo00YBo`00000005noNomoo`00Ool0009oo`04001oogoo0004Ool00`00Oomoo`02
Ool01000Oomoogoo0P0000=oo`00Ool0LWoo002=Ool300001U=oGkmoo`00Ool0009oo`04001oogoo
0003Ool01P00Ool00000Ool000=oo`800003Ool007oo07=oo`00SWoo0P0000=CWdmo00000P000Woo
00@007ooOol000=oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`1cOol0091oo`03
001CWe^o0080009oo`03001oo`0000=oo`03001oogoo009oo`80009oo`04001oo`00001fOol0095o
o`08CemCW`00001oo`00Ool000=oo`03001oogoo009oo`03001oogoo00800003Ool007oo07Moo`00
TWoo1@0000=oo`00Ool00Woo00D007ooOomoo`0000=oo`03001oo`0007Uoo`00Tgoo0`0000=oo`00
Ool00Woo00D007ooOomoo`0000=oo`<007Yoo`00Tgoo00@007oo000000=oo`03001oogoo009oo`08
001oogoo001oo`00Ool007Uoo`00Tgoo00<007oo00000P0000=oo`00Ool00goo00D007ooOol007oo
00<007Yoo`00Tgoo00@007oo001on08000Aoo`08001oogoo001oo`00Ool007]oo`00Tgoo00D007oo
001onGoh0080009oo`04001oogoo0002Ool2001lOol009=oo`05001oogoo001on0040002Ool01P00
Oomoo`00Ool007aoo`00Tgoo00H007ooOol007ohOoT3000017oo001oogoo0`00OGoo002@Ool:0000
0gnd00000002Ool00`00Ool0001nOol008moo`05Ocl007ooOol00002Ool00`00Oomoo`040002Ool0
0`00Ool0001nOol008ioo`03Ocl007oo009oo`05001oogooOol00003Ool400000goo001oo`1nOol0
08ioo`03Ocl007oo009oo`05001oogooOol00003Ool00`00Oo/000020020Ool008eoo`03Ocl007oo
00=oo`03001oogoo009oo`06001oogooOol007ok0`00Ogoo002<Ool2Ocl01@00Oomoogoo00001Goo
00<007ooOol00Woo00<007ok00000P00OWoo002;Ool2Ocl00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00OoYon`03001mOol008Yoo`=o?`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo009oo`03001onWok00<007aoo`00RWoo0Wlo00<007ooOol03P0000Qoo`00Oo]onWok001o
E000Ngoo0029Ool00glo00000003000017oOOomog`001Woo00@007ooOomoo`@00005OoYon`00Oe@0
001jOol008Qoo`800003Oal007oo00Eoo`03001oogoo00Eoo`03001oogoo00=oo`D00003Oe@007oo
07Qoo`00Qgoo00`007lOOamo7`00OomoggooOmmoogoO0007Ool00`00Oomoo`04Ool00`00Ooaon`05
001gOol008Ioo`05001o7glOOal00006Ool00`00Oomoo`06Ool00`00Oomoo`04Ool01@00Ooaoo7ok
Oo`01000MWoo0025Ool03@00Oamo7glO001oogoOOomoggooOmmoo`0000Qoo`03001oogoo00Eoo`05
001ongolOo]oo004001eOol008=oo`03DY@007lO009o7`03001oogoo00Ioo`03001oogoo00Moo`03
001oogoo00Eoo`04001oo7olOo/2Oo`01000Oc@00000Lgoo0022Ool00e:D001o7`03Oal01000Ommo
ogoO4P001Woo00X007okOoaongolOo/007lcOc@0079oo`00PGoo00=BU000Oal00WlO1P0000IoOWmo
OgmoOgmn0009Oml00`00OoiooP0500000goo001oo002Oo`00gokOoaoo00200000gld001oo`1`Ool0
081oo`03DYAo7`0000@0000:OgioOgmnOgmoOWmoOgioOgmn000;Oml00`00Ooioo`03Ooh00goo0000
000500001GolOo]oo000Oc@00P00Kgoo001oOol00e:D00000003OYT00`00OgioO`02Ogl01gmnOgmo
OgmoOgioO`0000]og`03001ooWon00MooP04001oV7nHOiP600000gld001oo`1]Ool007eoo`0CCY<0
0000OYYnVGjJOYT007mnOgmoOWmoOgioOgmnOgmoOWmo000037oO00D007onOoiooWoo00=ooP0;Oomo
oWon001oV7nGOiQoUgnHOiMoV004001]Ool007aoo`8000EnV@03001oOWmo009oO`05OgioOgmoOgmo
OP02Ogl00`00Ommog`0:Oml00`00OoiooP09Ooh20007OiP4001[Ool007]oo`80000BOYUnVWjIOYYn
V@00OgioOgmnOgmoOWmoOgioOgmnOgmoOP003WoO00<007ooOoh00Won00EoogonOoiooWoo00=ooP0:
001oUgnHOiMoV7nGOiQoU`00OY<2001ZOol007Uoo`03DY@0000000EnV@03001oOWmo009oO`03Ogh0
000001`000IooP03001oV7nH00EoV0800003O[@0000006Qoo`00Mgoo00P005:D001nVWjIOYYnVGjJ
200001in]gjhO[Mn^7jgO[P007ljOaUo>WlIOcYo6GljOaUo>WlIOcYo6GljOaUo>WlI001o=glhOcMo
>7lgOcP:00002GnGOiQoUgnHOiMoV000O[AnT`02001VOol007Eoo`04001BU5:D0002OYT5000047jg
O[Qn]gjhO[Mn^7jgO[Qn]gjhO[Mn^7jg001o>Glj0gli00Eo>WliOcUo>Glj00=o>@0BOcYo>Gli001o
>7lgOcQo=glhOcMo>7lgOcQo=glhOcMo>7lg1P000gnH00D007jdO[An]00006Eoo`00M7oo00=BU4jC
0000100003Q^T`00001n^7jgO[Qn]gjhO[Mn^7jgO[Qn]gjhO[Mn^7jg001o6GljOaUo>WlIOcYo6Glj
OaUo>WlIOcYo6GljOaUo>WlIOcX007lhOcMo>7lgOcQo=glhOcMo>7lgOcQo=glhOcMo>000O]An/gkD
1P0000AnTgjd000006=oo`00LWoo00<005:D00000P0017:D01<007jgO[Qn]gjhO[Mn^7jgO[Qn]gjh
O[Mn^7jgO[Qn]`00OcUo>P03OcT01GljOcUo>GliOcX00gli01Mo>WliOcUo>GljOcT007lgOcQo=glh
OcMo>7lgOcQo=glhOcMo>7lgOcQo=glh008000Ene0@0009n]003001oogoo061oo`00L7oo100000Eb
U6jCLYA^Tg:D0080000JO[Mn^7jgO[Qn]gjhO[Mn^7jgO[Qn]gjhO[Mn^7jgO[P007ljOaUo>WlIOcYo
6GljOaUo>Q40000EOcQo=glhOcMo>7lgOcQo=glhOcMo>7lg001n/gkDO[=ne7jcO]An/gkD00D0061o
o`00KWoo10001G:D0P0000Mn^7jgO[Qn]gjhO[Mn^00E000<OY@00`00OYAnU002OY@:00000glgOcQo
=`020008O]@5001NOol006aoo`@00004LYA^Tg:DKY<<0000<7ZDMY=jU7JCNYAfTgZDMY=jU000OYAn
TgjDOY=nU7jCOYAnTgjDOY=nU7jCOYAnTgjDOY=nU7jCOYAnTgjDOY=nU7jC001nTgjDOY=nU7jCOYAn
TgjDOY=nU7jCOYAnT`T00006O[=ne7jcO]An/gkD1P00Fgoo001ZOol40002LY@500004WZDMYAjU7JD
NYAfU7ZDMYAjU7JDNYAfU7ZDMYAjU7JDNYAfU08001UnU003001nU7jD019nU0P000=ne0800003OY@0
000005Uoo`00J7oo00<004jC0000200004IfTgZDMY=jU7JCNYAfTgZDMY=jU7JCNYAfTgZDMY=jU7JC
NYAfT`00OY=nU7jCOYAnTgjDOY=nU7jCOYAnTgjDOY=nU7jCOYAnTgjDOY=nU7jCOYAnTgjDOY=nU7jC
OY@007jDOY=nU7jCOYAnTgjDOY=nU7jCOYAnTgjDOY=nU7jCOYAnTgjDOY=nU0<00003OYAnTgjD00L0
0004OY@00000001FOol006Ioo`03001BU00000L0000>MYAjU7JDNYAfU7ZDMYAjU7JDNYAfU7ZDMYAj
U2h0011nU08000MnU0@00003OY@0000005Aoo`00Hgoo1@0000=JU000FY@00P0000=fTgZDMY<03P00
00=NU5ZCFY@00`00029ZU6ZCJYAZTfZDJY=ZU6ZCJYAZTfZDJY=ZU6ZCJYAZTfZDJY=ZU6ZCJYAZTfZD
JY=ZU6ZCJYAZTfZDJY=ZU6ZCJYAZT`800004KYAZTfjDJY<>000017jDOY=nU7jC0P0000UnU7jCOYAn
TgjDOY=nU7jCOY@01@00DWoo001POol500000eZD000000080009FY@b00000fjD00000008000016ZD
KYA^U6jD3@001WjD1000Cgoo001LOol:00001UZDFY=NU5ZCFYAJT`h000Uoo`03001oogoo00Qoo`03
001oogoo00=ooa<000eooa`00003OY@00000008004]oo`00F7oo5`0027oo00<007ooOol027oo00<0
07ooOol02Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol05`00Agoo001DOol;0002Ool20008Ool30008Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`04Ool02@00Ool007OoLomgog?oMomco`0300000doo0000000@000j
Ool0051oo`/000Aoo`8000Qoo`8000=oo`8000Aoo`8000]oo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`8000=oo`03001o
ogoo009oo`800006Momcog?oLomgog?o0P000U?o2P0000EOoe_oFomKoeoo00d002eoo`00BWoo2000
00Ako`00000000=oo`04001oogooOol20008Ool20007Ool200000goo001oo`0;Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Ool00007Ool200001W?oMomcogOoLomgo`@00003GomSoeoo00X0000=GomKoeooFomOoe_o
GomKoeooFomOoe_oGol02P008goo0013Ool@0006Ool01000Ool0000027oo0P002goo0P002goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol01goo0P002Woo0P000W?o00Egog?oLomcogOo00<000ESo`D00003Eol0000000@000=Ko`05
GomKoe_oFomOo`03Fol01UooFomKoe_oGomKo`L001aoo`00?7oo2P0017oo1@002Goo0`0027oo0P00
2goo0P000Woo10001Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol00goo0`000Woo00<007ooOol02Goo0P0000McogOoLomgog?o
Momco`0200001f?oGomSoeooHomOof?o00D00004FomGoe_oEol600004UooFomOoe_oGomKoeooFomO
oe_oGomKoeooFomOoe_oGomKo`8001Yoo`00=Woo2P001goo1@002Woo0`0027oo0P0037oo00<007oo
Ool01Woo0`000Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol00P001goo0P002Woo0P0000Qgog?oLomcogOoLol007oo0`001f?o
10001eOo3@000U_o00EOoe_oFomKoeoo008001Qoo`00;goo2`002goo10002Woo0`000Woo00<007oo
Ool017oo0P0037oo0P0037oo1@002Goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol01goo10002goo00<007ooOol02Goo0P0000UcogOoLomgo`00OomkogooNol00`0000QO
of?oGomSoeooHomOof?o100000QGoe_oEomKoeOoFomGo`0026_o2P005goo000XOol;00000goo0000
000;Ool4000;Ool30006Ool01000Oomoogoo0P003Goo00<007ooOol037oo00<007ooOol00Woo1P00
0goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Goo00@007ooOomoo`H000=oo`03001o
ogoo00Yoo`8000]oo`80009co`03001kogoo009oo`03Nomoogoo00<000MSo`L000EGo`8000i[o`03
001oogoo01Aoo`008Woo1`0027oo0`002Goo100000=oo`00Ool02Goo0`002Goo00@007oo000000eo
o`8000ioo`03001oogoo00Uoo`X000Ioo`03001oogoo00]oo`03001oogoo00Aoo`T000Yoo`03001o
ogoo00]oo`8000]oo`<0000:OomkogooNomoog_oOomkogooNol400002V?oGomSoeooHol007?oKomc
ofoo1@0000AGoe_oEomKo`8000][o`03001oogoo01=oo`0077oo1P003Goo0P001goo1@0017oo00<0
07ooOol01Goo100037oo0P003Woo00<007ooOol037oo0P003Goo00<007ooOol01Woo6`001goo00<0
07ooOol02Woo0P003Goo0P002goo00@007ooOomko`=oo`05NomoogooOomko`03Ool30003Hol02@00
Lom_og?oKomcofooLom_o`06000015Oo0000000026_o00<007ooOol04Woo000GOol5000@Ool30004
Ool50009Ool00`00Oomoo`02Ool3000>Ool20002Ool2000;Ool00`00Oomoo`0<Ool00`00Oomoo`0=
Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0<
Ool00`00Oomoo`06Ool20002Ool300003GooNomoog_oOomkogooNomoog_oOomkogoo00<0000?Hol0
0000KomcofooLom_og?oKomcofooLom_og?o00P000E[o`03001oogoo015oo`004Goo1P004goo0P00
0goo10003Goo00<007ooOol00`003Woo0`001Woo0P001goo0P003Woo00<007ooOol03Goo00<007oo
Ool03Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol037oo00<007ooOol037oo0P001Goo
00<007ooOol01Goo0P000Woo00EkogooOomoog_o00=oo`04NomoogooOol4000046ooLom_og?oKomc
ofooLom_og?oKomcofooLom_og?o1P000f_o00<007ooOol047oo000<Ool5000FOol30002Ool3000@
Ool01000Ool000003goo0P002goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol03Goo00<0
07ooOol03Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol03Goo0P00
00=oo`0000002Woo0`0000ikogooNomoog_oOomkogooNomoog_oOomkogoo1000019_og?oKomcofoo
Lom_og?oKomcofooLom_og?oKomcofooLol6000AOol000Ioo`H001Uoo`800003Ool0000001=oo`<0
00moo`<000ioo`800003Ool0000000moo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00eo
o`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`8000moo`<0009oo`05NomoogooOomk
o`03Ool00g_oOol00002Ool400004G?oKomcofooLom_og?oKomcofooLom_og?oKomcofooLol00P00
00=ko`00Ool03goo0002Ool4000MOol3000COol40002Ool00`00Oomoo`0;Ool2000COol3000=Ool2
000@Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool2000:Ool3
0002Ool2000@Ool200002gooNomoog_oOomkogooNomoog_o00001Woo100000m_og?oKomcofooLom_
og?oKomcofooLom_og?oKol00P0047oo000017oo000000005goo10000goo00<007ooOol047oo1000
1Woo00<007ooOol027oo0`004goo0P000goo100027oo00<007ooOol03goo00<007ooOol03goo00<0
07ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol017oo0`001goo0P0047oo0`00
0goo00EkogooOomoo`0000Yoo`D0000=KomcofooLom_og?oKomcofooLom_og?o00003goo0004Ool5
0006Ool8000:Ool00`00Oomoo`0=Ool4000;Ool00`00Oomoo`05Ool2000DOol20009Ool40003Ool0
0`00Oomoo`0@Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool0
0`00Oomoo`03000<Ool2000AOol3000017ooNomoo`0047oo100000YcofooLom_og?oKomcofooLol0
00ioo`002Goo1P004Goo00<007ooOol02Woo10003goo00<007ooOol00Woo0`0057oo0P003goo1@00
47oo00<007ooOol03goo00<007ooOol03goo00<007ooOol03Woo00<007ooOol03Goo10004Goo0P00
4Woo0P0000=ko`00Ool04goo100000I_og?oKomcofoo000>Ool000aoo`@0011oo`03001oogoo00Mo
o`<001Aoo`04001oo`00000EOol2000AOol20003Ool60009Ool00`00Oomoo`0@Ool00`00Oomoo`0?
Ool00`00Oomoo`0?Ool00`00Oomoo`06Ool60003Ool2000BOol2000BOol2000HOol400000g?oKol0
000=Ool0011oo`8000eoo`03001oogoo00Aoo`@001Moo`8001Eoo`80019oo`03001oogoo00Uoo`H0
00=oo`03001oogoo011oo`03001oogoo011oo`03001oogoo00ioo`04001oogooOol5000;Ool00`00
Oomoo`0AOol2000?Ool20002Ool00`00Oomoo`0HOol3000=Ool001ioo`04001oogooOol4000IOol0
1000Oomoogoo0P004Goo0P004goo00<007ooOol047oo30002Goo00<007ooOol04Goo00<007ooOol0
1Woo30004Goo00<007ooOol04Woo0P0037oo00<007ooOol01Goo0`0067oo00<007ooOol02Woo000F
Ool00`00Oomoo`04Ool00`00Ool00002000JOol00`00Oomoo`06Ool2000=Ool2000COol2000DOol0
0`00Oomoo`08OolV000:Ool00`00Oomoo`0AOol2000DOol20008Ool2000<Ool3000DOol00`00Oomo
o`0:Ool001Qoo`H001Yoo`8000eoo`8000Uoo`8001Aoo`03001oogoo01Aoo`03001oogoo015oo`03
001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo01=oo`8000Eoo`03001oogoo
00moo`<0019oo`03001oogoo00Uoo`006Woo0P0000=oo`00Ool05Woo0P004Woo0P001Goo0P005Goo
00<007ooOol057oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo
0P005Goo0P0000=oo`0000005Goo10003Woo00<007ooOol02Goo000LOol2000DOol00`00Oomoo`0F
Ool200000goo0000000EOol2000FOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`0COol00`00Oomoo`0COol2000KOol3000<Ool00`00Oomoo`08Ool001ioo`8000moo`03
001oogoo01Yoo`@001Aoo`03001oogoo01Eoo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo
01=oo`03001oogoo01=oo`80011oo`<000=oo`8001]oo`<000Uoo`03001oogoo00Qoo`0087oo0P00
2Woo00<007ooOol06goo0P0017oo10003goo00<007ooOol05Woo00<007ooOol04goo00<007ooOol0
57oo00<007ooOol04goo00<007ooOol057oo00<007ooOol02Goo100027oo0`006goo10001Goo00<0
07ooOol027oo000ROol20004Ool2000NOol2000:Ool50008Ool2000HOol00`00Oomoo`0DOol00`00
Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0EOol00`00Oomoo`05Ool3000?Ool3000LOol30000
17oo001oo`002Goo000TOol3000OOol2000AOol40003Ool00`00Oomoo`0GOol00`00Oomoo`0EOol0
0`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0EOol20002Ool3000EOol2000MOol200000goo
001oo`08Ool004=oo`<001Moo`L001Eoo`03001oogoo01Ioo`03001oogoo01Aoo`03001oogoo01Eo
o`03001oogoo01=oo`D001Yoo`<001Uoo`80009oo`03001oogoo00Moo`009goo00<007ooOol05goo
0P006Woo0P001Goo20003Goo00<007ooOol05Woo00<007ooOol05Goo00<007ooOol05Goo00<007oo
Ool02Woo200017oo0P0077oo0`0057oo0P001Goo00<007ooOol01Woo000XOol00`00Oomoo`0DOol2
000KOol00`00Oomoo`0=Ool80004Ool00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol0
0`00Oomoo`02Ool7000>Ool2000MOol2000@Ool20007Ool00`00Oomoo`06Ool002Yoo`03001oogoo
011oo`8001]oo`8001Qoo`X001=oo`03001oogoo01Ioo`03001oogoo015oo`X001Moo`8001eoo`<0
00]oo`8000Yoo`03001oogoo00Eoo`00:goo00<007ooOol037oo0`0077oo00<007ooOol06Woo00<0
07ooOol01Goo3@001Woo00<007ooOol05goo00<007ooOol017oo30001goo00<007ooOol06Goo0P00
7Woo0`001Woo0P0037oo00<007ooOol01Goo000/Ool00`00Oomoo`09Ool2000MOol2000LOol00`00
Oomoo`0COolW000DOol00`00Oomoo`0JOol2000OOol20002Ool2000>Ool00`00Oomoo`05Ool002eo
o`8000Moo`8001eoo`8001eoo`03001oogoo01Yoo`03001oogoo01Moo`03001oogoo01Uoo`03001o
ogoo01]oo`03001oogoo01ioo`80015oo`03001oogoo00Aoo`00;goo00<007ooOol00Woo0P007Woo
00<007ooOol077oo00<007ooOol06Woo00<007ooOol06Goo00<007ooOol06Goo00<007ooOol06goo
0P006Woo10000goo0`003Goo00<007ooOol017oo000`Ool5000MOol2000NOol00`00Oomoo`0KOol0
0`00Oomoo`0IOol00`00Oomoo`0JOol00`00Oomoo`0LOol2000DOol4000:Ool3000:Ool00`00Oomo
o`04Ool0035oo`04001oogooOol5000GOol00`00Oomoo`0MOol00`00Oomoo`0LOol00`00Oomoo`0J
Ool00`00Oomoo`0JOol2000NOol2000>Ool4000AOol30008Ool00`00Oomoo`03Ool0039oo`03001o
ogoo00Eoo`D0011oo`80021oo`03001oogoo01]oo`03001oogoo01]oo`03001oogoo01aoo`03001o
ogoo01eoo`8000Qoo`@001Qoo`8000Ioo`03001oogoo00=oo`00<goo00<007ooOol02Goo1@002Woo
00<007ooOol07goo00<007ooOol077oo00<007ooOol06goo00<007ooOol07Goo00<007ooOol07Woo
0P000Woo10007Woo0`000goo00<007ooOol00goo000dOol00`00Oomoo`0=Ool50003Ool2000QOol0
0`00Oomoo`0MOol00`00Oomoo`0LOol00`00Oomoo`0MOol00`00Oomoo`0LOol5000UOol300000goo
001oo`03Ool003Eoo`03001oogoo015oo`H001moo`03001oogoo01ioo`03001oogoo01aoo`03001o
ogoo01ioo`03001oogoo01Aoo`L000Eoo`03001oogoo02Eoo`8000Aoo`00=Woo00<007ooOol047oo
0P0017oo20005Woo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol07Woo00<007ooOol037oo
1`003Woo0P009Woo00<007ooOol00Goo000gOol00`00Oomoo`0=Ool2000>Ool8000=Ool00`00Oomo
o`0OOol00`00Oomoo`0LOolC000AOol00`00Oomoo`04Ool7000GOol2000TOol00`00Oomoo`01Ool0
03Moo`03001oogoo00]oo`8001Qoo`P000Aoo`03001oogoo021oo`03001oogoo019oo`X001=ooa`0
01aoo`8002=oo`40005oo`5oo`00>7oo00<007ooOol027oo0P008Woo30006Woo00<007ooOol01Goo
3P00>Goo3P0047oo0P008Goo0@000Goo0Goo000iOol00`00Oomoo`05Ool2000VOol00`00Oomoo`07
Ool@0008Ool:001EOol>0004Ool2000OOol10001Ool1Ool003Yoo`03001oogoo009oo`8002Moo`03
001oogoo01Qoo`P006eoo`/001]oo`40005oo`00>goo00@007oo000002Qoo`03001oogoo01Eoo`P0
07aoo`X0015oo`40005oo`00?7oo00<007ooOol09goo00<007ooOol03Woo2000SWoo2P001Woo0P00
0Goo000mOol00`00Oomoo`0UOol00`00Oomoo`07Ool8002POol60003Ool003ioo`03001oogoo02=o
o`03001oogoo00P00;5oo`00?goo00<007ooOol07Woo1`00^Goo0010Ool00`00Oomoo`0GOol60030
Ool0041oo`03001oogoo01=oo`@00<Ioo`00@Goo00<007ooOol03Woo0P00c7oo0012Ool00`00Oomo
o`07Ool3003AOol004=oo`L00=Ioo`00\
\>"],
    ImageRangeCache->{{{0, 287}, {213.688, 0}} -> {0, 0, 0, 0}}],
  "\n\t\t\tThe Riemann surfaces for the mapping  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \((z\^2\  - \ 1)\)\^\(1/2\)\)\)],
    AspectRatioFixed->True],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Section 9.3",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["  ",
    FontSize->16,
    FontWeight->"Bold"],
  StyleBox["Exercises for Mapping Involving Elementary Functions\n",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0.500008, 0.996109]],
  StyleBox["See textbook page 379.",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Section 9",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".4",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Mappings by Trigonometric Functions",
    ButtonData:>{"ca0904.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["GO TO  THE",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox["  ",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox[ButtonBox["Table of Contents",
    ButtonData:>{"content.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "\n"
}], "Text"]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{755, 597},
WindowMargins->{{32, Automatic}, {Automatic, 7}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->16,
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 9"->{
    Cell[4362, 144, 318, 12, 35, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 9"]},
  "Section 9.3"->{
    Cell[6378, 215, 10711, 142, 41, "Text",
      Evaluatable->False,
      CellTags->"Section 9.3"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 9", 234182, 8671},
  {"Section 9.3", 234299, 8675}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 615, 20, 109, "Text",
  Evaluatable->False],
Cell[2345, 74, 1980, 65, 248, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4362, 144, 318, 12, 35, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 9"],
Cell[4683, 158, 480, 8, 110, "Input",
  InitializationCell->True]
}, Closed]],
Cell[5178, 169, 593, 20, 32, "Text"],
Cell[5774, 191, 579, 20, 35, "Text"],

Cell[CellGroupData[{
Cell[6378, 215, 10711, 142, 41, "Text",
  Evaluatable->False,
  CellTags->"Section 9.3"],
Cell[17092, 359, 1310, 39, 113, "Text"],
Cell[18405, 400, 756, 22, 94, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19186, 426, 103, 2, 33, "Text"],
Cell[19292, 430, 219, 7, 37, "Text"],
Cell[19514, 439, 372, 8, 145, "Input"],
Cell[19889, 449, 317, 9, 56, "Text",
  Evaluatable->False],
Cell[20209, 460, 822, 18, 270, "Input"],
Cell[21034, 480, 107, 5, 52, "Text",
  Evaluatable->False],
Cell[21144, 487, 1258, 24, 305, "Input"],
Cell[22405, 513, 458, 15, 56, "Text",
  Evaluatable->False]
}, Closed]],
Cell[22878, 531, 784, 25, 96, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[23687, 560, 103, 2, 33, "Text"],
Cell[23793, 564, 169, 6, 36, "Text"],
Cell[23965, 572, 312, 6, 144, "Input"],
Cell[24280, 580, 268, 8, 55, "Text",
  Evaluatable->False],
Cell[24551, 590, 820, 18, 270, "Input"],
Cell[25374, 610, 107, 5, 52, "Text",
  Evaluatable->False],
Cell[25484, 617, 1371, 29, 336, "Input"],
Cell[26858, 648, 445, 14, 55, "Text",
  Evaluatable->False]
}, Closed]],
Cell[27318, 665, 847, 25, 94, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[28190, 694, 104, 2, 33, "Text"],
Cell[28297, 698, 169, 6, 40, "Text"],
Cell[28469, 706, 311, 6, 150, "Input"],
Cell[28783, 714, 345, 9, 59, "Text",
  Evaluatable->False],
Cell[29131, 725, 806, 18, 270, "Input"],
Cell[29940, 745, 107, 5, 52, "Text",
  Evaluatable->False],
Cell[30050, 752, 1094, 22, 309, "Input"],
Cell[31147, 776, 506, 17, 78, "Text",
  Evaluatable->False]
}, Closed]],
Cell[31668, 796, 1078, 36, 109, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[32771, 836, 104, 2, 33, "Text"],
Cell[32878, 840, 149, 6, 33, "Text"],
Cell[33030, 848, 297, 6, 133, "Input"],
Cell[33330, 856, 300, 10, 52, "Text",
  Evaluatable->False],
Cell[33633, 868, 773, 17, 253, "Input"],
Cell[34409, 887, 437, 13, 71, "Text",
  Evaluatable->False],
Cell[34849, 902, 403, 9, 137, "Input"],
Cell[35255, 913, 107, 5, 52, "Text",
  Evaluatable->False],
Cell[35365, 920, 1306, 24, 304, "Input"],
Cell[36674, 946, 438, 15, 71, "Text"]
}, Closed]],
Cell[37127, 964, 347, 12, 30, "Text"],
Cell[37477, 978, 171254, 6769, 378, "Text"],
Cell[208734, 7749, 491, 16, 60, "Text"]
}, Open  ]],
Cell[209240, 7768, 590, 20, 35, "Text"],
Cell[209833, 7790, 339, 13, 57, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

